@@ -5,12 +5,12 @@
 @author  Michael Behrisch
 @author  Daniel Krajzewicz
 @date    2008-10-09
-@version $Id: simpleManager.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: simpleManager.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Control the CityMobil parking lot with a simple first come first serve approach.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2008-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2008-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -18,9 +18,12 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
-import vehicleControl, statistics
+from __future__ import absolute_import
+import vehicleControl
+import statistics
 from constants import *
 
+
 class SimpleManager(vehicleControl.Manager):
 
     def __init__(self):
@@ -54,8 +57,9 @@ class SimpleManager(vehicleControl.Manager):
             row = -1
         else:
             row = int(edge[5])
-        if row < DOUBLE_ROWS-1:
-            vehicleControl.stopAt(vehicleID, "cyber%sto%s" % (row+1, row+2))
+        if row < DOUBLE_ROWS - 1:
+            vehicleControl.stopAt(
+                vehicleID, "cyber%sto%s" % (row + 1, row + 2))
         else:
             vehicleControl.stopAt(vehicleID, "cyberout")
         self.cyberCarLoad[vehicleID] = load
