@@ -6,12 +6,12 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2009-03-26
-@version $Id: embedded.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: embedded.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Tutorial for traffic light control via the TraCI interface.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2009-2014 DLR/TS, Germany
+Copyright (C) 2009-2017 DLR/TS, Germany
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -19,9 +19,13 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
 
-import os, sys, subprocess
-# the embedded python does not add the current dir to the python path, so we need to do it
+import os
+import sys
+import subprocess
+# the embedded python does not add the current dir to the python path, so
+# we need to do it
 sys.path.append(os.path.dirname(__file__))
 import runner
 
