@@ -6,12 +6,12 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2009-03-26
-@version $Id: runner.py 18096 2015-03-17 09:50:59Z behrisch $
+@version $Id: runner.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Tutorial for traffic light control via the TraCI interface.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2009-2015 DLR/TS, Germany
+Copyright (C) 2009-2017 DLR/TS, Germany
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -19,6 +19,8 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 
 import os
 import sys
@@ -38,16 +40,6 @@ except ImportError:
         "please declare environment variable 'SUMO_HOME' as the root directory of your sumo installation (it should contain folders 'bin', 'tools' and 'docs')")
 
 import traci
-# the port used for communicating with your sumo instance
-PORT = 8873
-
-NSGREEN = "GrGr"
-NSYELLOW = "yryr"
-WEGREEN = "rGrG"
-WEYELLOW = "ryry"
-
-PROGRAM = [WEYELLOW, WEYELLOW, WEYELLOW, NSGREEN, NSGREEN, NSGREEN,
-           NSGREEN, NSGREEN, NSGREEN, NSGREEN, NSGREEN, NSYELLOW, NSYELLOW, WEGREEN]
 
 
 def generate_routefile():
@@ -58,57 +50,58 @@ def generate_routefile():
     pEW = 1. / 11
     pNS = 1. / 30
     with open("data/cross.rou.xml", "w") as routes:
-        print >> routes, """<routes>
+        print("""<routes>
         <vType id="typeWE" accel="0.8" decel="4.5" sigma="0.5" length="5" minGap="2.5" maxSpeed="16.67" guiShape="passenger"/>
-        <vType id="typeNS" accel="0.8" decel="4.5" sigma="0.5" length="17" minGap="3" maxSpeed="25" guiShape="bus"/>
+        <vType id="typeNS" accel="0.8" decel="4.5" sigma="0.5" length="7" minGap="3" maxSpeed="25" guiShape="bus"/>
 
         <route id="right" edges="51o 1i 2o 52i" />
         <route id="left" edges="52o 2i 1o 51i" />
-        <route id="down" edges="54o 4i 3o 53i" />"""
+        <route id="down" edges="54o 4i 3o 53i" />""", file=routes)
         lastVeh = 0
         vehNr = 0
         for i in range(N):
             if random.uniform(0, 1) < pWE:
-                print >> routes, '    <vehicle id="right_%i" type="typeWE" route="right" depart="%i" />' % (
-                    vehNr, i)
+                print('    <vehicle id="right_%i" type="typeWE" route="right" depart="%i" />' % (
+                    vehNr, i), file=routes)
                 vehNr += 1
                 lastVeh = i
             if random.uniform(0, 1) < pEW:
-                print >> routes, '    <vehicle id="left_%i" type="typeWE" route="left" depart="%i" />' % (
-                    vehNr, i)
+                print('    <vehicle id="left_%i" type="typeWE" route="left" depart="%i" />' % (
+                    vehNr, i), file=routes)
                 vehNr += 1
                 lastVeh = i
             if random.uniform(0, 1) < pNS:
-                print >> routes, '    <vehicle id="down_%i" type="typeNS" route="down" depart="%i" color="1,0,0"/>' % (
-                    vehNr, i)
+                print('    <vehicle id="down_%i" type="typeNS" route="down" depart="%i" color="1,0,0"/>' % (
+                    vehNr, i), file=routes)
                 vehNr += 1
                 lastVeh = i
-        print >> routes, "</routes>"
+        print("</routes>", file=routes)
+
+# The program looks like this
+#    <tlLogic id="0" type="static" programID="0" offset="0">
+# the locations of the tls are      NESW
+#        <phase duration="31" state="GrGr"/>
+#        <phase duration="6"  state="yryr"/>
+#        <phase duration="31" state="rGrG"/>
+#        <phase duration="6"  state="ryry"/>
+#    </tlLogic>
 
 
 def run():
     """execute the TraCI control loop"""
-    traci.init(PORT)
-    programPointer = len(PROGRAM) - 1
     step = 0
+    # we start with phase 2 where EW has green
+    traci.trafficlights.setPhase("0", 2)
     while traci.simulation.getMinExpectedNumber() > 0:
         traci.simulationStep()
-        programPointer = min(programPointer + 1, len(PROGRAM) - 1)
-        numPriorityVehicles = traci.inductionloop.getLastStepVehicleNumber("0")
-        if numPriorityVehicles > 0:
-            if programPointer == len(PROGRAM) - 1:
-                # we are in the WEGREEN phase. start the priority phase
-                # sequence
-                programPointer = 0
-            elif PROGRAM[programPointer] != WEYELLOW:
-                # horizontal traffic is already stopped. restart priority phase
-                # sequence at green
-                programPointer = 3
+        if traci.trafficlights.getPhase("0") == 2:
+            # we are not already switching
+            if traci.inductionloop.getLastStepVehicleNumber("0") > 0:
+                # there is a vehicle from the north, switch
+                traci.trafficlights.setPhase("0", 3)
             else:
-                # we are in the WEYELLOW phase. continue sequence
-                pass
-        traci.trafficlights.setRedYellowGreenState(
-            "0", PROGRAM[programPointer])
+                # otherwise try to keep green for EW
+                traci.trafficlights.setPhase("0", 2)
         step += 1
     traci.close()
     sys.stdout.flush()
@@ -138,7 +131,6 @@ if __name__ == "__main__":
 
     # this is the normal way of using traci. sumo is started as a
     # subprocess and then the python script connects and runs
-    sumoProcess = subprocess.Popen([sumoBinary, "-c", "data/cross.sumocfg", "--tripinfo-output",
-                                    "tripinfo.xml", "--remote-port", str(PORT)], stdout=sys.stdout, stderr=sys.stderr)
+    traci.start([sumoBinary, "-c", "data/cross.sumocfg",
+                             "--tripinfo-output", "tripinfo.xml"])
     run()
-    sumoProcess.wait()
