@@ -5,12 +5,12 @@
 /// @author  Walter Bamberger
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGActivityGen.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: AGActivityGen.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Main class that handles City, Activities and Trips
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -45,10 +45,6 @@
 #include "AGActivityTripWriter.h"
 #include "city/AGTime.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -99,7 +95,7 @@ AGActivityGen::importInfoCity() {
 }
 
 bool
-AGActivityGen::timeTripValidation(AGTrip trip) {
+AGActivityGen::timeTripValidation(const AGTrip& trip) const {
     if (trip.getDay() > durationInDays + 1) {
         return false;
     }
@@ -123,7 +119,7 @@ AGActivityGen::timeTripValidation(AGTrip trip) {
 }
 
 void
-AGActivityGen::varDepTime(AGTrip& trip) {
+AGActivityGen::varDepTime(AGTrip& trip) const {
     if (trip.getType() != "default") {
         return;
     }
@@ -220,7 +216,7 @@ AGActivityGen::makeActivityTrips(int days, int beginSec, int endSec) {
                     expTrips.push_back(tr);
                 }
                 //else
-                //	std::cout << "trop tard 1 pour " << tr.getVehicleName() << " " << tr.getTime() << " day: " << tr.getDay() << std::endl;
+                //std::cout << "trop tard 1 pour " << tr.getVehicleName() << " " << tr.getTime() << " day: " << tr.getDay() << std::endl;
             }
         } else {
             AGTrip tr(it->getDep(), it->getArr(), it->getVehicleName(), it->getTime(), it->getDay());
@@ -239,7 +235,7 @@ AGActivityGen::makeActivityTrips(int days, int beginSec, int endSec) {
                 expTrips.push_back(tr);
             }
             //else
-            //	std::cout << "trop tard 2 pour " << tr.getVehicleName() << " " << tr.getTime() << " day: " << tr.getDay() << std::endl;
+            //std::cout << "trop tard 2 pour " << tr.getVehicleName() << " " << tr.getTime() << " day: " << tr.getDay() << std::endl;
         }
     }
 
