@@ -5,13 +5,13 @@
 /// @author  Walter Bamberger
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGActivity.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: AGActivity.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Parent object for all activities. Derived classes generate trips for each
 // household.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -115,11 +115,11 @@ protected:
     std::list<AGTrip> myPartialActivityTrips;
     int activityPriority;
     bool genDone;
-    SUMOReal timePerKm;
+    double timePerKm;
     /**
      * rate of taking the car instead of the bus because of personal preference
      */
-    SUMOReal carPreference;
+    double carPreference;
 
 };
 
