@@ -6,12 +6,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGTrip.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: AGTrip.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Class containing all information of a given trip (car, bus)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -100,30 +100,30 @@ public:
     void setDay(int day);
     const std::string& getType() const;
     void setType(std::string type);
-    std::list<AGPosition>* getPassed();
+    const std::list<AGPosition>* getPassed() const;
 
     /**
      * returns the time regarding the departure time
      * going through the different points and coming back to the initial position
      * given the time to make one kilometer
      */
-    int getRideBackArrTime(SUMOReal secPerKm) const;
+    int getRideBackArrTime(double secPerKm) const;
     /**
      * returns the estimated arrival time
      * given the time to make one kilometer
      */
-    int getArrTime(SUMOReal secPerKm) const;
+    int getArrTime(double secPerKm) const;
     /**
      * gives the time in seconds for the trip
      * given a speed in seconds per kilometer (in city, not car speed
      * but time needed to make a distance in the city)
      */
-    int getTimeTrip(SUMOReal secPerKm) const;
+    int getTimeTrip(double secPerKm) const;
     /**
      * estimate the departure time needed for a given arrival time
      * and a speed in seconds per kilometer
      */
-    int estimateDepTime(int arrTime, SUMOReal secPerKm) const;
+    int estimateDepTime(int arrTime, double secPerKm) const;
     /**
      * returns whether this is a daily trip or a one day trip
      */
