@@ -5,12 +5,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGAdult.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: AGAdult.cpp 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Person in working age: can be linked to a work position.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -45,7 +45,7 @@
 AGWorkPosition*
 AGAdult::randomFreeWorkPosition(std::vector<AGWorkPosition>* wps) {
     std::vector<AGWorkPosition*> freePos;
-    for (std::vector<AGWorkPosition>::iterator i = wps->begin(); i!= wps->end(); ++i) {
+    for (std::vector<AGWorkPosition>::iterator i = wps->begin(); i != wps->end(); ++i) {
         if (!i->isTaken()) {
             freePos.push_back(&*i);
         }
@@ -68,7 +68,7 @@ AGAdult::print() const {
 
 
 void
-AGAdult::tryToWork(SUMOReal rate, std::vector<AGWorkPosition>* wps) {
+AGAdult::tryToWork(double rate, std::vector<AGWorkPosition>* wps) {
     if (decide(rate)) {
         // Select the new work position before giving up the current one.
         // This avoids that the current one is the same as the new one.
