@@ -6,13 +6,13 @@
 /// @author  Walter Bamberger
 /// @author  Jakob Erdmann
 /// @date    July 2010
-/// @version $Id: AGCity.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: AGCity.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // City class that contains all other objects of the city: in particular
 // streets, households, bus lines, work positions and school
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -41,6 +41,7 @@
 #include <map>
 #include <iomanip>
 #include <utils/common/RandHelper.h>
+#include <utils/options/OptionsCont.h>
 #include <router/RONet.h>
 #include <router/ROEdge.h>
 #include "AGStreet.h"
@@ -60,23 +61,23 @@ AGCity::completeStreets() {
         streetsCompleted = true;
     }
 
-    SUMOReal pop = 0, work = 0;
+    double pop = 0, work = 0;
     std::vector<AGStreet*>::iterator it;
 
     for (it = streets.begin(); it != streets.end(); ++it) {
         pop += (*it)->getPopulation();
         work += (*it)->getWorkplaceNumber();
     }
-    statData.factorInhabitants = (SUMOReal)statData.inhabitants / pop;
+    statData.factorInhabitants = (double)statData.inhabitants / pop;
     //can be improved with other input data
-    SUMOReal neededWorkPositionsInCity = (1.0 - statData.unemployement)
-                                         * ((SUMOReal)statData.getPeopleYoungerThan(statData.limitAgeRetirement)
-                                            - (SUMOReal)statData.getPeopleYoungerThan(statData.limitAgeChildren))
-                                         + (SUMOReal)statData.incomingTraffic;
+    double neededWorkPositionsInCity = (1.0 - statData.unemployement)
+                                       * ((double)statData.getPeopleYoungerThan(statData.limitAgeRetirement)
+                                          - (double)statData.getPeopleYoungerThan(statData.limitAgeChildren))
+                                       + (double)statData.incomingTraffic;
     // we generate 5% more work positions that really needed: to avoid any expensive research of random work positions
-    neededWorkPositionsInCity *= SUMOReal(1.05);
+    neededWorkPositionsInCity *= double(1.05);
     statData.workPositions = (int)neededWorkPositionsInCity;
-    statData.factorWorkPositions = neededWorkPositionsInCity / (SUMOReal) work;
+    statData.factorWorkPositions = neededWorkPositionsInCity / (double) work;
 
     for (it = streets.begin(); it != streets.end(); ++it) {
         (*it)->setPopulation((*it)->getPopulation() * statData.factorInhabitants);
@@ -131,7 +132,7 @@ AGCity::generateWorkPositions() {
 void
 AGCity::generateOutgoingWP() {
     // work positions outside the city
-    SUMOReal nbrWorkers = static_cast<SUMOReal>(statData.getPeopleYoungerThan(statData.limitAgeRetirement) - statData.getPeopleYoungerThan(statData.limitAgeChildren));
+    double nbrWorkers = static_cast<double>(statData.getPeopleYoungerThan(statData.limitAgeRetirement) - statData.getPeopleYoungerThan(statData.limitAgeChildren));
     if (nbrWorkers <= 0) {
         return;
     }
@@ -139,7 +140,7 @@ AGCity::generateOutgoingWP() {
     /**
      * N_out = N_in * (ProportionOut / (1 - ProportionOut)) = N_out = N_in * (Noutworkers / (Nworkers - Noutworkers))
      */
-    int nbrOutWorkPositions = static_cast<int>(workPositions.size() * (static_cast<SUMOReal>(statData.outgoingTraffic)) / (nbrWorkers - static_cast<SUMOReal>(statData.outgoingTraffic)));
+    int nbrOutWorkPositions = static_cast<int>(workPositions.size() * (static_cast<double>(statData.outgoingTraffic)) / (nbrWorkers - static_cast<double>(statData.outgoingTraffic)));
 
     if (cityGates.empty()) {
         return;
@@ -168,13 +169,13 @@ AGCity::completeBusLines() {
 void
 AGCity::generatePopulation() {
     std::vector<AGStreet*>::iterator it;
-    SUMOReal people = 0;
+    double people = 0;
     nbrCars = 0;
-    unsigned int idHouseholds = 0;
+    int idHouseholds = 0;
     std::vector<int> numAdults(statData.households);
     std::vector<int> numChilds(statData.households);
     int totalChildrenLeft = statData.inhabitants - statData.getPeopleOlderThan(statData.limitAgeChildren);
-    const SUMOReal retiredProb = statData.getPeopleOlderThan(statData.limitAgeRetirement) / statData.getPeopleOlderThan(statData.limitAgeChildren);
+    const double retiredProb = statData.getPeopleOlderThan(statData.limitAgeRetirement) / statData.getPeopleOlderThan(statData.limitAgeChildren);
     for (int i = 0; i < statData.households; i++) {
         numAdults[i] = 1;
         numChilds[i] = 0;
@@ -188,7 +189,7 @@ AGCity::generatePopulation() {
     //compensate with adults for too many / missing children
     const int numSecondPers = statData.getPeopleOlderThan(statData.limitAgeChildren) - statData.households + totalChildrenLeft;
     for (int i = 0; i < numSecondPers; i++) {
-        unsigned int index = i % numAdults.size();
+        int index = i % numAdults.size();
         if (numAdults[index] >= 0) {
             numAdults[index] += 1;
         } else {
@@ -197,8 +198,8 @@ AGCity::generatePopulation() {
     }
     for (it = streets.begin(); it != streets.end(); ++it) {
         people += (*it)->getPopulation();
-        while (people > 0 && idHouseholds < (unsigned int)numAdults.size()) {
-            size_t i = RandHelper::rand(numAdults.size() - idHouseholds);
+        while (people > 0 && idHouseholds < (int)numAdults.size()) {
+            int i = RandHelper::rand((int)numAdults.size() - idHouseholds);
             ++idHouseholds;
             households.push_back(AGHousehold(*it, this, idHouseholds));
             households.back().generatePeople(abs(numAdults[i]), numChilds[i], numAdults[i] < 0); //&statData
@@ -290,6 +291,7 @@ AGCity::schoolAllocation() {
 
 void
 AGCity::workAllocation() {
+    const bool debug = OptionsCont::getOptions().getBool("debug");
     statData.AdultNbr = 0;
     //end tests
     /**
@@ -298,6 +300,10 @@ AGCity::workAllocation() {
     std::list<AGHousehold>::iterator it;
     bool shortage;
 
+    if (debug) {
+        std::cout << "\n";
+    }
+
     for (it = households.begin(); it != households.end(); ++it) {
         if (it->retiredHouseholders()) {
             continue;
@@ -307,6 +313,9 @@ AGCity::workAllocation() {
             std::cout << "===> ERROR: Not enough work positions in the city for all working people..." << std::endl;
         }
         statData.AdultNbr += it->getAdultNbr(); //TESTING
+        if (debug) {
+            std::cout << " processed " << statData.AdultNbr << " adults\r";
+        }
     }
 
     /**
@@ -361,7 +370,7 @@ AGCity::carAllocation() {
     }
     // new rate: the rate on the people that have'nt any car yet:
     // nR = (R * Drivers - AlreadyCars) / (Drivers - AlreadyCars)
-    SUMOReal newRate = statData.carRate * statData.getPeopleOlderThan(statData.limitAgeChildren) - statData.hhFarFromPT;
+    double newRate = statData.carRate * statData.getPeopleOlderThan(statData.limitAgeChildren) - statData.hhFarFromPT;
     if (statData.getPeopleOlderThan(statData.limitAgeChildren) == statData.hhFarFromPT) {
         newRate = 0.;
     } else {
@@ -386,7 +395,7 @@ AGCity::carAllocation() {
     //std::cout << "number of people far from public transport: " << statData.hhFarFromPT << std::endl;
     //std::cout << "original rate: " << setprecision(4) << statData.carRate << std::endl;
     //std::cout << "new rate: " << setprecision(4) << newRate << std::endl;
-    //std::cout << "real rate: " << setprecision(4) << (SUMOReal)nbrCars / (SUMOReal)statData.getPeopleOlderThan(statData.limitAgeChildren) << std::endl;
+    //std::cout << "real rate: " << setprecision(4) << (double)nbrCars / (double)statData.getPeopleOlderThan(statData.limitAgeChildren) << std::endl;
     //END TEST RESULTS
 }
 
@@ -420,7 +429,7 @@ AGCity::getRandomStreet() {
     if (streets.empty()) {
         throw (std::runtime_error("No street found in this city"));
     }
-    return *streets[RandHelper::rand(streets.size())];
+    return *RandHelper::getRandomFrom(streets);
 }
 
 /****************************************************************************/
