@@ -5,12 +5,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGPerson.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: AGPerson.cpp 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Parent object of every person, contains age and any natural characteristic
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -60,7 +60,7 @@ AGPerson::getAge() const {
 
 
 bool
-AGPerson::decide(SUMOReal proba) const {
+AGPerson::decide(double proba) const {
     return (RandHelper::rand(1000) < static_cast<int>(1000.0f * proba));
 }
 
