@@ -5,12 +5,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    July 2010
-/// @version $Id: AGStreet.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: AGStreet.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Represents a SUMO edge and contains people and work densities
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2010-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
 /****************************************************************************/
@@ -74,31 +74,31 @@ public:
         }
     };
 
-    AGStreet(const std::string& id, RONode* from, RONode* to, unsigned int index, const int priority);
+    AGStreet(const std::string& id, RONode* from, RONode* to, int index, const int priority);
 
     /** @brief Provides the number of persons living in this street.
      *
      * @return the number of inhabitants
      */
-    SUMOReal getPopulation() const;
+    double getPopulation() const;
 
     /** @brief Modifies the number of persons living in this street.
      *
      * @param[in] pop the new number of inhabitants
      */
-    void setPopulation(const SUMOReal pop);
+    void setPopulation(const double pop);
 
     /** @brief Provides the number of work places in this street.
      *
      * @return the number of work places
      */
-    SUMOReal getWorkplaceNumber() const;
+    double getWorkplaceNumber() const;
 
     /** @brief Modifies the number of work places in this street.
      *
      * @param[in] work the new number of work places
      */
-    void setWorkplaceNumber(const SUMOReal work);
+    void setWorkplaceNumber(const double work);
 
     /** @brief Prints a summary of the properties of this street to standard
      * output.
@@ -113,8 +113,8 @@ public:
     bool allows(const SUMOVehicleClass vclass) const;
 
 private:
-    SUMOReal myPopulation;
-    SUMOReal myNumWorkplaces;
+    double myPopulation;
+    double myNumWorkplaces;
 };
 
 #endif
