@@ -5,12 +5,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFDetFlowLoader.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: RODFDetFlowLoader.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A loader for detector flows
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -41,10 +41,6 @@
 #include <utils/common/UtilExceptions.h>
 #include "RODFDetFlowLoader.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -79,7 +75,7 @@ RODFDetFlowLoader::read(const std::string& file) {
             if (!myDetectorContainer.knows(detName)) {
                 continue;
             }
-            const SUMOReal parsedTime = TplConvert::_2SUMOReal((myLineHandler.get("time").c_str())) * myTimeScale - myTimeOffset;
+            const double parsedTime = TplConvert::_2double((myLineHandler.get("time").c_str())) * myTimeScale - myTimeOffset;
             // parsing as float to handle values which would cause int overflow
             if (parsedTime < myStartTime || parsedTime >= myEndTime) {
                 if (!myHaveWarnedAboutOverridingBoundaries) {
@@ -91,18 +87,18 @@ RODFDetFlowLoader::read(const std::string& file) {
             const SUMOTime time = (SUMOTime)(parsedTime + .5);
             FlowDef fd;
             fd.isLKW = 0;
-            fd.qPKW = TplConvert::_2SUMOReal(myLineHandler.get("qpkw").c_str());
+            fd.qPKW = TplConvert::_2double(myLineHandler.get("qpkw").c_str());
             fd.vPKW = 0;
             if (myLineHandler.know("vPKW")) {
-                fd.vPKW = TplConvert::_2SUMOReal(myLineHandler.get("vpkw").c_str());
+                fd.vPKW = TplConvert::_2double(myLineHandler.get("vpkw").c_str());
             }
             fd.qLKW = 0;
             if (myLineHandler.know("qLKW")) {
-                fd.qLKW = TplConvert::_2SUMOReal(myLineHandler.get("qlkw").c_str());
+                fd.qLKW = TplConvert::_2double(myLineHandler.get("qlkw").c_str());
             }
             fd.vLKW = 0;
             if (myLineHandler.know("vLKW")) {
-                fd.vLKW = TplConvert::_2SUMOReal(myLineHandler.get("vlkw").c_str());
+                fd.vLKW = TplConvert::_2double(myLineHandler.get("vlkw").c_str());
             }
             if (fd.qLKW < 0) {
                 fd.qLKW = 0;
