@@ -8,12 +8,12 @@
 /// @author  Laura Bieker
 /// @author  Melanie Knocke
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFDetector.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: RODFDetector.cpp 24095 2017-04-27 13:45:19Z namdre $
 ///
 // Class representing a detector within the DFROUTER
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2006-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2006-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -45,7 +45,8 @@
 #include "RODFRouteDesc.h"
 #include "RODFRouteCont.h"
 #include "RODFDetectorFlow.h"
-#include <utils/common/RandomDistributor.h>
+#include <utils/vehicle/SUMOVTypeParameter.h>
+#include <utils/distribution/RandomDistributor.h>
 #include <utils/common/StdDefs.h>
 #include <utils/common/TplConvert.h>
 #include <utils/geom/GeomHelper.h>
@@ -54,16 +55,12 @@
 #include <utils/common/StringUtils.h>
 #include <utils/options/OptionsCont.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
 RODFDetector::RODFDetector(const std::string& id, const std::string& laneID,
-                           SUMOReal pos, const RODFDetectorType type)
+                           double pos, const RODFDetectorType type)
     : Named(id), myLaneID(laneID), myPosition(pos), myType(type), myRoutes(0) {}
 
 
@@ -87,10 +84,10 @@ RODFDetector::setType(RODFDetectorType type) {
 }
 
 
-SUMOReal
+double
 RODFDetector::computeDistanceFactor(const RODFRouteDesc& rd) const {
-    SUMOReal distance = rd.edges2Pass[0]->getFromJunction()->getPosition().distanceTo(rd.edges2Pass.back()->getToJunction()->getPosition());
-    SUMOReal length = 0;
+    double distance = rd.edges2Pass[0]->getFromJunction()->getPosition().distanceTo(rd.edges2Pass.back()->getToJunction()->getPosition());
+    double length = 0;
     for (ROEdgeVector::const_iterator i = rd.edges2Pass.begin(); i != rd.edges2Pass.end(); ++i) {
         length += (*i)->getLength();
     }
@@ -128,7 +125,7 @@ RODFDetector::computeSplitProbabilities(const RODFNet* net, const RODFDetectorCo
             }
         }
     }
-    std::map<ROEdge*, SUMOReal> inFlows;
+    std::map<ROEdge*, double> inFlows;
     if (OptionsCont::getOptions().getBool("respect-concurrent-inflows")) {
         for (std::vector<RODFEdge*>::const_iterator i = nextDetEdges.begin(); i != nextDetEdges.end(); ++i) {
             std::set<ROEdge*> seen(preSplitEdges);
@@ -155,11 +152,11 @@ RODFDetector::computeSplitProbabilities(const RODFNet* net, const RODFDetectorCo
     // compute the probabilities to use a certain direction
     int index = 0;
     for (SUMOTime time = startTime; time < endTime; time += stepOffset, ++index) {
-        mySplitProbabilities.push_back(std::map<RODFEdge*, SUMOReal>());
-        SUMOReal overallProb = 0;
+        mySplitProbabilities.push_back(std::map<RODFEdge*, double>());
+        double overallProb = 0;
         // retrieve the probabilities
         for (std::vector<RODFEdge*>::const_iterator i = nextDetEdges.begin(); i != nextDetEdges.end(); ++i) {
-            SUMOReal flow = detectors.getAggFlowFor(*i, time, 60, flows) - inFlows[*i];
+            double flow = detectors.getAggFlowFor(*i, time, 60, flows) - inFlows[*i];
             overallProb += flow;
             mySplitProbabilities[index][*i] = flow;
         }
@@ -177,7 +174,7 @@ void
 RODFDetector::buildDestinationDistribution(const RODFDetectorCon& detectors,
         SUMOTime startTime, SUMOTime endTime, SUMOTime stepOffset,
         const RODFNet& net,
-        std::map<int, RandomDistributor<int>* >& into) const {
+        std::map<SUMOTime, RandomDistributor<int>* >& into) const {
     if (myRoutes == 0) {
         if (myType != DISCARDED_DETECTOR && myType != BETWEEN_DETECTOR) {
             WRITE_ERROR("Missing routes for detector '" + myID + "'.");
@@ -188,26 +185,26 @@ RODFDetector::buildDestinationDistribution(const RODFDetectorCon& detectors,
     // iterate through time (in output interval steps)
     for (SUMOTime time = startTime; time < endTime; time += stepOffset) {
         into[time] = new RandomDistributor<int>();
-        std::map<ROEdge*, SUMOReal> flowMap;
+        std::map<ROEdge*, double> flowMap;
         // iterate through the routes
         int index = 0;
         for (std::vector<RODFRouteDesc>::iterator ri = descs.begin(); ri != descs.end(); ++ri, index++) {
-            SUMOReal prob = 1.;
+            double prob = 1.;
             for (ROEdgeVector::iterator j = (*ri).edges2Pass.begin(); j != (*ri).edges2Pass.end() && prob > 0;) {
                 if (!net.hasDetector(*j)) {
                     ++j;
                     continue;
                 }
                 const RODFDetector& det = detectors.getAnyDetectorForEdge(static_cast<RODFEdge*>(*j));
-                const std::vector<std::map<RODFEdge*, SUMOReal> >& probs = det.getSplitProbabilities();
+                const std::vector<std::map<RODFEdge*, double> >& probs = det.getSplitProbabilities();
                 if (probs.size() == 0) {
                     prob = 0;
                     ++j;
                     continue;
                 }
-                const std::map<RODFEdge*, SUMOReal>& tprobs = probs[(time - startTime) / stepOffset];
+                const std::map<RODFEdge*, double>& tprobs = probs[(int)((time - startTime) / stepOffset)];
                 RODFEdge* splitEdge = 0;
-                for (std::map<RODFEdge*, SUMOReal>::const_iterator k = tprobs.begin(); k != tprobs.end(); ++k) {
+                for (std::map<RODFEdge*, double>::const_iterator k = tprobs.begin(); k != tprobs.end(); ++k) {
                     if (find(j, (*ri).edges2Pass.end(), (*k).first) != (*ri).edges2Pass.end()) {
                         prob *= (*k).second;
                         splitEdge = (*k).first;
@@ -220,7 +217,7 @@ RODFDetector::buildDestinationDistribution(const RODFDetectorCon& detectors,
                     ++j;
                 }
             }
-            into[time]->add(prob, index);
+            into[time]->add(index, prob);
             (*ri).overallProb = prob;
         }
     }
@@ -282,18 +279,18 @@ RODFDetector::hasRoutes() const {
 
 bool
 RODFDetector::writeEmitterDefinition(const std::string& file,
-                                     const std::map<int, RandomDistributor<int>* >& dists,
+                                     const std::map<SUMOTime, RandomDistributor<int>* >& dists,
                                      const RODFDetectorFlows& flows,
                                      SUMOTime startTime, SUMOTime endTime,
                                      SUMOTime stepOffset,
                                      bool includeUnusedRoutes,
-                                     SUMOReal scale,
+                                     double scale,
                                      bool insertionsOnly,
-                                     SUMOReal defaultSpeed) const {
+                                     double defaultSpeed) const {
     OutputDevice& out = OutputDevice::getDevice(file);
     OptionsCont& oc = OptionsCont::getOptions();
     if (getType() != SOURCE_DETECTOR) {
-        out.writeXMLHeader("calibrator");
+        out.writeXMLHeader("additional", "additional_file.xsd");
     }
     // routes
     if (myRoutes != 0 && myRoutes->get().size() != 0) {
@@ -310,7 +307,7 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                 out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, (*i).overallProb).closeTag();
             }
             if (isEmptyDist) {
-                out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, SUMOReal(1)).closeTag();
+                out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, double(1)).closeTag();
             }
         }
         out.closeTag(); // routeDistribution
@@ -326,7 +323,7 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
         int index = 0;
         for (SUMOTime time = startTime; time < endTime; time += stepOffset, index++) {
             // get own (departure flow)
-            assert(index < mflows.size());
+            assert(index < (int)mflows.size());
             const FlowDef& srcFD = mflows[index];  // !!! check stepOffset
             // get flows at end
             RandomDistributor<int>* destDist = dists.find(time) != dists.end() ? dists.find(time)->second : 0;
@@ -334,11 +331,11 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
             int carNo = (int)((srcFD.qPKW + srcFD.qLKW) * scale);
             for (int car = 0; car < carNo; ++car) {
                 // get the vehicle parameter
-                SUMOReal v = -1;
+                double v = -1;
                 std::string vtype;
                 int destIndex = destDist != 0 && destDist->getOverallProb() > 0 ? (int) destDist->get() : -1;
                 if (srcFD.isLKW >= 1) {
-                    srcFD.isLKW = srcFD.isLKW - (SUMOReal) 1.;
+                    srcFD.isLKW = srcFD.isLKW - (double) 1.;
                     v = srcFD.vLKW;
                     vtype = "LKW";
                 } else {
@@ -349,10 +346,10 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                 if (v <= 0 || v > 250) {
                     v = defaultSpeed;
                 } else {
-                    v = (SUMOReal)(v / 3.6);
+                    v = (double)(v / 3.6);
                 }
                 // compute the departure time
-                SUMOTime ctime = (SUMOTime)(time + ((SUMOReal) stepOffset * (SUMOReal) car / (SUMOReal) carNo));
+                SUMOTime ctime = (SUMOTime)(time + ((double) stepOffset * (double) car / (double) carNo));
 
                 // write
                 out.openTag(SUMO_TAG_VEHICLE);
@@ -373,12 +370,12 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                 if (oc.isSet("departpos")) {
                     std::string posDesc = oc.getString("departpos");
                     if (posDesc.substr(0, 8) == "detector") {
-                        SUMOReal position = myPosition;
+                        double position = myPosition;
                         if (posDesc.length() > 8) {
                             if (posDesc[8] == '+') {
-                                position += TplConvert::_2SUMOReal(posDesc.substr(9).c_str());
+                                position += TplConvert::_2double(posDesc.substr(9).c_str());
                             } else if (posDesc[8] == '-') {
-                                position -= TplConvert::_2SUMOReal(posDesc.substr(9).c_str());
+                                position -= TplConvert::_2double(posDesc.substr(9).c_str());
                             } else {
                                 throw NumberFormatException();
                             }
@@ -393,11 +390,7 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                 if (oc.isSet("departspeed")) {
                     out.writeNonEmptyAttr(SUMO_ATTR_DEPARTSPEED, oc.getString("departspeed"));
                 } else {
-                    if (v > defaultSpeed) {
-                        out.writeAttr(SUMO_ATTR_DEPARTSPEED, "max");
-                    } else {
-                        out.writeAttr(SUMO_ATTR_DEPARTSPEED, v);
-                    }
+                    out.writeAttr(SUMO_ATTR_DEPARTSPEED, v);
                 }
                 if (oc.isSet("arrivallane")) {
                     out.writeNonEmptyAttr(SUMO_ATTR_ARRIVALLANE, oc.getString("arrivallane"));
@@ -439,19 +432,19 @@ void
 RODFDetector::writeSingleSpeedTrigger(const std::string& file,
                                       const RODFDetectorFlows& flows,
                                       SUMOTime startTime, SUMOTime endTime,
-                                      SUMOTime stepOffset, SUMOReal defaultSpeed) {
+                                      SUMOTime stepOffset, double defaultSpeed) {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("vss");
+    out.writeXMLHeader("additional", "additional_file.xsd");
     const std::vector<FlowDef>& mflows = flows.getFlowDefs(myID);
     int index = 0;
     for (SUMOTime t = startTime; t < endTime; t += stepOffset, index++) {
-        assert(index < mflows.size());
+        assert(index < (int)mflows.size());
         const FlowDef& srcFD = mflows[index];
-        SUMOReal speed = MAX2(srcFD.vLKW, srcFD.vPKW);
+        double speed = MAX2(srcFD.vLKW, srcFD.vPKW);
         if (speed <= 0 || speed > 250) {
             speed = defaultSpeed;
         } else {
-            speed = (SUMOReal)(speed / 3.6);
+            speed = (double)(speed / 3.6);
         }
         out.openTag(SUMO_TAG_STEP).writeAttr(SUMO_ATTR_TIME, time2string(t)).writeAttr(SUMO_ATTR_SPEED, speed).closeTag();
     }
@@ -524,7 +517,7 @@ RODFDetectorCon::getDetectors() const {
 void
 RODFDetectorCon::save(const std::string& file) const {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("detectors");
+    out.writeXMLHeader("detectors", "detectors_file.xsd");
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         out.openTag(SUMO_TAG_DETECTOR_DEFINITION).writeAttr(SUMO_ATTR_ID, StringUtils::escapeXML((*i)->getID())).writeAttr(SUMO_ATTR_LANE, (*i)->getLaneID()).writeAttr(SUMO_ATTR_POSITION, (*i)->getPos());
         switch ((*i)->getType()) {
@@ -552,7 +545,7 @@ RODFDetectorCon::save(const std::string& file) const {
 void
 RODFDetectorCon::saveAsPOIs(const std::string& file) const {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("pois");
+    out.writeXMLHeader("additional", "additional_file.xsd");
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         out.openTag(SUMO_TAG_POI).writeAttr(SUMO_ATTR_ID, StringUtils::escapeXML((*i)->getID()));
         switch ((*i)->getType()) {
@@ -580,7 +573,7 @@ RODFDetectorCon::saveAsPOIs(const std::string& file) const {
 void
 RODFDetectorCon::saveRoutes(const std::string& file) const {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("routes");
+    out.writeXMLHeader("routes", "routes_file.xsd");
     std::vector<std::string> saved;
     // write for source detectors
     bool lastWasSaved = true;
@@ -624,7 +617,7 @@ RODFDetectorCon::writeEmitters(const std::string& file,
                                SUMOTime stepOffset, const RODFNet& net,
                                bool writeCalibrators,
                                bool includeUnusedRoutes,
-                               SUMOReal scale,
+                               double scale,
                                bool insertionsOnly) {
     // compute turn probabilities at detector
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
@@ -632,7 +625,35 @@ RODFDetectorCon::writeEmitters(const std::string& file,
     }
     //
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("additional", "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/additional_file.xsd\"");
+    out.writeXMLHeader("additional", "additional_file.xsd");
+    // write vType(s)
+    const bool separateVTypeOutput = OptionsCont::getOptions().getString("vtype-output") != "";
+    OutputDevice& vTypeOut = separateVTypeOutput ? OutputDevice::getDevice(OptionsCont::getOptions().getString("vtype-output")) : out;
+    if (separateVTypeOutput) {
+        vTypeOut.writeXMLHeader("additional", "additional_file.xsd");
+    }
+    const bool forceDev = !OptionsCont::getOptions().isDefault("speeddev");
+    const double speedDev = OptionsCont::getOptions().getFloat("speeddev");
+    if (OptionsCont::getOptions().getBool("vtype")) {
+        // write separate types
+        SUMOVTypeParameter pkwType = SUMOVTypeParameter("PKW", SVC_PASSENGER);
+        setSpeedFactorAndDev(pkwType, net.getMaxSpeedFactorPKW(), net.getAvgSpeedFactorPKW(), speedDev, forceDev);
+        pkwType.setParameter |= VTYPEPARS_VEHICLECLASS_SET;
+        pkwType.write(vTypeOut);
+        SUMOVTypeParameter lkwType = SUMOVTypeParameter("LKW", SVC_TRUCK);
+        setSpeedFactorAndDev(lkwType, net.getMaxSpeedFactorLKW(), net.getAvgSpeedFactorLKW(), speedDev, forceDev);
+        lkwType.setParameter |= VTYPEPARS_VEHICLECLASS_SET;
+        lkwType.write(vTypeOut);
+    } else {
+        // patch default type
+        SUMOVTypeParameter type = SUMOVTypeParameter(DEFAULT_VTYPE_ID, SVC_PASSENGER);
+        setSpeedFactorAndDev(type, MAX2(net.getMaxSpeedFactorPKW(), net.getMaxSpeedFactorLKW()), net.getAvgSpeedFactorPKW(), speedDev, forceDev);
+        if (type.setParameter != 0) {
+            type.write(vTypeOut);
+        }
+    }
+
+
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         RODFDetector* det = *i;
         // get file name for values (emitter/calibrator definition)
@@ -647,9 +668,9 @@ RODFDetectorCon::writeEmitters(const std::string& file,
             continue;
         }
         // try to write the definition
-        SUMOReal defaultSpeed = net.getEdge(det->getEdgeID())->getSpeed();
+        double defaultSpeed = net.getEdge(det->getEdgeID())->getSpeedLimit();
         //  ... compute routes' distribution over time
-        std::map<int, RandomDistributor<int>* > dists;
+        std::map<SUMOTime, RandomDistributor<int>* > dists;
         if (!insertionsOnly && flows.knows(det->getID())) {
             det->buildDestinationDistribution(*this, startTime, endTime, stepOffset, net, dists);
         }
@@ -667,6 +688,25 @@ RODFDetectorCon::writeEmitters(const std::string& file,
         }
     }
     out.close();
+    if (separateVTypeOutput) {
+        vTypeOut.close();
+    }
+}
+
+void
+RODFDetectorCon::setSpeedFactorAndDev(SUMOVTypeParameter& type, double maxFactor, double avgFactor, double dev, bool forceDev) {
+    if (avgFactor > 1) {
+        // systematically low speeds can easily be caused by traffic
+        // conditions. Whereas elevated speeds probably reflect speeding
+        type.speedFactor.getParameter()[0] = avgFactor;
+        type.setParameter |= VTYPEPARS_SPEEDFACTOR_SET;
+    }
+    if (forceDev || (maxFactor > 1 && maxFactor > type.speedFactor.getParameter()[0] + NUMERICAL_EPS)) {
+        // setting a non-zero speed deviation causes the simulation to recompute
+        // individual speedFactors to match departSpeed (MSEdge::insertVehicle())
+        type.speedFactor.getParameter()[1] = dev;
+        type.setParameter |= VTYPEPARS_SPEEDFACTOR_SET;
+    }
 }
 
 
@@ -674,10 +714,10 @@ void
 RODFDetectorCon::writeEmitterPOIs(const std::string& file,
                                   const RODFDetectorFlows& flows) {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("additional", "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/additional_file.xsd\"");
+    out.writeXMLHeader("additional", "additional_file.xsd");
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         RODFDetector* det = *i;
-        SUMOReal flow = flows.getFlowSumSecure(det->getID());
+        double flow = flows.getFlowSumSecure(det->getID());
         const unsigned char col = static_cast<unsigned char>(128 * flow / flows.getMaxDetectorFlow() + 128);
         out.openTag(SUMO_TAG_POI).writeAttr(SUMO_ATTR_ID, StringUtils::escapeXML((*i)->getID()) + ":" + toString(flow));
         switch ((*i)->getType()) {
@@ -710,12 +750,12 @@ RODFDetectorCon::getAggFlowFor(const ROEdge* edge, SUMOTime time, SUMOTime perio
     if (edge == 0) {
         return 0;
     }
-//    SUMOReal stepOffset = 60; // !!!
-//    SUMOReal startTime = 0; // !!!
+//    double stepOffset = 60; // !!!
+//    double startTime = 0; // !!!
 //    cout << edge->getID() << endl;
     assert(myDetectorEdgeMap.find(edge->getID()) != myDetectorEdgeMap.end());
     const std::vector<FlowDef>& flows = static_cast<const RODFEdge*>(edge)->getFlows();
-    SUMOReal agg = 0;
+    double agg = 0;
     for (std::vector<FlowDef>::const_iterator i = flows.begin(); i != flows.end(); ++i) {
         const FlowDef& srcFD = *i;
         if (srcFD.qLKW >= 0) {
@@ -728,7 +768,7 @@ RODFDetectorCon::getAggFlowFor(const ROEdge* edge, SUMOTime time, SUMOTime perio
     return (int) agg;
     /* !!! make this time variable
     if (flows.size()!=0) {
-        SUMOReal agg = 0;
+        double agg = 0;
         int beginIndex = (int)((time/stepOffset) - startTime);  // !!! falsch!!!
         for (SUMOTime t=0; t<period&&beginIndex<flows.size(); t+=(SUMOTime) stepOffset) {
             const FlowDef &srcFD = flows[beginIndex++];
@@ -753,14 +793,14 @@ RODFDetectorCon::writeSpeedTrigger(const RODFNet* const net,
                                    SUMOTime startTime, SUMOTime endTime,
                                    SUMOTime stepOffset) {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("additional", "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/additional_file.xsd\"");
+    out.writeXMLHeader("additional", "additional_file.xsd");
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         RODFDetector* det = *i;
         // write the declaration into the file
         if (det->getType() == SINK_DETECTOR && flows.knows(det->getID())) {
             std::string filename = FileHelpers::getFilePath(file) + "vss_" + det->getID() + ".def.xml";
             out.openTag(SUMO_TAG_VSS).writeAttr(SUMO_ATTR_ID, StringUtils::escapeXML(det->getID())).writeAttr(SUMO_ATTR_LANES, det->getLaneID()).writeAttr(SUMO_ATTR_FILE, filename).closeTag();
-            SUMOReal defaultSpeed = net != 0 ? net->getEdge(det->getEdgeID())->getSpeed() : (SUMOReal) 200.;
+            double defaultSpeed = net != 0 ? net->getEdge(det->getEdgeID())->getSpeedLimit() : (double) 200.;
             det->writeSingleSpeedTrigger(filename, flows, startTime, endTime, stepOffset, defaultSpeed);
         }
     }
@@ -771,13 +811,13 @@ RODFDetectorCon::writeSpeedTrigger(const RODFNet* const net,
 void
 RODFDetectorCon::writeEndRerouterDetectors(const std::string& file) {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("additional", "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/additional_file.xsd\"");
+    out.writeXMLHeader("additional", "additional_file.xsd");
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         RODFDetector* det = *i;
         // write the declaration into the file
         if (det->getType() == SINK_DETECTOR) {
             out.openTag(SUMO_TAG_REROUTER).writeAttr(SUMO_ATTR_ID, "endrerouter_" + StringUtils::escapeXML(det->getID())).writeAttr(SUMO_ATTR_EDGES, det->getLaneID());
-            out.writeAttr(SUMO_ATTR_POSITION, SUMOReal(0)).writeAttr(SUMO_ATTR_FILE, "endrerouter_" + det->getID() + ".def.xml").closeTag();
+            out.writeAttr(SUMO_ATTR_POSITION, 0.).writeAttr(SUMO_ATTR_FILE, "endrerouter_" + det->getID() + ".def.xml").closeTag();
         }
     }
     out.close();
@@ -789,12 +829,12 @@ RODFDetectorCon::writeValidationDetectors(const std::string& file,
         bool includeSources,
         bool singleFile, bool friendly) {
     OutputDevice& out = OutputDevice::getDevice(file);
-    out.writeXMLHeader("additional");
+    out.writeXMLHeader("additional", "additional_file.xsd");
     for (std::vector<RODFDetector*>::const_iterator i = myDetectors.begin(); i != myDetectors.end(); ++i) {
         RODFDetector* det = *i;
         // write the declaration into the file
         if (det->getType() != SOURCE_DETECTOR || includeSources) {
-            SUMOReal pos = det->getPos();
+            double pos = det->getPos();
             if (det->getType() == SOURCE_DETECTOR) {
                 pos += 1;
             }
@@ -872,13 +912,13 @@ RODFDetectorCon::guessEmptyFlows(RODFDetectorFlows& flows) {
         }
 
         // plain case: all of the prior detectors have routes
-        if (noPriorWithRoutes == prior.size()) {
+        if (noPriorWithRoutes == (int)prior.size()) {
             // the number of vehicles is the sum of all vehicles on prior
             continue;
         }
 
         // plain case: all of the follower detectors have routes
-        if (noFollowerWithRoutes == follower.size()) {
+        if (noFollowerWithRoutes == (int)follower.size()) {
             // the number of vehicles is the sum of all vehicles on follower
             continue;
         }
@@ -899,8 +939,8 @@ RODFDetectorCon::getAnyDetectorForEdge(const RODFEdge* const edge) const {
 
 
 void
-RODFDetectorCon::clearDists(std::map<int, RandomDistributor<int>* >& dists) const {
-    for (std::map<int, RandomDistributor<int>* >::iterator i = dists.begin(); i != dists.end(); ++i) {
+RODFDetectorCon::clearDists(std::map<SUMOTime, RandomDistributor<int>* >& dists) const {
+    for (std::map<SUMOTime, RandomDistributor<int>* >::iterator i = dists.begin(); i != dists.end(); ++i) {
         delete(*i).second;
     }
 }
