@@ -5,12 +5,12 @@
 /// @author  Jakob Erdmann
 /// @author  Yun-Pang Floetteroed
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFEdge.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: RODFEdge.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // An edge within the DFROUTER
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2006-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2006-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -35,15 +35,11 @@
 #include <utils/common/MsgHandler.h>
 #include "RODFEdge.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
-RODFEdge::RODFEdge(const std::string& id, RONode* from, RONode* to, unsigned int index, const int priority)
+RODFEdge::RODFEdge(const std::string& id, RONode* from, RONode* to, int index, const int priority)
     : ROEdge(id, from, to, index, priority) {}
 
 
