@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Yun-Pang Floetteroed
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFEdge.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: RODFEdge.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // An edge within the DFROUTER
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2006-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2006-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -61,7 +61,7 @@ public:
      * @param[in] to The node the edge ends at
      * @param[in] index The numeric id of the edge
      */
-    RODFEdge(const std::string& id, RONode* from, RONode* to, unsigned int index, const int priority);
+    RODFEdge(const std::string& id, RONode* from, RONode* to, int index, const int priority);
 
 
     /// @brief Destructor
