@@ -4,12 +4,12 @@
 /// @author  Laura Bieker
 /// @author  Michael Behrisch
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFRouteCont.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: RODFRouteCont.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A container for routes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -39,10 +39,6 @@
 #include <utils/common/ToString.h>
 #include <utils/iodevices/OutputDevice.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -91,7 +87,7 @@ RODFRouteCont::save(std::vector<std::string>& saved,
         assert(desc.edges2Pass.size() >= 1);
         out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_ID, prependix + desc.routename);
         out << " edges=\"";
-        for (std::vector<ROEdge*>::const_iterator k = desc.edges2Pass.begin(); k != desc.edges2Pass.end(); k++) {
+        for (ROEdgeVector::const_iterator k = desc.edges2Pass.begin(); k != desc.edges2Pass.end(); k++) {
             if (k != desc.edges2Pass.begin()) {
                 out << ' ';
             }
@@ -112,13 +108,13 @@ RODFRouteCont::sortByDistance() {
 
 
 void
-RODFRouteCont::removeIllegal(const std::vector<std::vector<ROEdge*> >& illegals) {
+RODFRouteCont::removeIllegal(const std::vector<ROEdgeVector >& illegals) {
     for (std::vector<RODFRouteDesc>::iterator i = myRoutes.begin(); i != myRoutes.end();) {
         RODFRouteDesc& desc = *i;
         bool remove = false;
-        for (std::vector<std::vector<ROEdge*> >::const_iterator j = illegals.begin(); !remove && j != illegals.end(); ++j) {
+        for (std::vector<ROEdgeVector >::const_iterator j = illegals.begin(); !remove && j != illegals.end(); ++j) {
             int noFound = 0;
-            for (std::vector<ROEdge*>::const_iterator k = (*j).begin(); !remove && k != (*j).end(); ++k) {
+            for (ROEdgeVector::const_iterator k = (*j).begin(); !remove && k != (*j).end(); ++k) {
                 if (find(desc.edges2Pass.begin(), desc.edges2Pass.end(), *k) != desc.edges2Pass.end()) {
                     noFound++;
                     if (noFound > 1) {
