@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Thu, 16.03.2006
-/// @version $Id: RODFRouteDesc.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: RODFRouteDesc.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A route within the DFROUTER
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -56,16 +56,16 @@ struct RODFRouteDesc {
     ROEdgeVector edges2Pass;
     /// @brief The name of the route
     std::string routename;
-    SUMOReal duration_2;
-    SUMOReal distance;
+    double duration_2;
+    double distance;
     int passedNo;
     const ROEdge* endDetectorEdge;
     const ROEdge* lastDetectorEdge;
-    SUMOReal distance2Last;
+    double distance2Last;
     SUMOTime duration2Last;
 
-    SUMOReal overallProb;
-    SUMOReal factor;
+    double overallProb;
+    double factor;
 
 };
 
