@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: GUIEvent_SimulationLoaded.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: GUIEvent_SimulationLoaded.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Event send when the simulation has been loaded by GUILadThread
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -65,8 +65,8 @@ public:
         : GUIEvent(EVENT_SIMULATION_LOADED),
           myNet(net), myBegin(startTime), myEnd(endTime),
           myFile(file), mySettingsFiles(settingsFiles),
-          myOsgView(osgView)
-    { }
+          myOsgView(osgView) {
+    }
 
     /// destructor
     ~GUIEvent_SimulationLoaded() { }
