@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    2004
-/// @version $Id: GUIGlobals.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUIGlobals.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // }
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -31,19 +31,17 @@
 
 #include "GUIGlobals.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static member variables definitions
 // ===========================================================================
-bool GUIGlobals::gQuitOnEnd;
+bool GUIGlobals::gRunAfterLoad = false;
 
 
-bool GUIGlobals::gRunAfterLoad;
+bool GUIGlobals::gQuitOnEnd = false;
 
 
+bool GUIGlobals::gDemoAutoReload = false;
+
 
 /****************************************************************************/
