@@ -6,12 +6,12 @@
 /// @author  Laura Bieker
 /// @author  Andreas Gaubatz
 /// @date    Sept 2002
-/// @version $Id: GUISUMOViewParent.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUISUMOViewParent.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A single child window which contains a view of the simulation area
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -56,7 +56,7 @@
 #include <guisim/GUILane.h>
 #include <guisim/GUINet.h>
 #include <guisim/GUIVehicleControl.h>
-#include <guisim/GUIPersonControl.h>
+#include <guisim/GUITransportableControl.h>
 #include <microsim/MSJunction.h>
 #include <microsim/MSGlobals.h>
 #include "GUIGlobals.h"
@@ -70,10 +70,6 @@
 #include <osgview/GUIOSGView.h>
 #endif
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // FOX callback mapping
@@ -208,13 +204,14 @@ GUISUMOViewParent::onCmdLocate(FXObject*, FXSelector sel, void*) {
             if (MSGlobals::gUseMesoSim) {
                 static_cast<GUIMEVehicleControl*>(static_cast<GUINet*>(MSNet::getInstance())->getGUIMEVehicleControl())->insertVehicleIDs(ids);
             } else {
-                static_cast<GUIVehicleControl&>(MSNet::getInstance()->getVehicleControl()).insertVehicleIDs(ids);
+                static_cast<GUIVehicleControl&>(MSNet::getInstance()->getVehicleControl()).insertVehicleIDs(
+                    ids, myParent->listParking(), myParent->listTeleporting());
             }
             icon = ICON_LOCATEVEHICLE;
             title = "Vehicle Chooser";
             break;
         case MID_LOCATEPERSON:
-            static_cast<GUIPersonControl&>(MSNet::getInstance()->getPersonControl()).insertPersonIDs(ids);
+            static_cast<GUITransportableControl&>(MSNet::getInstance()->getPersonControl()).insertPersonIDs(ids);
             icon = ICON_LOCATEPERSON;
             title = "Person Chooser";
             break;
