@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Oct/Nov 2003
-/// @version $Id: GUITLLogicPhasesTrackerWindow.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUITLLogicPhasesTrackerWindow.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // A window displaying the phase diagram of a tl-logic
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -37,7 +37,14 @@
 #include <bitset>
 #include <utility>
 #include <fx.h>
+// fx3d includes windows.h so we need to guard against macro pollution
+#ifdef WIN32
+#define NOMINMAX
+#endif
 #include <fx3d.h>
+#ifdef WIN32
+#undef NOMINMAX
+#endif
 #include <microsim/traffic_lights/MSSimpleTrafficLightLogic.h>
 #include <microsim/traffic_lights/MSTLLogicControl.h>
 #include <utils/common/ValueRetriever.h>
@@ -210,10 +217,10 @@ private:
     std::vector<std::string> myLinkNames;
 
     /// @brief The index of the first phase that fits into the window
-    size_t myFirstPhase2Show;
+    int myFirstPhase2Show;
 
     /// @brief The offset to draw the first phase (left offset)
-    size_t myFirstPhaseOffset;
+    SUMOTime myFirstPhaseOffset;
 
     /// @brief The time the diagram begins at
     SUMOTime myFirstTime2Show;
