@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    07.05.2009
-/// @version $Id: TraCIServerAPI_GUI.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: TraCIServerAPI_GUI.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // APIs for getting/setting GUI values via TraCI
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -45,11 +45,6 @@
 #include "GUIEvent_Screenshot.h"
 #include "TraCIServerAPI_GUI.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
-
 // ===========================================================================
 // method definitions
 // ===========================================================================
@@ -139,17 +134,21 @@ TraCIServerAPI_GUI::processSet(TraCIServer& server, tcpip::Storage& inputStorage
             if (!server.readTypeCheckingDouble(inputStorage, zoom)) {
                 return server.writeErrorStatusCmd(CMD_SET_GUI_VARIABLE, "The zoom must be given as a double.", outputStorage);
             }
-            off.set(v->getChanger().getXPos(), v->getChanger().getYPos(), zoom);
-            v->setViewport(off, p);
+            off.set(v->getChanger().getXPos(), v->getChanger().getYPos(), v->getChanger().zoom2ZPos(zoom));
+            p.set(off.x(), off.y(), 0);
+            v->setViewportFromTo(off, p);
         }
         break;
         case VAR_VIEW_OFFSET: {
-            Position off, p;
-            if (!server.readTypeCheckingPosition2D(inputStorage, off)) {
+            TraCIPosition tp;
+            if (!server.readTypeCheckingPosition2D(inputStorage, tp)) {
                 return server.writeErrorStatusCmd(CMD_SET_GUI_VARIABLE, "The view port must be given as a position.", outputStorage);
             }
-            off.set(off.x(), off.y(), v->getChanger().getZoom());
-            v->setViewport(off, p);
+
+            Position off, p;
+            off.set(tp.x, tp.y, v->getChanger().getZPos());
+            p.set(tp.x, tp.y, 0);
+            v->setViewportFromTo(off, p);
         }
         break;
         case VAR_VIEW_SCHEMA: {
@@ -190,9 +189,8 @@ TraCIServerAPI_GUI::processSet(TraCIServer& server, tcpip::Storage& inputStorage
                 if (veh == 0) {
                     return server.writeErrorStatusCmd(CMD_SET_GUI_VARIABLE, "Could not find vehicle '" + id + "'.", outputStorage);
                 }
-                if (!static_cast<GUIVehicle*>(veh)->hasActiveAddVisualisation(v, GUIBaseVehicle::VO_TRACKED)) {
+                if (v->getTrackedID() != static_cast<GUIVehicle*>(veh)->getGlID()) {
                     v->startTrack(static_cast<GUIVehicle*>(veh)->getGlID());
-                    static_cast<GUIVehicle*>(veh)->addActiveAddVisualisation(v, GUIBaseVehicle::VO_TRACKED);
                 }
             }
         }
