@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIEdgeControlBuilder.cpp 17262 2014-11-04 20:41:44Z behrisch $
+/// @version $Id: GUIEdgeControlBuilder.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Derivation of NLEdgeControlBuilder which build gui-edges
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -42,10 +42,6 @@
 #include "GUIEdgeControlBuilder.h"
 #include <gui/GUIGlobals.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -59,11 +55,12 @@ GUIEdgeControlBuilder::~GUIEdgeControlBuilder() {}
 
 MSLane*
 GUIEdgeControlBuilder::addLane(const std::string& id,
-                               SUMOReal maxSpeed, SUMOReal length,
+                               double maxSpeed, double length,
                                const PositionVector& shape,
-                               SUMOReal width,
-                               SVCPermissions permissions) {
-    MSLane* lane = new GUILane(id, maxSpeed, length, myActiveEdge, myCurrentNumericalLaneID++, shape, width, permissions, (int)myLaneStorage->size());
+                               double width,
+                               SVCPermissions permissions,
+                               int index, bool isRampAccel) {
+    MSLane* lane = new GUILane(id, maxSpeed, length, myActiveEdge, myCurrentNumericalLaneID++, shape, width, permissions, index, isRampAccel);
     myLaneStorage->push_back(lane);
     return lane;
 }
