@@ -6,12 +6,12 @@
 /// @author  Tamas Kurczveil
 /// @author  Pablo Alvarez Lopez
 /// @date    20-12-13
-/// @version $Id: GUIChargingStation.h 21014 2016-06-21 09:02:22Z behrisch $
+/// @version $Id: GUIChargingStation.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A lane area vehicles can halt at (gui-version)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -83,8 +83,8 @@ public:
      * @param[in] chargeInTransit enable or disable charge in transit
      * @param[in] chargeDelay delay in the charge
      */
-    GUIChargingStation(const std::string& id, MSLane& lane, SUMOReal frompos, SUMOReal topos,
-                       SUMOReal chargingPower, SUMOReal efficiency, bool chargeInTransit, int chargeDelay);
+    GUIChargingStation(const std::string& id, MSLane& lane, double frompos, double topos,
+                       double chargingPower, double efficiency, bool chargeInTransit, int chargeDelay);
 
     /// @brief Destructor
     ~GUIChargingStation();
@@ -128,10 +128,10 @@ public:
 
 private:
     /// @brief The rotations of the shape parts
-    std::vector<SUMOReal> myFGShapeRotations;
+    std::vector<double> myFGShapeRotations;
 
     /// @brief The lengths of the shape parts
-    std::vector<SUMOReal> myFGShapeLengths;
+    std::vector<double> myFGShapeLengths;
 
     /// @brief The shape
     PositionVector myFGShape;
@@ -140,7 +140,7 @@ private:
     Position myFGSignPos;
 
     /// @brief The rotation of the sign
-    SUMOReal myFGSignRot;
+    double myFGSignRot;
 };
 
 #endif
