@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Jan 2004
-/// @version $Id: GUIE3Collector.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUIE3Collector.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // The gui-version of a MSE3Collector
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -55,8 +55,8 @@ public:
     /// @brief Constructor
     GUIE3Collector(const std::string& id,
                    const CrossSectionVector& entries, const CrossSectionVector& exits,
-                   SUMOReal haltingSpeedThreshold,
-                   SUMOTime haltingTimeThreshold);
+                   double haltingSpeedThreshold,
+                   SUMOTime haltingTimeThreshold, const std::string& vTypes);
 
     /// @brief Destructor
     ~GUIE3Collector();
@@ -137,7 +137,7 @@ public:
             /// @brief The position
             Position myFGPosition;
             /// @brief The rotation
-            SUMOReal myFGRotation;
+            double myFGRotation;
         };
 
     protected:
@@ -145,8 +145,8 @@ public:
         SingleCrossingDefinition buildDefinition(const MSCrossSection& section);
 
         /// @brief Draws a single entry/exit point
-        void drawSingleCrossing(const Position& pos, SUMOReal rot,
-                                SUMOReal upscale) const;
+        void drawSingleCrossing(const Position& pos, double rot,
+                                double upscale) const;
 
     private:
         /// @brief The wrapped detector
