@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Sept 2002
-/// @version $Id: GUIEdge.cpp 20901 2016-06-07 11:50:11Z namdre $
+/// @version $Id: GUIEdge.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A road/street connecting two junctions (gui-version)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -49,6 +49,7 @@
 #include <microsim/MSEdge.h>
 #include <microsim/MSJunction.h>
 #include <microsim/MSLaneChanger.h>
+#include <microsim/MSInsertionControl.h>
 #include <microsim/MSGlobals.h>
 #include <microsim/logging/CastingFunctionBinding.h>
 #include <microsim/logging/FunctionBinding.h>
@@ -66,10 +67,6 @@
 #include <mesosim/MELoop.h>
 #include <mesosim/MEVehicle.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // included modules
@@ -90,8 +87,8 @@ GUIEdge::~GUIEdge() {
 
 
 MSLane&
-GUIEdge::getLane(size_t laneNo) {
-    assert(laneNo < myLanes->size());
+GUIEdge::getLane(int laneNo) {
+    assert(laneNo < (int)myLanes->size());
     return *((*myLanes)[laneNo]);
 }
 
@@ -111,9 +108,9 @@ GUIEdge::getIDs(bool includeInternal) {
 }
 
 
-SUMOReal
+double
 GUIEdge::getTotalLength(bool includeInternal, bool eachLane) {
-    SUMOReal result = 0;
+    double result = 0;
     for (MSEdge::DictType::const_iterator i = MSEdge::myDict.begin(); i != MSEdge::myDict.end(); ++i) {
         const MSEdge* edge = i->second;
         if (edge->getPurpose() != EDGEFUNCTION_INTERNAL || includeInternal) {
@@ -155,7 +152,7 @@ GUIEdge::getBoundary() const {
 
 void
 GUIEdge::fill(std::vector<GUIEdge*>& netsWrappers) {
-    size_t size = MSEdge::dictSize();
+    int size = MSEdge::dictSize();
     netsWrappers.reserve(size);
     for (DictType::iterator i = myDict.begin(); i != myDict.end(); ++i) {
         if (i->second->getPurpose() != MSEdge::EDGEFUNCTION_DISTRICT) {
@@ -176,7 +173,7 @@ GUIEdge::getPopUpMenu(GUIMainWindow& app, GUISUMOAbstractView& parent) {
     if (MSGlobals::gUseMesoSim) {
         buildShowParamsPopupEntry(ret);
     }
-    const SUMOReal pos = getLanes()[0]->getShape().nearest_offset_to_point2D(parent.getPositionInformation());
+    const double pos = getLanes()[0]->getShape().nearest_offset_to_point2D(parent.getPositionInformation());
     new FXMenuCommand(ret, ("pos: " + toString(pos)).c_str(), 0, 0, 0);
     buildPositionCopyEntry(ret, false);
     return ret;
@@ -187,27 +184,29 @@ GUIParameterTableWindow*
 GUIEdge::getParameterWindow(GUIMainWindow& app,
                             GUISUMOAbstractView& parent) {
     GUIParameterTableWindow* ret = 0;
-    ret = new GUIParameterTableWindow(app, *this, 16);
+    ret = new GUIParameterTableWindow(app, *this, 18);
     // add edge items
     ret->mkItem("length [m]", false, (*myLanes)[0]->getLength());
     ret->mkItem("allowed speed [m/s]", false, getAllowedSpeed());
-    ret->mkItem("brutto occupancy [%]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getBruttoOccupancy, 100.));
-    ret->mkItem("mean vehicle speed [m/s]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getMeanSpeed));
-    ret->mkItem("flow [veh/h/lane]", true, new FunctionBinding<GUIEdge, SUMOReal>(this, &GUIEdge::getFlow));
-    ret->mkItem("routing speed [m/s]", true, new FunctionBinding<MSEdge, SUMOReal>(this, &MSEdge::getRoutingSpeed));
-    ret->mkItem("#vehicles", true, new CastingFunctionBinding<GUIEdge, SUMOReal, unsigned int>(this, &GUIEdge::getVehicleNo));
+    ret->mkItem("brutto occupancy [%]", true, new FunctionBinding<GUIEdge, double>(this, &GUIEdge::getBruttoOccupancy, 100.));
+    ret->mkItem("mean vehicle speed [m/s]", true, new FunctionBinding<GUIEdge, double>(this, &GUIEdge::getMeanSpeed));
+    ret->mkItem("flow [veh/h/lane]", true, new FunctionBinding<GUIEdge, double>(this, &GUIEdge::getFlow));
+    ret->mkItem("routing speed [m/s]", true, new FunctionBinding<MSEdge, double>(this, &MSEdge::getRoutingSpeed));
+    ret->mkItem("#vehicles", true, new CastingFunctionBinding<GUIEdge, double, int>(this, &GUIEdge::getVehicleNo));
     ret->mkItem("vehicle ids", false, getVehicleIDs());
     // add segment items
     MESegment* segment = getSegmentAtPosition(parent.getPositionInformation());
     ret->mkItem("segment index", false, segment->getIndex());
+    ret->mkItem("segment queues", false, segment->numQueues());
     ret->mkItem("segment length [m]", false, segment->getLength());
     ret->mkItem("segment allowed speed [m/s]", false, segment->getEdge().getSpeedLimit());
     ret->mkItem("segment jam threshold [%]", false, segment->getRelativeJamThreshold() * 100);
-    ret->mkItem("segment brutto occupancy [%]", true, new FunctionBinding<MESegment, SUMOReal>(segment, &MESegment::getRelativeOccupancy, 100));
-    ret->mkItem("segment mean vehicle speed [m/s]", true, new FunctionBinding<MESegment, SUMOReal>(segment, &MESegment::getMeanSpeed));
-    ret->mkItem("segment flow [veh/h/lane]", true, new FunctionBinding<MESegment, SUMOReal>(segment, &MESegment::getFlow));
-    ret->mkItem("segment #vehicles", true, new CastingFunctionBinding<MESegment, SUMOReal, size_t>(segment, &MESegment::getCarNumber));
-    ret->mkItem("segment leader leave time", true, new FunctionBinding<MESegment, SUMOReal>(segment, &MESegment::getEventTimeSeconds));
+    ret->mkItem("segment brutto occupancy [%]", true, new FunctionBinding<MESegment, double>(segment, &MESegment::getRelativeOccupancy, 100));
+    ret->mkItem("segment mean vehicle speed [m/s]", true, new FunctionBinding<MESegment, double>(segment, &MESegment::getMeanSpeed));
+    ret->mkItem("segment flow [veh/h/lane]", true, new FunctionBinding<MESegment, double>(segment, &MESegment::getFlow));
+    ret->mkItem("segment #vehicles", true, new CastingFunctionBinding<MESegment, double, int>(segment, &MESegment::getCarNumber));
+    ret->mkItem("segment leader leave time", true, new FunctionBinding<MESegment, double>(segment, &MESegment::getEventTimeSeconds));
+    ret->mkItem("segment headway [s]", true, new FunctionBinding<MESegment, double>(segment, &MESegment::getLastHeadwaySeconds));
 
     // close building
     ret->closeBuilding();
@@ -256,10 +255,10 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
         GUILane* lane1 = dynamic_cast<GUILane*>((*myLanes)[0]);
         GUILane* lane2 = dynamic_cast<GUILane*>((*myLanes).back());
         if (lane1 != 0 && lane2 != 0) {
-            Position p = lane1->getShape().positionAtOffset(lane1->getShape().length() / (SUMOReal) 2.);
-            p.add(lane2->getShape().positionAtOffset(lane2->getShape().length() / (SUMOReal) 2.));
+            Position p = lane1->getShape().positionAtOffset(lane1->getShape().length() / (double) 2.);
+            p.add(lane2->getShape().positionAtOffset(lane2->getShape().length() / (double) 2.));
             p.mul(.5);
-            SUMOReal angle = lane1->getShape().rotationDegreeAtOffset(lane1->getShape().length() / (SUMOReal) 2.);
+            double angle = lane1->getShape().rotationDegreeAtOffset(lane1->getShape().length() / (double) 2.);
             angle += 90;
             if (angle > 90 && angle < 270) {
                 angle -= 180;
@@ -305,25 +304,25 @@ GUIEdge::drawMesoVehicles(const GUIVisualizationSettings& s) const {
         // draw the meso vehicles
         vehicleControl->secureVehicles();
         AbstractMutex::ScopedLocker locker(myLock);
-        size_t laneIndex = 0;
+        int laneIndex = 0;
         MESegment::Queue queue;
         for (std::vector<MSLane*>::const_iterator msl = myLanes->begin(); msl != myLanes->end(); ++msl, ++laneIndex) {
             GUILane* l = static_cast<GUILane*>(*msl);
             // go through the vehicles
-            SUMOReal segmentOffset = 0; // offset at start of current segment
+            double segmentOffset = 0; // offset at start of current segment
             for (MESegment* segment = MSGlobals::gMesoNet->getSegmentForEdge(*this);
                     segment != 0; segment = segment->getNextSegment()) {
-                const SUMOReal length = segment->getLength();
+                const double length = segment->getLength();
                 if (laneIndex < segment->numQueues()) {
                     // make a copy so we don't have to worry about synchronization
                     queue = segment->getQueue(laneIndex);
-                    const size_t queueSize = queue.size();
-                    SUMOReal vehiclePosition = segmentOffset + length;
+                    const int queueSize = (int)queue.size();
+                    double vehiclePosition = segmentOffset + length;
                     // draw vehicles beginning with the leader at the end of the segment
-                    SUMOReal xOff = 0;
-                    for (size_t i = 0; i < queueSize; ++i) {
+                    double xOff = 0;
+                    for (int i = 0; i < queueSize; ++i) {
                         GUIMEVehicle* veh = static_cast<GUIMEVehicle*>(queue[queueSize - i - 1]);
-                        const SUMOReal vehLength = veh->getVehicleType().getLengthWithGap();
+                        const double vehLength = veh->getVehicleType().getLengthWithGap();
                         while (vehiclePosition < segmentOffset) {
                             // if there is only a single queue for a
                             // multi-lane edge shift vehicles and start
@@ -332,7 +331,7 @@ GUIEdge::drawMesoVehicles(const GUIVisualizationSettings& s) const {
                             xOff += 2;
                         }
                         const Position p = l->geometryPositionAtOffset(vehiclePosition);
-                        const SUMOReal angle = l->getShape().rotationAtOffset(l->interpolateLanePosToGeometryPos(vehiclePosition));
+                        const double angle = l->getShape().rotationAtOffset(l->interpolateLanePosToGeometryPos(vehiclePosition));
                         veh->drawOnPos(s, p, angle);
                         vehiclePosition -= vehLength;
                     }
@@ -347,13 +346,13 @@ GUIEdge::drawMesoVehicles(const GUIVisualizationSettings& s) const {
 
 
 
-unsigned int
+int
 GUIEdge::getVehicleNo() const {
-    size_t vehNo = 0;
+    int vehNo = 0;
     for (MESegment* segment = MSGlobals::gMesoNet->getSegmentForEdge(*this); segment != 0; segment = segment->getNextSegment()) {
         vehNo += segment->getCarNumber();
     }
-    return (unsigned int)vehNo;
+    return (int)vehNo;
 }
 
 
@@ -372,33 +371,33 @@ GUIEdge::getVehicleIDs() const {
 }
 
 
-SUMOReal
+double
 GUIEdge::getFlow() const {
-    SUMOReal flow = 0;
+    double flow = 0;
     for (MESegment* segment = MSGlobals::gMesoNet->getSegmentForEdge(*this); segment != 0; segment = segment->getNextSegment()) {
-        flow += (SUMOReal) segment->getCarNumber() * segment->getMeanSpeed();
+        flow += (double) segment->getCarNumber() * segment->getMeanSpeed();
     }
     return 3600 * flow / (*myLanes)[0]->getLength();
 }
 
 
-SUMOReal
+double
 GUIEdge::getBruttoOccupancy() const {
-    SUMOReal occ = 0;
+    double occ = 0;
     for (MESegment* segment = MSGlobals::gMesoNet->getSegmentForEdge(*this); segment != 0; segment = segment->getNextSegment()) {
         occ += segment->getBruttoOccupancy();
     }
-    return occ / (*myLanes)[0]->getLength() / (SUMOReal)(myLanes->size());
+    return occ / (*myLanes)[0]->getLength() / (double)(myLanes->size());
 }
 
 
-SUMOReal
+double
 GUIEdge::getAllowedSpeed() const {
     return (*myLanes)[0]->getSpeedLimit();
 }
 
 
-SUMOReal
+double
 GUIEdge::getRelativeSpeed() const {
     return getMeanSpeed() / getAllowedSpeed();
 }
@@ -406,20 +405,21 @@ GUIEdge::getRelativeSpeed() const {
 
 void
 GUIEdge::setColor(const GUIVisualizationSettings& s) const {
+    myMesoColor = RGBColor(0, 0, 0); // default background color when using multiColor
     const GUIColorer& c = s.edgeColorer;
     if (!setFunctionalColor(c.getActive()) && !setMultiColor(c)) {
-        GLHelper::setColor(c.getScheme().getColor(getColorValue(c.getActive())));
+        myMesoColor = c.getScheme().getColor(getColorValue(c.getActive()));
     }
 }
 
 
 bool
-GUIEdge::setFunctionalColor(size_t activeScheme) const {
+GUIEdge::setFunctionalColor(int activeScheme) const {
     switch (activeScheme) {
         case 9: {
             const PositionVector& shape = getLanes()[0]->getShape();
-            SUMOReal hue = GeomHelper::naviDegree(shape.beginEndAngle()); // [0-360]
-            GLHelper::setColor(RGBColor::fromHSV(hue, 1., 1.));
+            double hue = GeomHelper::naviDegree(shape.beginEndAngle()); // [0-360]
+            myMesoColor = RGBColor::fromHSV(hue, 1., 1.);
             return true;
         }
         default:
@@ -430,7 +430,7 @@ GUIEdge::setFunctionalColor(size_t activeScheme) const {
 
 bool
 GUIEdge::setMultiColor(const GUIColorer& c) const {
-    const size_t activeScheme = c.getActive();
+    const int activeScheme = c.getActive();
     mySegmentColors.clear();
     switch (activeScheme) {
         case 10: // alternating segments
@@ -476,8 +476,8 @@ GUIEdge::setMultiColor(const GUIColorer& c) const {
 }
 
 
-SUMOReal
-GUIEdge::getColorValue(size_t activeScheme) const {
+double
+GUIEdge::getColorValue(int activeScheme) const {
     switch (activeScheme) {
         case 1:
             return gSelected.isSelected(getType(), getGlID());
@@ -495,13 +495,15 @@ GUIEdge::getColorValue(size_t activeScheme) const {
             return getRelativeSpeed();
         case 8:
             return getRoutingSpeed();
+        case 16:
+            return MSNet::getInstance()->getInsertionControl().getPendingEmits(getLanes()[0]);
     }
     return 0;
 }
 
 
-SUMOReal
-GUIEdge::getScaleValue(size_t activeScheme) const {
+double
+GUIEdge::getScaleValue(int activeScheme) const {
     switch (activeScheme) {
         case 1:
             return gSelected.isSelected(getType(), getGlID());
@@ -515,6 +517,8 @@ GUIEdge::getScaleValue(size_t activeScheme) const {
             return getFlow();
         case 6:
             return getRelativeSpeed();
+        case 7:
+            return MSNet::getInstance()->getInsertionControl().getPendingEmits(getLanes()[0]);
     }
     return 0;
 }
@@ -523,7 +527,7 @@ GUIEdge::getScaleValue(size_t activeScheme) const {
 MESegment*
 GUIEdge::getSegmentAtPosition(const Position& pos) {
     const PositionVector& shape = getLanes()[0]->getShape();
-    const SUMOReal lanePos = shape.nearest_offset_to_point2D(pos);
+    const double lanePos = shape.nearest_offset_to_point2D(pos);
     return MSGlobals::gMesoNet->getSegmentForEdge(*this, lanePos);
 }
 
@@ -553,7 +557,7 @@ GUIEdge::addRerouter() {
     MSTriggeredRerouter::RerouteInterval ri;
     ri.begin = MSNet::getInstance()->getCurrentTimeStep();
     ri.end = SUMOTime_MAX;
-    ri.edgeProbs.add(1, &MSTriggeredRerouter::mySpecialDest_keepDestination);
+    ri.edgeProbs.add(&MSTriggeredRerouter::mySpecialDest_keepDestination, 1.);
     rr->myIntervals.push_back(ri);
 
     // trigger rerouting for vehicles already on this edge
