@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUILane.h 20863 2016-06-03 09:27:22Z behrisch $
+/// @version $Id: GUILane.h 23564 2017-03-21 07:38:52Z namdre $
 ///
 // Representation of a lane in the micro simulation (gui-version)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -82,10 +82,10 @@ public:
      * @see SUMOVehicleClass
      * @see MSLane
      */
-    GUILane(const std::string& id, SUMOReal maxSpeed,
-            SUMOReal length, MSEdge* const edge, unsigned int numericalID,
-            const PositionVector& shape, SUMOReal width,
-            SVCPermissions permissions, unsigned int index);
+    GUILane(const std::string& id, double maxSpeed,
+            double length, MSEdge* const edge, int numericalID,
+            const PositionVector& shape, double width,
+            SVCPermissions permissions, int index, bool isRampAccel);
 
 
     /// @brief Destructor
@@ -159,7 +159,7 @@ public:
      * @param[in] v The vehicle which laps into this lane
      * @return This lane's length
      */
-    SUMOReal setPartialOccupation(MSVehicle* v);
+    double setPartialOccupation(MSVehicle* v);
 
     /** @brief Removes the information about a vehicle lapping into this lane
      * @param[in] v The vehicle which laps into this lane
@@ -210,29 +210,32 @@ public:
 
 
     const PositionVector& getShape() const;
-    const std::vector<SUMOReal>& getShapeRotations() const;
-    const std::vector<SUMOReal>& getShapeLengths() const;
+    const std::vector<double>& getShapeRotations() const;
+    const std::vector<double>& getShapeLengths() const;
 
-    SUMOReal firstWaitingTime() const;
+    double firstWaitingTime() const;
 
     /// @brief draw lane borders and white markings
-    void drawMarkings(const GUIVisualizationSettings& s, SUMOReal scale) const;
+    void drawMarkings(const GUIVisualizationSettings& s, double scale) const;
 
     /// @brief bike lane markings on top of an intersection
     void drawBikeMarkings() const;
 
     /// @brief draw crossties for railroads or pedestrian crossings
-    void drawCrossties(SUMOReal length, SUMOReal spacing, SUMOReal halfWidth) const;
+    void drawCrossties(double length, double spacing, double halfWidth) const;
 
-    SUMOReal getEdgeLaneNumber() const;
+    /// @brief direction indicators for lanes
+    void drawDirectionIndicators() const;
+
+    double getEdgeLaneNumber() const;
 
     /** @brief Returns the stored traveltime for the edge of this lane
      */
-    SUMOReal getStoredEdgeTravelTime() const;
+    double getStoredEdgeTravelTime() const;
 
     /** @brief Returns the loaded weight (effort) for the edge of this lane
      */
-    SUMOReal getLoadedEdgeWeight() const;
+    double getLoadedEdgeWeight() const;
 
 #ifdef HAVE_OSG
     void setGeometry(osg::Geometry* geom) {
@@ -266,7 +269,7 @@ protected:
      * @param[in] notification The cause of insertion (i.e. departure, teleport, parking) defaults to departure
      * @see MSLane::incorporateVehicle
      */
-    virtual void incorporateVehicle(MSVehicle* veh, SUMOReal pos, SUMOReal speed, SUMOReal posLat,
+    virtual void incorporateVehicle(MSVehicle* veh, double pos, double speed, double posLat,
                                     const MSLane::VehCont::iterator& at,
                                     MSMoveReminder::Notification notification = MSMoveReminder::NOTIFICATION_DEPARTED);
 
@@ -274,9 +277,8 @@ private:
     /// @brief helper methods
     void drawLinkNo(const GUIVisualizationSettings& s) const;
     void drawTLSLinkNo(const GUIVisualizationSettings& s, const GUINet& net) const;
-    void drawTextAtEnd(const std::string& text, const PositionVector& shape, SUMOReal x, const GUIVisualizationTextSettings& settings) const;
     void drawLinkRules(const GUIVisualizationSettings& s, const GUINet& net) const;
-    void drawLinkRule(const GUIVisualizationSettings& s, const GUINet& net, MSLink* link, const PositionVector& shape, SUMOReal x1, SUMOReal x2) const;
+    void drawLinkRule(const GUIVisualizationSettings& s, const GUINet& net, MSLink* link, const PositionVector& shape, double x1, double x2) const;
     void drawArrows() const;
     void drawLane2LaneConnections() const;
 
@@ -286,13 +288,13 @@ private:
 
 private:
     /// @brief gets the color value according to the current scheme index
-    SUMOReal getColorValue(size_t activeScheme) const;
+    double getColorValue(int activeScheme) const;
 
     /// @brief gets the scaling value according to the current scheme index
-    SUMOReal getScaleValue(size_t activeScheme) const;
+    double getScaleValue(int activeScheme) const;
 
     /// @brief sets the color according to the current scheme index and some lane function
-    bool setFunctionalColor(size_t activeScheme) const;
+    bool setFunctionalColor(int activeScheme) const;
 
     /// @brief sets multiple colors according to the current scheme index and some lane function
     bool setMultiColor(const GUIColorer& c) const;
@@ -307,10 +309,10 @@ private:
     bool drawAsWaterway(const GUIVisualizationSettings& s) const;
 
     /// The rotations of the shape parts
-    std::vector<SUMOReal> myShapeRotations;
+    std::vector<double> myShapeRotations;
 
     /// The lengths of the shape parts
-    std::vector<SUMOReal> myShapeLengths;
+    std::vector<double> myShapeLengths;
 
     /// The color of the shape parts (cached)
     mutable std::vector<RGBColor> myShapeColors;
@@ -319,10 +321,10 @@ private:
     std::vector<int> myShapeSegments;
 
     /// @brief Half of lane width, for speed-up
-    SUMOReal myHalfLaneWidth;
+    double myHalfLaneWidth;
 
     /// @brief Quarter of lane width, for speed-up
-    SUMOReal myQuarterLaneWidth;
+    double myQuarterLaneWidth;
 
 #ifdef HAVE_OSG
     osg::Geometry* myGeom;
@@ -330,7 +332,6 @@ private:
 
     /// @brief state for dynamic lane closings
     bool myAmClosed;
-    SVCPermissions myOriginalPermissions;
 
 private:
     /// The mutex used to avoid concurrent updates of the vehicle buffer
