@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Sept 2002
-/// @version $Id: GUINet.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GUINet.cpp 23987 2017-04-20 09:22:50Z namdre $
 ///
 // A MSNet extended by some values for usage within the gui
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -64,16 +64,12 @@
 
 #include <mesogui/GUIMEVehicleControl.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // definition of static variables used for visualisation of objects' values
 // ===========================================================================
-template std::vector< GLObjectValuePassConnector<SUMOReal>* > GLObjectValuePassConnector<SUMOReal>::myContainer;
-template MFXMutex GLObjectValuePassConnector<SUMOReal>::myLock;
+template std::vector< GLObjectValuePassConnector<double>* > GLObjectValuePassConnector<double>::myContainer;
+template MFXMutex GLObjectValuePassConnector<double>::myLock;
 
 template std::vector< GLObjectValuePassConnector<std::pair<int, class MSPhaseDefinition> >* > GLObjectValuePassConnector<std::pair<int, class MSPhaseDefinition> >::myContainer;
 template MFXMutex GLObjectValuePassConnector<std::pair<int, class MSPhaseDefinition> >::myLock;
@@ -191,7 +187,7 @@ GUINet::vehicleExists(const std::string& name) const {
 }
 
 
-unsigned int
+int
 GUINet::getLinkTLID(MSLink* link) const {
     if (myLinks2Logic.count(link) == 0) {
         assert(false);
@@ -221,7 +217,7 @@ GUINet::getLinkTLIndex(MSLink* link) const {
 
 void
 GUINet::guiSimulationStep() {
-    GLObjectValuePassConnector<SUMOReal>::updateAll();
+    GLObjectValuePassConnector<double>::updateAll();
     GLObjectValuePassConnector<std::pair<SUMOTime, MSPhaseDefinition> >::updateAll();
 }
 
@@ -279,15 +275,13 @@ GUINet::initGUIStructures() {
     // initialise edge storage for gui
     GUIEdge::fill(myEdgeWrapper);
     // initialise junction storage for gui
-    size_t size = myJunctions->size();
+    int size = myJunctions->size();
     myJunctionWrapper.reserve(size);
     const std::map<std::string, MSJunction*>& junctions = myJunctions->getMyMap();
     for (std::map<std::string, MSJunction*>::const_iterator i = junctions.begin(); i != junctions.end(); ++i) {
         myJunctionWrapper.push_back(new GUIJunctionWrapper(*(*i).second));
     }
     // build the visualization tree
-    float* cmin = new float[2];
-    float* cmax = new float[2];
     for (std::vector<GUIEdge*>::iterator i = myEdgeWrapper.begin(); i != myEdgeWrapper.end(); ++i) {
         GUIEdge* edge = *i;
         Boundary b;
@@ -297,10 +291,8 @@ GUINet::initGUIStructures() {
         }
         // make sure persons are always drawn and selectable since they depend on their edge being drawn
         b.grow(MSPModel::SIDEWALK_OFFSET + 1);
-        cmin[0] = b.xmin();
-        cmin[1] = b.ymin();
-        cmax[0] = b.xmax();
-        cmax[1] = b.ymax();
+        const float cmin[2] = { (float)b.xmin(), (float)b.ymin() };
+        const float cmax[2] = { (float)b.xmax(), (float)b.ymax() };
         myGrid.Insert(cmin, cmax, edge);
         myBoundary.add(b);
         if (myBoundary.getWidth() > 10e16 || myBoundary.getHeight() > 10e16) {
@@ -311,26 +303,22 @@ GUINet::initGUIStructures() {
         GUIJunctionWrapper* junction = *i;
         Boundary b = junction->getBoundary();
         b.grow(2.);
-        cmin[0] = b.xmin();
-        cmin[1] = b.ymin();
-        cmax[0] = b.xmax();
-        cmax[1] = b.ymax();
+        const float cmin[2] = { (float)b.xmin(), (float)b.ymin() };
+        const float cmax[2] = { (float)b.xmax(), (float)b.ymax() };
         myGrid.Insert(cmin, cmax, junction);
         myBoundary.add(b);
     }
-    delete[] cmin;
-    delete[] cmax;
     myGrid.add(myBoundary);
 }
 
 
-unsigned int
+int
 GUINet::getWholeDuration() const {
     return myLastSimDuration +/*myLastVisDuration+*/myLastIdleDuration;
 }
 
 
-unsigned int
+int
 GUINet::getSimDuration() const {
     return myLastSimDuration;
 }
@@ -344,43 +332,43 @@ GUINet::getVisDuration() const
 */
 
 
-SUMOReal
+double
 GUINet::getRTFactor() const {
     if (myLastSimDuration == 0) {
         return -1;
     }
-    return (SUMOReal) 1000. / (SUMOReal) myLastSimDuration;
+    return (double) 1000. / (double) myLastSimDuration;
 }
 
 
-SUMOReal
+double
 GUINet::getUPS() const {
     if (myLastSimDuration == 0) {
         return -1;
     }
-    return (SUMOReal) myLastVehicleMovementCount / (SUMOReal) myLastSimDuration * (SUMOReal) 1000.;
+    return (double) myLastVehicleMovementCount / (double) myLastSimDuration * (double) 1000.;
 }
 
 
-SUMOReal
+double
 GUINet::getMeanRTFactor(int duration) const {
     if (myOverallSimDuration == 0) {
         return -1;
     }
-    return ((SUMOReal)(duration) * (SUMOReal) 1000. / (SUMOReal)myOverallSimDuration);
+    return ((double)(duration) * (double) 1000. / (double)myOverallSimDuration);
 }
 
 
-SUMOReal
+double
 GUINet::getMeanUPS() const {
     if (myOverallSimDuration == 0) {
         return -1;
     }
-    return ((SUMOReal)myVehiclesMoved / (SUMOReal)myOverallSimDuration * (SUMOReal) 1000.);
+    return ((double)myVehiclesMoved / (double)myOverallSimDuration * (double) 1000.);
 }
 
 
-unsigned int
+int
 GUINet::getIdleDuration() const {
     return myLastIdleDuration;
 }
@@ -424,56 +412,57 @@ GUIParameterTableWindow*
 GUINet::getParameterWindow(GUIMainWindow& app,
                            GUISUMOAbstractView&) {
     GUIParameterTableWindow* ret =
-        new GUIParameterTableWindow(app, *this, 28);
+        new GUIParameterTableWindow(app, *this, 29);
     // add items
     ret->mkItem("loaded vehicles [#]", true,
-                new FunctionBinding<MSVehicleControl, unsigned int>(&getVehicleControl(), &MSVehicleControl::getLoadedVehicleNo));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getLoadedVehicleNo));
     ret->mkItem("insertion-backlogged vehicles [#]", true,
-                new FunctionBinding<MSInsertionControl, unsigned int>(&getInsertionControl(), &MSInsertionControl::getWaitingVehicleNo));
+                new FunctionBinding<MSInsertionControl, int>(&getInsertionControl(), &MSInsertionControl::getWaitingVehicleNo));
     ret->mkItem("departed vehicles [#]", true,
-                new FunctionBinding<MSVehicleControl, unsigned int>(&getVehicleControl(), &MSVehicleControl::getDepartedVehicleNo));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getDepartedVehicleNo));
     ret->mkItem("running vehicles [#]", true,
-                new FunctionBinding<MSVehicleControl, unsigned int>(&getVehicleControl(), &MSVehicleControl::getRunningVehicleNo));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getRunningVehicleNo));
     ret->mkItem("arrived vehicles [#]", true,
-                new FunctionBinding<MSVehicleControl, unsigned int>(&getVehicleControl(), &MSVehicleControl::getEndedVehicleNo));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getEndedVehicleNo));
     ret->mkItem("collisions [#]", true,
-                new FunctionBinding<MSVehicleControl, unsigned int>(&getVehicleControl(), &MSVehicleControl::getCollisionCount));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getCollisionCount));
     ret->mkItem("teleports [#]", true,
-                new FunctionBinding<MSVehicleControl, unsigned int>(&getVehicleControl(), &MSVehicleControl::getTeleportCount));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getTeleportCount));
     if (myPersonControl != 0) {
         ret->mkItem("loaded persons [#]", true,
-                    new FunctionBinding<MSTransportableControl, unsigned int>(&getPersonControl(), &MSTransportableControl::getLoadedNumber));
+                    new FunctionBinding<MSTransportableControl, int>(&getPersonControl(), &MSTransportableControl::getLoadedNumber));
         ret->mkItem("running persons [#]", true,
-                    new FunctionBinding<MSTransportableControl, unsigned int>(&getPersonControl(), &MSTransportableControl::getRunningNumber));
+                    new FunctionBinding<MSTransportableControl, int>(&getPersonControl(), &MSTransportableControl::getRunningNumber));
         ret->mkItem("jammed persons [#]", true,
-                    new FunctionBinding<MSTransportableControl, unsigned int>(&getPersonControl(), &MSTransportableControl::getJammedNumber));
+                    new FunctionBinding<MSTransportableControl, int>(&getPersonControl(), &MSTransportableControl::getJammedNumber));
     }
     ret->mkItem("end time [s]", false, OptionsCont::getOptions().getString("end"));
     ret->mkItem("begin time [s]", false, OptionsCont::getOptions().getString("begin"));
 //    ret->mkItem("time step [s]", true, new FunctionBinding<GUINet, SUMOTime>(this, &GUINet::getCurrentTimeStep));
     if (logSimulationDuration()) {
-        ret->mkItem("step duration [ms]", true, new FunctionBinding<GUINet, unsigned int>(this, &GUINet::getWholeDuration));
-        ret->mkItem("simulation duration [ms]", true, new FunctionBinding<GUINet, unsigned int>(this, &GUINet::getSimDuration));
+        ret->mkItem("step duration [ms]", true, new FunctionBinding<GUINet, int>(this, &GUINet::getWholeDuration));
+        ret->mkItem("simulation duration [ms]", true, new FunctionBinding<GUINet, int>(this, &GUINet::getSimDuration));
         /*
         ret->mkItem("visualisation duration [ms]", true,
-            new CastingFunctionBinding<GUINet, SUMOReal, int>(
+            new CastingFunctionBinding<GUINet, double, int>(
                 &(getNet()), &GUINet::getVisDuration));
         */
-        ret->mkItem("idle duration [ms]", true, new FunctionBinding<GUINet, unsigned int>(this, &GUINet::getIdleDuration));
-        ret->mkItem("duration factor []", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getRTFactor));
+        ret->mkItem("idle duration [ms]", true, new FunctionBinding<GUINet, int>(this, &GUINet::getIdleDuration));
+        ret->mkItem("duration factor []", true, new FunctionBinding<GUINet, double>(this, &GUINet::getRTFactor));
         /*
         ret->mkItem("mean duration factor []", true,
-            new FuncBinding_IntParam<GUINet, SUMOReal>(
+            new FuncBinding_IntParam<GUINet, double>(
                 &(getNet()), &GUINet::getMeanRTFactor), 1);
                 */
-        ret->mkItem("ups [#]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getUPS));
-        ret->mkItem("mean ups [#]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getMeanUPS));
+        ret->mkItem("ups [#]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getUPS));
+        ret->mkItem("mean ups [#]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getMeanUPS));
         if (OptionsCont::getOptions().getBool("duration-log.statistics")) {
-            ret->mkItem("avg. trip length [m]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getAvgRouteLength));
-            ret->mkItem("avg. trip duration [s]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getAvgDuration));
-            ret->mkItem("avg. trip waiting time [s]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getAvgWaitingTime));
-            ret->mkItem("avg. trip time loss [s]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getAvgTimeLoss));
-            ret->mkItem("avg. trip depart delay [s]", true, new FunctionBinding<GUINet, SUMOReal>(this, &GUINet::getAvgDepartDelay));
+            ret->mkItem("avg. trip length [m]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgRouteLength));
+            ret->mkItem("avg. trip duration [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgDuration));
+            ret->mkItem("avg. trip waiting time [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgWaitingTime));
+            ret->mkItem("avg. trip time loss [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgTimeLoss));
+            ret->mkItem("avg. trip depart delay [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgDepartDelay));
+            ret->mkItem("avg. trip speed [m/s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgTripSpeed));
         }
     }
     ret->mkItem("nodes [#]", false, (int)myJunctions->size());
