@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUINet.h 20768 2016-05-20 08:38:44Z behrisch $
+/// @version $Id: GUINet.h 23987 2017-04-20 09:22:50Z namdre $
 ///
 // A MSNet extended by some values for usage within the gui
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -170,32 +170,32 @@ public:
     /** @brief Returns the duration of the last step (sim+visualisation+idle) (in ms)
      * @return How long it took to compute and display the last step
      */
-    unsigned int getWholeDuration() const;
+    int getWholeDuration() const;
 
 
     /** @brief Returns the duration of the last step's simulation part (in ms)
      * @return How long it took to compute the last step
      */
-    unsigned int getSimDuration() const;
+    int getSimDuration() const;
 
 
     /// Returns the simulation speed as a factor to real time
-    SUMOReal getRTFactor() const;
+    double getRTFactor() const;
 
     /// Returns the update per seconds rate
-    SUMOReal getUPS() const;
+    double getUPS() const;
 
     /// Returns the simulation speed as a factor to real time
-    SUMOReal getMeanRTFactor(int duration) const;
+    double getMeanRTFactor(int duration) const;
 
     /// Returns the update per seconds rate
-    SUMOReal getMeanUPS() const;
+    double getMeanUPS() const;
 
     // Returns the duration of the last step's visualisation part (in ms)
     //int getVisDuration() const;
 
     /// Returns the duration of the last step's idle part (in ms)
-    unsigned int getIdleDuration() const;
+    int getIdleDuration() const;
 
     /// Sets the duration of the last step's simulation part
     void setSimDuration(int val);
@@ -207,21 +207,24 @@ public:
     void setIdleDuration(int val);
     //}
 
-    SUMOReal getAvgRouteLength() const {
+    double getAvgRouteLength() const {
         return MSDevice_Tripinfo::getAvgRouteLength();
     }
-    SUMOReal getAvgDuration() const {
+    double getAvgDuration() const {
         return MSDevice_Tripinfo::getAvgDuration();
     }
-    SUMOReal getAvgWaitingTime() const {
+    double getAvgWaitingTime() const {
         return MSDevice_Tripinfo::getAvgWaitingTime();
     }
-    SUMOReal getAvgTimeLoss() const {
+    double getAvgTimeLoss() const {
         return MSDevice_Tripinfo::getAvgTimeLoss();
     }
-    SUMOReal getAvgDepartDelay() const {
+    double getAvgDepartDelay() const {
         return MSDevice_Tripinfo::getAvgDepartDelay();
     }
+    double getAvgTripSpeed() const {
+        return MSDevice_Tripinfo::getAvgDuration() != 0 ? MSDevice_Tripinfo::getAvgRouteLength() / MSDevice_Tripinfo::getAvgDuration() : 0;
+    }
 
     /** @brief Returns the person control
      *
@@ -247,7 +250,7 @@ public:
 
     /** Returns the gl-id of the traffic light that controls the given link
      * valid only if the link is controlled by a tls */
-    unsigned int getLinkTLID(MSLink* link) const;
+    int getLinkTLID(MSLink* link) const;
 
     /** Returns the index of the link within the junction that controls the given link;
      * Returns -1 if the link is not controlled by a tls */
@@ -359,7 +362,7 @@ protected:
 
 
     /// @brief The step durations (simulation, /*visualisation, */idle)
-    unsigned int myLastSimDuration, /*myLastVisDuration, */myLastIdleDuration;
+    int myLastSimDuration, /*myLastVisDuration, */myLastIdleDuration;
 
     long myLastVehicleMovementCount, myOverallVehicleCount;
     long myOverallSimDuration;
