@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIPerson.cpp 21202 2016-07-19 13:40:35Z behrisch $
+/// @version $Id: GUIPerson.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // A MSPerson extended by some values for usage within the gui
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -59,10 +59,6 @@
 #include "GUIEdge.h"
 #include "GUIPerson.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 //#define GUIPerson_DEBUG_DRAW_WALKINGAREA_PATHS 1
 
 // ===========================================================================
@@ -136,9 +132,8 @@ GUIPerson::GUIPersonPopupMenu::onCmdHideWalkingareaPath(FXObject*, FXSelector, v
 long
 GUIPerson::GUIPersonPopupMenu::onCmdStartTrack(FXObject*, FXSelector, void*) {
     assert(myObject->getType() == GLO_PERSON);
-    if (!static_cast<GUIPerson*>(myObject)->hasActiveAddVisualisation(myParent, VO_TRACKED)) {
+    if (myParent->getTrackedID() != static_cast<GUIPerson*>(myObject)->getGlID()) {
         myParent->startTrack(static_cast<GUIPerson*>(myObject)->getGlID());
-        static_cast<GUIPerson*>(myObject)->addActiveAddVisualisation(myParent, VO_TRACKED);
     }
     return 1;
 }
@@ -146,7 +141,6 @@ GUIPerson::GUIPersonPopupMenu::onCmdStartTrack(FXObject*, FXSelector, void*) {
 long
 GUIPerson::GUIPersonPopupMenu::onCmdStopTrack(FXObject*, FXSelector, void*) {
     assert(myObject->getType() == GLO_PERSON);
-    static_cast<GUIPerson*>(myObject)->removeActiveAddVisualisation(myParent, VO_TRACKED);
     myParent->stopTrack();
     return 1;
 }
@@ -165,6 +159,14 @@ GUIPerson::GUIPerson(const SUMOVehicleParameter* pars, const MSVehicleType* vtyp
 
 
 GUIPerson::~GUIPerson() {
+    myLock.lock();
+    for (std::map<GUISUMOAbstractView*, int>::iterator i = myAdditionalVisualizations.begin(); i != myAdditionalVisualizations.end(); ++i) {
+        if (i->first->getTrackedID() == getGlID()) {
+            i->first->stopTrack();
+        }
+        while (i->first->removeAdditionalGLVisualisation(this));
+    }
+    myLock.unlock();
 }
 
 
@@ -187,8 +189,7 @@ GUIPerson::getPopUpMenu(GUIMainWindow& app,
         new FXMenuCommand(ret, "Show Walkingarea Path", 0, ret, MID_SHOW_WALKINGAREA_PATH);
     }
     new FXMenuSeparator(ret);
-    GUIGlID trackedID = parent.getTrackedID();
-    if (trackedID != getGlID()) {
+    if (parent.getTrackedID() != getGlID()) {
         new FXMenuCommand(ret, "Start Tracking", 0, ret, MID_START_TRACK);
     } else {
         new FXMenuCommand(ret, "Stop Tracking", 0, ret, MID_STOP_TRACK);
@@ -196,6 +197,7 @@ GUIPerson::getPopUpMenu(GUIMainWindow& app,
     new FXMenuSeparator(ret);
     //
     buildShowParamsPopupEntry(ret);
+    buildShowTypeParamsPopupEntry(ret);
     buildPositionCopyEntry(ret, false);
     return ret;
 }
@@ -207,21 +209,33 @@ GUIPerson::getParameterWindow(GUIMainWindow& app,
     GUIParameterTableWindow* ret =
         new GUIParameterTableWindow(app, *this, 16);
     // add items
-    //ret->mkItem("type [NAME]", false, myType->getID());
     ret->mkItem("stage", false, getCurrentStageDescription());
     ret->mkItem("start edge [id]", false, getFromEdge()->getID());
     ret->mkItem("dest edge [id]", false, getDestination().getID());
     ret->mkItem("edge [id]", false, getEdge()->getID());
-    ret->mkItem("position [m]", true, new FunctionBinding<GUIPerson, SUMOReal>(this, &GUIPerson::getEdgePos));
-    ret->mkItem("speed [m/s]", true, new FunctionBinding<GUIPerson, SUMOReal>(this, &GUIPerson::getSpeed));
-    ret->mkItem("angle [degree]", true, new FunctionBinding<GUIPerson, SUMOReal>(this, &GUIPerson::getNaviDegree));
-    ret->mkItem("waiting time [s]", true, new FunctionBinding<GUIPerson, SUMOReal>(this, &GUIPerson::getWaitingSeconds));
+    ret->mkItem("position [m]", true, new FunctionBinding<GUIPerson, double>(this, &GUIPerson::getEdgePos));
+    ret->mkItem("speed [m/s]", true, new FunctionBinding<GUIPerson, double>(this, &GUIPerson::getSpeed));
+    ret->mkItem("angle [degree]", true, new FunctionBinding<GUIPerson, double>(this, &GUIPerson::getNaviDegree));
+    ret->mkItem("waiting time [s]", true, new FunctionBinding<GUIPerson, double>(this, &GUIPerson::getWaitingSeconds));
 
     ret->mkItem("parameters [key:val]", false, toString(getParameter().getMap()));
-    ret->mkItem("", false, "");
+    // close building
+    ret->closeBuilding();
+    return ret;
+}
+
+
+GUIParameterTableWindow*
+GUIPerson::getTypeParameterWindow(GUIMainWindow& app,
+                                  GUISUMOAbstractView&) {
+    GUIParameterTableWindow* ret =
+        new GUIParameterTableWindow(app, *this, 9);
+    // add items
     ret->mkItem("Type Information:", false, "");
     ret->mkItem("type [id]", false, myVType->getID());
     ret->mkItem("length", false, myVType->getLength());
+    ret->mkItem("width", false, myVType->getWidth());
+    ret->mkItem("height", false, myVType->getHeight());
     ret->mkItem("minGap", false, myVType->getMinGap());
     ret->mkItem("maximum speed [m/s]", false, myVType->getMaxSpeed());
 
@@ -232,6 +246,7 @@ GUIPerson::getParameterWindow(GUIMainWindow& app,
 }
 
 
+
 Boundary
 GUIPerson::getCenteringBoundary() const {
     Boundary b;
@@ -255,7 +270,7 @@ GUIPerson::drawGL(const GUIVisualizationSettings& s) const {
     // set person color
     setColor(s);
     // scale
-    const SUMOReal upscale = s.personSize.getExaggeration(s, 80);
+    const double upscale = s.personSize.getExaggeration(s, 80);
     glScaled(upscale, upscale, 1);
     switch (s.personQuality) {
         case 0:
@@ -312,7 +327,7 @@ GUIPerson::drawGLAdditional(GUISUMOAbstractView* const parent, const GUIVisualiz
             GLHelper::setColor(darker);
             MSPersonStage_Walking* stage = dynamic_cast<MSPersonStage_Walking*>(getCurrentStage());
             assert(stage != 0);
-            const SUMOReal exaggeration = s.personSize.getExaggeration(s);
+            const double exaggeration = s.personSize.getExaggeration(s);
             const ConstMSEdgeVector& edges = stage->getRoute();
             for (ConstMSEdgeVector::const_iterator it = edges.begin(); it != edges.end(); ++it) {
                 GUILane* lane = static_cast<GUILane*>((*it)->getLanes()[0]);
@@ -365,13 +380,13 @@ GUIPerson::setFunctionalColor(int activeScheme) const {
             return false;
         }
         case 8: { // color by angle
-            SUMOReal hue = GeomHelper::naviDegree(getAngle());
+            double hue = GeomHelper::naviDegree(getAngle());
             GLHelper::setColor(RGBColor::fromHSV(hue, 1., 1.));
             return true;
         }
         case 9: { // color randomly (by pointer)
-            const SUMOReal hue = (long)this % 360; // [0-360]
-            const SUMOReal sat = (((long)this / 360) % 67) / 100.0 + 0.33; // [0.33-1]
+            const double hue = (long)this % 360; // [0-360]
+            const double sat = (((long)this / 360) % 67) / 100.0 + 0.33; // [0.33-1]
             GLHelper::setColor(RGBColor::fromHSV(hue, sat, 1.));
             return true;
         }
@@ -381,7 +396,7 @@ GUIPerson::setFunctionalColor(int activeScheme) const {
 }
 
 
-SUMOReal
+double
 GUIPerson::getColorValue(int activeScheme) const {
     switch (activeScheme) {
         case 4:
@@ -390,7 +405,7 @@ GUIPerson::getColorValue(int activeScheme) const {
             if (isWaiting4Vehicle()) {
                 return 3;
             } else {
-                return (SUMOReal)getCurrentStageType();
+                return (double)getCurrentStageType();
             }
         case 6:
             return getWaitingSeconds();
@@ -401,7 +416,7 @@ GUIPerson::getColorValue(int activeScheme) const {
 }
 
 
-SUMOReal
+double
 GUIPerson::getEdgePos() const {
     AbstractMutex::ScopedLocker locker(myLock);
     return MSPerson::getEdgePos();
@@ -415,21 +430,21 @@ GUIPerson::getPosition() const {
 }
 
 
-SUMOReal
+double
 GUIPerson::getNaviDegree() const {
     AbstractMutex::ScopedLocker locker(myLock);
     return GeomHelper::naviDegree(MSPerson::getAngle());
 }
 
 
-SUMOReal
+double
 GUIPerson::getWaitingSeconds() const {
     AbstractMutex::ScopedLocker locker(myLock);
     return MSPerson::getWaitingSeconds();
 }
 
 
-SUMOReal
+double
 GUIPerson::getSpeed() const {
     AbstractMutex::ScopedLocker locker(myLock);
     return MSPerson::getSpeed();
@@ -493,9 +508,9 @@ GUIPerson::drawAction_drawAsImage(const GUIVisualizationSettings& s) const {
         }
         int textureID = GUITexturesHelper::getTextureID(file);
         if (textureID > 0) {
-            const SUMOReal exaggeration = s.personSize.getExaggeration(s);
-            const SUMOReal halfLength = getVehicleType().getLength() / 2.0 * exaggeration;
-            const SUMOReal halfWidth = getVehicleType().getWidth() / 2.0 * exaggeration;
+            const double exaggeration = s.personSize.getExaggeration(s);
+            const double halfLength = getVehicleType().getLength() / 2.0 * exaggeration;
+            const double halfWidth = getVehicleType().getWidth() / 2.0 * exaggeration;
             GUITexturesHelper::drawTexturedBox(textureID, -halfWidth, -halfLength, halfWidth, halfLength);
         }
     } else {
