@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 25.07.2005
-/// @version $Id: GUITriggeredRerouter.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUITriggeredRerouter.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Reroutes vehicles passing an edge (gui version)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -53,10 +53,6 @@
 #include <foreign/polyfonts/polyfonts.h>
 #include <utils/gui/globjects/GLIncludes.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // FOX callback mapping
@@ -160,7 +156,7 @@ GUITriggeredRerouter::GUIManip_TriggeredRerouter::onCmdClose(FXObject*, FXSelect
 
 long
 GUITriggeredRerouter::GUIManip_TriggeredRerouter::onCmdUserDef(FXObject*, FXSelector, void*) {
-    myUsageProbability = (SUMOReal)(myUsageProbabilityDial->getValue());
+    myUsageProbability = (double)(myUsageProbabilityDial->getValue());
     static_cast<GUITriggeredRerouter*>(myObject)->setUserUsageProbability(myUsageProbability);
     static_cast<GUITriggeredRerouter*>(myObject)->setUserMode(true);
     myParent->updateChildren();
@@ -228,7 +224,7 @@ GUITriggeredRerouter::GUITriggeredRerouterPopupMenu::onCmdOpenManip(FXObject*,
 GUITriggeredRerouter::GUITriggeredRerouter(
     const std::string& id,
     const MSEdgeVector& edges,
-    SUMOReal prob, const std::string& aXMLFilename, bool off,
+    double prob, const std::string& aXMLFilename, bool off,
     SUMORTree& rtree) :
     MSTriggeredRerouter(id, edges, prob, aXMLFilename, off),
     GUIGlObject_AbstractAdd("rerouter", GLO_TRIGGER, id) {
@@ -324,7 +320,7 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::GUITriggeredRerouterEdge(GUIEdge
     myFGRotations.reserve(lanes.size());
     for (std::vector<MSLane*>::const_iterator i = lanes.begin(); i != lanes.end(); ++i) {
         const PositionVector& v = (*i)->getShape();
-        const SUMOReal pos = closed ? 3 : v.length() - (SUMOReal) 6.;
+        const double pos = closed ? 3 : v.length() - (double) 6.;
         myFGPositions.push_back((*i)->geometryPositionAtOffset(pos));
         myFGRotations.push_back(-v.rotationDegreeAtOffset(pos));
         myBoundary.add(myFGPositions.back());
@@ -351,10 +347,10 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::getParameterWindow(GUIMainWindow
 
 void
 GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSettings& s) const {
-    const SUMOReal exaggeration = s.addSize.getExaggeration(s);
+    const double exaggeration = s.addSize.getExaggeration(s);
     if (s.scale * exaggeration >= 3) {
         glPushName(getGlID());
-        const SUMOReal prob = myParent->getProbability();
+        const double prob = myParent->getProbability();
         if (myAmClosedEdge) {
             // draw closing symbol onto all lanes
             const RerouteInterval* const ri =
@@ -362,10 +358,10 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSet
             if (ri != 0 && prob > 0) {
                 // draw only if the edge is closed at this time
                 if (std::find(ri->closed.begin(), ri->closed.end(), myEdge) != ri->closed.end()) {
-                    const size_t noLanes = myFGPositions.size();
-                    for (size_t j = 0; j < noLanes; ++j) {
+                    const int noLanes = (int)myFGPositions.size();
+                    for (int j = 0; j < noLanes; ++j) {
                         Position pos = myFGPositions[j];
-                        SUMOReal rot = myFGRotations[j];
+                        double rot = myFGRotations[j];
                         glPushMatrix();
                         glTranslated(pos.x(), pos.y(), 0);
                         glRotated(rot, 0, 0, 1);
@@ -380,10 +376,10 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSet
                         glTranslated(0, 0, getType());
                         //glScaled(exaggeration, exaggeration, 1);
                         glColor3d(0.7, 0, 0);
-                        GLHelper::drawFilledCircle((SUMOReal) 1.3, noPoints);
+                        GLHelper::drawFilledCircle((double) 1.3, noPoints);
                         glTranslated(0, 0, .1);
                         glColor3d(1, 0, 0);
-                        GLHelper::drawFilledCircle((SUMOReal) 1.3, noPoints, 0, prob * 360);
+                        GLHelper::drawFilledCircle((double) 1.3, noPoints, 0, prob * 360);
                         glTranslated(0, 0, .1);
                         glColor3d(1, 1, 1);
                         glRotated(-90, 0, 0, 1);
@@ -402,9 +398,9 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSet
 
         } else {
             // draw rerouter symbol onto all lanes
-            for (size_t i = 0; i < myFGPositions.size(); ++i) {
+            for (int i = 0; i < (int)myFGPositions.size(); ++i) {
                 const Position& pos = myFGPositions[i];
-                SUMOReal rot = myFGRotations[i];
+                double rot = myFGRotations[i];
                 glPushMatrix();
                 glTranslated(pos.x(), pos.y(), 0);
                 glRotated(rot, 0, 0, 1);
@@ -427,7 +423,7 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSet
                 glColor3d(0, 0, 0);
                 pfSetPosition(0, 0);
                 pfSetScale(3.f);
-                SUMOReal w = pfdkGetStringWidth("U");
+                double w = pfdkGetStringWidth("U");
                 glRotated(180, 0, 1, 0);
                 glTranslated(-w / 2., 2, 0);
                 pfDrawString("U");
