@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Yun-Pang Floetteroed
 /// @date    Tue, 20 Jan 2004
-/// @version $Id: ROJTREdgeBuilder.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: ROJTREdgeBuilder.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // The builder for jtrrouter-edges
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -33,10 +33,6 @@
 #include "ROJTREdgeBuilder.h"
 #include "ROJTREdge.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
