@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: ROJTRFrame.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: ROJTRFrame.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Sets and checks options for jtr-routing
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -44,10 +44,6 @@
 #include <utils/common/SystemFrame.h>
 #include <utils/vehicle/SUMOVehicleParameter.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
