@@ -4,12 +4,12 @@
 /// @author  Laura Bieker
 /// @author  Michael Behrisch
 /// @date    Feb 2013
-/// @version $Id: ROMAAssignments.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: ROMAAssignments.cpp 24095 2017-04-27 13:45:19Z namdre $
 ///
 // Assignment methods
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -43,15 +43,11 @@
 #include "ROMAEdge.h"
 #include "ROMAAssignments.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static member variables
 // ===========================================================================
-std::map<const ROEdge* const, SUMOReal> ROMAAssignments::myPenalties;
+std::map<const ROEdge* const, double> ROMAAssignments::myPenalties;
 
 
 // ===========================================================================
@@ -59,7 +55,7 @@ std::map<const ROEdge* const, SUMOReal> ROMAAssignments::myPenalties;
 // ===========================================================================
 
 ROMAAssignments::ROMAAssignments(const SUMOTime begin, const SUMOTime end, const bool additiveTraffic,
-                                 const SUMOReal adaptionFactor, RONet& net, ODMatrix& matrix,
+                                 const double adaptionFactor, RONet& net, ODMatrix& matrix,
                                  SUMOAbstractRouter<ROEdge, ROVehicle>& router)
     : myBegin(begin), myEnd(end), myAdditiveTraffic(additiveTraffic), myAdaptionFactor(adaptionFactor), myNet(net), myMatrix(matrix), myRouter(router) {
     myDefaultVehicle = new ROVehicle(SUMOVehicleParameter(), 0, net.getVehicleTypeSecure(DEFAULT_VTYPE_ID), &net);
@@ -71,7 +67,7 @@ ROMAAssignments::~ROMAAssignments() {
 }
 
 // based on the definitions in PTV-Validate and in the VISUM-Cologne network
-SUMOReal
+double
 ROMAAssignments::getCapacity(const ROEdge* edge) {
     if (edge->getFunc() == ROEdge::ET_DISTRICT) {
         return 0;
@@ -83,39 +79,39 @@ ROMAAssignments::getCapacity(const ROEdge* edge) {
         return 0;
     } else if (roadClass == 0 || roadClass == 1)  {
         return edge->getLaneNo() * 2000.; //CR13 in table.py
-    } else if (roadClass == 2 && edge->getSpeed() <= 11.) {
+    } else if (roadClass == 2 && edge->getSpeedLimit() <= 11.) {
         return edge->getLaneNo() * 1333.33; //CR5 in table.py
-    } else if (roadClass == 2 && edge->getSpeed() > 11. && edge->getSpeed() <= 16.) {
+    } else if (roadClass == 2 && edge->getSpeedLimit() > 11. && edge->getSpeedLimit() <= 16.) {
         return edge->getLaneNo() * 1500.; //CR3 in table.py
-    } else if (roadClass == 2 && edge->getSpeed() > 16.) {
+    } else if (roadClass == 2 && edge->getSpeedLimit() > 16.) {
         return edge->getLaneNo() * 2000.; //CR13 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() <= 11.) {
+    } else if (roadClass == 3 && edge->getSpeedLimit() <= 11.) {
         return edge->getLaneNo() * 800.; //CR5 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() > 11. && edge->getSpeed() <= 13.) {
+    } else if (roadClass == 3 && edge->getSpeedLimit() > 11. && edge->getSpeedLimit() <= 13.) {
         return edge->getLaneNo() * 875.; //CR5 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() > 13. && edge->getSpeed() <= 16.) {
+    } else if (roadClass == 3 && edge->getSpeedLimit() > 13. && edge->getSpeedLimit() <= 16.) {
         return edge->getLaneNo() * 1500.; //CR4 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() > 16.) {
+    } else if (roadClass == 3 && edge->getSpeedLimit() > 16.) {
         return edge->getLaneNo() * 1800.; //CR13 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() <= 5.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() <= 5.) {
         return edge->getLaneNo() * 200.; //CR7 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 5. && edge->getSpeed() <= 7.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 5. && edge->getSpeedLimit() <= 7.) {
         return edge->getLaneNo() * 412.5; //CR7 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 7. && edge->getSpeed() <= 9.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 7. && edge->getSpeedLimit() <= 9.) {
         return edge->getLaneNo() * 600.; //CR6 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 9. && edge->getSpeed() <= 11.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 9. && edge->getSpeedLimit() <= 11.) {
         return edge->getLaneNo() * 800.; //CR5 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 11. && edge->getSpeed() <= 13.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 11. && edge->getSpeedLimit() <= 13.) {
         return edge->getLaneNo() * 1125.; //CR5 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 13. && edge->getSpeed() <= 16.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 13. && edge->getSpeedLimit() <= 16.) {
         return edge->getLaneNo() * 1583.; //CR4 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 16. && edge->getSpeed() <= 18.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 16. && edge->getSpeedLimit() <= 18.) {
         return edge->getLaneNo() * 1100.; //CR3 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 18. && edge->getSpeed() <= 22.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 18. && edge->getSpeedLimit() <= 22.) {
         return edge->getLaneNo() * 1200.; //CR3 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 22. && edge->getSpeed() <= 26.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 22. && edge->getSpeedLimit() <= 26.) {
         return edge->getLaneNo() * 1300.; //CR3 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 26.) {
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 26.) {
         return edge->getLaneNo() * 1400.; //CR3 in table.py
     }
     return edge->getLaneNo() * 800.; //CR5 in table.py
@@ -123,60 +119,60 @@ ROMAAssignments::getCapacity(const ROEdge* edge) {
 
 
 // based on the definitions in PTV-Validate and in the VISUM-Cologne network
-SUMOReal
-ROMAAssignments::capacityConstraintFunction(const ROEdge* edge, const SUMOReal flow) const {
+double
+ROMAAssignments::capacityConstraintFunction(const ROEdge* edge, const double flow) const {
     if (edge->getFunc() == ROEdge::ET_DISTRICT) {
         return 0;
     }
     const int roadClass = -edge->getPriority();
-    const SUMOReal capacity = getCapacity(edge);
+    const double capacity = getCapacity(edge);
     // TODO: differ road class 1 from the unknown road class 1!!!
     if (edge->getLaneNo() == 0) {
         // TAZ have no cost
         return 0;
     } else if (roadClass == 0 || roadClass == 1)  {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.3)) * 2.); //CR13 in table.py
-    } else if (roadClass == 2 && edge->getSpeed() <= 11.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
-    } else if (roadClass == 2 && edge->getSpeed() > 11. && edge->getSpeed() <= 16.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
-    } else if (roadClass == 2 && edge->getSpeed() > 16.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.3)) * 2.); //CR13 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() <= 11.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() > 11. && edge->getSpeed() <= 13.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() > 13. && edge->getSpeed() <= 16.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.7 * (flow / (capacity * 1.)) * 2.); //CR4 in table.py
-    } else if (roadClass == 3 && edge->getSpeed() > 16.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.3)) * 2.); //CR13 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() <= 5.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.5)) * 3.); //CR7 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 5. && edge->getSpeed() <= 7.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.5)) * 3.); //CR7 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 7. && edge->getSpeed() <= 9.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.8)) * 3.); //CR6 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 9. && edge->getSpeed() <= 11.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 11. && edge->getSpeed() <= 13.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 13. && edge->getSpeed() <= 16.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.7 * (flow / (capacity * 1.)) * 2.); //CR4 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 16. && edge->getSpeed() <= 18.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 18. && edge->getSpeed() <= 22.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 22. && edge->getSpeed() <= 26.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
-    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeed() > 26.) {
-        return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.3)) * 2.); //CR13 in table.py
+    } else if (roadClass == 2 && edge->getSpeedLimit() <= 11.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
+    } else if (roadClass == 2 && edge->getSpeedLimit() > 11. && edge->getSpeedLimit() <= 16.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
+    } else if (roadClass == 2 && edge->getSpeedLimit() > 16.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.3)) * 2.); //CR13 in table.py
+    } else if (roadClass == 3 && edge->getSpeedLimit() <= 11.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
+    } else if (roadClass == 3 && edge->getSpeedLimit() > 11. && edge->getSpeedLimit() <= 13.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
+    } else if (roadClass == 3 && edge->getSpeedLimit() > 13. && edge->getSpeedLimit() <= 16.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.7 * (flow / (capacity * 1.)) * 2.); //CR4 in table.py
+    } else if (roadClass == 3 && edge->getSpeedLimit() > 16.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.3)) * 2.); //CR13 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() <= 5.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.5)) * 3.); //CR7 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 5. && edge->getSpeedLimit() <= 7.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.5)) * 3.); //CR7 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 7. && edge->getSpeedLimit() <= 9.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.8)) * 3.); //CR6 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 9. && edge->getSpeedLimit() <= 11.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 11. && edge->getSpeedLimit() <= 13.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 13. && edge->getSpeedLimit() <= 16.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.7 * (flow / (capacity * 1.)) * 2.); //CR4 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 16. && edge->getSpeedLimit() <= 18.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 18. && edge->getSpeedLimit() <= 22.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 22. && edge->getSpeedLimit() <= 26.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
+    } else if ((roadClass >= 4 || roadClass == -1) && edge->getSpeedLimit() > 26.) {
+        return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 1.)) * 2.); //CR3 in table.py
     }
-    return edge->getLength() / edge->getSpeed() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
+    return edge->getLength() / edge->getSpeedLimit() * (1. + 1.*(flow / (capacity * 0.9)) * 3.); //CR5 in table.py
 }
 
 
 bool
-ROMAAssignments::addRoute(ConstROEdgeVector& edges, std::vector<RORoute*>& paths, std::string routeId, SUMOReal prob) {
+ROMAAssignments::addRoute(ConstROEdgeVector& edges, std::vector<RORoute*>& paths, std::string routeId, double prob) {
     std::vector<RORoute*>::iterator p;
     for (p = paths.begin(); p != paths.end(); p++) {
         if (edges == (*p)->getEdgeVector()) {
@@ -194,7 +190,7 @@ ROMAAssignments::addRoute(ConstROEdgeVector& edges, std::vector<RORoute*>& paths
 
 
 void
-ROMAAssignments::getKPaths(const int kPaths, const SUMOReal penalty) {
+ROMAAssignments::getKPaths(const int kPaths, const double penalty) {
     for (std::vector<ODCell*>::const_iterator i = myMatrix.getCells().begin(); i != myMatrix.getCells().end(); ++i) {
         ODCell* c = *i;
         myPenalties.clear();
@@ -213,10 +209,11 @@ ROMAAssignments::getKPaths(const int kPaths, const SUMOReal penalty) {
 
 void
 ROMAAssignments::resetFlows() {
+    const double begin = STEPS2TIME(MIN2(myBegin, myMatrix.getCells().front()->begin));
     for (std::map<std::string, ROEdge*>::const_iterator i = myNet.getEdgeMap().begin(); i != myNet.getEdgeMap().end(); ++i) {
         ROMAEdge* edge = static_cast<ROMAEdge*>(i->second);
-        edge->setFlow(STEPS2TIME(myBegin), STEPS2TIME(myEnd), 0.);
-        edge->setHelpFlow(STEPS2TIME(myBegin), STEPS2TIME(myEnd), 0.);
+        edge->setFlow(begin, STEPS2TIME(myEnd), 0.);
+        edge->setHelpFlow(begin, STEPS2TIME(myEnd), 0.);
     }
 }
 
@@ -243,7 +240,7 @@ ROMAAssignments::incremental(const int numIter, const bool verbose) {
         if (verbose) {
             WRITE_MESSAGE(" starting interval " + time2string(intervalStart));
         }
-        std::map<const ROMAEdge*, SUMOReal> loadedTravelTimes;
+        std::map<const ROMAEdge*, double> loadedTravelTimes;
         for (std::map<std::string, ROEdge*>::const_iterator i = myNet.getEdgeMap().begin(); i != myNet.getEdgeMap().end(); ++i) {
             ROMAEdge* edge = static_cast<ROMAEdge*>(i->second);
             if (edge->hasLoadedTravelTime(STEPS2TIME(intervalStart))) {
@@ -258,7 +255,7 @@ ROMAAssignments::incremental(const int numIter, const bool verbose) {
             int workerIndex = 0;
             for (std::vector<ODCell*>::const_iterator i = myMatrix.getCells().begin() + (*offset); i != cellsEnd; i++) {
                 ODCell* const c = *i;
-                const SUMOReal linkFlow = c->vehicleNumber / numIter;
+                const double linkFlow = c->vehicleNumber / numIter;
                 const SUMOTime begin = myAdditiveTraffic ? myBegin : c->begin;
 #ifdef HAVE_FOX
                 if (myNet.getThreadPool().size() > 0) {
@@ -293,16 +290,16 @@ ROMAAssignments::incremental(const int numIter, const bool verbose) {
 #endif
             for (std::vector<ODCell*>::const_iterator i = myMatrix.getCells().begin() + (*offset); i != cellsEnd; i++) {
                 ODCell* const c = *i;
-                const SUMOReal linkFlow = c->vehicleNumber / numIter;
+                const double linkFlow = c->vehicleNumber / numIter;
                 const SUMOTime begin = myAdditiveTraffic ? myBegin : c->begin;
                 const SUMOTime end = myAdditiveTraffic ? myEnd : c->end;
-                const SUMOReal intervalLengthInHours = STEPS2TIME(end - begin) / 3600.;
+                const double intervalLengthInHours = STEPS2TIME(end - begin) / 3600.;
                 const ConstROEdgeVector& edges = c->pathsVector.back()->getEdgeVector();
                 for (ConstROEdgeVector::const_iterator e = edges.begin(); e != edges.end(); e++) {
                     ROMAEdge* edge = static_cast<ROMAEdge*>(myNet.getEdge((*e)->getID()));
-                    const SUMOReal newFlow = edge->getFlow(STEPS2TIME(begin)) + linkFlow;
+                    const double newFlow = edge->getFlow(STEPS2TIME(begin)) + linkFlow;
                     edge->setFlow(STEPS2TIME(begin), STEPS2TIME(end), newFlow);
-                    SUMOReal travelTime = capacityConstraintFunction(edge, newFlow / intervalLengthInHours);
+                    double travelTime = capacityConstraintFunction(edge, newFlow / intervalLengthInHours);
                     if (lastBegin >= 0 && myAdaptionFactor > 0.) {
                         if (loadedTravelTimes.count(edge) != 0) {
                             travelTime = loadedTravelTimes[edge] * myAdaptionFactor + (1. - myAdaptionFactor) * travelTime;
@@ -320,9 +317,9 @@ ROMAAssignments::incremental(const int numIter, const bool verbose) {
 
 
 void
-ROMAAssignments::sue(const int maxOuterIteration, const int maxInnerIteration, const int kPaths, const SUMOReal penalty, const SUMOReal tolerance, const std::string /* routeChoiceMethod */) {
+ROMAAssignments::sue(const int maxOuterIteration, const int maxInnerIteration, const int kPaths, const double penalty, const double tolerance, const std::string /* routeChoiceMethod */) {
     getKPaths(kPaths, penalty);
-    std::map<const SUMOReal, SUMOReal> intervals;
+    std::map<const double, double> intervals;
     if (myAdditiveTraffic) {
         intervals[STEPS2TIME(myBegin)] = STEPS2TIME(myEnd);
     } else {
@@ -347,7 +344,7 @@ ROMAAssignments::sue(const int maxOuterIteration, const int maxInnerIteration, c
                 // calculate route flows
                 for (std::vector<RORoute*>::const_iterator j = c->pathsVector.begin(); j != c->pathsVector.end(); ++j) {
                     RORoute* r = *j;
-                    const SUMOReal pathFlow = r->getProbability() * c->vehicleNumber;
+                    const double pathFlow = r->getProbability() * c->vehicleNumber;
                     // assign edge flow deltas
                     for (ConstROEdgeVector::const_iterator e = r->getEdgeVector().begin(); e != r->getEdgeVector().end(); e++) {
                         ROMAEdge* edge = static_cast<ROMAEdge*>(myNet.getEdge((*e)->getID()));
@@ -357,12 +354,12 @@ ROMAAssignments::sue(const int maxOuterIteration, const int maxInnerIteration, c
             }
             // calculate new edge flows and check for stability
             int unstableEdges = 0;
-            for (std::map<const SUMOReal, SUMOReal>::const_iterator i = intervals.begin(); i != intervals.end(); ++i) {
-                const SUMOReal intervalLengthInHours = STEPS2TIME(i->second - i->first) / 3600.;
+            for (std::map<const double, double>::const_iterator i = intervals.begin(); i != intervals.end(); ++i) {
+                const double intervalLengthInHours = STEPS2TIME(i->second - i->first) / 3600.;
                 for (std::map<std::string, ROEdge*>::const_iterator e = myNet.getEdgeMap().begin(); e != myNet.getEdgeMap().end(); ++e) {
                     ROMAEdge* edge = static_cast<ROMAEdge*>(e->second);
-                    const SUMOReal oldFlow = edge->getFlow(i->first);
-                    SUMOReal newFlow = oldFlow;
+                    const double oldFlow = edge->getFlow(i->first);
+                    double newFlow = oldFlow;
                     if (inner == 0 && outer == 0) {
                         newFlow += edge->getHelpFlow(i->first);
                     } else {
@@ -382,7 +379,7 @@ ROMAAssignments::sue(const int maxOuterIteration, const int maxInnerIteration, c
                         newFlow = 0.;
                     }
                     edge->setFlow(i->first, i->second, newFlow);
-                    const SUMOReal travelTime = capacityConstraintFunction(edge, newFlow / intervalLengthInHours);
+                    const double travelTime = capacityConstraintFunction(edge, newFlow / intervalLengthInHours);
                     edge->addTravelTime(travelTime, i->first, i->second);
                     edge->setHelpFlow(i->first, i->second, 0.);
                 }
@@ -425,22 +422,22 @@ ROMAAssignments::sue(const int maxOuterIteration, const int maxInnerIteration, c
 }
 
 
-SUMOReal
-ROMAAssignments::getPenalizedEffort(const ROEdge* const e, const ROVehicle* const v, SUMOReal t) {
-    const std::map<const ROEdge* const, SUMOReal>::const_iterator i = myPenalties.find(e);
+double
+ROMAAssignments::getPenalizedEffort(const ROEdge* const e, const ROVehicle* const v, double t) {
+    const std::map<const ROEdge* const, double>::const_iterator i = myPenalties.find(e);
     return i == myPenalties.end() ? e->getEffort(v, t) : e->getEffort(v, t) + i->second;
 }
 
 
-SUMOReal
-ROMAAssignments::getPenalizedTT(const ROEdge* const e, const ROVehicle* const v, SUMOReal t) {
-    const std::map<const ROEdge* const, SUMOReal>::const_iterator i = myPenalties.find(e);
+double
+ROMAAssignments::getPenalizedTT(const ROEdge* const e, const ROVehicle* const v, double t) {
+    const std::map<const ROEdge* const, double>::const_iterator i = myPenalties.find(e);
     return i == myPenalties.end() ? e->getTravelTime(v, t) : e->getTravelTime(v, t) + i->second;
 }
 
 
-SUMOReal
-ROMAAssignments::getTravelTime(const ROEdge* const e, const ROVehicle* const v, SUMOReal t) {
+double
+ROMAAssignments::getTravelTime(const ROEdge* const e, const ROVehicle* const v, double t) {
     return e->getTravelTime(v, t);
 }
 
