@@ -4,12 +4,12 @@
 /// @author  Laura Bieker
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Jan 2004
-/// @version $Id: ROMAEdgeBuilder.h 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id: ROMAEdgeBuilder.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Interface for building instances of duarouter-edges
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -57,12 +57,8 @@ class RONode;
 class ROMAEdgeBuilder : public ROAbstractEdgeBuilder {
 public:
     /** @brief Constructor
-     *
-     * @param[in] useBoundariesOnOverride Whether edges shall use a boundary value if the requested is beyond known time scale
-     * @param[in] interpolate Whether edges shall interpolate at interval boundaries
-     * @todo useBoundariesOnOverride should not be a member of the edges
      */
-    ROMAEdgeBuilder(bool useBoundariesOnOverride, bool interpolate);
+    ROMAEdgeBuilder();
 
 
     /// @brief Destructor
