@@ -5,7 +5,7 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: ROMARouteHandler.cpp 20653 2016-05-05 13:03:28Z behrisch $
+/// @version $Id: ROMARouteHandler.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Parser and container for routes during their loading
 /****************************************************************************/
@@ -36,10 +36,6 @@
 #include <od/ODMatrix.h>
 #include "ROMARouteHandler.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
