@@ -5,12 +5,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Wed, 12 Dez 2001
-/// @version $Id: MSBitSetLogic.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: MSBitSetLogic.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Container for holding a right-of-way matrix
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -47,7 +47,7 @@
  *
  * N is sum of the number of links of the junction's inLanes.
  */
-template< size_t N >
+template< int N >
 class MSBitSetLogic : public MSJunctionLogic {
 public:
     /** @brief Container that holds the right of way bitsets.
@@ -65,7 +65,7 @@ public:
 
 public:
     /// Use this constructor only.
-    MSBitSetLogic(unsigned int nLinks,
+    MSBitSetLogic(int nLinks,
                   Logic* logic,
                   Foes* foes,
                   std::bitset<SUMO_MAX_CONNECTIONS> conts)
@@ -81,16 +81,16 @@ public:
 
 
     /// @brief Returns the response for the given link
-    const MSLogicJunction::LinkBits& getResponseFor(unsigned int linkIndex) const {
+    const MSLogicJunction::LinkBits& getResponseFor(int linkIndex) const {
         return (*myLogic)[linkIndex];
     }
 
     /// @brief Returns the foes for the given link
-    const MSLogicJunction::LinkBits& getFoesFor(unsigned int linkIndex) const {
+    const MSLogicJunction::LinkBits& getFoesFor(int linkIndex) const {
         return (*myInternalLinksFoes)[linkIndex];
     }
 
-    bool getIsCont(unsigned int linkIndex) const {
+    bool getIsCont(int linkIndex) const {
         return myConts.test(linkIndex);
     }
 
