@@ -6,12 +6,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Mon, 12 Mar 2001
-/// @version $Id: MSEdge.h 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: MSEdge.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // A road/street connecting two junctions
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -206,14 +206,14 @@ public:
      *
      * @return This edge's persons sorted by pos
      */
-    std::vector<MSTransportable*> getSortedPersons(SUMOTime timestep) const;
+    std::vector<MSTransportable*> getSortedPersons(SUMOTime timestep, bool includeRiding = false) const;
 
 
     /** @brief Returns this edge's containers sorted by pos
      *
      * @return This edge's containers sorted by pos
      */
-    std::vector<MSTransportable*> getSortedContainers(SUMOTime timestep) const;
+    std::vector<MSTransportable*> getSortedContainers(SUMOTime timestep, bool includeRiding = false) const;
 
     /** @brief Get the allowed lanes to reach the destination-edge.
      *
@@ -265,6 +265,10 @@ public:
         return myFunction == EDGEFUNCTION_WALKINGAREA;
     }
 
+    inline bool isTaz() const {
+        return myFunction == EDGEFUNCTION_DISTRICT;
+    }
+
     /** @brief Returns the numerical id of the edge
      * @return This edge's numerical id
      */
@@ -322,25 +326,11 @@ public:
     }
 
 
-    /** @brief Returns the list of edges from which this edge may be reached
-     * @return Edges from which this edge may be reached
-     */
-    const MSEdgeVector& getIncomingEdges() const {
-        return myPredecessors;
-    }
-
-    /** @brief Returns the list of edges that may be reached from this edge
-     * @return Edges that may be reached from this edge
-     */
-    const std::vector<MSEdge*>& getOutgoingEdges() const {
-        return mySuccessors;
-    }
-
     /** @brief Returns the number of edges that may be reached from this edge
      * @return The number of following edges
      */
-    unsigned int getNumSuccessors() const {
-        return (unsigned int) mySuccessors.size();
+    int getNumSuccessors() const {
+        return (int) mySuccessors.size();
     }
 
 
@@ -362,14 +352,13 @@ public:
      *
      * @return The number of edges following this edge
      */
-    unsigned int getNumPredecessors() const {
-        return (unsigned int) myPredecessors.size();
+    int getNumPredecessors() const {
+        return (int) myPredecessors.size();
     }
 
 
-    /** @brief Returns the edge at the given position from the list of reachable edges
-     * @param[in] pos The position of the list within the list of approached
-     * @return The following edge, stored at position pos
+    /** @brief
+     * @return
      */
     const MSEdgeVector& getPredecessors() const {
         return myPredecessors;
@@ -437,12 +426,14 @@ public:
      * @param[in] minSpeed The minimumSpeed to assume if traffic on this edge is stopped
      * @return The current effort (travel time) to pass the edge
      */
-    SUMOReal getCurrentTravelTime(const SUMOReal minSpeed = NUMERICAL_EPS) const;
+    double getCurrentTravelTime(const double minSpeed = NUMERICAL_EPS) const;
 
 
     /// @brief returns the minimum travel time for the given vehicle
-    inline SUMOReal getMinimumTravelTime(const SUMOVehicle* const veh) const {
-        if (veh != 0) {
+    inline double getMinimumTravelTime(const SUMOVehicle* const veh) const {
+        if (myFunction == EDGEFUNCTION_DISTRICT) {
+            return 0;
+        } else if (veh != 0) {
             return getLength() / getVehicleMaxSpeed(veh);
         } else {
             return getLength() / getSpeedLimit();
@@ -457,13 +448,13 @@ public:
      * @param[in] time The time for which the travel time shall be returned [s]
      * @return The traveltime needed by the given vehicle to pass the edge at the given time
      */
-    static inline SUMOReal getTravelTimeStatic(const MSEdge* const edge, const SUMOVehicle* const veh, SUMOReal time) {
+    static inline double getTravelTimeStatic(const MSEdge* const edge, const SUMOVehicle* const veh, double time) {
         return MSNet::getInstance()->getTravelTime(edge, veh, time);
     }
 
     /** @brief Returns the averaged speed used by the routing device
      */
-    SUMOReal getRoutingSpeed() const;
+    double getRoutingSpeed() const;
 
 
     /// @name Methods releated to vehicle insertion
@@ -481,17 +472,24 @@ public:
      *
      * @param[in] v The vehicle to insert
      * @param[in] time The current simulation time
-     * @param[in] checkOnly whether we perform only the check without actually inserting
+     * @param[in] checkOnly Whether we perform only the check without actually inserting
+     * @param[in] forceCheck Whether the full insertion check should be run for each pending vehicle
+     *            or whether insertion on lanes for which an insertion has already a failed should be ignored
+     *            in the current time step.
      * @return Whether the vehicle could be inserted
      * @see MSLane::insertVehicle
      */
-    bool insertVehicle(SUMOVehicle& v, SUMOTime time, const bool checkOnly = false) const;
+    bool insertVehicle(SUMOVehicle& v, SUMOTime time, const bool checkOnly = false, const bool forceCheck = false) const;
 
 
     /** @brief Finds the emptiest lane allowing the vehicle class
      *
-     * The emptiest lane is the one with the fewest vehicles on.
-     *  If there is more than one, the first according to its
+     * The emptiest lane is the one which vehicle insertion is most likely to succeed.
+     *
+     * If there are no vehicles before departPos, then the lane with the largest
+     * gap between departPos and the last vehicle is
+     * Otheriwise the lane with lowes occupancy is selected
+     * If there is more than one, the first according to its
      *  index in the lane container is chosen.
      *
      * If allowed==0, the lanes allowed for the given vehicle class
@@ -499,10 +497,11 @@ public:
      *
      * @param[in] allowed The lanes to choose from
      * @param[in] vclass The vehicle class to look for
+     * @param[in] departPos An upper bound on vehicle depart position
      * @return the least occupied lane
      * @see allowedLanes
      */
-    MSLane* getFreeLane(const std::vector<MSLane*>* allowed, const SUMOVehicleClass vclass) const;
+    MSLane* getFreeLane(const std::vector<MSLane*>* allowed, const SUMOVehicleClass vclass, double departPos) const;
 
 
     /** @brief Finds a depart lane for the given vehicle parameters
@@ -539,10 +538,12 @@ public:
     virtual void changeLanes(SUMOTime t);
 
 
-#ifdef HAVE_INTERNAL_LANES
     /// @todo extension: inner junctions are not filled
     const MSEdge* getInternalFollowingEdge(const MSEdge* followerAfterInternal) const;
-#endif
+
+
+    /// @brief returns the length of all internal edges on the junction until reaching the non-internal edge followerAfterInternal.
+    double getInternalFollowingLengthTo(const MSEdge* followerAfterInternal) const;
 
     /// @brief Returns whether the vehicle (class) is not allowed on the edge
     inline bool prohibits(const SUMOVehicle* const vehicle) const {
@@ -560,12 +561,12 @@ public:
     /** @brief Returns the edges's width (sum over all lanes)
      * @return This edges's width
      */
-    SUMOReal getWidth() const {
+    double getWidth() const {
         return myWidth;
     }
 
     /// @brief Returns the right side offsets of this edge's sublanes
-    const std::vector<SUMOReal> getSubLaneSides() const {
+    const std::vector<double> getSubLaneSides() const {
         return mySublaneSides;
     }
 
@@ -576,13 +577,13 @@ public:
      * @param[in] other The edge to which the distance shall be returned
      * @return The distance to the other edge
      */
-    SUMOReal getDistanceTo(const MSEdge* other) const;
+    double getDistanceTo(const MSEdge* other) const;
 
 
     /** @brief return the length of the edge
      * @return The edge's length
      */
-    inline SUMOReal getLength() const {
+    inline double getLength() const {
         return myLength;
     }
 
@@ -591,19 +592,22 @@ public:
      * @caution The speed limit of the first lane is retured; should probably be the fastest edge
      * @return The maximum speed allowed on this edge
      */
-    SUMOReal getSpeedLimit() const;
+    double getSpeedLimit() const;
+
+    /// @brief return shape.length() / myLength
+    double getLengthGeometryFactor() const;
 
     /** @brief Sets a new maximum speed for all lanes (used by TraCI and MSCalibrator)
      * @param[in] val the new speed in m/s
      */
-    void setMaxSpeed(SUMOReal val) const;
+    void setMaxSpeed(double val) const;
 
     /** @brief Returns the maximum speed the vehicle may use on this edge
      *
      * @caution Only the first lane is considered
      * @return The maximum velocity on this edge for the given vehicle
      */
-    SUMOReal getVehicleMaxSpeed(const SUMOVehicle* const veh) const;
+    double getVehicleMaxSpeed(const SUMOVehicle* const veh) const;
 
     virtual void addPerson(MSTransportable* p) const {
         myPersons.insert(p);
@@ -649,7 +653,10 @@ public:
     bool canChangeToOpposite();
 
     /// @brief get the mean speed
-    SUMOReal getMeanSpeed() const;
+    double getMeanSpeed() const;
+
+    /// @brief whether any lane has a minor link
+    bool hasMinorLink() const;
 
     /// @brief grant exclusive access to the mesoscopic state
     virtual void lock() const {}
@@ -666,7 +673,7 @@ public:
     static MSEdge* dictionary(const std::string& id);
 
     /// @brief Returns the number of edges
-    static size_t dictSize();
+    static int dictSize();
 
     /// @brief Returns all edges with a numerical id
     static const MSEdgeVector& getAllEdges();
@@ -752,6 +759,9 @@ protected:
     const std::vector<MSLane*>* getAllowedLanesWithDefault(const AllowedLanesCont& c, const MSEdge* dest) const;
 
 
+    /// @brief return upper bound for the depart position on this edge
+    double getDepartPosBound(const MSVehicle& veh, bool upper = true) const;
+
 protected:
     /// @brief This edge's numerical id
     const int myNumericalID;
@@ -771,6 +781,11 @@ protected:
     /// @brief The time of last insertion failure
     mutable SUMOTime myLastFailedInsertionTime;
 
+    /// @brief A cache for the rejected insertion attempts. Used to assure that no
+    ///        further insertion attempts are made on a lane where an attempt has
+    ///        already failed in the current time step if MSInsertionControl::myEagerInsertionCheck is off.
+    mutable std::set<int> myFailedInsertionMemory;
+
     /// @brief The crossed edges id for a crossing edge. On not crossing edges it is empty
     std::vector<std::string> myCrossingEdges;
 
@@ -816,13 +831,13 @@ protected:
     const int myPriority;
 
     /// Edge width [m]
-    SUMOReal myWidth;
+    double myWidth;
 
     /// @brief the length of the edge (cached value for speedup)
-    SUMOReal myLength;
+    double myLength;
 
     /// @brief the traveltime on the empty edge (cached value for speedup)
-    SUMOReal myEmptyTraveltime;
+    double myEmptyTraveltime;
 
     /// @brief whether this edge had a vehicle with less than max speed on it
     mutable bool myAmDelayed;
@@ -831,7 +846,7 @@ protected:
     bool myAmRoundabout;
 
     /// @brief the right side for each sublane on this edge
-    std::vector<SUMOReal> mySublaneSides;
+    std::vector<double> mySublaneSides;
 
     /// @name Static edge container
     /// @{
