@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Matthias Heppner
 /// @date    Mon, 12 Mar 2001
-/// @version $Id: MSEventControl.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSEventControl.cpp 24010 2017-04-21 17:00:09Z behrisch $
 ///
 // Stores time-dependant events and executes them at the proper time
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -38,10 +38,6 @@
 #include <utils/common/Command.h>
 #include "MSNet.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // member definitions
@@ -52,7 +48,7 @@ MSEventControl::MSEventControl()
 
 MSEventControl::~MSEventControl() {
     // delete the events
-    while (! myEvents.empty()) {
+    while (!myEvents.empty()) {
         Event e = myEvents.top();
         delete e.first;
         myEvents.pop();
@@ -60,26 +56,21 @@ MSEventControl::~MSEventControl() {
 }
 
 
-SUMOTime
-MSEventControl::addEvent(Command* operation,
-                         SUMOTime execTimeStep,
-                         AdaptType type) {
-    SUMOTime currTimeStep = getCurrentTimeStep();
-    if (type == ADAPT_AFTER_EXECUTION && execTimeStep <= currTimeStep) {
-        execTimeStep = currTimeStep;
-    }
-    Event newEvent = Event(operation, execTimeStep);
-    myEvents.push(newEvent);
-    return execTimeStep;
+void
+MSEventControl::addEvent(Command* operation, SUMOTime execTimeStep) {
+    myEvents.push(Event(operation, execTimeStep));
 }
 
 
 void
 MSEventControl::execute(SUMOTime execTime) {
     // Execute all events that are scheduled for execTime.
-    for (; !myEvents.empty();) {
+    while (!myEvents.empty()) {
         Event currEvent = myEvents.top();
-        if (currEvent.second == execTime || currEvent.second < execTime + DELTA_T) {
+        if (currEvent.second < 0) {
+            currEvent.second = execTime;
+        }
+        if (currEvent.second < execTime + DELTA_T) {
             Command* command = currEvent.first;
             myEvents.pop();
             SUMOTime time = 0;
@@ -102,14 +93,7 @@ MSEventControl::execute(SUMOTime execTime) {
                 myEvents.push(currEvent);
             }
         } else {
-            if (currEvent.second < execTime) {
-                // !!! more verbose information
-                WRITE_WARNING("Could not execute scheduled event.");
-                delete currEvent.first;
-                myEvents.pop();
-            } else {
-                break;
-            }
+            break;
         }
     }
 }
