@@ -8,12 +8,12 @@
 /// @author  Mario Krumnow
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: MSFrame.cpp 21076 2016-07-01 09:22:07Z namdre $
+/// @version $Id: MSFrame.cpp 23898 2017-04-10 11:10:21Z behrisch $
 ///
 // Sets and checks options for microsim; inits global outputs and settings
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -53,14 +53,11 @@
 #include <microsim/lcmodels/MSAbstractLaneChangeModel.h>
 #include <microsim/devices/MSDevice.h>
 #include <microsim/devices/MSDevice_Vehroutes.h>
+#include <microsim/output/MSStopOut.h>
 #include <utils/common/RandHelper.h>
 #include "MSFrame.h"
 #include <utils/common/SystemFrame.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -108,6 +105,8 @@ MSFrame::fillOptions() {
     oc.addDescription("load-state", "Input", "Loads a network state from FILE");
     oc.doRegister("load-state.offset", new Option_String("0", "TIME"));//!!! check, describe
     oc.addDescription("load-state.offset", "Input", "Shifts all times loaded from a saved state by the given offset");
+    oc.doRegister("load-state.remove-vehicles", new Option_String(""));
+    oc.addDescription("load-state.remove-vehicles", "Input", "Removes vehicles with the given IDs from the loaded state");
 
     //  register output options
     oc.doRegister("netstate-dump", new Option_FileName());
@@ -120,7 +119,7 @@ MSFrame::fillOptions() {
     oc.addSynonyme("netstate-dump.empty-edges", "netstate-output.empty-edges");
     oc.addSynonyme("netstate-dump.empty-edges", "dump-empty-edges", true);
     oc.addDescription("netstate-dump.empty-edges", "Output", "Write also empty edges completely when dumping");
-    oc.doRegister("netstate-dump.precision", new Option_Integer(OUTPUT_ACCURACY));
+    oc.doRegister("netstate-dump.precision", new Option_Integer(2));
     oc.addSynonyme("netstate-dump.precision", "netstate.precision");
     oc.addSynonyme("netstate-dump.precision", "netstate-output.precision");
     oc.addSynonyme("netstate-dump.precision", "dump-precision", true);
@@ -129,14 +128,17 @@ MSFrame::fillOptions() {
 
     oc.doRegister("emission-output", new Option_FileName());
     oc.addDescription("emission-output", "Output", "Save the emission values of each vehicle");
-    oc.doRegister("emission-output.precision", new Option_Integer(OUTPUT_ACCURACY));
+    oc.doRegister("emission-output.precision", new Option_Integer(2));
     oc.addDescription("emission-output.precision", "Output", "Write emission values with the given precision (default 2)");
 
     oc.doRegister("battery-output", new Option_FileName());
     oc.addDescription("battery-output", "Output", "Save the battery values of each vehicle");
-    oc.doRegister("battery-output.precision", new Option_Integer(OUTPUT_ACCURACY));
+    oc.doRegister("battery-output.precision", new Option_Integer(2));
     oc.addDescription("battery-output.precision", "Output", "Write battery values with the given precision (default 2)");
 
+    oc.doRegister("chargingstations-output", new Option_FileName());
+    oc.addDescription("chargingstations-output", "Output", "Write data of charging stations");
+
     oc.doRegister("fcd-output", new Option_FileName());
     oc.addDescription("fcd-output", "Output", "Save the Floating Car Data");
     oc.doRegister("fcd-output.geo", new Option_Bool(false));
@@ -204,6 +206,9 @@ MSFrame::fillOptions() {
     oc.doRegister("lanechange-output", new Option_FileName());
     oc.addDescription("lanechange-output", "Output", "Record lane changes and their motivations for all vehicles into FILE");
 
+    oc.doRegister("stop-output", new Option_FileName());
+    oc.addDescription("stop-output", "Output", "Record stops and loading/unloading of passenger and containers for all vehicles into FILE");
+
 #ifdef _DEBUG
     oc.doRegister("movereminder-output", new Option_FileName());
     oc.addDescription("movereminder-output", "Output", "Save movereminder states of selected vehicles into FILE");
@@ -211,11 +216,15 @@ MSFrame::fillOptions() {
     oc.addDescription("movereminder-output.vehicles", "Output", "List of vehicle ids which shall save their movereminder states");
 #endif
 
-    oc.doRegister("save-state.times", new Option_IntVector(IntVector()));//!!! check, describe
+    oc.doRegister("save-state.times", new Option_IntVector(IntVector()));
     oc.addDescription("save-state.times", "Output", "Use INT[] as times at which a network state written");
-    oc.doRegister("save-state.prefix", new Option_FileName("state"));//!!! check, describe
+    oc.doRegister("save-state.period", new Option_String("-1", "TIME"));
+    oc.addDescription("save-state.period", "Output", "save state repeatedly after TIME period");
+    oc.doRegister("save-state.prefix", new Option_FileName("state"));
     oc.addDescription("save-state.prefix", "Output", "Prefix for network states");
-    oc.doRegister("save-state.files", new Option_FileName());//!!! check, describe
+    oc.doRegister("save-state.suffix", new Option_FileName(".sbx"));
+    oc.addDescription("save-state.suffix", "Output", "Suffix for network states (.sbx or .xml)");
+    oc.doRegister("save-state.files", new Option_FileName());//
     oc.addDescription("save-state.files", "Output", "Files for network states");
 
     // register the simulation settings
@@ -228,6 +237,9 @@ MSFrame::fillOptions() {
     oc.doRegister("step-length", new Option_String("1", "TIME"));
     oc.addDescription("step-length", "Time", "Defines the step duration in seconds");
 
+    oc.doRegister("step-method.ballistic", new Option_Bool(false));
+    oc.addDescription("step-method.ballistic", "Processing", "Whether to use ballistic method for the positional update of vehicles (default is a semi-implicit Euler method).");
+
     oc.doRegister("lateral-resolution", new Option_Float(-1));
     oc.addDescription("lateral-resolution", "Processing", "Defines the resolution in m when handling lateral positioning within a lane (with -1 all vehicles drive at the center of their lane");
 
@@ -235,13 +247,11 @@ MSFrame::fillOptions() {
     oc.doRegister("route-steps", 's', new Option_String("200", "TIME"));
     oc.addDescription("route-steps", "Processing", "Load routes for the next number of seconds ahead");
 
-#ifdef HAVE_INTERNAL_LANES
     oc.doRegister("no-internal-links", new Option_Bool(false));
     oc.addDescription("no-internal-links", "Processing", "Disable (junction) internal links");
 
     oc.doRegister("ignore-junction-blocker", new Option_String("-1", "TIME"));
     oc.addDescription("ignore-junction-blocker", "Processing", "Ignore vehicles which block the junction after they have been standing for SECONDS (-1 means never ignore)");
-#endif
 
     oc.doRegister("ignore-route-errors", new Option_Bool(false));
     oc.addDescription("ignore-route-errors", "Processing", "Do not check whether routes are connected");
@@ -252,13 +262,19 @@ MSFrame::fillOptions() {
     oc.doRegister("collision.action", new Option_String("teleport"));
     oc.addDescription("collision.action", "Processing", "How to deal with collisions: [none,warn,teleport,remove]");
 
+    oc.doRegister("collision.stoptime", new Option_String("0", "TIME"));
+    oc.addDescription("collision.stoptime", "Processing", "Let vehicle stop for TIME before performing collision.action (except for action 'none')");
+
     oc.doRegister("collision.check-junctions", new Option_Bool(false));
     oc.addDescription("collision.check-junctions", "Processing", "Enables collisions checks on junctions");
 
     oc.doRegister("max-num-vehicles", new Option_Integer(-1));
     oc.addDescription("max-num-vehicles", "Processing", "Delay vehicle insertion to stay within the given maximum number");
 
-    oc.doRegister("scale", new Option_Float());
+    oc.doRegister("max-num-teleports", new Option_Integer(-1));
+    oc.addDescription("max-num-teleports", "Processing", "Abort the simulation if the given maximum number of teleports is exceeded");
+
+    oc.doRegister("scale", new Option_Float(1.));
     oc.addDescription("scale", "Processing", "Scale demand by the given factor (by discarding or duplicating vehicles)");
 
     oc.doRegister("time-to-teleport", new Option_String("300", "TIME"));
@@ -282,9 +298,6 @@ MSFrame::fillOptions() {
     oc.doRegister("random-depart-offset", new Option_String("0", "TIME"));
     oc.addDescription("random-depart-offset", "Processing", "Each vehicle receives a random offset to its depart value drawn uniformly from [0, TIME]");
 
-    oc.doRegister("lanechange.allow-swap", new Option_Bool(false));
-    oc.addDescription("lanechange.allow-swap", "Processing", "Whether blocking vehicles trying to change lanes may be swapped");
-
     oc.doRegister("lanechange.duration", new Option_String("0", "TIME"));
     oc.addDescription("lanechange.duration", "Processing", "Duration of a lane change maneuver (default 0)");
 
@@ -294,6 +307,10 @@ MSFrame::fillOptions() {
     oc.doRegister("tls.all-off", new Option_Bool(false));
     oc.addDescription("tls.all-off", "Processing", "Switches off all traffic lights.");
 
+    oc.doRegister("time-to-impatience", new Option_String("300", "TIME"));
+    oc.addDescription("time-to-impatience", "Processing", "Specify how long a vehicle may wait until impatience grows from 0 to 1, defaults to 300, non-positive values disable impatience growth");
+
+
     // pedestrian model
     oc.doRegister("pedestrian.model", new Option_String("striping"));
     oc.addDescription("pedestrian.model", "Processing", "Select among pedestrian models ['nonInteracting', 'striping']");
@@ -355,7 +372,7 @@ MSFrame::fillOptions() {
     oc.addDescription("meso-tauff", "Mesoscopic", "Factor for calculating the net free-free headway time");
     oc.doRegister("meso-taufj", new Option_String("1.13", "TIME"));
     oc.addDescription("meso-taufj", "Mesoscopic", "Factor for calculating the net free-jam headway time");
-    oc.doRegister("meso-taujf", new Option_String("2", "TIME"));
+    oc.doRegister("meso-taujf", new Option_String("1.73", "TIME"));
     oc.addDescription("meso-taujf", "Mesoscopic", "Factor for calculating the jam-free headway time");
     oc.doRegister("meso-taujj", new Option_String("1.4", "TIME"));
     oc.addDescription("meso-taujj", "Mesoscopic", "Factor for calculating the jam-jam headway time");
@@ -372,6 +389,9 @@ MSFrame::fillOptions() {
     oc.doRegister("meso-tls-penalty", new Option_Float(0));
     oc.addDescription("meso-tls-penalty", "Mesoscopic",
                       "Apply scaled time penalties when driving across tls controlled junctions based on green split instead of checking actual phases");
+    oc.doRegister("meso-minor-penalty", new Option_String("0", "TIME"));
+    oc.addDescription("meso-minor-penalty", "Mesoscopic",
+                      "Apply fixed time penalty when driving across a minor link. When using --meso-junction-control.limited, the penalty is not applied whenever limited control is active.");
     oc.doRegister("meso-overtaking", new Option_Bool(false));
     oc.addDescription("meso-overtaking", "Mesoscopic", "Enable mesoscopic overtaking");
     oc.doRegister("meso-recheck", new Option_String("0", "TIME"));
@@ -401,6 +421,12 @@ MSFrame::fillOptions() {
     oc.doRegister("disable-textures", 'T', new Option_Bool(false));
     oc.addDescription("disable-textures", "GUI Only", "Do not load background pictures");
 
+    oc.doRegister("window-size", new Option_String());
+    oc.addDescription("window-size", "GUI Only", "Create initial window with the given x,y size");
+
+    oc.doRegister("window-pos", new Option_String());
+    oc.addDescription("window-pos", "GUI Only", "Create initial window at the given x,y position");
+
 #ifdef HAVE_OSG
     oc.doRegister("osg-view", new Option_Bool(false));
     oc.addDescription("osg-view", "GUI Only", "Start with an OpenSceneGraph view instead of the regular 2D view");
@@ -420,6 +446,7 @@ MSFrame::buildStreams() {
     OutputDevice::createDeviceByOption("fcd-output", "fcd-export", "fcd_file.xsd");
     OutputDevice::createDeviceByOption("emission-output", "emission-export", "emission_file.xsd");
     OutputDevice::createDeviceByOption("battery-output", "battery-export");
+    OutputDevice::createDeviceByOption("chargingstations-output", "chargingstations-export");
     OutputDevice::createDeviceByOption("full-output", "full-export", "full_file.xsd");
     OutputDevice::createDeviceByOption("queue-output", "queue-export", "queue_file.xsd");
     OutputDevice::createDeviceByOption("amitran-output", "trajectories", "amitran/trajectories.xsd\" timeStepSize=\"" + toString(STEPS2MS(DELTA_T)));
@@ -428,12 +455,14 @@ MSFrame::buildStreams() {
     OutputDevice::createDeviceByOption("link-output", "link-output");
     OutputDevice::createDeviceByOption("bt-output", "bt-output");
     OutputDevice::createDeviceByOption("lanechange-output", "lanechanges");
+    OutputDevice::createDeviceByOption("stop-output", "stops", "stopinfo_file.xsd");
 
 #ifdef _DEBUG
     OutputDevice::createDeviceByOption("movereminder-output", "movereminder-output");
 #endif
 
     MSDevice_Vehroutes::init();
+    MSStopOut::init();
 }
 
 
@@ -445,11 +474,9 @@ MSFrame::checkOptions() {
         WRITE_ERROR("No network file (-n) specified.");
         ok = false;
     }
-    if (!oc.isDefault("scale")) {
-        if (oc.getFloat("scale") < 0.) {
-            WRITE_ERROR("Invalid scaling factor.");
-            ok = false;
-        }
+    if (oc.getFloat("scale") < 0.) {
+        WRITE_ERROR("Invalid scaling factor.");
+        ok = false;
     }
     if (oc.getBool("vehroute-output.exit-times") && !oc.isSet("vehroute-output")) {
         WRITE_ERROR("A vehroute-output file is needed for exit times.");
@@ -498,16 +525,28 @@ MSFrame::checkOptions() {
     if (string2time(oc.getString("lanechange.duration")) > 0 && oc.getFloat("lateral-resolution") > 0) {
         WRITE_ERROR("Only one of the options 'lanechange.duration' or 'lateral-resolution' may be given.");
     }
-    if (oc.getBool("lanechange.allow-swap")) {
-        WRITE_WARNING("The option 'lanechange.allow-swap' is deprecated, and will not be supported in future versions of SUMO.");
-    }
     if (oc.getBool("ignore-accidents")) {
         WRITE_WARNING("The option 'ignore-accidents' is deprecated. Use 'collision.action none' instead.");
     }
     if (oc.getBool("duration-log.statistics") && oc.isDefault("verbose")) {
         oc.set("verbose", "true");
     }
+    if (oc.isDefault("precision") && string2time(oc.getString("step-length")) < 10) {
+        oc.set("precision", "3");
+    }
+    if (oc.getInt("precision") > 2) {
+        if (oc.isDefault("netstate-dump.precision")) {
+            oc.set("netstate-dump.precision", toString(oc.getInt("precision")));
+        }
+        if (oc.isDefault("emission-output.precision")) {
+            oc.set("emission-output.precision", toString(oc.getInt("precision")));
+        }
+        if (oc.isDefault("battery-output.precision")) {
+            oc.set("battery-output.precision", toString(oc.getInt("precision")));
+        }
+    }
     ok &= MSDevice::checkOptions(oc);
+    ok &= SystemFrame::checkOptions();
     return ok;
 }
 
@@ -517,17 +556,13 @@ MSFrame::setMSGlobals(OptionsCont& oc) {
     // pre-initialise the network
     // set whether empty edges shall be printed on dump
     MSGlobals::gOmitEmptyEdgesOnDump = !oc.getBool("netstate-dump.empty-edges");
-#ifdef HAVE_INTERNAL_LANES
     // set whether internal lanes shall be used
     MSGlobals::gUsingInternalLanes = !oc.getBool("no-internal-links");
     MSGlobals::gIgnoreJunctionBlocker = string2time(oc.getString("ignore-junction-blocker")) < 0 ?
                                         std::numeric_limits<SUMOTime>::max() : string2time(oc.getString("ignore-junction-blocker"));
-#else
-    MSGlobals::gUsingInternalLanes = false;
-    MSGlobals::gIgnoreJunctionBlocker = 0;
-#endif
     // set the grid lock time
     MSGlobals::gTimeToGridlock = string2time(oc.getString("time-to-teleport")) < 0 ? 0 : string2time(oc.getString("time-to-teleport"));
+    MSGlobals::gTimeToImpatience = string2time(oc.getString("time-to-impatience"));
     MSGlobals::gTimeToGridlockHighways = string2time(oc.getString("time-to-teleport.highways")) < 0 ? 0 : string2time(oc.getString("time-to-teleport.highways"));
     MSGlobals::gCheck4Accidents = !oc.getBool("ignore-accidents");
     MSGlobals::gCheckRoutes = !oc.getBool("ignore-route-errors");
@@ -538,6 +573,8 @@ MSFrame::setMSGlobals(OptionsCont& oc) {
     MSGlobals::gMesoLimitedJunctionControl = oc.getBool("meso-junction-control.limited");
     MSGlobals::gMesoOvertaking = oc.getBool("meso-overtaking");
     MSGlobals::gMesoTLSPenalty = oc.getFloat("meso-tls-penalty");
+    MSGlobals::gMesoMinorPenalty = string2time(oc.getString("meso-minor-penalty"));
+    MSGlobals::gSemiImplicitEulerUpdate = !oc.getBool("step-method.ballistic");
     if (MSGlobals::gUseMesoSim) {
         MSGlobals::gUsingInternalLanes = false;
     }
@@ -545,7 +582,6 @@ MSFrame::setMSGlobals(OptionsCont& oc) {
     MSAbstractLaneChangeModel::initGlobalOptions(oc);
     MSLane::initCollisionOptions(oc);
 
-
     DELTA_T = string2time(oc.getString("step-length"));
 #ifdef _DEBUG
     if (oc.isSet("movereminder-output")) {
