@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    late summer 2003
-/// @version $Id: MSGlobals.h 20550 2016-04-26 10:57:45Z namdre $
+/// @version $Id: MSGlobals.h 23379 2017-03-14 13:02:11Z namdre $
 ///
 // Some static variables for faster access
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2003-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2003-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -58,6 +58,10 @@ public:
     /// Information whether empty edges shall be written on dump
     static bool gOmitEmptyEdgesOnDump;
 
+    /* Allows switching between time step integration methods
+     * "Semi-Implicit Euler" (default) and the ballistic update rule. */
+    static bool gSemiImplicitEulerUpdate;
+
     /** Information how long the simulation shall wait until it recognizes
         a vehicle as a grid lock participant */
     static SUMOTime gTimeToGridlock;
@@ -65,10 +69,14 @@ public:
     /** The time to detect grid locks on highways */
     static SUMOTime gTimeToGridlockHighways;
 
+    /** Information how long a vehicle must wait for impatience to grow from 0 to 1 */
+    static SUMOTime gTimeToImpatience;
+
     /// Information whether the simulation regards internal lanes
     static bool gUsingInternalLanes;
 
-    /// Information whether the simulation regards internal lanes
+    /** Vehicles on internal lanes (even partially) with a waiting time that exceeds this threshold
+     * no longer block cross-traffic on the junction */
     static SUMOTime gIgnoreJunctionBlocker;
 
     /** information whether the network shall check for collisions */
@@ -81,7 +89,7 @@ public:
     static SUMOTime gLaneChangeDuration;
 
     /** Lateral resolution within a lane */
-    static SUMOReal gLateralResolution;
+    static double gLateralResolution;
 
     /// Information whether a state has been loaded
     static bool gStateLoaded;
@@ -96,7 +104,10 @@ public:
     static bool gMesoOvertaking;
 
     /** scaling factor for macroscopic time penalty when passing tls controlled intersection */
-    static SUMOReal gMesoTLSPenalty;
+    static double gMesoTLSPenalty;
+
+    /** penalty time for passing a minor link */
+    static SUMOTime gMesoMinorPenalty;
 
     /// mesoscopic simulation infrastructure
     static MELoop* gMesoNet;
