@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Mon, 12 Mar 2001
-/// @version $Id: MSInsertionControl.h 20626 2016-05-03 12:49:04Z namdre $
+/// @version $Id: MSInsertionControl.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Inserts vehicles into the network when their departure time is reached
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -62,7 +62,7 @@ class MSVehicleControl;
  *
  * Vehicles are not controlled (created, deleted) by this class.
  *
- * @todo Whe a vehicle is deleted due to waiting too long or because of vaporizing, ths is not reported anywhere
+ * @todo When a vehicle is deleted due to waiting too long or because of vaporizing, this is not reported anywhere
  */
 class MSInsertionControl {
 public:
@@ -96,7 +96,7 @@ public:
      * @param[in] time The current simulation time
      * @return The number of vehicles that could be inserted into the net
      */
-    unsigned int emitVehicles(SUMOTime time);
+    int emitVehicles(SUMOTime time);
 
 
     /** @brief Adds a single vehicle for departure
@@ -123,7 +123,7 @@ public:
      *
      * @return The number of vehicles that could not (yet) be inserted into the net
      */
-    unsigned int getWaitingVehicleNo() const;
+    int getWaitingVehicleNo() const;
 
 
     /** @brief Returns the number of flows that are still active
@@ -149,6 +149,8 @@ public:
      */
     void determineCandidates(SUMOTime time);
 
+    /// @brief return the number of pending emits for the given lane
+    int getPendingEmits(const MSLane* lane);
 
 private:
     /** @brief Tries to emit the vehicle
@@ -165,15 +167,8 @@ private:
      * @param[in] refusedEmits Container to insert vehicles that could not be emitted into
      * @return The number of emitted vehicles (0 or 1)
      */
-    unsigned int tryInsert(SUMOTime time, SUMOVehicle* veh,
-                           MSVehicleContainer::VehicleVector& refusedEmits);
-
-
-    /** @brief Checks whether any flow is blocked due to this vehicle and clears the block
-     *
-     * @param[in] veh The vehicle to check for
-     */
-    void checkFlowWait(SUMOVehicle* veh);
+    int tryInsert(SUMOTime time, SUMOVehicle* veh,
+                  MSVehicleContainer::VehicleVector& refusedEmits);
 
 
     /** @brief Adds all vehicles that should have been emitted earlier to the refuse container
@@ -206,12 +201,8 @@ private:
     struct Flow {
         /// @brief The paramters
         SUMOVehicleParameter* pars;
-        /// @brief whether it has route or vehicle type distribution
-        bool isVolatile;
-        /// @brief The last created vehicle
-        SUMOVehicle* vehicle;
         /// @brief the running index
-        unsigned int index;
+        int index;
     };
 
     /// @brief Container for periodical vehicle parameters
@@ -224,11 +215,17 @@ private:
     SUMOTime myMaxDepartDelay;
 
     /// @brief Whether an edge on which a vehicle could not depart should be ignored in the same step
-    bool myCheckEdgesOnce;
+    bool myEagerInsertionCheck;
 
     /// @brief Storage for maximum vehicle number
     int myMaxVehicleNumber;
 
+    /// @brief Last time at which pending emits for each edge where counted
+    SUMOTime myPendingEmitsUpdateTime;
+
+    /// @brief the number of pending emits for each edge in the current time step
+    std::map<const MSLane*, int> myPendingEmitsForLane;
+
 
 private:
     /// @brief Invalidated copy constructor.
