@@ -8,12 +8,12 @@
 /// @author  Michael Behrisch
 /// @author  Mario Krumnow
 /// @date    Mon, 12 Mar 2001
-/// @version $Id: MSLane.h 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: MSLane.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // Representation of a lane in the micro simulation
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -92,9 +92,9 @@ public:
 
     /** Function-object in order to find the vehicle, that has just
         passed the detector. */
-    struct VehPosition : public std::binary_function < const MSVehicle*, SUMOReal, bool > {
+    struct VehPosition : public std::binary_function < const MSVehicle*, double, bool > {
         /// compares vehicle position to the detector position
-        bool operator()(const MSVehicle* cmp, SUMOReal pos) const;
+        bool operator()(const MSVehicle* cmp, double pos) const;
     };
 
     class AnyVehicleIterator {
@@ -177,11 +177,12 @@ public:
      * @param[in] width The width of the lane
      * @param[in] permissions Encoding of the Vehicle classes that may drive on this lane
      * @param[in] index The index of this lane within its parent edge
+     * @param[in] isRampAccel Whether this lane is an acceleratin lane
      * @see SUMOVehicleClass
      */
-    MSLane(const std::string& id, SUMOReal maxSpeed, SUMOReal length, MSEdge* const edge,
-           unsigned int numericalID, const PositionVector& shape, SUMOReal width,
-           SVCPermissions permissions, int index);
+    MSLane(const std::string& id, double maxSpeed, double length, MSEdge* const edge,
+           int numericalID, const PositionVector& shape, double width,
+           SVCPermissions permissions, int index, bool isRampAccel);
 
 
     /// @brief Destructor
@@ -260,7 +261,7 @@ public:
      *  does not cause unexpected behaviour on consecutive lanes. Returns false
      *  if the vehicle can not be inserted.
      *
-     * If the insertion can take place, incorporateVehicleis called and true is returned.
+     * If the insertion can take place, incorporateVehicle() is called and true is returned.
      *
      * @param[in] vehicle The vehicle to insert
      * @param[in] speed The speed with which it shall be inserted
@@ -271,12 +272,17 @@ public:
      * @return Whether the vehicle could be inserted
      * @see MSVehicle::enterLaneAtInsertion
      */
-    bool isInsertionSuccess(MSVehicle* vehicle, SUMOReal speed, SUMOReal pos, SUMOReal posLat,
+    bool isInsertionSuccess(MSVehicle* vehicle, double speed, double pos, double posLat,
                             bool recheckNextLanes,
                             MSMoveReminder::Notification notification);
 
-    bool checkFailure(MSVehicle* aVehicle, SUMOReal& speed, SUMOReal& dist, const SUMOReal nspeed, const bool patchSpeed, const std::string errorMsg) const;
-    bool lastInsertion(MSVehicle& veh, SUMOReal mspeed);
+    // XXX: Documentation?
+    bool checkFailure(MSVehicle* aVehicle, double& speed, double& dist, const double nspeed, const bool patchSpeed, const std::string errorMsg) const;
+
+    /** @brief inserts vehicle as close as possible to the last vehicle on this
+     * lane (or at the end of the lane if there is no leader)
+     */
+    bool lastInsertion(MSVehicle& veh, double mspeed, bool patchSpeed);
 
     /** @brief Tries to insert the given vehicle on any place
      *
@@ -285,7 +291,7 @@ public:
      * @param[in] notification The cause of insertion (i.e. departure, teleport, parking) defaults to departure
      * @return Whether the vehicle could be inserted
      */
-    bool freeInsertion(MSVehicle& veh, SUMOReal speed,
+    bool freeInsertion(MSVehicle& veh, double speed,
                        MSMoveReminder::Notification notification = MSMoveReminder::NOTIFICATION_DEPARTED);
 
 
@@ -298,7 +304,7 @@ public:
      * @param[in] notification The cause of insertion (i.e. departure, teleport, parking) defaults to departure
      * @param[in] posLat The lateral position at which the vehicle shall be inserted
      */
-    void forceVehicleInsertion(MSVehicle* veh, SUMOReal pos, MSMoveReminder::Notification notification, SUMOReal posLat = 0);
+    void forceVehicleInsertion(MSVehicle* veh, double pos, MSMoveReminder::Notification notification, double posLat = 0);
     /// @}
 
 
@@ -312,7 +318,7 @@ public:
      * @param[in] v The vehicle which laps into this lane
      * @return This lane's length
      */
-    virtual SUMOReal setPartialOccupation(MSVehicle* v);
+    virtual double setPartialOccupation(MSVehicle* v);
 
     /** @brief Removes the information about a vehicle lapping into this lane
      * @param[in] v The vehicle which laps into this lane
@@ -329,15 +335,13 @@ public:
      * @param[in] allowCached Whether the cached value may be used
      * @return Information about the last vehicles
      */
-    const MSLeaderInfo& getLastVehicleInformation(const MSVehicle* ego, SUMOReal latOffset, SUMOReal minPos = 0, bool allowCached = true) const;
+    const MSLeaderInfo& getLastVehicleInformation(const MSVehicle* ego, double latOffset, double minPos = 0, bool allowCached = true) const;
 
     /// @brief analogue to getLastVehicleInformation but in the upstream direction
-    const MSLeaderInfo& getFirstVehicleInformation(const MSVehicle* ego, SUMOReal latOffset, bool onlyFrontOnLane, SUMOReal maxPos = std::numeric_limits<SUMOReal>::max(), bool allowCached = true) const;
+    const MSLeaderInfo& getFirstVehicleInformation(const MSVehicle* ego, double latOffset, bool onlyFrontOnLane, double maxPos = std::numeric_limits<double>::max(), bool allowCached = true) const;
 
     /// @}
 
-
-
     /// @name Access to vehicles
     /// @{
 
@@ -411,7 +415,7 @@ public:
     /** @brief Returns this lane's numerical id
      * @return This lane's numerical id
      */
-    inline size_t getNumericalID() const {
+    inline int getNumericalID() const {
         return myNumericalID;
     }
 
@@ -424,25 +428,30 @@ public:
     }
 
     /// @brief return shape.length() / myLength
-    inline SUMOReal getLengthGeometryFactor() const {
+    inline double getLengthGeometryFactor() const {
         return myLengthGeometryFactor;
     }
 
+    /// @brief return whether this lane is an acceleration lane
+    inline bool isAccelLane() const {
+        return myIsRampAccel;
+    }
+
     /* @brief fit the given lane position to a visibly suitable geometry position
      * (lane length might differ from geometry length) */
-    inline SUMOReal interpolateLanePosToGeometryPos(SUMOReal lanePos) const {
+    inline double interpolateLanePosToGeometryPos(double lanePos) const {
         return lanePos * myLengthGeometryFactor;
     }
 
     /* @brief fit the given lane position to a visibly suitable geometry position
      * and return the coordinates */
-    inline const Position geometryPositionAtOffset(SUMOReal offset, SUMOReal lateralOffset = 0) const {
+    inline const Position geometryPositionAtOffset(double offset, double lateralOffset = 0) const {
         return myShape.positionAtOffset(interpolateLanePosToGeometryPos(offset), lateralOffset);
     }
 
     /* @brief fit the given geomtry position to a valid lane position
      * (lane length might differ from geometry length) */
-    inline SUMOReal interpolateGeometryPosToLanePos(SUMOReal geometryPos) const {
+    inline double interpolateGeometryPosToLanePos(double geometryPos) const {
         return geometryPos / myLengthGeometryFactor;
     }
 
@@ -450,9 +459,9 @@ public:
      * @param[in] The vehicle to return the adapted speed limit for
      * @return This lane's resulting max. speed
      */
-    inline SUMOReal getVehicleMaxSpeed(const SUMOVehicle* const veh) const {
+    inline double getVehicleMaxSpeed(const SUMOVehicle* const veh) const {
         if (myRestrictions != 0) {
-            std::map<SUMOVehicleClass, SUMOReal>::const_iterator r = myRestrictions->find(veh->getVClass());
+            std::map<SUMOVehicleClass, double>::const_iterator r = myRestrictions->find(veh->getVClass());
             if (r != myRestrictions->end()) {
                 return MIN2(veh->getMaxSpeed(), r->second * veh->getChosenSpeedFactor());
             }
@@ -464,7 +473,7 @@ public:
     /** @brief Returns the lane's maximum allowed speed
      * @return This lane's maximum allowed speed
      */
-    inline SUMOReal getSpeedLimit() const {
+    inline double getSpeedLimit() const {
         return myMaxSpeed;
     }
 
@@ -472,7 +481,7 @@ public:
     /** @brief Returns the lane's length
      * @return This lane's length
      */
-    inline SUMOReal getLength() const {
+    inline double getLength() const {
         return myLength;
     }
 
@@ -488,7 +497,7 @@ public:
     /** @brief Returns the lane's width
      * @return This lane's width
      */
-    SUMOReal getWidth() const {
+    double getWidth() const {
         return myWidth;
     }
 
@@ -544,6 +553,12 @@ public:
     /// returns the container with all links !!!
     const MSLinkCont& getLinkCont() const;
 
+    /// returns the link to the given lane or 0, if it is not connected
+    MSLink* getLinkTo(const MSLane*) const;
+
+    /// Returns the entry link if this is an internal lane, else 0
+    MSLink* getEntryLink() const;
+
 
     /// Returns true if there is not a single vehicle on the lane.
     bool empty() const {
@@ -554,12 +569,12 @@ public:
     /** @brief Sets a new maximum speed for the lane (used by TraCI and MSCalibrator)
      * @param[in] val the new speed in m/s
      */
-    void setMaxSpeed(SUMOReal val);
+    void setMaxSpeed(double val);
 
     /** @brief Sets a new length for the lane (used by TraCI only)
      * @param[in] val the new length in m
      */
-    void setLength(SUMOReal val);
+    void setLength(double val);
 
     /** @brief Returns the lane's edge
      * @return This lane's edge
@@ -572,7 +587,7 @@ public:
     /** @brief Returns the lane's follower if it is an internal lane, the edge of the lane otherwise
      * @return This lane's follower
      */
-    const MSEdge* getInternalFollower() const;
+    const MSEdge* getNextNormal() const;
 
 
     /// @brief Static (sic!) container methods
@@ -607,8 +622,8 @@ public:
     /** @brief Returns the number of stored lanes
      * @return The number of stored lanes
      */
-    static size_t dictSize() {
-        return myDict.size();
+    static int dictSize() {
+        return (int)myDict.size();
     }
 
 
@@ -628,12 +643,13 @@ public:
 
 
 
+    // XXX: succLink does not exist... Documentation?
     /** Same as succLink, but does not throw any assertions when
         the succeeding link could not be found;
         Returns the myLinks.end() instead; Further, the number of edges to
         look forward may be given */
     static MSLinkCont::const_iterator succLinkSec(const SUMOVehicle& veh,
-            unsigned int nRouteSuccs,
+            int nRouteSuccs,
             const MSLane& succLinkSource,
             const std::vector<MSLane*>& conts);
 
@@ -650,6 +666,9 @@ public:
         partial occupation*/
     bool isEmpty() const;
 
+    /** Returns whether the lane pertains to an internal edge*/
+    bool isInternal() const;
+
     /// @brief returns the last vehicle for which this lane is responsible or 0
     MSVehicle* getLastFullVehicle() const;
 
@@ -676,9 +695,12 @@ public:
     MSLane* getParallelLane(int offset) const;
 
 
-    inline void setPermissions(SVCPermissions permissions) {
-        myPermissions = permissions;
-    }
+    /** @brief Sets the permissions to the given value. If a transientID is given, the permissions are recored as temporary
+     * @param[in] permissions The new permissions
+     * @param[in] transientID The id of the permission-modification or the special value PERMANENT
+     */
+    void setPermissions(SVCPermissions permissions, long transientID);
+    void resetPermissions(long transientID);
 
 
     inline bool allowsVehicleClass(SUMOVehicleClass vclass) const {
@@ -690,7 +712,7 @@ public:
 
     struct IncomingLaneInfo {
         MSLane* lane;
-        SUMOReal length;
+        double length;
         MSLink* viaLink;
     };
 
@@ -705,15 +727,12 @@ public:
 
 
 
-    /// @brief return the follower with the largest missing rear gap among all predecessor lanes (within dist)
-    std::pair<MSVehicle* const, SUMOReal> getFollowerOnConsecutive(
-        SUMOReal backOffset, SUMOReal leaderSpeed, SUMOReal leaderMaxDecel, SUMOReal dist = -1) const;
-
     /// @brief return the sublane followers with the largest missing rear gap among all predecessor lanes (within dist)
-    MSLeaderDistanceInfo getFollowersOnConsecutive(const MSVehicle* ego, bool allSublanes) const;
+    MSLeaderDistanceInfo getFollowersOnConsecutive(const MSVehicle* ego, double backOffset,
+            bool allSublanes, double searchDist = -1, bool ignoreMinorLinks = false) const;
 
     /// @brief return by how much further the leader must be inserted to avoid rear end collisions
-    SUMOReal getMissingRearGap(SUMOReal backOffset, SUMOReal leaderSpeed, SUMOReal leaderMaxDecel) const;
+    double getMissingRearGap(const MSVehicle* leader, double backOffset, double leaderSpeed) const;
 
     /** @brief Returns the immediate leader of veh and the distance to veh
      * starting on this lane
@@ -727,7 +746,7 @@ public:
      * @param[in] checkTmpVehicles Whether myTmpVehicles should be used instead of myVehicles
      * @return
      */
-    std::pair<MSVehicle* const, SUMOReal> getLeader(const MSVehicle* veh, const SUMOReal vehPos, const std::vector<MSLane*>& bestLaneConts, SUMOReal dist = -1, bool checkTmpVehicles = false) const;
+    std::pair<MSVehicle* const, double> getLeader(const MSVehicle* veh, const double vehPos, const std::vector<MSLane*>& bestLaneConts, double dist = -1, bool checkTmpVehicles = false) const;
 
     /** @brief Returns the immediate leader and the distance to him
      *
@@ -751,11 +770,11 @@ public:
      * @param[in] bestLaneConts The lanes the vehicle will use in future
      * @return
      */
-    std::pair<MSVehicle* const, SUMOReal> getLeaderOnConsecutive(SUMOReal dist, SUMOReal seen,
-            SUMOReal speed, const MSVehicle& veh, const std::vector<MSLane*>& bestLaneConts) const;
+    std::pair<MSVehicle* const, double> getLeaderOnConsecutive(double dist, double seen,
+            double speed, const MSVehicle& veh, const std::vector<MSLane*>& bestLaneConts) const;
 
     /// @brief Returns the immediate leaders and the distance to them (as getLeaderOnConsecutive but for the sublane case)
-    void getLeadersOnConsecutive(SUMOReal dist, SUMOReal seen, SUMOReal speed, const MSVehicle* ego,
+    void getLeadersOnConsecutive(double dist, double seen, double speed, const MSVehicle* ego,
                                  const std::vector<MSLane*>& bestLaneConts, MSLeaderDistanceInfo& result) const;
 
     /** @brief Returns the most dangerous leader and the distance to him
@@ -775,7 +794,7 @@ public:
      * @param[in] veh The (ego) vehicle for which the information shall be computed
      * @return
      */
-    std::pair<MSVehicle* const, SUMOReal> getCriticalLeader(SUMOReal dist, SUMOReal seen, SUMOReal speed, const MSVehicle& veh) const;
+    std::pair<MSVehicle* const, double> getCriticalLeader(double dist, double seen, double speed, const MSVehicle& veh) const;
 
     /* @brief return the partial vehicle closest behind ego or 0
      * if no such vehicle exists */
@@ -790,6 +809,22 @@ public:
      */
     MSLane* getLogicalPredecessorLane(const MSEdge& fromEdge) const;
 
+
+    /** Return the main predecessor lane for the current.
+     * If there are several incoming lanes, the first attempt is to return the priorized.
+     * If this does not yield an unambiguous lane, the one with the least angle difference
+     * to the current is selected.
+     */
+    MSLane* getCanonicalPredecessorLane() const;
+
+
+    /** Return the main successor lane for the current.
+     * If there are several outgoing lanes, the first attempt is to return the priorized.
+     * If this does not yield an unambiguous lane, the one with the least angle difference
+     * to the current is selected.
+     */
+    MSLane* getCanonicalSuccessorLane() const;
+
     /// @brief get the state of the link from the logical predecessor to this lane
     LinkState getIncomingLinkState() const;
 
@@ -802,30 +837,30 @@ public:
     /** @brief Returns the mean speed on this lane
      * @return The average speed of vehicles during the last step; default speed if no vehicle was on this lane
      */
-    SUMOReal getMeanSpeed() const;
+    double getMeanSpeed() const;
 
     /** @brief Returns the overall waiting time on this lane
     * @return The sum of the waiting time of all vehicles during the last step;
     */
-    SUMOReal getWaitingSeconds() const;
+    double getWaitingSeconds() const;
 
 
     /** @brief Returns the brutto (including minGaps) occupancy of this lane during the last step
      * @return The occupancy during the last step
      */
-    SUMOReal getBruttoOccupancy() const;
+    double getBruttoOccupancy() const;
 
 
     /** @brief Returns the netto (excluding minGaps) occupancy of this lane during the last step (including minGaps)
      * @return The occupancy during the last step
      */
-    SUMOReal getNettoOccupancy() const;
+    double getNettoOccupancy() const;
 
 
     /** @brief Returns the sum of lengths of vehicles, including their minGaps, which were on the lane during the last step
      * @return The sum of vehicle lengths of vehicles in the last step
      */
-    inline SUMOReal getBruttoVehLenSum() const {
+    inline double getBruttoVehLenSum() const {
         return myBruttoVehicleLengthSum;
     }
 
@@ -833,57 +868,60 @@ public:
     /** @brief Returns the sum of last step CO2 emissions
      * @return CO2 emissions of vehicles on this lane during the last step
      */
-    SUMOReal getCO2Emissions() const;
+    double getCO2Emissions() const;
 
 
     /** @brief Returns the sum of last step CO emissions
      * @return CO emissions of vehicles on this lane during the last step
      */
-    SUMOReal getCOEmissions() const;
+    double getCOEmissions() const;
 
 
     /** @brief Returns the sum of last step PMx emissions
      * @return PMx emissions of vehicles on this lane during the last step
      */
-    SUMOReal getPMxEmissions() const;
+    double getPMxEmissions() const;
 
 
     /** @brief Returns the sum of last step NOx emissions
      * @return NOx emissions of vehicles on this lane during the last step
      */
-    SUMOReal getNOxEmissions() const;
+    double getNOxEmissions() const;
 
 
     /** @brief Returns the sum of last step HC emissions
      * @return HC emissions of vehicles on this lane during the last step
      */
-    SUMOReal getHCEmissions() const;
+    double getHCEmissions() const;
 
 
     /** @brief Returns the sum of last step fuel consumption
     * @return fuel consumption of vehicles on this lane during the last step
     */
-    SUMOReal getFuelConsumption() const;
+    double getFuelConsumption() const;
 
 
     /** @brief Returns the sum of last step electricity consumption
     * @return electricity consumption of vehicles on this lane during the last step
     */
-    SUMOReal getElectricityConsumption() const;
+    double getElectricityConsumption() const;
 
 
     /** @brief Returns the sum of last step noise emissions
      * @return noise emissions of vehicles on this lane during the last step
      */
-    SUMOReal getHarmonoise_NoiseEmissions() const;
+    double getHarmonoise_NoiseEmissions() const;
     /// @}
 
-    void setRightSideOnEdge(SUMOReal value, int rightmostSublane) {
+    void setRightSideOnEdge(double value, int rightmostSublane) {
         myRightSideOnEdge = value;
         myRightmostSublane = rightmostSublane;
     }
 
-    SUMOReal getRightSideOnEdge() const {
+    /// @brief initialized vClass-specific speed limits
+    void initRestrictions();
+
+    double getRightSideOnEdge() const {
         return myRightSideOnEdge;
     }
 
@@ -891,7 +929,7 @@ public:
         return myRightmostSublane;
     }
 
-    SUMOReal getCenterOnEdge() const {
+    double getCenterOnEdge() const {
         return myRightSideOnEdge + 0.5 * myWidth;
     }
 
@@ -902,20 +940,31 @@ public:
     MSLane* getOpposite() const;
 
     /// @brief return the corresponding position on the opposite lane
-    SUMOReal getOppositePos(SUMOReal pos) const;
+    double getOppositePos(double pos) const;
 
-    std::pair<MSVehicle* const, SUMOReal> getOppositeLeader(const MSVehicle* ego, SUMOReal dist) const;
+    /* @brief find leader for a vehicle depending the relative driving direction
+     * @param[in] ego The ego vehicle
+     * @param[in] dist The look-ahead distance when looking at consecutive lanes
+     * @param[in] oppositeDir Whether the lane has the opposite driving direction of ego
+     * @return the leader vehicle and it's gap to ego
+     */
+    std::pair<MSVehicle* const, double> getOppositeLeader(const MSVehicle* ego, double dist, bool oppositeDir) const;
 
-    std::pair<MSVehicle* const, SUMOReal> getOppositeFollower(const MSVehicle* ego) const;
+    /* @brief find follower for a vehicle that is located on the opposite of this lane
+     * @param[in] ego The ego vehicle
+     * @return the follower vehicle and it's gap to ego
+     */
+    std::pair<MSVehicle* const, double> getOppositeFollower(const MSVehicle* ego) const;
 
 
     /** @brief Find follower vehicle for the given ego vehicle (which may be on the opposite direction lane)
      * @param[in] ego The ego vehicle
      * @param[in] egoPos The ego position mapped to the current lane
      * @param[in] dist The look-back distance when looking at consecutive lanes
+     * @param[in] ignoreMinorLinks Whether backward search should stop at minor links
      * @return the follower vehicle and it's gap to ego
      */
-    std::pair<MSVehicle* const, SUMOReal> getFollower(const MSVehicle* ego, SUMOReal egoPos, SUMOReal dist) const;
+    std::pair<MSVehicle* const, double> getFollower(const MSVehicle* ego, double egoPos, double dist, bool ignoreMinorLinks) const;
 
     /// @name State saving/loading
     /// @{
@@ -963,6 +1012,13 @@ public:
         return myCollisionAction == COLLISION_ACTION_TELEPORT;
     }
 
+    static CollisionAction getCollisionAction() {
+        return myCollisionAction;
+    }
+
+    static const long CHANGE_PERMISSIONS_PERMANENT = 0;
+    static const long CHANGE_PERMISSIONS_GUI = 1;
+
 protected:
     /// moves myTmpVehicles int myVehicles after a lane change procedure
     virtual void swapAfterLaneChange(SUMOTime t);
@@ -978,41 +1034,41 @@ protected:
      * @param[in] at
      * @param[in] notification The cause of insertion (i.e. departure, teleport, parking) defaults to departure
      */
-    virtual void incorporateVehicle(MSVehicle* veh, SUMOReal pos, SUMOReal speed, SUMOReal posLat,
+    virtual void incorporateVehicle(MSVehicle* veh, double pos, double speed, double posLat,
                                     const MSLane::VehCont::iterator& at,
                                     MSMoveReminder::Notification notification = MSMoveReminder::NOTIFICATION_DEPARTED);
 
 
     /// @brief detect whether there is a collision between the two vehicles
-    bool detectCollisionBetween(SUMOTime timestep, const std::string& stage, const MSVehicle* collider, const MSVehicle* victim,
+    bool detectCollisionBetween(SUMOTime timestep, const std::string& stage, MSVehicle* collider, MSVehicle* victim,
                                 std::set<const MSVehicle*, SUMOVehicle::ComparatorIdLess>& toRemove,
                                 std::set<const MSVehicle*>& toTeleport) const;
 
     /// @brief take action upon collision
-    void handleCollisionBetween(SUMOTime timestep, const std::string& stage, const MSVehicle* collider, const MSVehicle* victim,
-                                SUMOReal gap, SUMOReal latGap,
+    void handleCollisionBetween(SUMOTime timestep, const std::string& stage, MSVehicle* collider, MSVehicle* victim,
+                                double gap, double latGap,
                                 std::set<const MSVehicle*, SUMOVehicle::ComparatorIdLess>& toRemove,
                                 std::set<const MSVehicle*>& toTeleport) const;
 
     /// @brief compute maximum braking distance on this lane
-    SUMOReal getMaximumBrakeDist() const;
+    double getMaximumBrakeDist() const;
 
     /* @brief determine depart speed and whether it may be patched
      * @param[in] veh The departing vehicle
      * @param[out] whether the speed may be patched to account for safety
      * @return the depart speed
      */
-    SUMOReal getDepartSpeed(const MSVehicle& veh, bool& patchSpeed);
+    double getDepartSpeed(const MSVehicle& veh, bool& patchSpeed);
 
     /** @brief return the maximum safe speed for insertion behind leaders
      * (a negative value indicates that safe insertion is impossible) */
-    SUMOReal safeInsertionSpeed(const MSVehicle* veh, const MSLeaderInfo& leaders, SUMOReal speed);
+    double safeInsertionSpeed(const MSVehicle* veh, const MSLeaderInfo& leaders, double speed);
 
     /// @brief departure position where the vehicle fits fully onto the lane (if possible)
-    SUMOReal basePos(const MSVehicle& veh) const;
+    double basePos(const MSVehicle& veh) const;
 
     /// Unique numerical ID (set on reading by netload)
-    size_t myNumericalID;
+    int myNumericalID;
 
     /// The shape of the lane
     PositionVector myShape;
@@ -1055,37 +1111,49 @@ protected:
 
 
     /// Lane length [m]
-    SUMOReal myLength;
+    double myLength;
 
     /// Lane width [m]
-    const SUMOReal myWidth;
+    const double myWidth;
 
     /// The lane's edge, for routing only.
     MSEdge* const myEdge;
 
     /// Lane-wide speedlimit [m/s]
-    SUMOReal myMaxSpeed;
+    double myMaxSpeed;
 
     /// The vClass permissions for this lane
     SVCPermissions myPermissions;
 
-    /// The vClass speed restrictions for this lane
-    const std::map<SUMOVehicleClass, SUMOReal>* myRestrictions;
+    /// The original vClass permissions for this lane (before temporary modifications)
+    SVCPermissions myOriginalPermissions;
 
+    /// The vClass speed restrictions for this lane
+    const std::map<SUMOVehicleClass, double>* myRestrictions;
+
+    /// All direct predecessor lanes
     std::vector<IncomingLaneInfo> myIncomingLanes;
+
+    ///
     mutable MSLane* myLogicalPredecessorLane;
 
+    /// Similar to LogicalPredecessorLane, @see getCanonicalPredecessorLane()
+    mutable MSLane* myCanonicalPredecessorLane;
+
+    /// Main successor lane, @see getCanonicalSuccessorLane()
+    mutable MSLane* myCanonicalSuccessorLane;
 
     /// @brief The current length of all vehicles on this lane, including their minGaps
-    SUMOReal myBruttoVehicleLengthSum;
+    double myBruttoVehicleLengthSum;
 
     /// @brief The current length of all vehicles on this lane, excluding their minGaps
-    SUMOReal myNettoVehicleLengthSum;
+    double myNettoVehicleLengthSum;
 
     /** The lane's Links to it's succeeding lanes and the default
         right-of-way rule, i.e. blocked or not blocked. */
     MSLinkCont myLinks;
 
+    /// All direct internal and direct (disregarding internal predecessors) non-internal predecessor lanes of this lane
     std::map<MSEdge*, std::vector<MSLane*> > myApproachingLanes;
 
     /// @brief leaders on all sublanes as seen by approaching vehicles (cached)
@@ -1101,16 +1169,22 @@ protected:
     mutable SUMOTime myFollowerInfoTime;
 
     /// @brief precomputed myShape.length / myLength
-    const SUMOReal myLengthGeometryFactor;
+    const double myLengthGeometryFactor;
+
+    /// @brief whether this lane is an acceleration lane
+    const bool myIsRampAccel;
 
     /// @brief the combined width of all lanes with lower index on myEdge
-    SUMOReal myRightSideOnEdge;
+    double myRightSideOnEdge;
     /// @brief the index of the rightmost sublane of this lane on myEdge
     int myRightmostSublane;
 
     // @brief the ids of neighboring lanes
     std::vector<std::string> myNeighs;
 
+    // @brief transient changes in permissions
+    std::map<long, SVCPermissions> myPermissionChanges;
+
     /// definition of the static dictionary type
     typedef std::map< std::string, MSLane* > DictType;
 
@@ -1124,6 +1198,7 @@ private:
     /// @brief the action to take on collisions
     static CollisionAction myCollisionAction;
     static bool myCheckJunctionCollisions;
+    static SUMOTime myCollisionStopTime;
 
     /**
      * @class vehicle_position_sorter
@@ -1171,7 +1246,7 @@ private:
 
     };
 
-    /** @class by_id_sorter
+    /** @class by_connections_to_sorter
      * @brief Sorts edges by their angle relative to the given edge (straight comes first)
      *
      */
@@ -1187,7 +1262,48 @@ private:
         by_connections_to_sorter& operator=(const by_connections_to_sorter&); // just to avoid a compiler warning
     private:
         const MSEdge* const myEdge;
-        SUMOReal myLaneDir;
+        double myLaneDir;
+    };
+
+
+
+    /** @class incoming_lane_priority_sorter
+     * @brief Sorts lanes (IncomingLaneInfos) by their priority or, if this doesn't apply,
+     *         wrt. the angle difference magnitude relative to the target lane's angle (straight comes first)
+     */
+    class incoming_lane_priority_sorter {
+    public:
+        /// @brief constructor
+        explicit incoming_lane_priority_sorter(const MSLane* targetLane);
+
+        /// @brief comparing operator
+        int operator()(const IncomingLaneInfo& lane1, const IncomingLaneInfo& lane2) const;
+
+    private:
+        incoming_lane_priority_sorter& operator=(const incoming_lane_priority_sorter&); // just to avoid a compiler warning
+    private:
+        const MSLane* const myLane;
+        double myLaneDir;
+    };
+
+
+    /** @class outgoing_lane_priority_sorter
+     * @brief Sorts lanes (their origin link) by the priority of their noninternal target edges or, if this doesn't yield an unambiguous result,
+     *         wrt. the angle difference magnitude relative to the target lane's angle (straight comes first)
+     */
+    class outgoing_lane_priority_sorter {
+    public:
+        /// @brief constructor
+        explicit outgoing_lane_priority_sorter(const MSLane* sourceLane);
+
+        /// @brief comparing operator
+        int operator()(const MSLink* link1, const MSLink* link2) const;
+
+    private:
+        outgoing_lane_priority_sorter& operator=(const outgoing_lane_priority_sorter&); // just to avoid a compiler warning
+    private:
+        const MSLane* const myLane;
+        double myLaneDir;
     };
 
     /**
