@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Wed, 12 Dez 2001
-/// @version $Id: MSRightOfWayJunction.cpp 21210 2016-07-21 10:02:38Z behrisch $
+/// @version $Id: MSRightOfWayJunction.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // junction.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -41,10 +41,6 @@
 #include <cmath>
 #include <utils/common/RandHelper.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -54,17 +50,9 @@ MSRightOfWayJunction::MSRightOfWayJunction(const std::string& id,
         const Position& position,
         const PositionVector& shape,
         std::vector<MSLane*> incoming,
-#ifdef HAVE_INTERNAL_LANES
         std::vector<MSLane*> internal,
-#endif
-        MSJunctionLogic* logic)
-    : MSLogicJunction(id, type, position, shape, incoming
-#ifdef HAVE_INTERNAL_LANES
-    , internal),
-#else
-                     ),
-#endif
-      myLogic(logic) {}
+        MSJunctionLogic* logic) : MSLogicJunction(id, type, position, shape, incoming, internal),
+    myLogic(logic) {}
 
 
 MSRightOfWayJunction::~MSRightOfWayJunction() {
@@ -113,7 +101,6 @@ MSRightOfWayJunction::postloadInit() {
                 if (linkResponse.test(c)) {
                     MSLink* foe = sortedLinks[c].second;
                     myLinkFoeLinks[*j].push_back(foe);
-#ifdef HAVE_INTERNAL_LANES
                     if (MSGlobals::gUsingInternalLanes && foe->getViaLane() != 0) {
                         assert(foe->getViaLane()->getLinkCont().size() == 1);
                         MSLink* foeExitLink = foe->getViaLane()->getLinkCont()[0];
@@ -122,7 +109,6 @@ MSRightOfWayJunction::postloadInit() {
                             myLinkFoeLinks[*j].push_back(foeExitLink);
                         }
                     }
-#endif
                 }
             }
             std::vector<MSLink*> foes;
@@ -130,7 +116,6 @@ MSRightOfWayJunction::postloadInit() {
                 if (linkFoes.test(c)) {
                     MSLink* foe = sortedLinks[c].second;
                     foes.push_back(foe);
-#ifdef HAVE_INTERNAL_LANES
                     MSLane* l = foe->getViaLane();
                     if (l == 0) {
                         continue;
@@ -142,12 +127,10 @@ MSRightOfWayJunction::postloadInit() {
                             foes.push_back(*q);
                         }
                     }
-#endif
                 }
             }
 
             myLinkFoeInternalLanes[*j] = std::vector<MSLane*>();
-#ifdef HAVE_INTERNAL_LANES
             if (MSGlobals::gUsingInternalLanes && myInternalLanes.size() > 0) {
                 int li = 0;
                 for (int c = 0; c < (int)sortedLinks.size(); ++c) {
@@ -166,9 +149,7 @@ MSRightOfWayJunction::postloadInit() {
                     ++li;
                 }
             }
-#endif
             (*j)->setRequestInformation((int)requestPos, hasFoes, cont, myLinkFoeLinks[*j], myLinkFoeInternalLanes[*j]);
-#ifdef HAVE_INTERNAL_LANES
             // the exit link for a link before an internal junction is handled in MSInternalJunction
             // so we need to skip if cont=true
             if (MSGlobals::gUsingInternalLanes && (*j)->getViaLane() != 0 && !cont) {
@@ -177,7 +158,6 @@ MSRightOfWayJunction::postloadInit() {
                 exitLink->setRequestInformation((int)requestPos, false, false, std::vector<MSLink*>(),
                                                 myLinkFoeInternalLanes[*j], (*j)->getViaLane());
             }
-#endif
             for (std::vector<MSLink*>::const_iterator k = foes.begin(); k != foes.end(); ++k) {
                 (*j)->addBlockedLink(*k);
                 (*k)->addBlockedLink(*j);
