@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: MSRoute.h 21201 2016-07-19 11:57:22Z behrisch $
+/// @version $Id: MSRoute.h 23341 2017-03-13 10:11:12Z behrisch $
 ///
 // A vehicle route
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -39,7 +39,7 @@
 #include <vector>
 #include <algorithm>
 #include <utils/common/Named.h>
-#include <utils/common/RandomDistributor.h>
+#include <utils/distribution/RandomDistributor.h>
 #include <utils/common/RGBColor.h>
 #include <utils/vehicle/SUMOVehicleParameter.h>
 #include <utils/common/Parameterised.h>
@@ -141,7 +141,7 @@ public:
      * @param[in] includeInternal Whether the lengths of internal edges shall be counted
      * @return             distance between the position fromPos on fromEdge and toPos on toEdge
      */
-    SUMOReal getDistanceBetween(SUMOReal fromPos, SUMOReal toPos, const MSEdge* fromEdge, const MSEdge* toEdge, bool includeInternal = true) const;
+    double getDistanceBetween(double fromPos, double toPos, const MSEdge* fromEdge, const MSEdge* toEdge, bool includeInternal = true) const;
 
     /** @brief Compute the distance between 2 given edges on this route, including the length of internal lanes.
      * This has the same semantics as above but uses iterators instead of edge
@@ -154,7 +154,7 @@ public:
      * @param[in] includeInternal Whether the lengths of internal edges shall be counted
      * @return             distance between the position fromPos on fromEdge and toPos on toEdge
      */
-    SUMOReal getDistanceBetween(SUMOReal fromPos, SUMOReal toPos, const MSRouteIterator& fromEdge, const MSRouteIterator& toEdge, bool includeInternal = true) const;
+    double getDistanceBetween(double fromPos, double toPos, const MSRouteIterator& fromEdge, const MSRouteIterator& toEdge, bool includeInternal = true) const;
 
     /// Returns the color
     const RGBColor& getColor() const;
@@ -163,7 +163,7 @@ public:
      *
      * @return The route's costs (normally the time needed to pass it)
      */
-    SUMOReal getCosts() const {
+    double getCosts() const {
         return myCosts;
     }
 
@@ -171,7 +171,7 @@ public:
      *
      * @param[in] costs The new route costs
      */
-    void setCosts(SUMOReal costs) {
+    void setCosts(double costs) {
         myCosts = costs;
     }
 
@@ -243,7 +243,7 @@ private:
     const RGBColor* const myColor;
 
     /// @brief The assigned or calculated costs
-    SUMOReal myCosts;
+    double myCosts;
 
     /// @brief List of the stops on the parsed route
     std::vector<SUMOVehicleParameter::Stop> myStops;
