@@ -5,12 +5,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: MSRouteHandler.cpp 20768 2016-05-20 08:38:44Z behrisch $
+/// @version $Id: MSRouteHandler.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // Parser and container for routes during their loading
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -57,10 +57,6 @@
 #include <microsim/MSGlobals.h>
 #include <utils/xml/SUMOVehicleParserHelper.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static members
@@ -78,7 +74,8 @@ MSRouteHandler::MSRouteHandler(const std::string& file,
     myActiveContainerPlan(0),
     myAddVehiclesDirectly(addVehiclesDirectly),
     myCurrentVTypeDistribution(0),
-    myCurrentRouteDistribution(0) {
+    myCurrentRouteDistribution(0),
+    myAmLoadingState(false) {
     myActiveRoute.reserve(100);
 }
 
@@ -217,18 +214,18 @@ MSRouteHandler::myStartElement(int element,
                     if (attrs.hasAttribute(SUMO_ATTR_DURATION) && duration <= 0) {
                         throw ProcessError("Non-positive walking duration for  '" + myVehicleParameter->id + "'.");
                     }
-                    SUMOReal speed = DEFAULT_PEDESTRIAN_SPEED;
+                    double speed = DEFAULT_PEDESTRIAN_SPEED;
                     const MSVehicleType* vtype = MSNet::getInstance()->getVehicleControl().getVType(myVehicleParameter->vtypeid, &myParsingRNG);
                     // need to check for explicitly set speed since we might have // DEFAULT_VEHTYPE
-                    if (vtype != 0 && vtype->wasSet(VTYPEPARS_MAXSPEED_SET)) {
-                        speed = vtype->getMaxSpeed();
+                    if (vtype != 0) {
+                        speed = vtype->getMaxSpeed() * vtype->computeChosenSpeedDeviation(&myParsingRNG);
                     }
-                    speed = attrs.getOpt<SUMOReal>(SUMO_ATTR_SPEED, 0, ok, speed);
+                    speed = attrs.getOpt<double>(SUMO_ATTR_SPEED, 0, ok, speed);
                     if (speed <= 0) {
                         throw ProcessError("Non-positive walking speed for  '" + myVehicleParameter->id + "'.");
                     }
-                    SUMOReal departPos = 0;
-                    SUMOReal arrivalPos = 0;
+                    double departPos = 0;
+                    double arrivalPos = 0;
                     MSStoppingPlace* bs = 0;
                     if (attrs.hasAttribute(SUMO_ATTR_EDGES)) {
                         MSEdge::parseEdgesList(attrs.get<std::string>(SUMO_ATTR_EDGES, myVehicleParameter->id.c_str(), ok), myActiveRoute, myActiveRouteID);
@@ -271,7 +268,8 @@ MSRouteHandler::myStartElement(int element,
                         myActivePlan->push_back(new MSTransportable::Stage_Waiting(
                                                     *myActiveRoute.front(), -1, myVehicleParameter->depart, departPos, "start", true));
                     }
-                    myActivePlan->push_back(new MSPerson::MSPersonStage_Walking(myActiveRoute, bs, duration, speed, departPos, arrivalPos));
+                    const double departPosLat = attrs.getOpt<double>(SUMO_ATTR_DEPARTPOS_LAT, 0, ok, 0);
+                    myActivePlan->push_back(new MSPerson::MSPersonStage_Walking(myActiveRoute, bs, duration, speed, departPos, arrivalPos, departPosLat));
                     myActiveRoute.clear();
                 } catch (ProcessError&) {
                     deleteActivePlans();
@@ -324,15 +322,15 @@ MSRouteHandler::myStartElement(int element,
             case SUMO_TAG_TRANSHIP: {
                 myActiveRoute.clear();
                 bool ok = true;
-                SUMOReal departPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_DEPARTPOS, myVehicleParameter->id.c_str(), ok, 0);
-                SUMOReal arrivalPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ARRIVALPOS, myVehicleParameter->id.c_str(), ok, -NUMERICAL_EPS);
-                SUMOReal speed = DEFAULT_CONTAINER_TRANSHIP_SPEED;
+                double departPos = attrs.getOpt<double>(SUMO_ATTR_DEPARTPOS, myVehicleParameter->id.c_str(), ok, 0);
+                double arrivalPos = attrs.getOpt<double>(SUMO_ATTR_ARRIVALPOS, myVehicleParameter->id.c_str(), ok, -NUMERICAL_EPS);
+                double speed = DEFAULT_CONTAINER_TRANSHIP_SPEED;
                 const MSVehicleType* vtype = MSNet::getInstance()->getVehicleControl().getVType(myVehicleParameter->vtypeid);
                 // need to check for explicitly set speed since we might have // DEFAULT_VEHTYPE
                 if (vtype != 0 && vtype->wasSet(VTYPEPARS_MAXSPEED_SET)) {
                     speed = vtype->getMaxSpeed();
                 }
-                speed = attrs.getOpt<SUMOReal>(SUMO_ATTR_SPEED, 0, ok, speed);
+                speed = attrs.getOpt<double>(SUMO_ATTR_SPEED, 0, ok, speed);
                 if (speed <= 0) {
                     throw ProcessError("Non-positive tranship speed for container  '" + myVehicleParameter->id + "'.");
                 }
@@ -423,7 +421,7 @@ MSRouteHandler::openVehicleTypeDistribution(const SUMOSAXAttributes& attrs) {
                 if (type == 0) {
                     throw ProcessError("Unknown vtype '" + vtypeID + "' in distribution '" + myCurrentVTypeDistributionID + "'.");
                 }
-                myCurrentVTypeDistribution->add(type->getDefaultProbability(), type);
+                myCurrentVTypeDistribution->add(type, type->getDefaultProbability());
             }
         }
     }
@@ -485,9 +483,9 @@ MSRouteHandler::openRoute(const SUMOSAXAttributes& attrs) {
     if (myActiveRouteRefID != "" && MSRoute::dictionary(myActiveRouteRefID, &myParsingRNG) == 0) {
         WRITE_ERROR("Invalid reference to route '" + myActiveRouteRefID + "' in route " + rid + ".");
     }
-    myActiveRouteProbability = attrs.getOpt<SUMOReal>(SUMO_ATTR_PROB, myActiveRouteID.c_str(), ok, DEFAULT_VEH_PROB);
+    myActiveRouteProbability = attrs.getOpt<double>(SUMO_ATTR_PROB, myActiveRouteID.c_str(), ok, DEFAULT_VEH_PROB);
     myActiveRouteColor = attrs.hasAttribute(SUMO_ATTR_COLOR) ? new RGBColor(attrs.get<RGBColor>(SUMO_ATTR_COLOR, myActiveRouteID.c_str(), ok)) : 0;
-    myCurrentCosts = attrs.getOpt<SUMOReal>(SUMO_ATTR_COST, myActiveRouteID.c_str(), ok, -1);
+    myCurrentCosts = attrs.getOpt<double>(SUMO_ATTR_COST, myActiveRouteID.c_str(), ok, -1);
     if (ok && myCurrentCosts != -1 && myCurrentCosts < 0) {
         WRITE_ERROR("Invalid cost for route '" + myActiveRouteID + "'.");
     }
@@ -510,7 +508,7 @@ MSRouteHandler::myEndElement(int element) {
                 }
             } else {
                 if (myCurrentVTypeDistribution != 0) {
-                    myCurrentVTypeDistribution->add(vehType->getDefaultProbability(), vehType);
+                    myCurrentVTypeDistribution->add(vehType, vehType->getDefaultProbability());
                 }
             }
         }
@@ -547,7 +545,7 @@ MSRouteHandler::closeRoute(const bool mayBeDisconnected) {
             if (myActiveRouteRefID != "" && myCurrentRouteDistribution != 0) {
                 const MSRoute* route = MSRoute::dictionary(myActiveRouteRefID, &myParsingRNG);
                 if (route != 0) {
-                    if (myCurrentRouteDistribution->add(myActiveRouteProbability, route)) {
+                    if (myCurrentRouteDistribution->add(route, myActiveRouteProbability)) {
                         route->addReference();
                     }
                 }
@@ -584,7 +582,7 @@ MSRouteHandler::closeRoute(const bool mayBeDisconnected) {
             }
         } else {
             if (myCurrentRouteDistribution != 0) {
-                if (myCurrentRouteDistribution->add(myActiveRouteProbability, route)) {
+                if (myCurrentRouteDistribution->add(route, myActiveRouteProbability)) {
                     route->addReference();
                 }
             }
@@ -614,31 +612,31 @@ MSRouteHandler::openRouteDistribution(const SUMOSAXAttributes& attrs) {
         }
     }
     myCurrentRouteDistribution = new RandomDistributor<const MSRoute*>();
-    std::vector<SUMOReal> probs;
+    std::vector<double> probs;
     if (attrs.hasAttribute(SUMO_ATTR_PROBS)) {
         bool ok = true;
         StringTokenizer st(attrs.get<std::string>(SUMO_ATTR_PROBS, myCurrentRouteDistributionID.c_str(), ok));
         while (st.hasNext()) {
-            probs.push_back(TplConvert::_2SUMORealSec(st.next().c_str(), 1.0));
+            probs.push_back(TplConvert::_2doubleSec(st.next().c_str(), 1.0));
         }
     }
     if (attrs.hasAttribute(SUMO_ATTR_ROUTES)) {
         bool ok = true;
         StringTokenizer st(attrs.get<std::string>(SUMO_ATTR_ROUTES, myCurrentRouteDistributionID.c_str(), ok));
-        size_t probIndex = 0;
+        int probIndex = 0;
         while (st.hasNext()) {
             std::string routeID = st.next();
             const MSRoute* route = MSRoute::dictionary(routeID, &myParsingRNG);
             if (route == 0) {
                 throw ProcessError("Unknown route '" + routeID + "' in distribution '" + myCurrentRouteDistributionID + "'.");
             }
-            const SUMOReal prob = (probs.size() > probIndex ? probs[probIndex] : 1.0);
-            if (myCurrentRouteDistribution->add(prob, route, false)) {
+            const double prob = ((int)probs.size() > probIndex ? probs[probIndex] : 1.0);
+            if (myCurrentRouteDistribution->add(route, prob, false)) {
                 route->addReference();
             }
             probIndex++;
         }
-        if (probs.size() > 0 && probIndex != probs.size()) {
+        if (probs.size() > 0 && probIndex != (int)probs.size()) {
             WRITE_WARNING("Got " + toString(probs.size()) + " probabilities for " + toString(probIndex) +
                           " routes in routeDistribution '" + myCurrentRouteDistributionID + "'");
         }
@@ -675,7 +673,7 @@ MSRouteHandler::closeVehicle() {
     MSVehicleControl& vehControl = MSNet::getInstance()->getVehicleControl();
     if (myVehicleParameter->departProcedure == DEPART_GIVEN) {
         // let's check whether this vehicle had to depart before the simulation starts
-        if (!(myAddVehiclesDirectly || checkLastDepart()) || myVehicleParameter->depart < string2time(OptionsCont::getOptions().getString("begin"))) {
+        if (!(myAddVehiclesDirectly || checkLastDepart()) || (myVehicleParameter->depart < string2time(OptionsCont::getOptions().getString("begin")) && !myAmLoadingState)) {
             if (route != 0) {
                 route->addReference();
                 route->release();
@@ -693,6 +691,9 @@ MSRouteHandler::closeVehicle() {
             if (vtype == 0) {
                 throw ProcessError("The vehicle type '" + myVehicleParameter->vtypeid + "' for vehicle '" + myVehicleParameter->id + "' is not known.");
             }
+            if (vtype->getVehicleClass() == SVC_PEDESTRIAN) {
+                WRITE_WARNING("Vehicle type '" + vtype->getID() + "' with vClass=pedestrian should only be used for persons and not for vehicle '" + myVehicleParameter->id + "'.");
+            }
         } else {
             // there should be one (at least the default one)
             vtype = vehControl.getVType(DEFAULT_VTYPE_ID, &myParsingRNG);
@@ -733,7 +734,7 @@ MSRouteHandler::closeVehicle() {
             }
         }
         // maybe we do not want this vehicle to be inserted due to scaling
-        unsigned int quota = vehControl.getQuota();
+        int quota = vehControl.getQuota();
         if (quota > 0) {
             vehControl.addVehicle(myVehicleParameter->id, vehicle);
             if (myVehicleParameter->departProcedure == DEPART_TRIGGERED) {
@@ -754,7 +755,7 @@ MSRouteHandler::closeVehicle() {
                 vehControl.registerOneWaitingForContainer();
             } else {
                 // !!! no upscaling for triggered vehicles yet
-                for (unsigned int i = 1; i < quota; i++) {
+                for (int i = 1; i < quota; i++) {
                     MSNet::getInstance()->getInsertionControl().add(vehicle);
                     SUMOVehicleParameter* newPars = new SUMOVehicleParameter(*myVehicleParameter);
                     newPars->id = myVehicleParameter->id + "." + toString(i);
@@ -856,7 +857,10 @@ MSRouteHandler::closeContainer() {
 
 void
 MSRouteHandler::closeFlow() {
+    myInsertStopEdgesAt = -1;
     if (myVehicleParameter->repetitionNumber == 0) {
+        delete myVehicleParameter;
+        myVehicleParameter = 0;
         return;
     }
     // let's check whether vehicles had to depart before the simulation starts
@@ -866,6 +870,8 @@ MSRouteHandler::closeFlow() {
         while (myVehicleParameter->repetitionsDone * myVehicleParameter->repetitionOffset < offsetToBegin) {
             myVehicleParameter->repetitionsDone++;
             if (myVehicleParameter->repetitionsDone == myVehicleParameter->repetitionNumber) {
+                delete myVehicleParameter;
+                myVehicleParameter = 0;
                 return;
             }
         }
@@ -892,7 +898,6 @@ MSRouteHandler::closeFlow() {
         }
     }
     myVehicleParameter = 0;
-    myInsertStopEdgesAt = -1;
 }
 
 
@@ -919,7 +924,7 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
         // ok, we have a bus stop
         MSStoppingPlace* bs = MSNet::getInstance()->getBusStop(stop.busstop);
         if (bs == 0) {
-            WRITE_ERROR("The bus stop '" + stop.busstop + "' is not known" + errorSuffix);
+            WRITE_ERROR("The busStop '" + stop.busstop + "' is not known" + errorSuffix);
             return;
         }
         const MSLane& l = bs->getLane();
@@ -932,7 +937,7 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
         // ok, we have obviously a container stop
         MSStoppingPlace* cs = MSNet::getInstance()->getContainerStop(stop.containerstop);
         if (cs == 0) {
-            WRITE_ERROR("The container stop '" + stop.containerstop + "' is not known" + errorSuffix);
+            WRITE_ERROR("The containerStop '" + stop.containerstop + "' is not known" + errorSuffix);
             return;
         }
         const MSLane& l = cs->getLane();
@@ -940,6 +945,19 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
         stop.endPos = cs->getEndLanePosition();
         stop.startPos = cs->getBeginLanePosition();
         edge = &l.getEdge();
+    } //try to parse the assigned parking area
+    else if (stop.parkingarea != "") {
+        // ok, we have obviously a parking area
+        MSStoppingPlace* pa = MSNet::getInstance()->getParkingArea(stop.parkingarea);
+        if (pa == 0) {
+            WRITE_ERROR("The parkingArea '" + stop.parkingarea + "' is not known" + errorSuffix);
+            return;
+        }
+        const MSLane& l = pa->getLane();
+        stop.lane = l.getID();
+        stop.endPos = pa->getEndLanePosition();
+        stop.startPos = pa->getBeginLanePosition();
+        edge = &l.getEdge();
     } else if (stop.chargingStation != "") {
         // ok, we have a charging station
         MSChargingStation* cs = MSNet::getInstance()->getChargingStation(stop.chargingStation);
@@ -949,7 +967,7 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
             stop.endPos = cs->getEndLanePosition();
             stop.startPos = cs->getBeginLanePosition();
         } else {
-            WRITE_ERROR("The charging station '" + stop.chargingStation + "' is not known" + errorSuffix);
+            WRITE_ERROR("The chargingStation '" + stop.chargingStation + "' is not known" + errorSuffix);
             return;
         }
     } else {
@@ -976,7 +994,7 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
                     stop.startPos = stop.endPos - POSITION_EPS;
                 }
             } else {
-                WRITE_ERROR("A stop must be placed on a bus stop, a charging station, a container stop or a lane" + errorSuffix);
+                WRITE_ERROR("A stop must be placed on a busStop, a chargingStation, a containerStop a parkingArea or a lane" + errorSuffix);
                 return;
             }
         }
@@ -999,12 +1017,12 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
             myActiveContainerPlan->push_back(new MSTransportable::Stage_Waiting(
                                                  MSLane::dictionary(stop.lane)->getEdge(), -1, myVehicleParameter->depart, myVehicleParameter->departPos, "start", true));
         }
-        stop.endPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ENDPOS, 0, ok, MSLane::dictionary(stop.lane)->getLength());
+        stop.endPos = attrs.getOpt<double>(SUMO_ATTR_ENDPOS, 0, ok, MSLane::dictionary(stop.lane)->getLength());
         if (attrs.hasAttribute(SUMO_ATTR_POSITION)) {
             WRITE_WARNING("Deprecated attribute 'pos' in description of stop" + errorSuffix);
-            stop.endPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_POSITION, 0, ok, stop.endPos);
+            stop.endPos = attrs.getOpt<double>(SUMO_ATTR_POSITION, 0, ok, stop.endPos);
         }
-        stop.startPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_STARTPOS, 0, ok, MAX2((SUMOReal)0., stop.endPos - 2 * POSITION_EPS));
+        stop.startPos = attrs.getOpt<double>(SUMO_ATTR_STARTPOS, 0, ok, MAX2(0., stop.endPos - 2 * POSITION_EPS));
         const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, 0, ok, false);
         if (!ok || !checkStopPos(stop.startPos, stop.endPos, MSLane::dictionary(stop.lane)->getLength(), POSITION_EPS, friendlyPos)) {
             WRITE_ERROR("Invalid start or end position for stop on lane '" + stop.lane + "'" + errorSuffix);
@@ -1013,7 +1031,7 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
     }
     if (myActivePlan != 0) {
         std::string actType = attrs.getOpt<std::string>(SUMO_ATTR_ACTTYPE, 0, ok, "waiting");
-        SUMOReal pos = (stop.startPos + stop.endPos) / 2.;
+        double pos = (stop.startPos + stop.endPos) / 2.;
         if (!myActivePlan->empty()) {
             pos = myActivePlan->back()->getArrivalPos();
         }
@@ -1038,7 +1056,7 @@ MSRouteHandler::addStop(const SUMOSAXAttributes& attrs) {
 void
 MSRouteHandler::parseWalkPositions(const SUMOSAXAttributes& attrs, const std::string& personID,
                                    const MSEdge* fromEdge, const MSEdge*& toEdge,
-                                   SUMOReal& departPos, SUMOReal& arrivalPos, MSStoppingPlace*& bs, bool& ok) {
+                                   double& departPos, double& arrivalPos, MSStoppingPlace*& bs, bool& ok) {
     const std::string description = "person '" + personID + "' walking from " + fromEdge->getID();
 
     departPos = parseWalkPos(SUMO_ATTR_DEPARTPOS, description, fromEdge,
@@ -1059,8 +1077,8 @@ MSRouteHandler::parseWalkPositions(const SUMOSAXAttributes& attrs, const std::st
         }
         arrivalPos = (bs->getBeginLanePosition() + bs->getEndLanePosition()) / 2.;
         if (attrs.hasAttribute(SUMO_ATTR_ARRIVALPOS)) {
-            const SUMOReal arrPos = parseWalkPos(SUMO_ATTR_ARRIVALPOS, description, toEdge,
-                                                 attrs.get<std::string>(SUMO_ATTR_ARRIVALPOS, description.c_str(), ok));
+            const double arrPos = parseWalkPos(SUMO_ATTR_ARRIVALPOS, description, toEdge,
+                                               attrs.get<std::string>(SUMO_ATTR_ARRIVALPOS, description.c_str(), ok));
             if (arrPos >= bs->getBeginLanePosition() && arrPos < bs->getEndLanePosition()) {
                 arrivalPos = arrPos;
             } else {
@@ -1081,9 +1099,9 @@ MSRouteHandler::parseWalkPositions(const SUMOSAXAttributes& attrs, const std::st
 }
 
 
-SUMOReal
+double
 MSRouteHandler::parseWalkPos(SumoXMLAttr attr, const std::string& id, const MSEdge* edge, const std::string& val) {
-    SUMOReal result;
+    double result;
     std::string error;
     ArrivalPosDefinition proc;
     // only supports 'random' and 'max'
