@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Wed, 10. Dec 2003
-/// @version $Id: MSVehicleControl.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: MSVehicleControl.cpp 23840 2017-04-06 08:45:47Z namdre $
 ///
 // The class responsible for building and deletion of vehicles
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -44,10 +44,6 @@
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/options/OptionsCont.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // member method definitions
@@ -68,7 +64,6 @@ MSVehicleControl::MSVehicleControl() :
     myDefaultPedTypeMayBeDeleted(true),
     myWaitingForPerson(0),
     myWaitingForContainer(0),
-    myScale(-1),
     myMaxSpeedFactor(1),
     myMinDeceleration(SUMOVTypeParameter::getDefaultDecel(SVC_IGNORING)) {
     SUMOVTypeParameter defType(DEFAULT_VTYPE_ID, SVC_PASSENGER);
@@ -77,9 +72,7 @@ MSVehicleControl::MSVehicleControl() :
     defPedType.setParameter |= VTYPEPARS_VEHICLECLASS_SET;
     myVTypeDict[DEFAULT_PEDTYPE_ID] = MSVehicleType::build(defPedType);
     OptionsCont& oc = OptionsCont::getOptions();
-    if (oc.isSet("scale")) {
-        myScale = oc.getFloat("scale");
-    }
+    myScale = oc.getFloat("scale");
     myMaxRandomDepartOffset = string2time(oc.getString("random-depart-offset"));
 }
 
@@ -97,7 +90,7 @@ MSVehicleControl::~MSVehicleControl() {
     myVTypeDistDict.clear();
     // delete vehicle types
     for (VTypeDictType::iterator i = myVTypeDict.begin(); i != myVTypeDict.end(); ++i) {
-        delete(*i).second;
+        //delete(*i).second;
     }
     myVTypeDict.clear();
 }
@@ -156,7 +149,7 @@ MSVehicleControl::vehicleDeparted(const SUMOVehicle& v) {
 
 
 void
-MSVehicleControl::setState(int runningVehNo, int loadedVehNo, int endedVehNo, SUMOReal totalDepartureDelay, SUMOReal totalTravelTime) {
+MSVehicleControl::setState(int runningVehNo, int loadedVehNo, int endedVehNo, double totalDepartureDelay, double totalTravelTime) {
     myRunningVehNo = runningVehNo;
     myLoadedVehNo = loadedVehNo;
     myEndedVehNo = endedVehNo;
@@ -260,6 +253,15 @@ MSVehicleControl::addVType(MSVehicleType* vehType) {
 }
 
 
+void
+MSVehicleControl::removeVType(const MSVehicleType* vehType) {
+    assert(vehType != 0);
+    assert(myVTypeDict.find(vehType->getID()) != myVTypeDict.end());
+    myVTypeDict.erase(vehType->getID());
+    delete vehType;
+}
+
+
 bool
 MSVehicleControl::addVTypeDistribution(const std::string& id, RandomDistributor<MSVehicleType*>* vehTypeDistribution) {
     if (checkVType(id)) {
@@ -328,13 +330,13 @@ MSVehicleControl::removeWaiting(const MSEdge* const edge, SUMOVehicle* vehicle)
 
 
 SUMOVehicle*
-MSVehicleControl::getWaitingVehicle(const MSEdge* const edge, const std::set<std::string>& lines, const SUMOReal position, const std::string ridingID) {
+MSVehicleControl::getWaitingVehicle(const MSEdge* const edge, const std::set<std::string>& lines, const double position, const std::string ridingID) {
     if (myWaiting.find(edge) != myWaiting.end()) {
         // for every vehicle waiting vehicle at this edge
         std::vector<SUMOVehicle*> waitingTooFarAway;
         for (std::vector<SUMOVehicle*>::const_iterator it = myWaiting[edge].begin(); it != myWaiting[edge].end(); ++it) {
             const std::string& line = (*it)->getParameter().line == "" ? (*it)->getParameter().id : (*it)->getParameter().line;
-            SUMOReal vehiclePosition = (*it)->getPositionOnLane();
+            double vehiclePosition = (*it)->getPositionOnLane();
             // if the line of the vehicle is contained in the set of given lines and the vehicle is stopped and is positioned
             // in the interval [position - t, position + t] for a tolerance t=10
             if (lines.count(line)) {
@@ -369,7 +371,7 @@ MSVehicleControl::abortWaiting() {
 
 
 int
-MSVehicleControl::getQuota(SUMOReal frac) const {
+MSVehicleControl::getQuota(double frac) const {
     frac = frac < 0 ? myScale : frac;
     if (frac < 0 || frac == 1.) {
         return 1;
