@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Fri, 30.01.2009
-/// @version $Id: MSDevice_Emissions.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSDevice_Emissions.h 23665 2017-03-27 09:04:40Z namdre $
 ///
 // A device which collects vehicular emissions
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -102,9 +102,13 @@ public:
         * @see MSMoveReminder::notifyMove
         * @see PollutantsInterface
         */
-    bool notifyMove(SUMOVehicle& veh, SUMOReal oldPos, SUMOReal newPos, SUMOReal newSpeed);
+    bool notifyMove(SUMOVehicle& veh, double oldPos, double newPos, double newSpeed);
     /// @}
 
+    /// @brief return the name for this type of device
+    const std::string deviceName() const {
+        return "emissions";
+    }
 
     /** @brief Called on writing tripinfo output
      *
