@@ -4,12 +4,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Tue, 04 Dec 2007
-/// @version $Id: MSDevice_Routing.h 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: MSDevice_Routing.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // A device that performs vehicle rerouting based on current edge speeds
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2007-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2007-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -62,7 +62,7 @@ class MSLane;
  * The routing-device system consists of in-vehicle devices that perform a routing
  *  and a simulation-wide (static) methods for colecting edge weights.
  *
- * The edge weights container "myEdgeEfforts" is pre-initialised as soon as one
+ * The edge weights container "myEdgeSpeeds" is pre-initialised as soon as one
  *  device is built and is kept updated via an event that adapts it to the current
  *  mean speed on the simulated network's edges.
  *
@@ -80,6 +80,11 @@ public:
      */
     static void insertOptions(OptionsCont& oc);
 
+    /** @brief checks MSDevice_Routing-options
+     * @param[filled] oc The options container with the user-defined options
+     */
+    static bool checkOptions(OptionsCont& oc);
+
 
     /** @brief Build devices for the given vehicle, if needed
      *
@@ -106,7 +111,7 @@ public:
 
     /// @brief returns whether any routing actions take place
     static bool isEnabled() {
-        return !myWithTaz && !myEdgeEfforts.empty();
+        return !myWithTaz && !myEdgeSpeeds.empty();
     }
 
     /// @brief return the router instance
@@ -155,9 +160,14 @@ public:
      * @see MSEventHandler
      * @see WrappingCommand
      */
-    bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason);
+    bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
     /// @}
 
+    /// @brief return the name for this type of device
+    const std::string deviceName() const {
+        return "rerouting";
+    }
+
 
     /// @brief initiate the rerouting, create router / thread pool on first use
     void reroute(const SUMOTime currentTime, const bool onInit = false);
@@ -176,7 +186,7 @@ public:
     }
 
     /// @brief return current travel speed assumption
-    static SUMOReal getAssumedSpeed(const MSEdge* edge);
+    static double getAssumedSpeed(const MSEdge* edge);
 
 
 private:
@@ -274,7 +284,7 @@ private:
      * @return The effort (time to pass in this case) for an edge
      * @see DijkstraRouterTT_ByProxi
      */
-    static SUMOReal getEffort(const MSEdge* const e, const SUMOVehicle* const v, SUMOReal t);
+    static double getEffort(const MSEdge* const e, const SUMOVehicle* const v, double t);
 
 
 
@@ -315,11 +325,11 @@ private:
     /// @brief The weights adaptation/overwriting command
     static Command* myEdgeWeightSettingCommand;
 
-    /// @brief The container of edge efforts
-    static std::vector<SUMOReal> myEdgeEfforts;
+    /// @brief The container of edge speeds
+    static std::vector<double> myEdgeSpeeds;
 
     /// @brief Information which weight prior edge efforts have
-    static SUMOReal myAdaptationWeight;
+    static double myAdaptationWeight;
 
     /// @brief At which time interval the edge weights get updated
     static SUMOTime myAdaptationInterval;
@@ -327,6 +337,15 @@ private:
     /// @brief Information when the last edge weight adaptation occured
     static SUMOTime myLastAdaptation;
 
+    /// @brief The number of steps for averaging edge speeds (ring-buffer)
+    static int myAdaptationSteps;
+
+    /// @brief The current index in the pastEdgeSpeed ring-buffer
+    static int myAdaptationStepsIndex;
+
+    /// @brief The container of edge speeds
+    static std::vector<std::vector<double> > myPastEdgeSpeeds;
+
     /// @brief whether taz shall be used at initial rerouting
     static bool myWithTaz;
 
@@ -340,7 +359,7 @@ private:
     static AStarRouter<MSEdge, SUMOVehicle, prohibited_withPermissions<MSEdge, SUMOVehicle> >* myRouterWithProhibited;
 
     /// @brief Whether to disturb edge weights dynamically
-    static SUMOReal myRandomizeWeightsFactor;
+    static double myRandomizeWeightsFactor;
 
 #ifdef HAVE_FOX
     static FXWorkerThread::Pool myThreadPool;
