@@ -6,12 +6,12 @@
 /// @author  Melanie Weber
 /// @author  Andreas Kendziorra
 /// @date    Fri, 30.01.2009
-/// @version $Id: MSDevice_Transportable.h 21184 2016-07-18 07:12:20Z behrisch $
+/// @version $Id: MSDevice_Transportable.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // A device which is used to keep track of persons and containers riding with a vehicle
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -78,7 +78,7 @@ public:
      * @see MSMoveReminder
      * @see MSMoveReminder::notifyMove
      */
-    bool notifyMove(SUMOVehicle& veh, SUMOReal oldPos, SUMOReal newPos, SUMOReal newSpeed);
+    bool notifyMove(SUMOVehicle& veh, double oldPos, double newPos, double newSpeed);
 
 
     /** @brief Adds passengers on vehicle insertion
@@ -89,7 +89,7 @@ public:
      * @see MSMoveReminder::notifyEnter
      * @see MSMoveReminder::Notification
      */
-    bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason);
+    bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
 
 
     /** @brief Passengers leaving on arrival
@@ -101,11 +101,18 @@ public:
      *
      * @return True if it did not leave the net.
      */
-    bool notifyLeave(SUMOVehicle& veh, SUMOReal lastPos,
-                     MSMoveReminder::Notification reason);
+    bool notifyLeave(SUMOVehicle& veh, double lastPos,
+                     MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
     /// @}
 
 
+    /// @brief return the name for this type of device
+    const std::string deviceName() const {
+        return myAmContainer ? "container" : "person";
+    }
+
+    /// @brief try to retrieve the given parameter from this device. Throw exception for unsupported key
+    std::string getParameter(const std::string& key) const;
 
     /** @brief Add a passenger
      *
@@ -114,6 +121,13 @@ public:
     void addTransportable(MSTransportable* transportable);
 
 
+    /** @brief Remove a passenger (TraCI)
+     *
+     * @param[in] transportable The passenger / container to remove.
+     */
+    void removeTransportable(MSTransportable* transportable);
+
+
     /** @brief Return the number of passengers / containers
      * @return The number of stored transportables
      */
