@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    2004-11-23
-/// @version $Id: MSInductLoop.h 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: MSInductLoop.h 23800 2017-04-04 09:37:29Z behrisch $
 ///
 // An unextended detector measuring at a fixed position on a fixed lane.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -77,12 +77,13 @@ public:
      * Adds reminder to MSLane.
      *
      * @param[in] id Unique id
-     * @param[in] lane Lane where detector woks on
+     * @param[in] lane Lane where detector works on
      * @param[in] position Position of the detector within the lane
-     * @param[in] splitByType Whether additional information split by vehicle classes shall be generated
+     * @param[in] vTypes which vehicle types are considered
      */
     MSInductLoop(const std::string& id, MSLane* const lane,
-                 SUMOReal positionInMeters, bool splitByType);
+                 double positionInMeters,
+                 const std::string& vTypes);
 
 
     /// @brief Destructor
@@ -97,7 +98,7 @@ public:
     /** @brief Returns the position of the detector on the lane
      * @return The detector's position in meters
      */
-    SUMOReal getPosition() const {
+    double getPosition() const {
         return myPosition;
     }
 
@@ -114,7 +115,7 @@ public:
      * @return True if vehicle enters the induction loop
      * @see Notification
      */
-    bool notifyEnter(SUMOVehicle& veh, Notification reason);
+    bool notifyEnter(SUMOVehicle& veh, Notification reason, const MSLane* enteredLane = 0);
 
     /** @brief Checks whether the vehicle shall be counted and/or shall still touch this MSMoveReminder
      *
@@ -132,7 +133,7 @@ public:
      * @see enterDetectorByMove
      * @see leaveDetectorByMove
      */
-    bool notifyMove(SUMOVehicle& veh, SUMOReal oldPos, SUMOReal newPos, SUMOReal newSpeed);
+    bool notifyMove(SUMOVehicle& veh, double oldPos, double newPos, double newSpeed);
 
 
     /** @brief Dismisses the vehicle if it is on the detector due to a lane change
@@ -149,7 +150,7 @@ public:
      * @see MSMoveReminder
      * @see MSMoveReminder::notifyLeave
      */
-    bool notifyLeave(SUMOVehicle& veh, SUMOReal lastPos, MSMoveReminder::Notification reason);
+    bool notifyLeave(SUMOVehicle& veh, double lastPos, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
 
 
     //@}
@@ -166,7 +167,7 @@ public:
      *
      * @return The speed [m/s] of the vehicle if one is on the detector, -1 otherwise
      */
-    SUMOReal getCurrentSpeed() const;
+    double getCurrentSpeed() const;
 
 
     /** @brief Returns the length of the vehicle on the detector
@@ -176,7 +177,7 @@ public:
      *
      * @return The length [m] of the vehicle if one is on the detector, -1 otherwise
      */
-    SUMOReal getCurrentLength() const;
+    double getCurrentLength() const;
 
 
     /** @brief Returns the current occupancy
@@ -188,7 +189,7 @@ public:
      * @return This detector's current occupancy
      * @todo recheck (especially if more than one vehicle has passed)
      */
-    SUMOReal getCurrentOccupancy() const;
+    double getCurrentOccupancy() const;
 
 
     /** @brief Returns the number of vehicles that have passed the detector
@@ -200,7 +201,7 @@ public:
      * @return The number of vehicles that have passed the detector
      * @todo recheck (especially if more than one vehicle has passed)
      */
-    unsigned int getCurrentPassedNumber() const;
+    int getCurrentPassedNumber() const;
 
 
     /** @brief Returns the ids of vehicles that have passed the detector
@@ -215,7 +216,7 @@ public:
      *
      * @return Timesteps from last leaving (detection) of the detector
      */
-    SUMOReal getTimestepsSinceLastDetection() const;
+    double getTimeSinceLastDetection() const;
     //@}
 
 
@@ -260,7 +261,7 @@ public:
          * @param[in] entryTimestep The time at which the vehicle entered the detector
          * @param[in] leaveTimestep The time at which the vehicle left the detector
          */
-        VehicleData(const std::string& id, SUMOReal vehLength, SUMOReal entryTimestep, SUMOReal leaveTimestep,
+        VehicleData(const std::string& id, double vehLength, double entryTimestep, double leaveTimestep,
                     const std::string& typeID)
             : idM(id), lengthM(vehLength), entryTimeM(entryTimestep), leaveTimeM(leaveTimestep),
               speedM(vehLength / MAX2(leaveTimestep - entryTimestep, NUMERICAL_EPS)), typeIDM(typeID) {}
@@ -268,13 +269,13 @@ public:
         /// @brief The id of the vehicle
         std::string idM;
         /// @brief Length of the vehicle
-        SUMOReal lengthM;
+        double lengthM;
         /// @brief Entry-time of the vehicle in [s]
-        SUMOReal entryTimeM;
+        double entryTimeM;
         /// @brief Leave-time of the vehicle in [s]
-        SUMOReal leaveTimeM;
+        double leaveTimeM;
         /// @brief Speed of the vehicle in [m/s]
-        SUMOReal speedM;
+        double speedM;
         /// @brief Type of the vehicle in
         std::string typeIDM;
     };
@@ -283,8 +284,8 @@ public:
     /** @brief Returns vehicle data for vehicles that have been on the detector starting at the given time
      *
      * @param[in] t The time from which vehicles shall be counted
-     * @param[in] full Whether entryTime or leaveTime shall be compaired against t
-     *            (the latter gives a more complete picture but may include vehicles in multiple steps  even if they did not stay on the detectort)
+     * @param[in] leaveTime Whether entryTime or leaveTime shall be compared against t
+     *            (the latter gives a more complete picture but may include vehicles in multiple steps even if they did not stay on the detector)
      * @return The list of vehicles
      */
     virtual std::vector<VehicleData> collectVehiclesOnDet(SUMOTime t, bool leaveTime = false) const;
@@ -298,7 +299,7 @@ protected:
      * @param veh The entering vehicle.
      * @param entryTimestep Timestep (not necessary integer) of entrance.
      */
-    virtual void enterDetectorByMove(SUMOVehicle& veh, SUMOReal entryTimestep);
+    virtual void enterDetectorByMove(SUMOVehicle& veh, double entryTimestep);
 
 
     /** @brief Processes a vehicle that leaves the detector
@@ -309,14 +310,14 @@ protected:
      * @param veh The leaving vehicle.
      * @param leaveTimestep Timestep (not necessary integer) of leaving.
      */
-    virtual void leaveDetectorByMove(SUMOVehicle& veh, SUMOReal leaveTimestep);
+    virtual void leaveDetectorByMove(SUMOVehicle& veh, double leaveTimestep);
 
 
     /** @brief Removes a vehicle from the detector's map myVehiclesOnDet.
      * @param veh The leaving vehicle.
      * @param lastPos The last position of the leaving vehicle.
      */
-    virtual void leaveDetectorByLaneChange(SUMOVehicle& veh, SUMOReal lastPos);
+    virtual void leaveDetectorByLaneChange(SUMOVehicle& veh, double lastPos);
     /// @}
 
 
@@ -325,12 +326,12 @@ protected:
     ///@{
 
     /// @brief Adds up VehicleData::speedM
-    static inline SUMOReal speedSum(SUMOReal sumSoFar, const MSInductLoop::VehicleData& data) {
+    static inline double speedSum(double sumSoFar, const MSInductLoop::VehicleData& data) {
         return sumSoFar + data.speedM;
     }
 
     /// @brief Adds up VehicleData::lengthM
-    static inline SUMOReal lengthSum(SUMOReal sumSoFar, const MSInductLoop::VehicleData& data) {
+    static inline double lengthSum(double sumSoFar, const MSInductLoop::VehicleData& data) {
         return sumSoFar + data.lengthM;
     }
     ///@}
@@ -338,19 +339,16 @@ protected:
 
 protected:
     /// @brief Detector's position on lane [m]
-    const SUMOReal myPosition;
-
-    /// @brief Whether additional information split by vehicle classes shall be generated
-    bool mySplitByType;
+    const double myPosition;
 
     /// @brief Leave-time of the last vehicle detected [s]
-    SUMOReal myLastLeaveTime;
+    double myLastLeaveTime;
 
     /// @brief Occupancy by the last vehicle detected.
-    SUMOReal myLastOccupancy;
+    double myLastOccupancy;
 
-    /// @brief The number of dismissed vehicles
-    unsigned myDismissedVehicleNumber;
+    /// @brief The number of entered vehicles
+    int myEnteredVehicleNumber;
 
 
     /// @brief Type of myVehicleDataCont.
@@ -364,14 +362,12 @@ protected:
 
 
     /// @brief Type of myVehiclesOnDet
-    typedef std::map< SUMOVehicle*, SUMOReal > VehicleMap;
+
+    typedef std::map< SUMOVehicle*, double > VehicleMap;
 
     /// @brief Data for vehicles that have entered the detector (vehicle -> enter time)
     VehicleMap myVehiclesOnDet;
 
-    void writeTypedXMLOutput(OutputDevice& dev, SUMOTime startTime, SUMOTime stopTime,
-                             const std::string& type, const VehicleDataCont& vdc, const VehicleMap& vm);
-
 private:
     /// @brief Invalidated copy constructor.
     MSInductLoop(const MSInductLoop&);
