@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    2011-09.08
-/// @version $Id: MSInstantInductLoop.cpp 20970 2016-06-15 10:59:59Z behrisch $
+/// @version $Id: MSInstantInductLoop.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // An instantaneous induction loop
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2011-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -45,18 +45,15 @@
 #include <utils/common/StringUtils.h>
 #include <utils/iodevices/OutputDevice.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
 MSInstantInductLoop::MSInstantInductLoop(const std::string& id,
-        OutputDevice& od, MSLane* const lane, SUMOReal positionInMeters) :
+        OutputDevice& od, MSLane* const lane, double positionInMeters,
+        const std::string& vTypes) :
     MSMoveReminder(id, lane),
-    MSDetectorFileOutput(id),
+    MSDetectorFileOutput(id, vTypes),
     myOutputDevice(od),
     myPosition(positionInMeters), myLastExitTime(-1) {
     assert(myPosition >= 0 && myPosition <= myLane->getLength());
@@ -69,31 +66,38 @@ MSInstantInductLoop::~MSInstantInductLoop() {
 
 
 bool
-MSInstantInductLoop::notifyMove(SUMOVehicle& veh, SUMOReal oldPos,
-                                SUMOReal newPos, SUMOReal newSpeed) {
+MSInstantInductLoop::notifyMove(SUMOVehicle& veh, double oldPos,
+                                double newPos, double newSpeed) {
+    if (!vehicleApplies(veh)) {
+        return false;
+    }
     if (newPos < myPosition) {
         // detector not reached yet
         return true;
     }
+
+    const double oldSpeed = veh.getPreviousSpeed();
+    double enterSpeed = MSGlobals::gSemiImplicitEulerUpdate ? newSpeed : oldSpeed; // NOTE: For the euler update, the vehicle is assumed to travel at constant speed for the whole time step
+
     if (newPos >= myPosition && oldPos < myPosition/* && static_cast<MSVehicle&>(veh).getLane() == myLane*/) {
-        SUMOReal entryTime = SIMTIME;
-        if (newSpeed != 0) {
-            if (myPosition < newPos) {
-                entryTime -= (newPos - myPosition) / newSpeed;
-            }
-        }
+        const double timeBeforeEnter = MSCFModel::passingTime(oldPos, myPosition, newPos, oldSpeed, newSpeed);
+        const double entryTime = SIMTIME - TS + timeBeforeEnter;
+        enterSpeed = MSCFModel::speedAfterTime(timeBeforeEnter, oldSpeed, newPos - oldPos);
         if (myLastExitTime >= 0) {
-            write("enter", entryTime, veh, newSpeed, "gap", entryTime - myLastExitTime);
+            write("enter", entryTime, veh, enterSpeed, "gap", entryTime - myLastExitTime);
         } else {
-            write("enter", entryTime, veh, newSpeed);
+            write("enter", entryTime, veh, enterSpeed);
         }
         myEntryTimes[&veh] = entryTime;
     }
-    if (newPos - veh.getVehicleType().getLength() > myPosition) {
-        std::map<SUMOVehicle*, SUMOReal>::iterator i = myEntryTimes.find(&veh);
+    const double newBackPos = newPos - veh.getVehicleType().getLength();
+    const double oldBackPos = oldPos - veh.getVehicleType().getLength();
+    if (newBackPos > myPosition) {
+        std::map<SUMOVehicle*, double>::iterator i = myEntryTimes.find(&veh);
         if (i != myEntryTimes.end()) {
             // vehicle passed the detector
-            const SUMOReal leaveTime = SIMTIME - (newPos - veh.getVehicleType().getLength() - myPosition) / newSpeed;
+            const double timeBeforeLeave = MSCFModel::passingTime(oldBackPos, myPosition, newBackPos, oldSpeed, newSpeed);
+            const double leaveTime = SIMTIME - TS + timeBeforeLeave;
             write("leave", leaveTime, veh, newSpeed, "occupancy", leaveTime - (*i).second);
             myEntryTimes.erase(i);
             myLastExitTime = leaveTime;
@@ -107,7 +111,7 @@ MSInstantInductLoop::notifyMove(SUMOVehicle& veh, SUMOReal oldPos,
 
 
 void
-MSInstantInductLoop::write(const char* state, SUMOReal t, SUMOVehicle& veh, SUMOReal speed, const char* add, SUMOReal addValue) {
+MSInstantInductLoop::write(const char* state, double t, SUMOVehicle& veh, double speed, const char* add, double addValue) {
     myOutputDevice.openTag("instantOut").writeAttr(
         "id", getID()).writeAttr("time", toString(t)).writeAttr("state", state).writeAttr(
             "vehID", veh.getID()).writeAttr("speed", toString(speed)).writeAttr(
@@ -121,13 +125,13 @@ MSInstantInductLoop::write(const char* state, SUMOReal t, SUMOVehicle& veh, SUMO
 
 
 bool
-MSInstantInductLoop::notifyLeave(SUMOVehicle& veh, SUMOReal lastPos, MSMoveReminder::Notification reason) {
+MSInstantInductLoop::notifyLeave(SUMOVehicle& veh, double /* lastPos */, MSMoveReminder::Notification reason, const MSLane* /* enteredLane */) {
     if (reason == MSMoveReminder::NOTIFICATION_JUNCTION) {
         // vehicle might have jumped over detector at the end of the lane. we need
         // one more notifyMove to register it
         return true;
     }
-    std::map<SUMOVehicle*, SUMOReal>::iterator i = myEntryTimes.find(&veh);
+    std::map<SUMOVehicle*, double>::iterator i = myEntryTimes.find(&veh);
     if (i != myEntryTimes.end()) {
         write("leave", SIMTIME, veh, veh.getSpeed());
         myEntryTimes.erase(i);
@@ -138,7 +142,7 @@ MSInstantInductLoop::notifyLeave(SUMOVehicle& veh, SUMOReal lastPos, MSMoveRemin
 
 void
 MSInstantInductLoop::writeXMLDetectorProlog(OutputDevice& dev) const {
-    dev.writeXMLHeader("instantE1");
+    dev.writeXMLHeader("instantE1", "instant_e1_file.xsd");
 }
 
 
