@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Tue, 17.11.2009
-/// @version $Id: MSMeanData.h 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: MSMeanData.h 23188 2017-03-02 11:59:04Z luecken $
 ///
 // Data collector for edges/lanes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -70,13 +70,13 @@ public:
      * @class MeanDataValues
      * @brief Data structure for mean (aggregated) edge/lane values
      *
-     * Structure holding values that describe the emissions aggregated
+     * Structure holding values that describe the emissions (XXX: emissions?) aggregated, refs. #2579
      *  over some seconds.
      */
     class MeanDataValues : public MSMoveReminder {
     public:
         /** @brief Constructor */
-        MeanDataValues(MSLane* const lane, const SUMOReal length, const bool doAdd, const std::set<std::string>* const vTypes = 0);
+        MeanDataValues(MSLane* const lane, const double length, const bool doAdd, const MSMeanData* const parent);
 
         /** @brief Destructor */
         virtual ~MeanDataValues();
@@ -101,7 +101,7 @@ public:
          * @see MSMoveReminder::notifyEnter
          * @see MSMoveReminder::Notification
          */
-        virtual bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason);
+        virtual bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
 
 
         /** @brief Checks whether the reminder still has to be notified about the vehicle moves
@@ -117,8 +117,8 @@ public:
          *
          * @return True if vehicle hasn't passed the reminder completely.
          */
-        bool notifyMove(SUMOVehicle& veh, SUMOReal oldPos,
-                        SUMOReal newPos, SUMOReal newSpeed);
+        bool notifyMove(SUMOVehicle& veh, double oldPos,
+                        double newPos, double newSpeed);
 
 
         /** @brief Called if the vehicle leaves the reminder's lane
@@ -129,16 +129,8 @@ public:
          * @see MSMoveReminder
          * @see MSMoveReminder::notifyLeave
          */
-        virtual bool notifyLeave(SUMOVehicle& veh, SUMOReal lastPos,
-                                 MSMoveReminder::Notification reason);
-
-
-        /** @brief Tests whether the vehicles type is to be regarded
-         *
-         * @param[in] veh The regarded vehicle
-         * @return whether the type of the vehicle is in the set of regarded types
-         */
-        bool vehicleApplies(const SUMOVehicle& veh) const;
+        virtual bool notifyLeave(SUMOVehicle& veh, double lastPos,
+                                 MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
 
 
         /** @brief Returns whether any data was collected.
@@ -160,30 +152,36 @@ public:
          * @exception IOError If an error on writing occurs (!!! not yet implemented)
          */
         virtual void write(OutputDevice& dev, const SUMOTime period,
-                           const SUMOReal numLanes, const SUMOReal defaultTravelTime,
+                           const double numLanes, const double defaultTravelTime,
                            const int numVehicles = -1) const = 0;
 
         /** @brief Returns the number of collected sample seconds.
-         * @return the number of collected sample seconds
-         */
-        virtual SUMOReal getSamples() const;
+        * @return the number of collected sample seconds
+        */
+        virtual double getSamples() const;
+
+        /** @brief Returns the total travelled distance.
+        * @return the total travelled distance
+        */
+        double getTravelledDistance() const {
+            return travelledDistance;
+        }
 
     protected:
+        /// @brief The meandata parent
+        const MSMeanData* const myParent;
+
         /// @brief The length of the lane / edge the data collector is on
-        const SUMOReal myLaneLength;
+        const double myLaneLength;
 
         /// @name Collected values
         /// @{
         /// @brief The number of sampled vehicle movements (in s)
-        SUMOReal sampleSeconds;
-    public:
-        /// @brief The sum of the distances the vehicles travelled
-        SUMOReal travelledDistance;
-        //@}
+        double sampleSeconds;
 
-    protected:
-        /// @brief The vehicle types to look for (0 or empty means all)
-        const std::set<std::string>* const myVehicleTypes;
+        /// @brief The sum of the distances the vehicles travelled
+        double travelledDistance;
+        //@}
 
     };
 
@@ -195,9 +193,8 @@ public:
     class MeanDataValueTracker : public MeanDataValues {
     public:
         /** @brief Constructor */
-        MeanDataValueTracker(MSLane* const lane, const SUMOReal length,
-                             const std::set<std::string>* const vTypes = 0,
-                             const MSMeanData* const parent = 0);
+        MeanDataValueTracker(MSLane* const lane, const double length,
+                             const MSMeanData* const parent);
 
         /** @brief Destructor */
         virtual ~MeanDataValueTracker();
@@ -216,16 +213,9 @@ public:
         /// @{
 
         /** @brief Internal notification about the vehicle moves
-         *
-         * Indicator if the reminders is still active for the passed
-         * vehicle/parameters. If false, the vehicle will erase this reminder
-         * from it's reminder-container.
-         *
-         * @param[in] veh Vehicle that asks this reminder.
-         * @param[in] timeOnLane time the vehicle spent on the lane.
-         * @param[in] speed Moving speed.
+         *  @see MSMoveReminder::notifyMoveInternal().
          */
-        void notifyMoveInternal(SUMOVehicle& veh, SUMOReal timeOnLane, SUMOReal speed);
+        void notifyMoveInternal(const SUMOVehicle& veh, const double frontOnLane, const double timeOnLane, const double meanSpeedFrontOnLane, const double meanSpeedVehicleOnLane, const double travelledDistanceFrontOnLane, const double travelledDistanceVehicleOnLane);
 
 
         /** @brief Called if the vehicle leaves the reminder's lane
@@ -237,7 +227,7 @@ public:
          * @see MSMoveReminder
          * @see MSMoveReminder::notifyLeave
          */
-        bool notifyLeave(SUMOVehicle& veh, SUMOReal lastPos, MSMoveReminder::Notification reason);
+        bool notifyLeave(SUMOVehicle& veh, double lastPos, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
 
 
         /** @brief Computes current values and adds them to their sums
@@ -251,7 +241,7 @@ public:
          * @see MSMoveReminder::notifyEnter
          * @return Always true
          */
-        bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason);
+        bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
         //@}
 
         bool isEmpty() const;
@@ -264,14 +254,14 @@ public:
          * @exception IOError If an error on writing occurs (!!! not yet implemented)
          */
         void write(OutputDevice& dev, const SUMOTime period,
-                   const SUMOReal numLanes, const SUMOReal defaultTravelTime,
+                   const double numLanes, const double defaultTravelTime,
                    const int numVehicles = -1) const;
 
         int getNumReady() const;
 
         void clearFirst();
 
-        SUMOReal getSamples() const;
+        double getSamples() const;
 
     private:
         class TrackerEntry {
@@ -296,14 +286,11 @@ public:
         };
 
         /// @brief The map of vehicles to data entries
-        std::map<SUMOVehicle*, TrackerEntry*> myTrackedData;
+        std::map<const SUMOVehicle*, TrackerEntry*> myTrackedData;
 
         /// @brief The currently active meandata "intervals"
         std::list<TrackerEntry*> myCurrentData;
 
-        /// @brief The meandata parent
-        const MSMeanData* myParent;
-
     };
 
 
@@ -326,9 +313,9 @@ public:
                const SUMOTime dumpBegin, const SUMOTime dumpEnd,
                const bool useLanes, const bool withEmpty,
                const bool printDefaults, const bool withInternal,
-               const bool trackVehicles, const SUMOReal minSamples,
-               const SUMOReal maxTravelTime,
-               const std::set<std::string> vTypes);
+               const bool trackVehicles, const double minSamples,
+               const double maxTravelTime,
+               const std::string& vTypes);
 
 
     /// @brief Destructor
@@ -370,6 +357,14 @@ public:
      */
     virtual void detectorUpdate(const SUMOTime step);
 
+    double getMinSamples() const {
+        return myMinSamples;
+    }
+
+    double getMaxTravelTime() const {
+        return myMaxTravelTime;
+    }
+
 
 protected:
     /** @brief Create an instance of MeanDataValues
@@ -377,7 +372,7 @@ protected:
      * @param[in] lane The lane to create for
      * @param[in] doAdd whether to add the values as reminder to the lane
      */
-    virtual MSMeanData::MeanDataValues* createValues(MSLane* const lane, const SUMOReal length, const bool doAdd) const = 0;
+    virtual MSMeanData::MeanDataValues* createValues(MSLane* const lane, const double length, const bool doAdd) const = 0;
 
     /** @brief Resets network value in order to allow processing of the next interval
      *
@@ -431,13 +426,10 @@ protected:
 
 protected:
     /// @brief the minimum sample seconds
-    const SUMOReal myMinSamples;
+    const double myMinSamples;
 
     /// @brief the maximum travel time to write
-    const SUMOReal myMaxTravelTime;
-
-    /// @brief The vehicle types to look for (empty means all)
-    const std::set<std::string> myVehicleTypes;
+    const double myMaxTravelTime;
 
     /// @brief Value collectors; sorted by edge, then by lane
     std::vector<std::vector<MeanDataValues*> > myMeasures;
