@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Mon, 10.05.2004
-/// @version $Id: MSMeanData_Emissions.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSMeanData_Emissions.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Emission data collector for edges/lanes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -72,9 +72,8 @@ public:
     class MSLaneMeanDataValues : public MSMeanData::MeanDataValues {
     public:
         /** @brief Constructor */
-        MSLaneMeanDataValues(MSLane* const lane, const SUMOReal length, const bool doAdd,
-                             const std::set<std::string>* const vTypes = 0,
-                             const MSMeanData_Emissions* parent = 0);
+        MSLaneMeanDataValues(MSLane* const lane, const double length, const bool doAdd,
+                             const MSMeanData_Emissions* parent);
 
         /** @brief Destructor */
         virtual ~MSLaneMeanDataValues();
@@ -101,31 +100,20 @@ public:
          * @exception IOError If an error on writing occurs (!!! not yet implemented)
          */
         void write(OutputDevice& dev, const SUMOTime period,
-                   const SUMOReal numLanes, const SUMOReal defaultTravelTime,
+                   const double numLanes, const double defaultTravelTime,
                    const int numVehicles = -1) const;
 
 
     protected:
         /** @brief Internal notification about the vehicle moves
-         *
-         * Indicator if the reminders is still active for the passed
-         * vehicle/parameters. If false, the vehicle will erase this reminder
-         * from it's reminder-container.
-         *
-         * @param[in] veh Vehicle that asks this reminder.
-         * @param[in] timeOnLane time the vehicle spent on the lane.
-         * @param[in] speed Moving speed.
+         *  @see MSMoveReminder::notifyMoveInternal()
          */
-        void notifyMoveInternal(SUMOVehicle& veh, SUMOReal timeOnLane,
-                                SUMOReal speed);
+        void notifyMoveInternal(const SUMOVehicle& veh, const double /* frontOnLane */, const double timeOnLane, const double /*meanSpeedFrontOnLane*/, const double meanSpeedVehicleOnLane, const double travelledDistanceFrontOnLane, const double travelledDistanceVehicleOnLane);
 
 
     private:
         /// @brief Collected values
         PollutantsInterface::Emissions myEmissions;
-        /// @brief The meandata parent
-        const MSMeanData_Emissions* myParent;
-
     };
 
 
@@ -149,8 +137,8 @@ public:
                          const bool useLanes, const bool withEmpty,
                          const bool printDefaults, const bool withInternal,
                          const bool trackVehicles,
-                         const SUMOReal minSamples, const SUMOReal maxTravelTime,
-                         const std::set<std::string> vTypes);
+                         const double minSamples, const double maxTravelTime,
+                         const std::string& vTypes);
 
 
     /// @brief Destructor
@@ -164,7 +152,7 @@ protected:
      * @param[in] lane The lane to create for
      * @param[in] doAdd whether to add the values as reminder to the lane
      */
-    MSMeanData::MeanDataValues* createValues(MSLane* const lane, const SUMOReal length, const bool doAdd) const;
+    MSMeanData::MeanDataValues* createValues(MSLane* const lane, const double length, const bool doAdd) const;
 
 
 
