@@ -5,12 +5,12 @@
 /// @author  Mario Krumnow
 /// @author  Michael Behrisch
 /// @date    2012-04-26
-/// @version $Id: MSQueueExport.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MSQueueExport.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Export the queueing length in front of a junction (very experimental!)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2012-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -45,10 +45,6 @@
 #include <mesosim/MESegment.h>
 #endif
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -65,8 +61,8 @@ void
 MSQueueExport::writeEdge(OutputDevice& of) {
     of.openTag("lanes");
     MSEdgeControl& ec = MSNet::getInstance()->getEdgeControl();
-    const std::vector<MSEdge*>& edges = ec.getEdges();
-    for (std::vector<MSEdge*>::const_iterator e = edges.begin(); e != edges.end(); ++e) {
+    const MSEdgeVector& edges = ec.getEdges();
+    for (MSEdgeVector::const_iterator e = edges.begin(); e != edges.end(); ++e) {
         MSEdge& edge = **e;
         const std::vector<MSLane*>& lanes = edge.getLanes();
         for (std::vector<MSLane*>::const_iterator lane = lanes.begin(); lane != lanes.end(); ++lane) {
@@ -80,12 +76,12 @@ MSQueueExport::writeEdge(OutputDevice& of) {
 void
 MSQueueExport::writeLane(OutputDevice& of, const MSLane& lane) {
     // maximum of all vehicle waiting times
-    SUMOReal queueing_time = 0.0;
+    double queueing_time = 0.0;
     // back of last stopped vehicle (XXX does not check for continuous queue)
-    SUMOReal queueing_length = 0.0;
+    double queueing_length = 0.0;
     // back of last slow vehicle (XXX does not check for continuous queue)
-    SUMOReal queueing_length2 = 0.0;
-    const SUMOReal threshold_velocity = 5 / 3.6; // slow
+    double queueing_length2 = 0.0;
+    const double threshold_velocity = 5 / 3.6; // slow
 
     if (!lane.empty()) {
         for (MSLane::VehCont::const_iterator it_veh = lane.myVehicles.begin(); it_veh != lane.myVehicles.end(); ++it_veh) {
@@ -96,13 +92,13 @@ MSQueueExport::writeLane(OutputDevice& of, const MSLane& lane) {
 
             if (veh.getWaitingSeconds() > 0) {
                 queueing_time = MAX2(veh.getWaitingSeconds(), queueing_time);
-                const SUMOReal veh_back_to_lane_end = (lane.getLength() - veh.getPositionOnLane()) + veh.getVehicleType().getLength();
+                const double veh_back_to_lane_end = (lane.getLength() - veh.getPositionOnLane()) + veh.getVehicleType().getLength();
                 queueing_length = MAX2(veh_back_to_lane_end, queueing_length);
             }
 
             //Experimental
             if (veh.getSpeed() < (threshold_velocity) && (veh.getPositionOnLane() > (veh.getLane()->getLength()) * 0.25)) {
-                const SUMOReal veh_back_to_lane_end = (lane.getLength() - veh.getPositionOnLane()) + veh.getVehicleType().getLength();
+                const double veh_back_to_lane_end = (lane.getLength() - veh.getPositionOnLane()) + veh.getVehicleType().getLength();
                 queueing_length2 = MAX2(veh_back_to_lane_end, queueing_length2);
             }
         }
