@@ -3,12 +3,12 @@
 /// @author  Melanie Weber
 /// @author  Andreas Kendziorra
 /// @date    Jan 2015
-/// @version $Id: MSRailSignal.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: MSRailSignal.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A rail signal logic
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -42,10 +42,6 @@
 #include "MSPhaseDefinition.h"
 #include "MSTLLogicControl.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 
 // ===========================================================================
@@ -72,13 +68,13 @@ MSRailSignal::init(NLDetectorBuilder&) {
             MSLink* link = (*i);
             MSLane* toLane = link->getLane();   //the lane this link is leading to
             myLinksToLane[toLane].push_back(link);
-            myLinkIndices[link] = (unsigned int)std::distance(myLinks.begin(), i2); //assign the index of link to link
+            myLinkIndices[link] = (int)std::distance(myLinks.begin(), i2); //assign the index of link to link
 
             //find all lanes leading from a previous signal to link (we presume that there exists only one path from a previous signal to link)
-            std::vector<MSLane*> afferentBlock; //the vector of lanes leading from a previous signal to link
+            std::vector<const MSLane*> afferentBlock; //the vector of lanes leading from a previous signal to link
             bool noRailSignal = true;   //true if the considered lane is not outgoing from a rail signal
             //get the approaching lane of the link
-            MSLane* approachingLane = link->getApproachingLane();   //the lane this link is coming from
+            const MSLane* approachingLane = link->getLaneBefore();   //the lane this link is coming from
             afferentBlock.push_back(approachingLane);
             const MSLane* currentLane = approachingLane;
             //look recursively for all lanes that lie before approachingLane and add them to afferentBlock until a rail signal is found
@@ -200,7 +196,7 @@ MSRailSignal::getAppropriateState() {
                 bool hasOccupiedBlock = false;
                 std::vector<MSLink*>::const_iterator k;
                 for (k = myLinksToLane[lane].begin(); k != myLinksToLane[lane].end(); k++) { //for every link leading to lane
-                    std::vector<MSLane*>::const_iterator l;
+                    std::vector<const MSLane*>::const_iterator l;
                     for (l = myAfferentBlocks[(*k)].begin(); l != myAfferentBlocks[(*k)].end(); l++) {    //for every lane of the block leading from a previous signal to the link (*k)
                         if (!(*l)->isEmpty()) { //if this lane is not empty
                             hasOccupiedBlock = true;
@@ -265,11 +261,11 @@ MSRailSignal::getPhaseIndexAtTime(SUMOTime) const {
 }
 
 SUMOTime
-MSRailSignal::getOffsetFromIndex(unsigned int) const {
+MSRailSignal::getOffsetFromIndex(int) const {
     return 0;
 }
 
-unsigned int
+int
 MSRailSignal::getIndexFromOffset(SUMOTime) const {
     return 0;
 }
