@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    02. March 2012
-/// @version $Id: NBAlgorithms.h 21201 2016-07-19 11:57:22Z behrisch $
+/// @version $Id: NBAlgorithms.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // Algorithms for network computation
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2012-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -32,14 +32,14 @@
 #endif
 
 #include <map>
-
+#include "NBEdgeCont.h"
+#include "NBNodeCont.h"
 
 // ===========================================================================
 // class declarations
 // ===========================================================================
 class NBEdge;
-class NBNodeCont;
-class NBTypeCont;
+class NBNode;
 
 // ===========================================================================
 // class definitions
@@ -75,7 +75,7 @@ private:
     struct Combination {
         NBEdge* from;
         NBEdge* to;
-        SUMOReal angle;
+        double angle;
     };
 
 
@@ -144,7 +144,6 @@ public:
         crossing_by_junction_angle_sorter& operator=(const crossing_by_junction_angle_sorter& s);
 
     };
-private:
     /** @brief Assures correct order for same-angle opposite-direction edges
      * @param[in] n The currently processed node
      * @param[in] i1 Pointer to first edge
@@ -167,22 +166,22 @@ private:
 
     protected:
         /// @brief Converts the angle of the edge if it is an incoming edge
-        SUMOReal getConvAngle(NBEdge* e) const {
-            SUMOReal angle = e->getAngleAtNode(myNode);
+        double getConvAngle(NBEdge* e) const {
+            double angle = e->getAngleAtNode(myNode);
             if (angle < 0.) {
                 angle = 360. + angle;
             }
             // convert angle if the edge is an outgoing edge
             if (e->getFromNode() == myNode) {
-                angle += (SUMOReal) 180.;
-                if (angle >= (SUMOReal) 360.) {
-                    angle -= (SUMOReal) 360.;
+                angle += (double) 180.;
+                if (angle >= (double) 360.) {
+                    angle -= (double) 360.;
                 }
             }
             if (angle < 0.1 || angle > 359.9) {
-                angle = (SUMOReal) 0.;
+                angle = (double) 0.;
             }
-            assert(angle >= (SUMOReal)0 && angle < (SUMOReal)360);
+            assert(angle >= 0 && angle < (double)360);
             return angle;
         }
 
@@ -209,6 +208,10 @@ public:
      */
     static void computeNodeTypes(NBNodeCont& nc);
 
+    /** @brief Computes a single node type
+     * @param[in] node the single node to compute node type
+     */
+    static void computeSingleNodeType(NBNode* node);
 };
 
 
@@ -226,6 +229,11 @@ public:
      */
     static void computeEdgePriorities(NBNodeCont& nc);
 
+    /** @brief Computes edge priorities within a single node
+     * @param[in] node the single node
+     */
+    static void computeEdgePrioritiesSingleNode(NBNode* node);
+
 private:
     /** @brief Sets the priorites in case of a priority junction
      * @param[in] n The node to set edges' priorities
