@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Sascha Krieg
 /// @date    Fri, 19 Jul 2002
-/// @version $Id: NBCapacity2Lanes.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NBCapacity2Lanes.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A helper class which computes the lane number from given capacity
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -50,7 +50,7 @@ public:
      *
      * @param[in] divider Value for the norming divider
      */
-    NBCapacity2Lanes(SUMOReal divider) : myDivider(divider) { }
+    NBCapacity2Lanes(double divider) : myDivider(divider) { }
 
 
     /// @brief Destructor
@@ -65,7 +65,7 @@ public:
      * @param[in] capacity The capacity to convert
      * @return The capacity converted to the number of lanes
      */
-    int get(SUMOReal capacity) const {
+    int get(double capacity) const {
         capacity /= myDivider;
         if (capacity > (int) capacity) {
             capacity += 1;
@@ -79,7 +79,7 @@ public:
 
 private:
     /// @brief The norming divider
-    SUMOReal myDivider;
+    double myDivider;
 
 };
 
