@@ -5,12 +5,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NBEdgeCont.cpp 21090 2016-07-01 18:50:17Z namdre $
+/// @version $Id: NBEdgeCont.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // Storage for edges, including some functionality operating on multiple edges
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -56,10 +56,6 @@
 #include <utils/common/UtilExceptions.h>
 #include <utils/iodevices/OutputDevice.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -81,7 +77,7 @@ NBEdgeCont::~NBEdgeCont() {
 void
 NBEdgeCont::applyOptions(OptionsCont& oc) {
     // set edges dismiss/accept options
-    myEdgesMinSpeed = oc.isSet("keep-edges.min-speed") ? oc.getFloat("keep-edges.min-speed") : -1;
+    myEdgesMinSpeed = oc.getFloat("keep-edges.min-speed");
     myRemoveEdgesAfterJoining = oc.exists("keep-edges.postload") && oc.getBool("keep-edges.postload");
     // we possibly have to load the edges to keep/remove
     if (oc.isSet("keep-edges.input-file")) {
@@ -117,9 +113,9 @@ NBEdgeCont::applyOptions(OptionsCont& oc) {
         std::vector<std::string> polyS = oc.getStringVector(oc.isSet("keep-edges.in-boundary") ?
                                          "keep-edges.in-boundary" : "keep-edges.in-geo-boundary");
         // !!! throw something if length<4 || length%2!=0?
-        std::vector<SUMOReal> poly;
+        std::vector<double> poly;
         for (std::vector<std::string>::iterator i = polyS.begin(); i != polyS.end(); ++i) {
-            poly.push_back(TplConvert::_2SUMOReal((*i).c_str())); // !!! may throw something anyhow...
+            poly.push_back(TplConvert::_2double((*i).c_str())); // !!! may throw something anyhow...
         }
         if (poly.size() < 4) {
             throw ProcessError("Invalid boundary: need at least 2 coordinates");
@@ -132,9 +128,9 @@ NBEdgeCont::applyOptions(OptionsCont& oc) {
             myPrunningBoundary.push_back(Position(poly[2], poly[3]));
             myPrunningBoundary.push_back(Position(poly[0], poly[3]));
         } else {
-            for (std::vector<SUMOReal>::iterator j = poly.begin(); j != poly.end();) {
-                SUMOReal x = *j++;
-                SUMOReal y = *j++;
+            for (std::vector<double>::iterator j = poly.begin(); j != poly.end();) {
+                double x = *j++;
+                double y = *j++;
                 myPrunningBoundary.push_back(Position(x, y));
             }
         }
@@ -188,7 +184,15 @@ NBEdgeCont::ignoreFilterMatch(NBEdge* edge) {
     // check whether the edge is a named edge to keep
     if (!myRemoveEdgesAfterJoining && myEdges2Keep.size() != 0) {
         if (find(myEdges2Keep.begin(), myEdges2Keep.end(), edge->getID()) == myEdges2Keep.end()) {
-            return true;
+            // explicit whitelisting may be combined additively with other filters
+            if (myVehicleClasses2Keep == 0 && myVehicleClasses2Remove == 0
+                    && myTypes2Keep.size() == 0 && myTypes2Remove.size() == 0
+                    && myPrunningBoundary.size() == 0) {
+                return true;
+            }
+        } else {
+            // explicit whitelisting overrides other filters
+            return false;
         }
     }
     // check whether the edge is a named edge to remove
@@ -232,7 +236,7 @@ NBEdgeCont::ignoreFilterMatch(NBEdge* edge) {
             }
             myNeedGeoTransformedPrunningBoundary = false;
         }
-        if (!(edge->getGeometry().getBoxBoundary().grow((SUMOReal) POSITION_EPS).overlapsWith(myPrunningBoundary))) {
+        if (!(edge->getGeometry().getBoxBoundary().grow((double) POSITION_EPS).overlapsWith(myPrunningBoundary))) {
             return true;
         }
     }
@@ -333,21 +337,21 @@ NBEdgeCont::retrievePossiblySplit(const std::string& id, const std::string& hint
 
 
 NBEdge*
-NBEdgeCont::retrievePossiblySplit(const std::string& id, SUMOReal pos) const {
+NBEdgeCont::retrievePossiblySplit(const std::string& id, double pos) const {
     // check whether the edge was not split, yet
     NBEdge* edge = retrieve(id);
     if (edge != 0) {
         return edge;
     }
-    size_t maxLength = 0;
+    int maxLength = 0;
     std::string tid = id + "[";
     for (EdgeCont::const_iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
         if ((*i).first.find(tid) == 0) {
-            maxLength = MAX2(maxLength, (*i).first.length());
+            maxLength = MAX2(maxLength, (int)(*i).first.length());
         }
     }
     // find the part of the edge which matches the position
-    SUMOReal seen = 0;
+    double seen = 0;
     std::vector<std::string> names;
     names.push_back(id + "[1]");
     names.push_back(id + "[0]");
@@ -359,7 +363,7 @@ NBEdgeCont::retrievePossiblySplit(const std::string& id, SUMOReal pos) const {
         // The edge was splitted; check its subparts within the
         //  next step
         if (edge == 0) {
-            if (cid.length() + 3 < maxLength) {
+            if ((int)cid.length() + 3 < maxLength) {
                 names.push_back(cid + "[1]");
                 names.push_back(cid + "[0]");
             }
@@ -411,7 +415,7 @@ NBEdgeCont::rename(NBEdge* edge, const std::string& newID) {
 bool
 NBEdgeCont::splitAt(NBDistrictCont& dc, NBEdge* edge, NBNode* node) {
     return splitAt(dc, edge, node, edge->getID() + "[0]", edge->getID() + "[1]",
-                   (unsigned int) edge->myLanes.size(), (unsigned int) edge->myLanes.size());
+                   (int) edge->myLanes.size(), (int) edge->myLanes.size());
 }
 
 
@@ -419,10 +423,10 @@ bool
 NBEdgeCont::splitAt(NBDistrictCont& dc, NBEdge* edge, NBNode* node,
                     const std::string& firstEdgeName,
                     const std::string& secondEdgeName,
-                    unsigned int noLanesFirstEdge, unsigned int noLanesSecondEdge,
-                    const SUMOReal speed,
+                    int noLanesFirstEdge, int noLanesSecondEdge,
+                    const double speed,
                     const int changedLeft) {
-    SUMOReal pos;
+    double pos;
     pos = edge->getGeometry().nearest_offset_to_point2D(node->getPosition());
     if (pos <= 0) {
         pos = GeomHelper::nearest_offset_on_line_to_point2D(
@@ -439,11 +443,11 @@ NBEdgeCont::splitAt(NBDistrictCont& dc, NBEdge* edge, NBNode* node,
 
 bool
 NBEdgeCont::splitAt(NBDistrictCont& dc,
-                    NBEdge* edge, SUMOReal pos, NBNode* node,
+                    NBEdge* edge, double pos, NBNode* node,
                     const std::string& firstEdgeName,
                     const std::string& secondEdgeName,
-                    unsigned int noLanesFirstEdge, unsigned int noLanesSecondEdge,
-                    const SUMOReal speed,
+                    int noLanesFirstEdge, int noLanesSecondEdge,
+                    const double speed,
                     const int changedLeft
                    ) {
     // there must be at least some overlap between first and second edge
@@ -506,6 +510,8 @@ NBEdgeCont::splitAt(NBDistrictCont& dc,
         }
     }
     // erase the splitted edge
+    patchRoundabouts(edge, one, two, myRoundabouts);
+    patchRoundabouts(edge, one, two, myGuessedRoundabouts);
     erase(dc, edge);
     insert(one, true);
     insert(two, true);
@@ -514,6 +520,22 @@ NBEdgeCont::splitAt(NBDistrictCont& dc,
 }
 
 
+void
+NBEdgeCont::patchRoundabouts(NBEdge* orig, NBEdge* part1, NBEdge* part2, std::set<EdgeSet>& roundabouts) {
+    std::set<EdgeSet> addLater;
+    for (std::set<EdgeSet>::iterator it = roundabouts.begin(); it != roundabouts.end(); ++it) {
+        EdgeSet roundaboutSet = *it;
+        if (roundaboutSet.count(orig) > 0) {
+            roundaboutSet.erase(orig);
+            roundaboutSet.insert(part1);
+            roundaboutSet.insert(part2);
+        }
+        addLater.insert(roundaboutSet);
+    }
+    roundabouts.clear();
+    roundabouts.insert(addLater.begin(), addLater.end());
+}
+
 
 // ----- container access methods
 std::vector<std::string>
@@ -556,7 +578,7 @@ NBEdgeCont::splitGeometry(NBNodeCont& nc) {
 
 
 void
-NBEdgeCont::reduceGeometries(const SUMOReal minDist) {
+NBEdgeCont::reduceGeometries(const double minDist) {
     for (EdgeCont::iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
         (*i).second->reduceGeometry(minDist);
     }
@@ -564,7 +586,7 @@ NBEdgeCont::reduceGeometries(const SUMOReal minDist) {
 
 
 void
-NBEdgeCont::checkGeometries(const SUMOReal maxAngle, const SUMOReal minRadius, bool fix) {
+NBEdgeCont::checkGeometries(const double maxAngle, const double minRadius, bool fix) {
     if (maxAngle > 0 || minRadius > 0) {
         for (EdgeCont::iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
             (*i).second->checkGeometry(maxAngle, minRadius, fix);
@@ -609,20 +631,24 @@ NBEdgeCont::computeLanes2Edges() {
 void
 NBEdgeCont::recheckLanes() {
     for (EdgeCont::iterator i = myEdges.begin(); i != myEdges.end(); i++) {
-        i->second->recheckLanes();
+        NBEdge* edge = i->second;
+        edge->recheckLanes();
         // check opposites
-        if (i->second->getNumLanes() > 0) {
-            const std::string& oppositeID = i->second->getLanes().back().oppositeID;
+        if (edge->getNumLanes() > 0) {
+            const std::string& oppositeID = edge->getLanes().back().oppositeID;
             if (oppositeID != "" && oppositeID != "-") {
-                const NBEdge* oppEdge = retrieve(oppositeID.substr(0, oppositeID.rfind("_")));
-                if (oppEdge == 0) {
-                    throw ProcessError("Unknown opposite lane '" + oppositeID + "' for edge '" + i->second->getID() + "'!");
+                NBEdge* oppEdge = retrieve(oppositeID.substr(0, oppositeID.rfind("_")));
+                if (oppEdge == 0 || oppEdge->getLaneID(oppEdge->getNumLanes() - 1) != oppositeID) {
+                    WRITE_WARNING("Removing unknown opposite lane '" + oppositeID + "' for edge '" + edge->getID() + "'.");
+                    edge->getLaneStruct(edge->getNumLanes() - 1).oppositeID = "";
+                    continue;
                 }
-                if (fabs(oppEdge->getLoadedLength() - i->second->getLoadedLength()) > POSITION_EPS) {
-                    throw ProcessError("Opposite lane '" + oppositeID + "' differs in length from edge '" + i->second->getID() + "'!");
+                if (fabs(oppEdge->getLoadedLength() - edge->getLoadedLength()) > POSITION_EPS) {
+                    throw ProcessError("Opposite lane '" + oppositeID + "' (length " + toString(oppEdge->getLoadedLength()) + ") differs in length from edge '" + edge->getID() + "' (length "
+                                       + toString(edge->getLoadedLength()) + ")!");
                 }
-                if (oppEdge->getFromNode() != i->second->getToNode() || oppEdge->getToNode() != i->second->getFromNode()) {
-                    throw ProcessError("Opposite lane '" + oppositeID + "' does not connect the same nodes as edge '" + i->second->getID() + "'!");
+                if (oppEdge->getFromNode() != edge->getToNode() || oppEdge->getToNode() != edge->getFromNode()) {
+                    throw ProcessError("Opposite lane '" + oppositeID + "' does not connect the same nodes as edge '" + edge->getID() + "'!");
                 }
             }
         }
@@ -672,8 +698,8 @@ NBEdgeCont::joinSameNodeConnectingEdges(NBDistrictCont& dc,
     //   the replacement where the edge is a node's incoming edge.
 
     // count the number of lanes, the speed and the id
-    unsigned int nolanes = 0;
-    SUMOReal speed = 0;
+    int nolanes = 0;
+    double speed = 0;
     int priority = 0;
     std::string id;
     sort(edges.begin(), edges.end(), NBContHelper::same_connection_edge_sorter());
@@ -728,7 +754,7 @@ NBEdgeCont::joinSameNodeConnectingEdges(NBDistrictCont& dc,
         }
     }
     //  copy outgoing connections to the new edge
-    unsigned int currLane = 0;
+    int currLane = 0;
     for (i = edges.begin(); i != edges.end(); i++) {
         newEdge->moveOutgoingConnectionsFrom(*i, currLane);
         currLane += (*i)->getNumLanes();
@@ -736,8 +762,8 @@ NBEdgeCont::joinSameNodeConnectingEdges(NBDistrictCont& dc,
     // patch tl-information
     currLane = 0;
     for (i = edges.begin(); i != edges.end(); i++) {
-        unsigned int noLanes = (*i)->getNumLanes();
-        for (unsigned int j = 0; j < noLanes; j++, currLane++) {
+        int noLanes = (*i)->getNumLanes();
+        for (int j = 0; j < noLanes; j++, currLane++) {
             // replace in traffic lights
             tlc.replaceRemoved(*i, j, newEdge, currLane);
         }
@@ -752,7 +778,7 @@ NBEdgeCont::joinSameNodeConnectingEdges(NBDistrictCont& dc,
 void
 NBEdgeCont::guessOpposites() {
     //@todo magic values
-    const SUMOReal distanceThreshold = 7;
+    const double distanceThreshold = 7;
     for (EdgeCont::iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
         NBEdge* edge = i->second;
         const int numLanes = edge->getNumLanes();
@@ -760,10 +786,10 @@ NBEdgeCont::guessOpposites() {
             NBEdge::Lane& lastLane = edge->getLaneStruct(numLanes - 1);
             if (lastLane.oppositeID == "") {
                 NBEdge* opposite = 0;
-                //SUMOReal minOppositeDist = std::numeric_limits<SUMOReal>::max();
+                //double minOppositeDist = std::numeric_limits<double>::max();
                 for (EdgeVector::const_iterator j = edge->getToNode()->getOutgoingEdges().begin(); j != edge->getToNode()->getOutgoingEdges().end(); ++j) {
                     if ((*j)->getToNode() == edge->getFromNode() && !(*j)->getLanes().empty()) {
-                        const SUMOReal distance = VectorHelper<SUMOReal>::maxValue(lastLane.shape.distances((*j)->getLanes().back().shape));
+                        const double distance = VectorHelper<double>::maxValue(lastLane.shape.distances((*j)->getLanes().back().shape));
                         if (distance < distanceThreshold) {
                             //minOppositeDist = distance;
                             opposite = *j;
@@ -782,38 +808,52 @@ NBEdgeCont::guessOpposites() {
 void
 NBEdgeCont::recheckLaneSpread() {
     for (EdgeCont::iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
-        std::string oppositeID;
-        if ((*i).first[0] == '-') {
-            oppositeID = (*i).first.substr(1);
+        NBEdge* opposite = getOppositeByID(i->first);
+        if (opposite != 0) {
+            i->second->setLaneSpreadFunction(LANESPREAD_RIGHT);
+            opposite->setLaneSpreadFunction(LANESPREAD_RIGHT);
         } else {
-            oppositeID = "-" + (*i).first;
-        }
-        if (myEdges.find(oppositeID) != myEdges.end()) {
-            (*i).second->setLaneSpreadFunction(LANESPREAD_RIGHT);
-            myEdges.find(oppositeID)->second->setLaneSpreadFunction(LANESPREAD_RIGHT);
-        } else {
-            (*i).second->setLaneSpreadFunction(LANESPREAD_CENTER);
+            i->second->setLaneSpreadFunction(LANESPREAD_CENTER);
         }
     }
 }
 
 
+NBEdge*
+NBEdgeCont::getOppositeByID(const std::string& edgeID) const {
+    const std::string oppositeID = edgeID[0] == '-' ? edgeID.substr(1) :  "-" + edgeID;
+    EdgeCont::const_iterator it = myEdges.find(oppositeID);
+    return it != myEdges.end() ? it->second : (NBEdge*)0;
+}
+
+NBEdge*
+NBEdgeCont::getByID(const std::string& edgeID) const {
+    EdgeCont::const_iterator it = myEdges.find(edgeID);
+    return it != myEdges.end() ? it->second : (NBEdge*)0;
+}
 
 // ----- other
 void
-NBEdgeCont::addPostProcessConnection(const std::string& from, int fromLane, const std::string& to, int toLane, bool mayDefinitelyPass, bool keepClear, SUMOReal contPos) {
-    myConnections.push_back(PostProcessConnection(from, fromLane, to, toLane, mayDefinitelyPass, keepClear, contPos));
+NBEdgeCont::addPostProcessConnection(const std::string& from, int fromLane, const std::string& to, int toLane, bool mayDefinitelyPass,
+                                     bool keepClear, double contPos, double visibility, bool warnOnly) {
+    myConnections.push_back(PostProcessConnection(from, fromLane, to, toLane, mayDefinitelyPass, keepClear, contPos, visibility, warnOnly));
 }
 
 
 void
 NBEdgeCont::recheckPostProcessConnections() {
+    const bool warnOnly = OptionsCont::getOptions().exists("ignore-errors.connections") && OptionsCont::getOptions().getBool("ignore-errors.connections");
     for (std::vector<PostProcessConnection>::const_iterator i = myConnections.begin(); i != myConnections.end(); ++i) {
         NBEdge* from = retrievePossiblySplit((*i).from, true);
         NBEdge* to = retrievePossiblySplit((*i).to, false);
         if (from == 0 || to == 0 ||
                 !from->addLane2LaneConnection((*i).fromLane, to, (*i).toLane, NBEdge::L2L_USER, true, (*i).mayDefinitelyPass, (*i).keepClear, (*i).contPos)) {
-            WRITE_ERROR("Could not insert connection between '" + (*i).from + "' and '" + (*i).to + "' after build.");
+            const std::string msg = "Could not insert connection between '" + (*i).from + "' and '" + (*i).to + "' after build.";
+            if (warnOnly || (*i).warnOnly) {
+                WRITE_WARNING(msg);
+            } else {
+                WRITE_ERROR(msg);
+            }
         }
     }
     // during loading we also kept some ambiguous connections in hope they might be valid after processing
@@ -837,13 +877,13 @@ NBEdgeCont::recheckPostProcessConnections() {
 
 EdgeVector
 NBEdgeCont::getGeneratedFrom(const std::string& id) const {
-    size_t len = id.length();
+    int len = (int)id.length();
     EdgeVector ret;
     for (EdgeCont::const_iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
         std::string curr = (*i).first;
         // the next check makes it possibly faster - we don not have
         //  to compare the names
-        if (curr.length() <= len) {
+        if ((int)curr.length() <= len) {
             continue;
         }
         // the name must be the same as the given id but something
@@ -853,7 +893,7 @@ NBEdgeCont::getGeneratedFrom(const std::string& id) const {
             continue;
         }
         // ok, maybe the edge is a compound made during joining of edges
-        size_t pos = curr.find(id);
+        std::string::size_type pos = curr.find(id);
         // surely not
         if (pos == std::string::npos) {
             continue;
@@ -925,19 +965,19 @@ NBEdgeCont::guessRoundabouts() {
             EdgeVector::const_iterator me = find(edges.begin(), edges.end(), e);
             NBContHelper::nextCW(edges, me);
             NBEdge* left = *me;
-            SUMOReal angle = fabs(NBHelpers::relAngle(e->getAngleAtNode(e->getToNode()), left->getAngleAtNode(e->getToNode())));
+            double angle = fabs(NBHelpers::relAngle(e->getAngleAtNode(e->getToNode()), left->getAngleAtNode(e->getToNode())));
             if (angle >= 90) {
                 // roundabouts do not have sharp turns (or they wouldn't be called 'round')
                 doLoop = false;
                 break;
             }
             EdgeVector::const_iterator loopClosed = find(loopEdges.begin(), loopEdges.end(), left);
-            const size_t loopSize = loopEdges.end() - loopClosed;
+            const int loopSize = (int)(loopEdges.end() - loopClosed);
             if (loopSize > 0) {
                 // loop found
                 if (loopSize < 3) {
                     doLoop = false; // need at least 3 edges for a roundabout
-                } else if (loopSize < loopEdges.size()) {
+                } else if (loopSize < (int)loopEdges.size()) {
                     // remove initial edges not belonging to the loop
                     EdgeVector(loopEdges.begin() + (loopEdges.size() - loopSize), loopEdges.end()).swap(loopEdges);
                 }
@@ -973,13 +1013,13 @@ NBEdgeCont::guessRoundabouts() {
 }
 
 
-SUMOReal
+double
 NBEdgeCont::formFactor(const EdgeVector& loopEdges) {
     PositionVector points;
     for (EdgeVector::const_iterator it = loopEdges.begin(); it != loopEdges.end(); ++it) {
         points.append((*it)->getGeometry());
     }
-    SUMOReal circumference = points.length2D();
+    double circumference = points.length2D();
     return 4 * M_PI * points.area() / (circumference * circumference);
 }
 
@@ -1024,7 +1064,8 @@ NBEdgeCont::markRoundabouts() {
                 inEdge->removeFromConnections(inEdge->getTurnDestination(), -1);
             }
             // let the connections to succeeding roundabout edge have a higher priority
-            (*j)->setJunctionPriority(node, 1000);
+            (*j)->setJunctionPriority(node, NBEdge::ROUNDABOUT);
+            (*j)->setJunctionPriority((*j)->getFromNode(), NBEdge::ROUNDABOUT);
             node->setRoundabout();
         }
     }
@@ -1034,11 +1075,13 @@ void
 NBEdgeCont::generateStreetSigns() {
     for (EdgeCont::iterator i = myEdges.begin(); i != myEdges.end(); ++i) {
         NBEdge* e = i->second;
-        // is this a "real" junction?
-        // XXX nyi
-        //continue
-        const SUMOReal offset = MAX2((SUMOReal)0, e->getLength() - 3);
-        switch (e->getToNode()->getType()) {
+        const double offset = MAX2(0., e->getLength() - 3);
+        if (e->getToNode()->isSimpleContinuation(false)) {
+            // not a "real" junction?
+            continue;
+        }
+        const SumoXMLNodeType nodeType = e->getToNode()->getType();
+        switch (nodeType) {
             case NODETYPE_PRIORITY:
                 // yield or major?
                 if (e->getJunctionPriority(e->getToNode()) > 0) {
@@ -1069,7 +1112,7 @@ NBEdgeCont::generateStreetSigns() {
 
 
 int
-NBEdgeCont::guessSidewalks(SUMOReal width, SUMOReal minSpeed, SUMOReal maxSpeed, bool fromPermissions) {
+NBEdgeCont::guessSidewalks(double width, double minSpeed, double maxSpeed, bool fromPermissions) {
     int sidewalksCreated = 0;
     const std::vector<std::string> edges = OptionsCont::getOptions().getStringVector("sidewalks.guess.exclude");
     std::set<std::string> exclude(edges.begin(), edges.end());
@@ -1094,17 +1137,28 @@ NBEdgeCont::guessSidewalks(SUMOReal width, SUMOReal minSpeed, SUMOReal maxSpeed,
 
 
 int
-NBEdgeCont::mapToNumericalIDs() {
-    IDSupplier idSupplier("", getAllNames());
-    EdgeVector toChange;
+NBEdgeCont::remapIDs(bool numericaIDs, bool reservedIDs) {
+    std::vector<std::string> avoid = getAllNames();
+    std::set<std::string> reserve;
+    if (reservedIDs) {
+        NBHelpers::loadPrefixedIDsFomFile(OptionsCont::getOptions().getString("reserved-ids"), "edge:", reserve);
+        avoid.insert(avoid.end(), reserve.begin(), reserve.end());
+    }
+    IDSupplier idSupplier("", avoid);
+    std::set<NBEdge*, Named::ComparatorIdLess> toChange;
     for (EdgeCont::iterator it = myEdges.begin(); it != myEdges.end(); it++) {
-        try {
-            TplConvert::_str2int(it->first);
-        } catch (NumberFormatException&) {
-            toChange.push_back(it->second);
+        if (numericaIDs) {
+            try {
+                TplConvert::_str2long(it->first);
+            } catch (NumberFormatException&) {
+                toChange.insert(it->second);
+            }
+        }
+        if (reservedIDs && reserve.count(it->first) > 0) {
+            toChange.insert(it->second);
         }
     }
-    for (EdgeVector::iterator it = toChange.begin(); it != toChange.end(); ++it) {
+    for (std::set<NBEdge*, Named::ComparatorIdLess>::iterator it = toChange.begin(); it != toChange.end(); ++it) {
         NBEdge* edge = *it;
         myEdges.erase(edge->getID());
         edge->setID(idSupplier.getNext());
@@ -1113,4 +1167,57 @@ NBEdgeCont::mapToNumericalIDs() {
     return (int)toChange.size();
 }
 
+
+void
+NBEdgeCont::checkOverlap(double threshold, double zThreshold) const {
+    for (EdgeCont::const_iterator it = myEdges.begin(); it != myEdges.end(); it++) {
+        const NBEdge* e1 = it->second;
+        Boundary b1 = e1->getGeometry().getBoxBoundary();
+        b1.grow(e1->getTotalWidth());
+        PositionVector outline1 = e1->getCCWBoundaryLine(*e1->getFromNode());
+        outline1.append(e1->getCCWBoundaryLine(*e1->getToNode()));
+        // check is symmetric. only check once per pair
+        for (EdgeCont::const_iterator it2 = it; it2 != myEdges.end(); it2++) {
+            const NBEdge* e2 = it2->second;
+            if (e1 == e2) {
+                continue;
+            }
+            Boundary b2 = e2->getGeometry().getBoxBoundary();
+            b2.grow(e2->getTotalWidth());
+            if (b1.overlapsWith(b2)) {
+                PositionVector outline2 = e2->getCCWBoundaryLine(*e2->getFromNode());
+                outline2.append(e2->getCCWBoundaryLine(*e2->getToNode()));
+                const double overlap = outline1.getOverlapWith(outline2, zThreshold);
+                if (overlap > threshold) {
+                    WRITE_WARNING("Edge '" + e1->getID() + "' overlaps with edge '" + e2->getID() + "' by " + toString(overlap) + ".");
+                }
+            }
+        }
+    }
+}
+
+
+void
+NBEdgeCont::checkGrade(double threshold) const {
+    for (EdgeCont::const_iterator it = myEdges.begin(); it != myEdges.end(); it++) {
+        const NBEdge* edge = it->second;
+        for (int i = 0; i < (int)edge->getNumLanes(); i++) {
+            const double grade = edge->getLaneShape(i).getMaxGrade();
+            if (grade > threshold) {
+                WRITE_WARNING("Edge '" + edge->getID() + "' has a grade of " + toString(grade * 100) + "%.");
+                break;
+            }
+        }
+        const std::vector<NBEdge::Connection>& connections = edge->getConnections();
+        for (std::vector<NBEdge::Connection>::const_iterator it_con = connections.begin(); it_con != connections.end(); ++it_con) {
+            const NBEdge::Connection& c = *it_con;
+            const double grade = MAX2(c.shape.getMaxGrade(), c.viaShape.getMaxGrade());
+            if (grade > threshold) {
+                WRITE_WARNING("Connection '" + c.getDescription(edge) + "' has a grade of " + toString(grade * 100) + "%.");
+                break;
+            }
+        }
+    }
+}
+
 /****************************************************************************/
