@@ -7,12 +7,12 @@
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
 /// @date    20 Nov 2001
-/// @version $Id: NBNetBuilder.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: NBNetBuilder.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // Instance responsible for building networks
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -41,13 +41,13 @@
 #include "NBTrafficLightLogicCont.h"
 #include "NBDistrictCont.h"
 #include "NBDistrict.h"
-#include "NBDistribution.h"
 #include "NBRequest.h"
 #include "NBTypeCont.h"
 #include <utils/options/OptionsCont.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/common/StringTokenizer.h>
+#include <utils/common/SUMOVehicleClass.h>
 #include <utils/common/SysUtils.h>
 #include <utils/common/ToString.h>
 #include <utils/geom/GeoConvHelper.h>
@@ -55,17 +55,14 @@
 #include "NBAlgorithms_Ramps.h"
 #include "NBHeightMapper.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
 NBNetBuilder::NBNetBuilder() :
     myEdgeCont(myTypeCont),
-    myHaveLoadedNetworkWithoutInternalEdges(false) {
+    myHaveLoadedNetworkWithoutInternalEdges(false),
+    myNetworkHaveCrossings(false) {
 }
 
 
@@ -75,7 +72,8 @@ NBNetBuilder::~NBNetBuilder() {}
 void
 NBNetBuilder::applyOptions(OptionsCont& oc) {
     // apply options to type control
-    myTypeCont.setDefaults(oc.getInt("default.lanenumber"), oc.getFloat("default.lanewidth"), oc.getFloat("default.speed"), oc.getInt("default.priority"));
+    myTypeCont.setDefaults(oc.getInt("default.lanenumber"), oc.getFloat("default.lanewidth"), oc.getFloat("default.speed"),
+                           oc.getInt("default.priority"), parseVehicleClasses("", oc.getString("default.disallow")));
     // apply options to edge control
     myEdgeCont.applyOptions(oc);
     // apply options to traffic light logics control
@@ -84,12 +82,9 @@ NBNetBuilder::applyOptions(OptionsCont& oc) {
 
 
 void
-NBNetBuilder::compute(OptionsCont& oc,
-                      const std::set<std::string>& explicitTurnarounds,
-                      bool removeElements) {
+NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurnarounds, bool mayAddOrRemove) {
     GeoConvHelper& geoConvHelper = GeoConvHelper::getProcessing();
 
-
     const bool lefthand = oc.getBool("lefthand");
     if (lefthand) {
         mirrorX();
@@ -161,7 +156,7 @@ NBNetBuilder::compute(OptionsCont& oc,
         WRITE_MESSAGE(" Joined " + toString(numJoined) + " junction cluster(s).");
     }
     //
-    if (removeElements) {
+    if (mayAddOrRemove) {
         int no = 0;
         const bool removeGeometryNodes = oc.exists("geometry.remove") && oc.getBool("geometry.remove");
         before = SysUtils::getCurrentMillis();
@@ -189,7 +184,7 @@ NBNetBuilder::compute(OptionsCont& oc,
     }
     geoConvHelper.computeFinal(lefthand); // information needed for location element fixed at this point
 
-    if (oc.exists("geometry.min-dist") && oc.isSet("geometry.min-dist")) {
+    if (oc.exists("geometry.min-dist") && !oc.isDefault("geometry.min-dist")) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Reducing geometries");
         myEdgeCont.reduceGeometries(oc.getFloat("geometry.min-dist"));
@@ -197,7 +192,7 @@ NBNetBuilder::compute(OptionsCont& oc,
     }
     // @note: removing geometry can create similar edges so joinSimilarEdges  must come afterwards
     // @note: likewise splitting can destroy similarities so joinSimilarEdges must come before
-    if (removeElements && oc.getBool("edges.join")) {
+    if (mayAddOrRemove && oc.getBool("edges.join")) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Joining similar edges");
         myNodeCont.joinSimilarEdges(myDistrictCont, myEdgeCont, myTLLCont);
@@ -209,7 +204,7 @@ NBNetBuilder::compute(OptionsCont& oc,
         PROGRESS_DONE_MESSAGE();
     }
     //
-    if (oc.exists("geometry.split") && oc.getBool("geometry.split")) {
+    if (mayAddOrRemove && oc.exists("geometry.split") && oc.getBool("geometry.split")) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Splitting geometry edges");
         myEdgeCont.splitGeometry(myNodeCont);
@@ -223,12 +218,14 @@ NBNetBuilder::compute(OptionsCont& oc,
     // correct edge geometries to avoid overlap
     myNodeCont.avoidOverlap();
     // guess ramps
-    if ((oc.exists("ramps.guess") && oc.getBool("ramps.guess")) || (oc.exists("ramps.set") && oc.isSet("ramps.set"))) {
-        before = SysUtils::getCurrentMillis();
-        PROGRESS_BEGIN_MESSAGE("Guessing and setting on-/off-ramps");
-        NBNodesEdgesSorter::sortNodesEdges(myNodeCont);
-        NBRampsComputer::computeRamps(*this, oc);
-        PROGRESS_TIME_MESSAGE(before);
+    if (mayAddOrRemove) {
+        if ((oc.exists("ramps.guess") && oc.getBool("ramps.guess")) || (oc.exists("ramps.set") && oc.isSet("ramps.set"))) {
+            before = SysUtils::getCurrentMillis();
+            PROGRESS_BEGIN_MESSAGE("Guessing and setting on-/off-ramps");
+            NBNodesEdgesSorter::sortNodesEdges(myNodeCont);
+            NBRampsComputer::computeRamps(*this, oc);
+            PROGRESS_TIME_MESSAGE(before);
+        }
     }
     // guess sidewalks
     if (oc.getBool("sidewalks.guess") || oc.getBool("sidewalks.guess.from-permissions")) {
@@ -243,12 +240,10 @@ NBNetBuilder::compute(OptionsCont& oc,
     myEdgeCont.recheckPostProcessConnections();
 
     // remap ids if wished
-    if (oc.getBool("numerical-ids")) {
-        int numChangedEdges = myEdgeCont.mapToNumericalIDs();
-        int numChangedNodes = myNodeCont.mapToNumericalIDs();
-        if (numChangedEdges + numChangedNodes > 0) {
-            WRITE_MESSAGE("Remapped " + toString(numChangedEdges) + " edge IDs and " + toString(numChangedNodes) + " node IDs.");
-        }
+    int numChangedEdges = myEdgeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"));
+    int numChangedNodes = myNodeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"));
+    if (numChangedEdges + numChangedNodes > 0) {
+        WRITE_MESSAGE("Remapped " + toString(numChangedEdges) + " edge IDs and " + toString(numChangedNodes) + " node IDs.");
     }
 
     //
@@ -286,10 +281,10 @@ NBNetBuilder::compute(OptionsCont& oc,
 
     // APPLY SPEED MODIFICATIONS
     if (oc.exists("speed.offset")) {
-        const SUMOReal speedOffset = oc.getFloat("speed.offset");
-        const SUMOReal speedFactor = oc.getFloat("speed.factor");
-        if (speedOffset != 0 || speedFactor != 1 || oc.isSet("speed.minimum")) {
-            const SUMOReal speedMin = oc.isSet("speed.minimum") ? oc.getFloat("speed.minimum") : -std::numeric_limits<SUMOReal>::infinity();
+        const double speedOffset = oc.getFloat("speed.offset");
+        const double speedFactor = oc.getFloat("speed.factor");
+        if (speedOffset != 0 || speedFactor != 1) {
+            const double speedMin = oc.getFloat("speed.minimum");
             before = SysUtils::getCurrentMillis();
             PROGRESS_BEGIN_MESSAGE("Applying speed modifications");
             for (std::map<std::string, NBEdge*>::const_iterator i = myEdgeCont.begin(); i != myEdgeCont.end(); ++i) {
@@ -306,27 +301,31 @@ NBNetBuilder::compute(OptionsCont& oc,
     NBNodeTypeComputer::computeNodeTypes(myNodeCont);
     PROGRESS_TIME_MESSAGE(before);
     //
-    bool haveCrossings = false;
+    myNetworkHaveCrossings = false;
     if (oc.getBool("crossings.guess")) {
-        haveCrossings = true;
+        myNetworkHaveCrossings = true;
         int crossings = 0;
         for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
             crossings += (*i).second->guessCrossings();
         }
         WRITE_MESSAGE("Guessed " + toString(crossings) + " pedestrian crossings.");
     }
-    if (!haveCrossings) {
+    if (!myNetworkHaveCrossings) {
         // recheck whether we had crossings in the input
         for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
             if (i->second->getCrossings().size() > 0) {
-                haveCrossings = true;
+                myNetworkHaveCrossings = true;
                 break;
             }
         }
     }
 
-    if (oc.isDefault("no-internal-links") && !haveCrossings && myHaveLoadedNetworkWithoutInternalEdges) {
+    if (oc.isDefault("no-internal-links") && !myNetworkHaveCrossings && myHaveLoadedNetworkWithoutInternalEdges) {
         oc.set("no-internal-links", "true");
+    } else if (!mayAddOrRemove && myNetworkHaveCrossings) {
+        // crossings added via netedit
+        oc.resetWritable();
+        oc.set("no-internal-links", "false");
     }
 
     //
@@ -376,7 +375,7 @@ NBNetBuilder::compute(OptionsCont& oc,
     myEdgeCont.recheckLanes();
     PROGRESS_TIME_MESSAGE(before);
 
-    if (haveCrossings && !oc.getBool("no-internal-links")) {
+    if (myNetworkHaveCrossings && !oc.getBool("no-internal-links")) {
         for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
             i->second->buildCrossingsAndWalkingAreas();
         }
@@ -437,23 +436,56 @@ NBNetBuilder::compute(OptionsCont& oc,
         PROGRESS_TIME_MESSAGE(before);
     }
 
+    for (std::map<std::string, NBEdge*>::const_iterator i = myEdgeCont.begin(); i != myEdgeCont.end(); ++i) {
+        (*i).second->sortOutgoingConnectionsByIndex();
+    }
     // FINISHING INNER EDGES
     if (!oc.getBool("no-internal-links")) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Building inner edges");
-        for (std::map<std::string, NBEdge*>::const_iterator i = myEdgeCont.begin(); i != myEdgeCont.end(); ++i) {
-            (*i).second->sortOutgoingConnectionsByIndex();
-        }
         // walking areas shall only be built if crossings are wished as well
         for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
             (*i).second->buildInnerEdges();
         }
         PROGRESS_TIME_MESSAGE(before);
     }
+    // PATCH NODE SHAPES
+    if (oc.getFloat("junctions.scurve-stretch") > 0) {
+        // @note: nodes have collected correction hints in buildInnerEdges()
+        before = SysUtils::getCurrentMillis();
+        PROGRESS_BEGIN_MESSAGE("stretching junctions to smooth geometries");
+        myEdgeCont.computeLaneShapes();
+        myNodeCont.computeNodeShapes();
+        myEdgeCont.computeEdgeShapes();
+        for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
+            (*i).second->buildInnerEdges();
+        }
+        PROGRESS_TIME_MESSAGE(before);
+    }
     if (lefthand) {
         mirrorX();
     };
 
+    if (oc.exists("geometry.check-overlap")  && oc.getFloat("geometry.check-overlap") > 0) {
+        before = SysUtils::getCurrentMillis();
+        PROGRESS_BEGIN_MESSAGE("Checking overlapping edges");
+        myEdgeCont.checkOverlap(oc.getFloat("geometry.check-overlap"), oc.getFloat("geometry.check-overlap.vertical-threshold"));
+        PROGRESS_TIME_MESSAGE(before);
+    }
+    if (oc.exists("geometry.max-grade") && oc.getFloat("geometry.max-grade") > 0 && geoConvHelper.getConvBoundary().getZRange() > 0) {
+        before = SysUtils::getCurrentMillis();
+        PROGRESS_BEGIN_MESSAGE("Checking edge grade");
+        // user input is in %
+        myEdgeCont.checkGrade(oc.getFloat("geometry.max-grade") / 100);
+        PROGRESS_TIME_MESSAGE(before);
+    }
+    if (oc.exists("ptstop-output") && oc.isSet("ptstop-output")) {
+        before = SysUtils::getCurrentMillis();
+        PROGRESS_BEGIN_MESSAGE("Processing public transport stops");
+        myPTStopCont.process(myEdgeCont);
+        PROGRESS_TIME_MESSAGE(before);
+    }
+
     // report
     WRITE_MESSAGE("-----------------------------------------------------");
     WRITE_MESSAGE("Summary:");
@@ -472,13 +504,288 @@ NBNetBuilder::compute(OptionsCont& oc,
 }
 
 
+void
+NBNetBuilder::computeSingleNode(NBNode* node, OptionsCont& oc, const std::set<std::string>& explicitTurnarounds, bool mayAddOrRemove) {
+
+    GeoConvHelper& geoConvHelper = GeoConvHelper::getProcessing();
+
+    const bool lefthand = oc.getBool("lefthand");
+    if (lefthand) {
+        mirrorX();
+    };
+
+    // MODIFYING THE SETS OF NODES AND EDGES
+
+    // Removes edges that are connecting the same node
+    node->removeSelfLoops(myDistrictCont, myEdgeCont, myTLLCont);
+    //
+    if (oc.exists("remove-edges.isolated") && oc.getBool("remove-edges.isolated")) {
+        myNodeCont.removeIsolatedRoads(myDistrictCont, myEdgeCont, myTLLCont);
+    }
+    //
+    if (oc.exists("keep-edges.postload") && oc.getBool("keep-edges.postload")) {
+        if (oc.isSet("keep-edges.explicit") || oc.isSet("keep-edges.input-file")) {
+            myEdgeCont.removeUnwishedEdges(myDistrictCont);
+        }
+    }
+    if (oc.getBool("junctions.join") || (oc.exists("ramps.guess") && oc.getBool("ramps.guess"))) {
+        // preliminary geometry computations to determine the length of edges
+        // This depends on turning directions and sorting of edge list
+        // in case junctions are joined geometry computations have to be repeated
+        // preliminary roundabout computations to avoid damaging roundabouts via junctions.join or ramps.guess
+        NBTurningDirectionsComputer::computeTurnDirectionsForNode(node, false);
+        node->sortEdges(false);
+        myEdgeCont.computeLaneShapes();
+        node->computeNodeShape(-1);
+        myEdgeCont.computeEdgeShapes();
+        if (oc.getBool("roundabouts.guess")) {
+            myEdgeCont.guessRoundabouts();
+        }
+        const std::set<EdgeSet>& roundabouts = myEdgeCont.getRoundabouts();
+        for (std::set<EdgeSet>::const_iterator it_round = roundabouts.begin();
+                it_round != roundabouts.end(); ++it_round) {
+            std::vector<std::string> nodeIDs;
+            for (EdgeSet::const_iterator it_edge = it_round->begin(); it_edge != it_round->end(); ++it_edge) {
+                nodeIDs.push_back((*it_edge)->getToNode()->getID());
+            }
+            myNodeCont.addJoinExclusion(nodeIDs);
+        }
+    }
+    // join junctions (may create new "geometry"-nodes so it needs to come before removing these
+    if (oc.exists("junctions.join-exclude") && oc.isSet("junctions.join-exclude")) {
+        myNodeCont.addJoinExclusion(oc.getStringVector("junctions.join-exclude"));
+    }
+    int numJoined = myNodeCont.joinLoadedClusters(myDistrictCont, myEdgeCont, myTLLCont);
+    if (oc.getBool("junctions.join")) {
+        numJoined += myNodeCont.joinJunctions(oc.getFloat("junctions.join-dist"), myDistrictCont, myEdgeCont, myTLLCont);
+    }
+    if (oc.getBool("junctions.join") || (oc.exists("ramps.guess") && oc.getBool("ramps.guess"))) {
+        // reset geometry to avoid influencing subsequent steps (ramps.guess)
+        myEdgeCont.computeLaneShapes();
+    }
+    //
+    if (mayAddOrRemove) {
+        const bool removeGeometryNodes = oc.exists("geometry.remove") && oc.getBool("geometry.remove");
+        // removeUnwishedNodes needs turnDirections. @todo: try to call this less often
+        NBTurningDirectionsComputer::computeTurnDirectionsForNode(node, false);
+        myNodeCont.removeUnwishedNodes(myDistrictCont, myEdgeCont, myTLLCont, removeGeometryNodes);
+    }
+
+    // MOVE TO ORIGIN
+    // compute new boundary after network modifications have taken place
+    Boundary boundary;
+    boundary.add(node->getPosition());
+    for (std::map<std::string, NBEdge*>::const_iterator it = myEdgeCont.begin(); it != myEdgeCont.end(); ++it) {
+        boundary.add(it->second->getGeometry().getBoxBoundary());
+    }
+    geoConvHelper.setConvBoundary(boundary);
+
+    if (!oc.getBool("offset.disable-normalization") && oc.isDefault("offset.x") && oc.isDefault("offset.y")) {
+        moveToOrigin(geoConvHelper, lefthand);
+    }
+    geoConvHelper.computeFinal(lefthand); // information needed for location element fixed at this point
+
+    if (oc.exists("geometry.min-dist") && !oc.isDefault("geometry.min-dist")) {
+        myEdgeCont.reduceGeometries(oc.getFloat("geometry.min-dist"));
+    }
+    // @note: removing geometry can create similar edges so joinSimilarEdges  must come afterwards
+    // @note: likewise splitting can destroy similarities so joinSimilarEdges must come before
+    if (mayAddOrRemove && oc.getBool("edges.join")) {
+        myNodeCont.joinSimilarEdges(myDistrictCont, myEdgeCont, myTLLCont);
+    }
+    if (oc.getBool("opposites.guess")) {
+        myEdgeCont.guessOpposites();
+    }
+    //
+    if (mayAddOrRemove && oc.exists("geometry.split") && oc.getBool("geometry.split")) {
+        myEdgeCont.splitGeometry(myNodeCont);
+    }
+    // turning direction
+    NBTurningDirectionsComputer::computeTurnDirectionsForNode(node, true);
+    // correct edge geometries to avoid overlap
+    node->avoidOverlap();
+    // guess ramps
+    if (mayAddOrRemove) {
+        if ((oc.exists("ramps.guess") && oc.getBool("ramps.guess")) || (oc.exists("ramps.set") && oc.isSet("ramps.set"))) {
+            node->sortEdges(false);
+            NBRampsComputer::computeRamps(*this, oc);
+        }
+    }
+    // guess sidewalks
+    if (oc.getBool("sidewalks.guess") || oc.getBool("sidewalks.guess.from-permissions")) {
+        myEdgeCont.guessSidewalks(oc.getFloat("default.sidewalk-width"),
+                                  oc.getFloat("sidewalks.guess.min-speed"),
+                                  oc.getFloat("sidewalks.guess.max-speed"),
+                                  oc.getBool("sidewalks.guess.from-permissions"));
+    }
+
+    // check whether any not previously setable connections may be set now
+    myEdgeCont.recheckPostProcessConnections();
+
+    // remap ids if wished
+    myEdgeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"));
+    myNodeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"));
+
+    //
+    if (oc.exists("geometry.max-angle")) {
+        myEdgeCont.checkGeometries(
+            DEG2RAD(oc.getFloat("geometry.max-angle")),
+            oc.getFloat("geometry.min-radius"),
+            oc.getBool("geometry.min-radius.fix"));
+    }
+
+    // GEOMETRY COMPUTATION
+    //
+    node->sortEdges(false);
+    myEdgeCont.computeLaneShapes();
+    //
+    if (oc.exists("geometry.junction-mismatch-threshold")) {
+        node->computeNodeShape(oc.getFloat("geometry.junction-mismatch-threshold"));
+    } else {
+        node->computeNodeShape(-1);
+    }
+    //
+    myEdgeCont.computeEdgeShapes();
+    // resort edges based on the node and edge shapes
+    node->sortEdges(true);
+    NBTurningDirectionsComputer::computeTurnDirectionsForNode(node, false);
+
+    // APPLY SPEED MODIFICATIONS
+    if (oc.exists("speed.offset")) {
+        const double speedOffset = oc.getFloat("speed.offset");
+        const double speedFactor = oc.getFloat("speed.factor");
+        if (speedOffset != 0 || speedFactor != 1) {
+            const double speedMin = oc.getFloat("speed.minimum");
+            for (std::map<std::string, NBEdge*>::const_iterator i = myEdgeCont.begin(); i != myEdgeCont.end(); ++i) {
+                (*i).second->setSpeed(-1, MAX2((*i).second->getSpeed() * speedFactor + speedOffset, speedMin));
+            }
+        }
+    }
+
+    // CONNECTIONS COMPUTATION
+    //
+    NBNodeTypeComputer::computeSingleNodeType(node);
+    //
+    myNetworkHaveCrossings = false;
+    if (oc.getBool("crossings.guess")) {
+        myNetworkHaveCrossings = true;
+        int crossings = 0;
+        crossings += node->guessCrossings();
+    }
+    if (!myNetworkHaveCrossings) {
+        // recheck whether we had crossings in the input
+        if (node->getCrossings().size() > 0) {
+            myNetworkHaveCrossings = true;
+        }
+    }
+
+    if (oc.isDefault("no-internal-links") && !myNetworkHaveCrossings && myHaveLoadedNetworkWithoutInternalEdges) {
+        oc.set("no-internal-links", "true");
+    } else if (!mayAddOrRemove && myNetworkHaveCrossings) {
+        // crossings added via netedit
+        oc.resetWritable();
+        oc.set("no-internal-links", "false");
+    }
+
+    //
+    NBEdgePriorityComputer::computeEdgePrioritiesSingleNode(node);
+    //
+    myEdgeCont.computeEdge2Edges(oc.getBool("no-left-connections"));
+    //
+    if (oc.getBool("roundabouts.guess")) {
+        myEdgeCont.guessRoundabouts();
+    }
+    myEdgeCont.markRoundabouts();
+    //
+    myEdgeCont.computeLanes2Edges();
+    //
+    node->computeLanes2Lanes();
+    myEdgeCont.sortOutgoingLanesConnections();
+    //
+    if (!oc.getBool("no-turnarounds")) {
+        myEdgeCont.appendTurnarounds(oc.getBool("no-turnarounds.tls"));
+    } else {
+        myEdgeCont.appendTurnarounds(explicitTurnarounds, oc.getBool("no-turnarounds.tls"));
+    }
+    //
+    myEdgeCont.recheckLanes();
+
+    if (myNetworkHaveCrossings && !oc.getBool("no-internal-links")) {
+        node->buildCrossingsAndWalkingAreas();
+    }
+
+    // GUESS TLS POSITIONS
+    if (oc.isSet("tls.set")) {
+        std::vector<std::string> tlControlledNodes = oc.getStringVector("tls.set");
+        TrafficLightType type = SUMOXMLDefinitions::TrafficLightTypes.get(oc.getString("tls.default-type"));
+        for (std::vector<std::string>::const_iterator i = tlControlledNodes.begin(); i != tlControlledNodes.end(); ++i) {
+            if (node != 0) {
+                myNodeCont.setAsTLControlled(node, myTLLCont, type);
+            }
+        }
+    }
+    myNodeCont.guessTLs(oc, myTLLCont);
+    //
+    if (oc.getBool("tls.join")) {
+        myNodeCont.joinTLS(myTLLCont, oc.getFloat("tls.join-dist"));
+    }
+
+    // COMPUTING RIGHT-OF-WAY AND TRAFFIC LIGHT PROGRAMS
+    //
+    myTLLCont.setTLControllingInformation(myEdgeCont, myNodeCont);
+    //
+    node->computeLogic(myEdgeCont, oc);
+    //
+    std::pair<int, int> numbers = myTLLCont.computeLogics(oc);
+    std::string progCount = "";
+    if (numbers.first != numbers.second) {
+        progCount = "(" + toString(numbers.second) + " programs) ";
+    }
+    //
+    if (oc.isSet("street-sign-output")) {
+        myEdgeCont.generateStreetSigns();
+    }
+
+    for (std::map<std::string, NBEdge*>::const_iterator i = myEdgeCont.begin(); i != myEdgeCont.end(); ++i) {
+        (*i).second->sortOutgoingConnectionsByIndex();
+    }
+    // FINISHING INNER EDGES
+    if (!oc.getBool("no-internal-links")) {
+        // walking areas shall only be built if crossings are wished as well
+        node->buildInnerEdges();
+    }
+    // PATCH NODE SHAPES
+    if (oc.getFloat("junctions.scurve-stretch") > 0) {
+        // @note: nodes have collected correction hints in buildInnerEdges()
+        myEdgeCont.computeLaneShapes();
+        node->computeNodeShape(-1);
+        myEdgeCont.computeEdgeShapes();
+        node->buildInnerEdges();
+    }
+    if (lefthand) {
+        mirrorX();
+    };
+
+    if (oc.exists("geometry.check-overlap")  && oc.getFloat("geometry.check-overlap") > 0) {
+        myEdgeCont.checkOverlap(oc.getFloat("geometry.check-overlap"), oc.getFloat("geometry.check-overlap.vertical-threshold"));
+    }
+    if (oc.exists("geometry.max-grade") && oc.getFloat("geometry.max-grade") > 0 && geoConvHelper.getConvBoundary().getZRange() > 0) {
+        // user input is in %
+        myEdgeCont.checkGrade(oc.getFloat("geometry.max-grade") / 100);
+    }
+    if (oc.exists("ptstop-output") && oc.isSet("ptstop-output")) {
+        myPTStopCont.process(myEdgeCont);
+    }
+}
+
+
 void
 NBNetBuilder::moveToOrigin(GeoConvHelper& geoConvHelper, bool lefthand) {
     long before = SysUtils::getCurrentMillis();
     PROGRESS_BEGIN_MESSAGE("Moving network to origin");
     Boundary boundary = geoConvHelper.getConvBoundary();
-    const SUMOReal x = -boundary.xmin();
-    const SUMOReal y = -(lefthand ? boundary.ymax() : boundary.ymin());
+    const double x = -boundary.xmin();
+    const double y = -(lefthand ? boundary.ymax() : boundary.ymin());
     //if (lefthand) {
     //    y = boundary.ymax();
     //}
@@ -491,6 +798,9 @@ NBNetBuilder::moveToOrigin(GeoConvHelper& geoConvHelper, bool lefthand) {
     for (std::map<std::string, NBDistrict*>::const_iterator i = myDistrictCont.begin(); i != myDistrictCont.end(); ++i) {
         (*i).second->reshiftPosition(x, y);
     }
+    for (std::map<std::string, NBPTStop*>::const_iterator i = myPTStopCont.begin(); i != myPTStopCont.end(); ++i) {
+        (*i).second->reshiftPostion(x, y);
+    }
     geoConvHelper.moveConvertedBy(x, y);
     PROGRESS_TIME_MESSAGE(before);
 }
@@ -512,7 +822,7 @@ NBNetBuilder::mirrorX() {
 
 
 bool
-NBNetBuilder::transformCoordinates(Position& from, bool includeInBoundary, GeoConvHelper* from_srs) {
+NBNetBuilder::transformCoordinate(Position& from, bool includeInBoundary, GeoConvHelper* from_srs) {
     Position orig(from);
     bool ok = GeoConvHelper::getProcessing().x2cartesian(from, includeInBoundary);
     if (ok) {
@@ -521,7 +831,7 @@ NBNetBuilder::transformCoordinates(Position& from, bool includeInBoundary, GeoCo
             if (from_srs != 0 && from_srs->usingGeoProjection()) {
                 from_srs->cartesian2geo(orig);
             }
-            SUMOReal z = hm.getZ(orig);
+            double z = hm.getZ(orig);
             from = Position(from.x(), from.y(), z);
         }
     }
@@ -531,12 +841,12 @@ NBNetBuilder::transformCoordinates(Position& from, bool includeInBoundary, GeoCo
 
 bool
 NBNetBuilder::transformCoordinates(PositionVector& from, bool includeInBoundary, GeoConvHelper* from_srs) {
-    const SUMOReal maxLength = OptionsCont::getOptions().getFloat("geometry.max-segment-length");
+    const double maxLength = OptionsCont::getOptions().getFloat("geometry.max-segment-length");
     if (maxLength > 0 && from.size() > 1) {
         // transformation to cartesian coordinates must happen before we can check segment length
         PositionVector copy = from;
         for (int i = 0; i < (int) from.size(); i++) {
-            transformCoordinates(copy[i], false);
+            transformCoordinate(copy[i], false);
         }
         // check lengths and insert new points where needed (in the original
         // coordinate system)
@@ -544,7 +854,7 @@ NBNetBuilder::transformCoordinates(PositionVector& from, bool includeInBoundary,
         for (int i = 0; i < (int)copy.size() - 1; i++) {
             Position start = from[i + inserted];
             Position end = from[i + inserted + 1];
-            SUMOReal length = copy[i].distanceTo(copy[i + 1]);
+            double length = copy[i].distanceTo(copy[i + 1]);
             const Position step = (end - start) * (maxLength / length);
             int steps = 0;
             while (length > maxLength) {
@@ -559,7 +869,7 @@ NBNetBuilder::transformCoordinates(PositionVector& from, bool includeInBoundary,
     }
     bool ok = true;
     for (int i = 0; i < (int) from.size(); i++) {
-        ok = ok && transformCoordinates(from[i], includeInBoundary, from_srs);
+        ok = ok && transformCoordinate(from[i], includeInBoundary, from_srs);
     }
     return ok;
 }
