@@ -3,12 +3,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Nov 2012
-/// @version $Id: NBSign.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NBSign.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A class representing a street sign
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2012-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -72,7 +72,7 @@ public:
      * @param[in] offset The offset of the sign from the start of its edge
      * @param[in] label The (optional) label (for SPEED, SLOPE etc)
      */
-    NBSign(SignType type, SUMOReal offset, const std::string label = "");
+    NBSign(SignType type, double offset, const std::string label = "");
 
 
     /// @brief Destructor
@@ -87,7 +87,7 @@ private:
     SignType myType;
 
     /// @brief The offset of the sign from the start of its edge
-    SUMOReal myOffset;
+    double myOffset;
 
     /// @brief The (optional) label (for SPEED, SLOPE etc)
     std::string myLabel;
