@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: NBTrafficLightDefinition.cpp 20691 2016-05-10 13:38:51Z behrisch $
+/// @version $Id: NBTrafficLightDefinition.cpp 23654 2017-03-24 12:21:55Z namdre $
 ///
 // The base class for traffic light logic definitions
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -44,10 +44,6 @@
 #include "NBOwnTLDef.h"
 #include "NBContHelper.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 // ===========================================================================
 // static members
 // ===========================================================================
@@ -123,10 +119,10 @@ NBTrafficLightDefinition::compute(OptionsCont& oc) {
         return 0;
     }
     // compute the time needed to brake
-    unsigned int brakingTime = computeBrakingTime(oc.getFloat("tls.yellow.min-decel"));
+    int brakingTime = computeBrakingTime(oc.getFloat("tls.yellow.min-decel"));
     // perform the computation depending on whether the traffic light
     //  definition was loaded or shall be computed new completely
-    if (oc.isSet("tls.yellow.time")) {
+    if (!oc.isDefault("tls.yellow.time")) {
         brakingTime = oc.getInt("tls.yellow.time");
     }
     NBTrafficLightLogic* ret = myCompute(brakingTime);
@@ -141,10 +137,10 @@ NBTrafficLightDefinition::amInvalid() const {
 }
 
 
-unsigned int
-NBTrafficLightDefinition::computeBrakingTime(SUMOReal minDecel) const {
-    SUMOReal vmax = NBContHelper::maxSpeed(myIncomingEdges);
-    return (unsigned int)(vmax / minDecel);
+int
+NBTrafficLightDefinition::computeBrakingTime(double minDecel) const {
+    double vmax = NBContHelper::maxSpeed(myIncomingEdges);
+    return (int)(vmax / minDecel);
 }
 
 
@@ -419,8 +415,8 @@ NBTrafficLightDefinition::collectAllLinks() {
     // build the list of links which are controled by the traffic light
     for (EdgeVector::iterator i = myIncomingEdges.begin(); i != myIncomingEdges.end(); i++) {
         NBEdge* incoming = *i;
-        unsigned int noLanes = incoming->getNumLanes();
-        for (unsigned int j = 0; j < noLanes; j++) {
+        int noLanes = incoming->getNumLanes();
+        for (int j = 0; j < noLanes; j++) {
             std::vector<NBEdge::Connection> connected = incoming->getConnectionsFromLane(j);
             for (std::vector<NBEdge::Connection>::iterator k = connected.begin(); k != connected.end(); k++) {
                 const NBEdge::Connection& el = *k;
@@ -437,6 +433,9 @@ NBTrafficLightDefinition::collectAllLinks() {
             }
         }
     }
+    if (myControlledLinks.size() > 0 && tlIndex == 0) {
+        WRITE_WARNING("The rail crossing '" + getID() + "' does not have any roads.");
+    }
 }
 
 
@@ -477,6 +476,10 @@ NBTrafficLightDefinition::rightOnRedConflict(int index, int foeIndex) const {
             (*i)->removeTrafficLight(&dummy);
         }
         myRightOnRedConflictsReady = true;
+        //std::cout << " rightOnRedConflicts tls=" << getID() << " pro=" << getProgramID() << "\n";
+        //for (RightOnRedConflicts::const_iterator it = myRightOnRedConflicts.begin(); it != myRightOnRedConflicts.end(); ++it) {
+        //    std::cout << "   " << it->first << ", " << it->second << "\n";
+        //}
     }
     return std::find(myRightOnRedConflicts.begin(), myRightOnRedConflicts.end(), std::make_pair(index, foeIndex)) != myRightOnRedConflicts.end();
 }
