@@ -2,12 +2,12 @@
 /// @file    GNEConnectorFrame.cpp
 /// @author  Jakob Erdmann
 /// @date    May 2011
-/// @version $Id: GNEConnectorFrame.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: GNEConnectorFrame.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // The Widget for modifying lane-to-lane connections
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -28,17 +28,16 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_VERSION_H
-#include <version.h>
-#endif
-
 #include <iostream>
 #include <utils/foxtools/fxexdefs.h>
 #include <utils/foxtools/MFXUtils.h>
 #include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/gui/div/GUIIOGlobals.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
+#include <utils/gui/div/GUIDesigns.h>
 #include <utils/gui/globjects/GUIGlObjectStorage.h>
+#include <utils/gui/images/GUIIconSubSys.h>
+
 #include "GNEInspectorFrame.h"
 #include "GNEConnectorFrame.h"
 #include "GNESelectorFrame.h"
@@ -48,14 +47,11 @@
 #include "GNEUndoList.h"
 #include "GNENet.h"
 #include "GNELane.h"
+#include "GNEConnection.h"
 #include "GNEInternalLane.h"
 #include "GNEEdge.h"
 #include "GNEJunction.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // FOX callback mapping
@@ -72,7 +68,7 @@ FXDEFMAP(GNEConnectorFrame) GNEConnectorFrameMap[] = {
 };
 
 // Object implementation
-FXIMPLEMENT(GNEConnectorFrame, FXScrollWindow, GNEConnectorFrameMap, ARRAYNUMBER(GNEConnectorFrameMap))
+FXIMPLEMENT(GNEConnectorFrame, FXVerticalFrame, GNEConnectorFrameMap, ARRAYNUMBER(GNEConnectorFrameMap))
 
 // ===========================================================================
 // static members
@@ -86,66 +82,55 @@ RGBColor GNEConnectorFrame::conflictColor;
 // ===========================================================================
 // method definitions
 // ===========================================================================
-GNEConnectorFrame::GNEConnectorFrame(FXComposite* parent, GNEViewNet* viewNet):
-    GNEFrame(parent, viewNet, "Edit Connections"),
+GNEConnectorFrame::GNEConnectorFrame(FXHorizontalFrame* horizontalFrameParent, GNEViewNet* viewNet):
+    GNEFrame(horizontalFrameParent, viewNet, "Edit Connections"),
     myCurrentLane(0) {
-    // heading
-    myDescription = new FXLabel(myContentFrame, "", 0, JUSTIFY_LEFT);
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
+    // Create groupbox for lane information
+    myGroupBoxDescription = new FXGroupBox(myContentFrame, "Lane", GUIDesignGroupBoxFrame);
+
+    // Create label for lane description and update it
+    myLaneDescriptionLabel = new FXLabel(myGroupBoxDescription, "", 0, GUIDesignLabelLeft);
     updateDescription();
 
-    // buttons
-    // "Cancel"
-    new FXButton(myContentFrame, "Cancel\t\tDiscard connection modifications (Esc)", 0, this, MID_CANCEL,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "OK"
-    new FXButton(myContentFrame, "OK\t\tSave connection modifications (Enter)", 0, this, MID_OK,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
-    // "Select Dead Ends"
-    new FXButton(myContentFrame,
-                 "Select Dead Ends\t\tSelects all lanes that have no outgoing connection (clears previous selection)",
-                 0, this, MID_GNE_SELECT_DEAD_ENDS,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "Select Dead Starts"
-    new FXButton(myContentFrame,
-                 "Select Dead Starts\t\tSelects all lanes that have no incoming connection (clears previous selection)",
-                 0, this, MID_GNE_SELECT_DEAD_STARTS,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "Select Conflicts"
-    new FXButton(myContentFrame,
-                 "Select Conflicts\t\tSelects all lanes with more than one incoming connection from the same edge (clears previous selection)",
-                 0, this, MID_GNE_SELECT_CONFLICTS,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "Select Edges which may always pass"
-    new FXButton(myContentFrame,
-                 "Select Passing\t\tSelects all lanes with a connection that has has the 'pass' attribute set",
-                 0, this, MID_GNE_SELECT_PASS,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "Clear Selected"
-    new FXButton(myContentFrame,
-                 "Clear Selected\t\tClears all connections of all selected objects",
-                 0, this, MID_CHOOSEN_CLEAR,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "Reset Selected"
-    new FXButton(myContentFrame,
-                 "Reset Selected\nJunctions\t\tRecomputes connections at all selected junctions",
-                 0, this, MID_CHOOSEN_RESET,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
+    // Create GroupBox for Buttons
+    myGroupBoxModifications = new FXGroupBox(myContentFrame, "Modifications", GUIDesignGroupBoxFrame);
+
+    // Create "Cancel" button
+    myCancelButton = new FXButton(myGroupBoxModifications, "Cancel\t\tDiscard connection modifications (Esc)",
+                                  GUIIconSubSys::getIcon(ICON_CANCEL), this, MID_CANCEL, GUIDesignButton);
+    // Create "OK" button
+    mySaveButton = new FXButton(myGroupBoxModifications, "OK\t\tSave connection modifications (Enter)",
+                                GUIIconSubSys::getIcon(ICON_ACCEPT), this, MID_OK, GUIDesignButton);
+
+    // Create groupbox for operations
+    myGroupBoxOperations = new FXGroupBox(myContentFrame, "Operations", GUIDesignGroupBoxFrame);
+
+    // Create "Select Dead Ends" button
+    mySelectDeadEndsButton = new FXButton(myGroupBoxOperations, "Select Dead Ends\t\tSelects all lanes that have no outgoing connection (clears previous selection)",
+                                          0, this, MID_GNE_SELECT_DEAD_ENDS, GUIDesignButton);
+    // Create "Select Dead Starts" button
+    mySelectDeadStartsButton = new FXButton(myGroupBoxOperations, "Select Dead Starts\t\tSelects all lanes that have no incoming connection (clears previous selection)",
+                                            0, this, MID_GNE_SELECT_DEAD_STARTS, GUIDesignButton);
+    // Create "Select Conflicts" button
+    mySelectConflictsButton = new FXButton(myGroupBoxOperations, "Select Conflicts\t\tSelects all lanes with more than one incoming connection from the same edge (clears previous selection)",
+                                           0, this, MID_GNE_SELECT_CONFLICTS, GUIDesignButton);
+    // Create "Select Edges which may always pass" button
+    mySelectPassingButton = new FXButton(myGroupBoxOperations, "Select Passing\t\tSelects all lanes with a connection that has has the 'pass' attribute set",
+                                         0, this, MID_GNE_SELECT_PASS, GUIDesignButton);
+    // Create "Clear Selected" button
+    myClearSelectedButton = new FXButton(myGroupBoxOperations, "Clear Selected\t\tClears all connections of all selected objects",
+                                         0, this, MID_CHOOSEN_CLEAR, GUIDesignButton);
+    // Create "Reset Selected" button
+    myResetSelectedButton = new FXButton(myGroupBoxOperations, "Reset Selected\nJunctions\t\tRecomputes connections at all selected junctions",
+                                         0, this, MID_CHOOSEN_RESET, GUIDesignButton);
+
+    // Create groupbox for selection hints
+    myGroupBoxSelection = new FXGroupBox(myContentFrame, "Selection", GUIDesignGroupBoxFrame);
 
-    new FXHorizontalSeparator(this, SEPARATOR_GROOVE | LAYOUT_FILL_X);
     // Selection Hint
-    new FXLabel(myContentFrame, "Hold <SHIFT> while\nclicking to create\nunyielding conn's.\n", 0, JUSTIFY_LEFT);
-    new FXLabel(myContentFrame, "Hold <CTRL> while\nclicking to create\nconflicting conn's.\n", 0, JUSTIFY_LEFT);
-    // Legend
+    myHoldShiftLabel = new FXLabel(myGroupBoxSelection, "Hold <SHIFT> while clicking\nto create unyielding\nconnections (pass=true).", 0, GUIDesignLabelLeft);
+    myHoldControlLabel = new FXLabel(myGroupBoxSelection, "Hold <CTRL> while clicking\nto create conflicting\nconnections (i.e. at zipper nodes)", 0, GUIDesignLabelLeft);
+
     // init colors here to avoid static order fiasco (https://isocpp.org/wiki/faq/ctors#static-init-order)
     sourceColor = RGBColor::CYAN;
     potentialTargetColor = RGBColor(0, 64, 0, 255);
@@ -153,42 +138,33 @@ GNEConnectorFrame::GNEConnectorFrame(FXComposite* parent, GNEViewNet* viewNet):
     targetPassColor = RGBColor::MAGENTA;
     conflictColor = RGBColor::YELLOW;
 
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
-    FXLabel* l;
-    new FXLabel(myContentFrame, "Color Legend:", 0, JUSTIFY_LEFT);
-    l = new FXLabel(myContentFrame, "Source", 0, JUSTIFY_LEFT);
-    l->setBackColor(MFXUtils::getFXColor(sourceColor));
-    l = new FXLabel(myContentFrame, "Target", 0, JUSTIFY_LEFT);
-    l->setBackColor(MFXUtils::getFXColor(targetColor));
-    l = new FXLabel(myContentFrame, "Possible Target", 0, JUSTIFY_LEFT);
-    l->setBackColor(MFXUtils::getFXColor(potentialTargetColor));
-    l = new FXLabel(myContentFrame, "Target (pass)", 0, JUSTIFY_LEFT);
-    l->setBackColor(MFXUtils::getFXColor(targetPassColor));
-    l = new FXLabel(myContentFrame, "Conflict", 0, JUSTIFY_LEFT);
-    l->setBackColor(MFXUtils::getFXColor(conflictColor));
+
+    // create groupbox for legend
+    myGroupBoxLegend = new FXGroupBox(myContentFrame, "Legend", GUIDesignGroupBoxFrame);
+
+    // create source label
+    mySourceLabel = new FXLabel(myGroupBoxLegend, "Source", 0, GUIDesignLabelLeft);
+    mySourceLabel->setBackColor(MFXUtils::getFXColor(sourceColor));
+
+    // create target label
+    myTargetLabel = new FXLabel(myGroupBoxLegend, "Target", 0, GUIDesignLabelLeft);
+    myTargetLabel->setBackColor(MFXUtils::getFXColor(targetColor));
+
+    // create possible target label
+    myPossibleTargetLabel = new FXLabel(myGroupBoxLegend, "Possible Target", 0, GUIDesignLabelLeft);
+    myPossibleTargetLabel->setBackColor(MFXUtils::getFXColor(potentialTargetColor));
+
+    // create target (pass) label
+    myTargetPassLabel = new FXLabel(myGroupBoxLegend, "Target (pass)", 0, GUIDesignLabelLeft);
+    myTargetPassLabel->setBackColor(MFXUtils::getFXColor(targetPassColor));
+
+    // create conflict label
+    myConflictLabel = new FXLabel(myGroupBoxLegend, "Conflict", 0, GUIDesignLabelLeft);
+    myConflictLabel->setBackColor(MFXUtils::getFXColor(conflictColor));
 }
 
 
-GNEConnectorFrame::~GNEConnectorFrame() {
-}
-
-
-void
-GNEConnectorFrame::show() {
-    // Show Scroll window
-    FXScrollWindow::show();
-    // Show Frame Area in which this GNEFrame is placed
-    myViewNet->getViewParent()->showFramesArea();
-}
-
-
-void
-GNEConnectorFrame::hide() {
-    // Hide ScrollWindow
-    FXScrollWindow::hide();
-    // Hide Frame Area in which this GNEFrame is placed
-    myViewNet->getViewParent()->hideFramesArea();
-}
+GNEConnectorFrame::~GNEConnectorFrame() {}
 
 
 void
@@ -197,17 +173,14 @@ GNEConnectorFrame::handleLaneClick(GNELane* lane, bool mayDefinitelyPass, bool a
         myCurrentLane = lane;
         myCurrentLane->setSpecialColor(&sourceColor);
         initTargets();
-        buildIinternalLanes(lane->getParentEdge().getNBEdge()->getToNode());
         myNumChanges = 0;
-        myViewNet->getUndoList()->p_begin("modify connections");
+        myViewNet->getUndoList()->p_begin("modify " + toString(SUMO_TAG_CONNECTION) + "s");
     } else if (myPotentialTargets.count(lane) || allowConflict) {
         const int fromIndex = myCurrentLane->getIndex();
         GNEEdge& srcEdge = myCurrentLane->getParentEdge();
         GNEEdge& destEdge = lane->getParentEdge();
-        const std::string& destEdgeID = destEdge.getMicrosimID();
         std::vector<NBEdge::Connection> connections = srcEdge.getNBEdge()->getConnectionsFromLane(fromIndex);
         bool changed = false;
-        NBConnection deletedConnection = NBConnection::InvalidConnection;
         LaneStatus status = getLaneStatus(connections, lane);
         if (status == CONFLICTED && allowConflict) {
             status = UNCONNECTED;
@@ -215,34 +188,31 @@ GNEConnectorFrame::handleLaneClick(GNELane* lane, bool mayDefinitelyPass, bool a
         switch (status) {
             case UNCONNECTED:
                 if (toggle) {
-                    myViewNet->getUndoList()->add(new GNEChange_Connection(&srcEdge, fromIndex,
-                                                  destEdgeID, lane->getIndex(), mayDefinitelyPass, true), true);
+                    // create new connection
+                    NBEdge::Connection newCon(fromIndex, destEdge.getNBEdge(), lane->getIndex(), mayDefinitelyPass);
+                    myViewNet->getUndoList()->add(new GNEChange_Connection(&srcEdge, newCon, true), true);
                     lane->setSpecialColor(mayDefinitelyPass ? &targetPassColor : &targetColor);
-                    changed = true;
+                    srcEdge.getGNEJunctionDestiny()->invalidateTLS(myViewNet->getUndoList());
                 }
                 break;
             case CONNECTED:
-            case CONNECTED_PASS:
-                myViewNet->getUndoList()->add(new GNEChange_Connection(&srcEdge, fromIndex, destEdgeID, lane->getIndex(),
-                                              status == CONNECTED_PASS, false), true);
+            case CONNECTED_PASS: {
+                // remove connection
+                GNEConnection* con = srcEdge.retrieveConnection(fromIndex, destEdge.getNBEdge(), lane->getIndex());
+                myViewNet->getNet()->deleteConnection(con, myViewNet->getUndoList());
                 lane->setSpecialColor(&potentialTargetColor);
                 changed = true;
-                deletedConnection = NBConnection(srcEdge.getNBEdge(), fromIndex,
-                                                 destEdge.getNBEdge(), lane->getIndex(),
-                                                 (int)getTLLLinkNumber(connections, lane));
                 break;
+            }
             case CONFLICTED:
-                myViewNet->setStatusBarText("Another lane from the same edge already connects to that lane");
+                myViewNet->setStatusBarText("Another lane from the same edge already connects to that " + toString(SUMO_TAG_LANE));
                 break;
         }
         if (changed) {
             myNumChanges += 1;
-            GNEJunction* affected = myViewNet->getNet()->retrieveJunction(srcEdge.getDest()->getMicrosimID());
-            affected->invalidateTLS(myViewNet->getUndoList(), deletedConnection);
-            buildIinternalLanes(myCurrentLane->getParentEdge().getNBEdge()->getToNode());
         }
     } else {
-        myViewNet->setStatusBarText("Invalid target for connection");
+        myViewNet->setStatusBarText("Invalid target for " + toString(SUMO_TAG_CONNECTION));
     }
     updateDescription();
 }
@@ -381,7 +351,7 @@ GNEConnectorFrame::onCmdSelectPass(FXObject*, FXSelector, void*) {
 long
 GNEConnectorFrame::onCmdClearSelectedConnections(FXObject*, FXSelector, void*) {
     onCmdCancel(0, 0, 0);
-    myViewNet->getUndoList()->p_begin("clear connections from selected lanes, edges and junctions");
+    myViewNet->getUndoList()->p_begin("clear connections from selected lanes, edges and " + toString(SUMO_TAG_JUNCTION) + "s");
     const std::set<GUIGlID> ids = gSelected.getSelected();
     for (std::set<GUIGlID>::const_iterator it = ids.begin(); it != ids.end(); it++) {
         GUIGlID id = *it;
@@ -448,11 +418,9 @@ GNEConnectorFrame::onCmdResetSelectedConnections(FXObject*, FXSelector, void*) {
 void
 GNEConnectorFrame::updateDescription() const {
     if (myCurrentLane == 0) {
-        myDescription->setText("No Lane Selected\n");
+        myLaneDescriptionLabel->setText("No Lane Selected\n");
     } else {
-        myDescription->setText((
-                                   myCurrentLane->getMicrosimID() + "\n(" +
-                                   toString(myNumChanges) + " changes)").c_str());
+        myLaneDescriptionLabel->setText(("Lane id: " + myCurrentLane->getMicrosimID() + "\nNumber of changes: " + toString(myNumChanges)).c_str());
     }
 }
 
@@ -460,7 +428,7 @@ GNEConnectorFrame::updateDescription() const {
 void
 GNEConnectorFrame::initTargets() {
     // gather potential targets
-    NBNode* nbn = myCurrentLane->getParentEdge().getDest()->getNBNode();
+    NBNode* nbn = myCurrentLane->getParentEdge().getGNEJunctionDestiny()->getNBNode();
 
     const EdgeVector& outgoing = nbn->getOutgoingEdges();
     for (EdgeVector::const_iterator it = outgoing.begin(); it != outgoing.end(); it++) {
@@ -503,7 +471,6 @@ GNEConnectorFrame::cleanup() {
     myNumChanges = 0;
     myCurrentLane->setSpecialColor(0);
     myCurrentLane = 0;
-    buildIinternalLanes(0); // only clears
     updateDescription();
 }
 
@@ -532,48 +499,4 @@ GNEConnectorFrame::getLaneStatus(const std::vector<NBEdge::Connection>& connecti
 }
 
 
-int
-GNEConnectorFrame::getTLLLinkNumber(const std::vector<NBEdge::Connection>& connections, GNELane* targetLane) {
-    const int fromIndex = myCurrentLane->getIndex();
-    NBEdge* destEdge = targetLane->getParentEdge().getNBEdge();
-    const int toIndex = targetLane->getIndex();
-    std::vector<NBEdge::Connection>::const_iterator it = find_if(
-                connections.begin(), connections.end(),
-                NBEdge::connections_finder(fromIndex, destEdge, toIndex));
-    assert(it != connections.end());
-    return it->tlLinkNo;
-}
-
-
-void
-GNEConnectorFrame::buildIinternalLanes(NBNode* node) {
-    // clean up previous objects
-    SUMORTree& rtree = myViewNet->getNet()->getVisualisationSpeedUp();
-    for (std::map<int, GNEInternalLane*>::iterator it = myInternalLanes.begin(); it != myInternalLanes.end(); it++) {
-        rtree.removeAdditionalGLObject(it->second);
-        delete it->second;
-    }
-    myInternalLanes.clear();
-    if (node != 0) {
-        const int NUM_POINTS = 5;
-        SUMORTree& rtree = myViewNet->getNet()->getVisualisationSpeedUp();
-        std::string innerID = ":" + node->getID(); // see NWWriter_SUMO::writeInternalEdges
-
-        int index = 0;
-        const EdgeVector& incoming = node->getIncomingEdges();
-        for (EdgeVector::const_iterator it_edg = incoming.begin(); it_edg != incoming.end(); it_edg++) {
-            const std::vector<NBEdge::Connection>& conns = (*it_edg)->getConnections();
-            for (std::vector<NBEdge::Connection>::const_iterator it_con = conns.begin(); it_con != conns.end(); ++it_con) {
-                const PositionVector shape = node->computeInternalLaneShape(*it_edg, *it_con, NUM_POINTS);
-                LinkState state = node->getLinkState(*it_edg, it_con->toEdge, it_con->fromLane, it_con->toLane, it_con->mayDefinitelyPass, it_con->tlID);
-                GNEInternalLane* ilane = new GNEInternalLane(0, innerID + '_' + toString(index) , shape, -1, state);
-                rtree.addAdditionalGLObject(ilane);
-                myInternalLanes[index] = ilane;
-                index++;
-            }
-        }
-    }
-}
-
-
 /****************************************************************************/
