@@ -2,12 +2,12 @@
 /// @file    GNEDetectorE1.cpp
 /// @author  Pablo Alvarez Lopez
 /// @date    Nov 2015
-/// @version $Id: GNEDetector.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: GNEDetector.cpp 23560 2017-03-20 14:57:08Z palcraft $
 ///
 ///
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
-// Copyright (C) 2001-2013 DLR (http://www.dlr.de/) and contributors
+// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -55,64 +55,61 @@
 #include "GNEViewNet.h"
 
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif
-
 // ===========================================================================
 // member method definitions
 // ===========================================================================
 
-GNEDetector::GNEDetector(const std::string& id, GNEViewNet* viewNet, SumoXMLTag tag, GNELane* lane, SUMOReal posOverLane, int freq, const std::string& filename, bool blocked, GNEAdditionalSet* parent) :
-    GNEAdditional(id, viewNet, Position(posOverLane, 0), tag, parent, blocked),
-    myLane(lane),
+GNEDetector::GNEDetector(const std::string& id, GNEViewNet* viewNet, SumoXMLTag tag, GUIIcon icon, GNELane* lane, double posOverLane, double freq, const std::string& filename) :
+    GNEAdditional(id, viewNet, Position(posOverLane, 0), tag, icon),
     myFreq(freq),
     myFilename(filename) {
-    myLane->addAdditional(this);
+    // This additional belongs to a Lane
+    myLane = lane;
 }
 
 
 GNEDetector::~GNEDetector() {
-    if (myLane) {
-        myLane->removeAdditional(this);
-    }
 }
 
 
 void
-GNEDetector::moveAdditional(SUMOReal posx, SUMOReal posy, GNEUndoList* undoList) {
+GNEDetector::moveAdditionalGeometry(double offsetx, double offsety) {
     // Due a detector is placed over an lane ignore Warning of posy
-    UNUSED_PARAMETER(posy);
-    // if item isn't blocked
-    if (myBlocked == false) {
-        // Move to Right if posx is positive, to left if posx is negative
-        if (((posx > 0) && ((myPosition.x() + posx) < myLane->getLaneShapeLenght())) || ((posx < 0) && ((myPosition.x() + posx) > 0))) {
-            // change attribute
-            undoList->p_add(new GNEChange_Attribute(this, SUMO_ATTR_POSITION, toString(myPosition.x() + posx)));
-        }
+    UNUSED_PARAMETER(offsety);
+    // declare start and end positions
+    double startPos = myPosition.x();
+    double endPos = 0;
+    // set endPos if additional has the attribute length
+    if (GNEAttributeCarrier::hasAttribute(getTag(), SUMO_ATTR_LENGTH)) {
+        endPos = startPos + GNEAttributeCarrier::parse<double>(getAttribute(SUMO_ATTR_LENGTH));
+    }
+    // Move to Right if distance is positive, to left if distance is negative
+    if (((offsetx > 0) && ((endPos + offsetx) < myLane->getLaneShapeLength())) || ((offsetx < 0) && ((startPos + offsetx) > 0))) {
+        // change attribute
+        myPosition.set(myPosition.x() + offsetx, 0);
+        // Update geometry
+        updateGeometry();
     }
 }
 
 
-GNELane*
-GNEDetector::getLane() const {
-    return myLane;
-}
-
-
 void
-GNEDetector::removeLaneReference() {
-    myLane = NULL;
+GNEDetector::commmitAdditionalGeometryMoved(double oldPosx, double, GNEUndoList* undoList) {
+    undoList->p_begin("position of " + toString(getTag()));
+    undoList->p_add(new GNEChange_Attribute(this, SUMO_ATTR_POSITION, toString(myPosition.x()), true, toString(oldPosx)));
+    undoList->p_end();
+    // Refresh element
+    myViewNet->getNet()->refreshAdditional(this);
 }
 
 
-SUMOReal
+double
 GNEDetector::getPositionOverLane() const {
     return myPosition.x();
 }
 
 
-int
+double
 GNEDetector::getFrequency() const {
     return myFreq;
 }
@@ -125,11 +122,11 @@ GNEDetector::getFilename() const {
 
 
 void
-GNEDetector::setPositionOverLane(SUMOReal pos) {
+GNEDetector::setPositionOverLane(double pos) {
     if (pos < 0) {
-        throw InvalidArgument("Position '" + toString(pos) + "' not allowed. Must be greather than 0");
-    } else if (pos > myLane->getLaneShapeLenght()) {
-        throw InvalidArgument("Position '" + toString(pos) + "' not allowed. Must be smaller than lane length");
+        throw InvalidArgument("Position '" + toString(pos) + "' of " + toString(getTag()) + " not allowed. Must be greater than 0");
+    } else if (pos > myLane->getLaneShapeLength()) {
+        throw InvalidArgument("Position '" + toString(pos) + "' of " + toString(getTag()) + " not allowed. Must be smaller than lane length");
     } else {
         myPosition = Position(pos, 0);
     }
@@ -137,11 +134,11 @@ GNEDetector::setPositionOverLane(SUMOReal pos) {
 
 
 void
-GNEDetector::setFrequency(int freq) {
-    if (freq >= 0) {
+GNEDetector::setFrequency(const double freq) {
+    if (freq > 0) {
         myFreq = freq;
     } else {
-        throw InvalidArgument("Frequency '" + toString(freq) + "' not allowed. Must be greather than 0");
+        throw InvalidArgument("Frequency '" + toString(freq) + "' not allowed. Must be greater than 0");
     }
 }
 
@@ -152,16 +149,6 @@ GNEDetector::setFilename(std::string filename) {
 }
 
 
-void
-GNEDetector::changeLane(GNELane* newLane) {
-    myLane->removeAdditional(this);
-    myLane = newLane;
-    myLane->addAdditional(this);
-    updateGeometry();
-    getViewNet()->update();
-}
-
-
 const std::string&
 GNEDetector::getParentName() const {
     return myLane->getMicrosimID();
@@ -169,7 +156,7 @@ GNEDetector::getParentName() const {
 
 
 void
-GNEDetector::drawDetectorIcon(const int GNELogoID, SUMOReal sizex, SUMOReal sizey) const {
+GNEDetector::drawDetectorIcon(const int GNELogoID, double sizex, double sizey) const {
     // Add a draw matrix
     glPushMatrix();
     // Traslate to center
