@@ -2,13 +2,13 @@
 /// @file    GNEEdge.h
 /// @author  Jakob Erdmann
 /// @date    Feb 2011
-/// @version $Id: GNEEdge.h 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GNEEdge.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // A road/street connecting two junctions (netedit-version, adapted from GUIEdge)
 // Basically a container for an NBEdge with drawing and editing capabilities
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -39,8 +39,11 @@
 class GNENet;
 class GNEJunction;
 class GNELane;
+class GNEConnection;
 class GNEAdditional;
-class GNEAdditionalSet;
+class GNERouteProbe;
+class GNEVaporizer;
+class GNERerouter;
 
 // ===========================================================================
 // class definitions
@@ -58,14 +61,14 @@ class GNEEdge : public GNENetElement {
     friend class GNEChange_Connection;
 
 public:
-    /// @brief Definition of the lane's positions vector
+    /// @brief Definition of the lane's vector
     typedef std::vector<GNELane*> LaneVector;
 
-    /// @brief Definition of the additionals list
-    typedef std::vector<GNEAdditional*> AdditionalVector;
+    /// @brief Definition of the connection's vector
+    typedef std::vector<GNEConnection*> ConnectionVector;
 
-    /// @brief Definition of the additionalSets list
-    typedef std::vector<GNEAdditionalSet*> AdditionalSetVector;
+    /// @brief Definition of the additionals vector
+    typedef std::vector<GNEAdditional*> AdditionalVector;
 
     /**@brief Constructor.
      * @param[in] nbe The represented edge
@@ -78,6 +81,7 @@ public:
     ~GNEEdge();
 
     /// @brief update pre-computed geometry information
+    /// @note if current editing mode is Move, connection's geometry will not be updated
     void updateGeometry();
 
     /// Returns the street's geometry
@@ -117,17 +121,17 @@ public:
     void drawGL(const GUIVisualizationSettings& s) const;
     /// @}
 
-    /**@brief update edge geometry after junction move */
+    /// @brief update edge geometry after junction move
     void updateJunctionPosition(GNEJunction* junction, const Position& origPos);
 
     /// @brief returns the internal NBEdge
     NBEdge* getNBEdge();
 
     /// @brief returns the source-junction
-    GNEJunction* getSource() const;
+    GNEJunction* getGNEJunctionSource() const;
 
     /// @brief returns the destination-junction
-    GNEJunction* getDest() const;
+    GNEJunction* getGNEJunctionDestiny() const;
 
     /**@brief change the edge geometry
      * It is up to the Edge to decide whether an new geometry node should be
@@ -190,11 +194,11 @@ public:
      */
     void setGeometry(PositionVector geom, bool inner);
 
-    /**@brief update edge geometry and inform the lanes
-     * let the lanes recompute their precomputed geometry information
-     * (needed after computing junction shapes)
-     */
-    void updateLaneGeometriesAndAdditionals();
+    /// @brief remake connections
+    void remakeGNEConnections();
+
+    /// @brief remake connections of all incoming edges
+    void remakeIncomingGNEConnections();
 
     /// @brief copy edge attributes from tpl
     void copyTemplate(GNEEdge* tpl, GNEUndoList* undolist);
@@ -205,6 +209,12 @@ public:
     /// @brief returns a reference to the lane vector
     const std::vector<GNELane*>& getLanes();
 
+    /// @brief returns a reference to the GNEConnection vector
+    const std::vector<GNEConnection*>& getGNEConnections();
+
+    /// @brief get connection
+    GNEConnection* retrieveConnection(int fromLane, NBEdge* to, int toLane);
+
     /// @brief whether this edge was created from a split
     bool wasSplit();
 
@@ -215,37 +225,61 @@ public:
     /// @brief override to also set lane ids
     void setMicrosimID(const std::string& newID);
 
-    /// @brief add additional to this edge
-    bool addAdditional(GNEAdditional* additional);
+    /// @brief add additional child to this edge
+    void addAdditionalChild(GNEAdditional* additional);
 
-    /// @brief remove additional from this edge
-    bool removeAdditional(GNEAdditional* additional);
+    /// @brief remove additional child from this edge
+    void removeAdditionalChild(GNEAdditional* additional);
 
     /// @brief return list of additionals associated with this edge
-    const std::vector<GNEAdditional*>& getAdditionals() const;
+    const std::vector<GNEAdditional*>& getAdditionalChilds() const;
 
-    /// @brief add GNEAdditionalSet to this edge
-    bool addAdditionalSet(GNEAdditionalSet* additionalSet);
+    /// @brief add a reference to a rerouter that has this edge as parameter
+    void addGNERerouter(GNERerouter* rerouter);
 
-    /// @brief remove GNEAdditionalSet from this edge
-    bool removeAdditionalSet(GNEAdditionalSet* additionalSet);
+    /// @brief remove a reference to a rerouter that has this edge as parameter
+    void removeGNERerouter(GNERerouter* rerouter);
 
-    /// @brief return list of additionalSets associated with this edge
-    const std::vector<GNEAdditionalSet*>& getAdditionalSets();
+    /// @brief get rerouters vinculated with this edge
+    const std::vector<GNERerouter*>& getGNERerouters() const;
+
+    /// @brief get number of rerouters that has this edge as parameters
+    int getNumberOfGNERerouters() const;
+
+    /// @brief check if edge has a restricted lane
+    bool hasRestrictedLane(SUMOVehicleClass vclass) const;
 
     // the radius in which to register clicks for geometry nodes
-    static const SUMOReal SNAP_RADIUS;
+    static const double SNAP_RADIUS;
+
+    /// @brief clear current connections
+    void clearGNEConnections();
+
+    /// @brief obtain relative positions of RouteProbes
+    int getRouteProbeRelativePosition(GNERouteProbe* routeProbe) const;
+
+    /// @brief obtain relative positions of Vaporizer
+    int getVaporizerRelativePosition(GNEVaporizer* vaporizer) const;
 
 protected:
     /// @brief the underlying NBEdge
     NBEdge& myNBEdge;
 
+    /// @brief pointer to GNEJunction source
+    GNEJunction* myGNEJunctionSource;
+
+    /// @brief pointer to GNEJunction destiny
+    GNEJunction* myGNEJunctionDestiny;
+
     /// @brief restore point for undo
     PositionVector myOrigShape;
 
-    /// @brief List of this edges lanes
+    /// @brief vectgor with the lanes of this edge
     LaneVector myLanes;
 
+    /// @brief vector with the connections of this edge
+    ConnectionVector myGNEConnections;
+
     /// @brief whether we are responsible for deleting myNBNode
     bool myAmResponsible;
 
@@ -255,11 +289,11 @@ protected:
     /// @brief modification status of the connections
     std::string myConnectionStatus;
 
-    /// @brief list with the additonals vinculated with this edge
+    /// @brief list with the additionals vinculated with this edge
     AdditionalVector myAdditionals;
 
-    /// @brief list with the additonalSets vinculated with this edge
-    AdditionalSetVector myAdditionalSets;
+    /// @brief list of reroutes that has this edge as parameter
+    std::vector<GNERerouter*> myReroutes;
 
 private:
     /// @brief set attribute after validation
@@ -277,7 +311,7 @@ private:
      * with this number are restored. If none are found the attributes for the
      * leftmost lane are copied
      */
-    void setNumLanes(unsigned int numLanes, GNEUndoList* undoList);
+    void setNumLanes(int numLanes, GNEUndoList* undoList);
 
     /// @brief@brief increase number of lanes by one use the given attributes and restore the GNELane
     void addLane(GNELane* lane, const NBEdge::Lane& laneAttrs);
@@ -286,10 +320,11 @@ private:
     void removeLane(GNELane* lane);
 
     /// @brief adds a connection
-    void addConnection(unsigned int fromLane, const std::string& toEdgeID, unsigned int toLane, bool mayPass);
+    void addConnection(NBEdge::Connection nbCon, GNEConnection* con);
 
     /// @brief removes a connection
-    void removeConnection(unsigned int fromLane, const std::string& toEdgeID, unsigned int toLane);
+    void removeConnection(NBEdge::Connection nbCon);
+
 };
 
 
