@@ -2,12 +2,12 @@
 /// @file    GNEInternalLane.cpp
 /// @author  Jakob Erdmann
 /// @date    June 2011
-/// @version $Id: GNEInternalLane.cpp 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GNEInternalLane.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A class for visualizing Inner Lanes (used when editing traffic lights)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -54,10 +54,6 @@
 #include "GNEInternalLane.h"
 #include "GNETLSEditorFrame.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // FOX callback mapping
@@ -111,7 +107,7 @@ GNEInternalLane::GNEInternalLane(GNETLSEditorFrame* editor, const std::string& i
             const Position& f = myShape[i];
             const Position& s = myShape[i + 1];
             myShapeLengths.push_back(f.distanceTo2D(s));
-            myShapeRotations.push_back((SUMOReal) atan2((s.x() - f.x()), (f.y() - s.y())) * (SUMOReal) 180.0 / (SUMOReal) PI);
+            myShapeRotations.push_back((double) atan2((s.x() - f.x()), (f.y() - s.y())) * (double) 180.0 / (double) PI);
         }
     }
 }
@@ -202,8 +198,7 @@ GNEInternalLane::getPopUpMenu(GUIMainWindow& app, GUISUMOAbstractView& parent) {
 
 
 GUIParameterTableWindow*
-GNEInternalLane::getParameterWindow(GUIMainWindow& app,
-                                    GUISUMOAbstractView&) {
+GNEInternalLane::getParameterWindow(GUIMainWindow& app, GUISUMOAbstractView&) {
     GUIParameterTableWindow* ret =
         new GUIParameterTableWindow(app, *this, 2);
     // add items
@@ -227,7 +222,7 @@ GNEInternalLane::colorForLinksState(FXuint state) {
         // special case (default gui does not distinguish between yellow major/minor
         return RGBColor(179, 179, 0, 255);
     } else {
-        return getLinkColor((LinkState)state);
+        return GUIVisualizationSettings::getLinkColor((LinkState)state);
     }
 }
 
