@@ -2,13 +2,13 @@
 /// @file    GNEJunction.cpp
 /// @author  Jakob Erdmann
 /// @date    Feb 2011
-/// @version $Id: GNEJunction.cpp 21851 2016-10-31 12:20:12Z behrisch $
+/// @version $Id: GNEJunction.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // A class for visualizing and editing junctions in netedit (adapted from
 // GUIJunctionWrapper)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -59,15 +59,11 @@
 #include "GNEConnection.h"
 #include "GNEJunction.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 // ===========================================================================
 // method definitions
 // ===========================================================================
 GNEJunction::GNEJunction(NBNode& nbn, GNENet* net, bool loaded) :
-    GNENetElement(net, nbn.getID(), GLO_JUNCTION, SUMO_TAG_JUNCTION),
+    GNENetElement(net, nbn.getID(), GLO_JUNCTION, SUMO_TAG_JUNCTION, ICON_JUNCTION),
     myNBNode(nbn),
     myOrigPos(nbn.getPosition()),
     myAmCreateEdgeSource(false),
@@ -76,7 +72,6 @@ GNEJunction::GNEJunction(NBNode& nbn, GNENet* net, bool loaded) :
     myHasValidLogic(loaded),
     myAmTLSSelected(false) {
     updateGeometry();
-    rebuildCrossings(false);
 }
 
 
@@ -84,12 +79,14 @@ GNEJunction::~GNEJunction() {
     if (myAmResponsible) {
         delete &myNBNode;
     }
-    rebuildCrossings(true);
+    dropGNECrossings();
 }
 
 
 void
 GNEJunction::updateGeometry() {
+    //myNet->getNetBuilder()->computeSingleNode(&myNBNode, OptionsCont::getOptions());
+
     const double EXTENT = 2;
     myBoundary = Boundary(
                      myOrigPos.x() - EXTENT, myOrigPos.y() - EXTENT,
@@ -98,23 +95,22 @@ GNEJunction::updateGeometry() {
         myBoundary.add(myNBNode.getShape().getBoxBoundary());
     }
     myMaxSize = MAX2(myBoundary.getWidth(), myBoundary.getHeight());
+    rebuildGNECrossings();
 }
 
 
 void
-GNEJunction::rebuildCrossings(bool deleteOnly) {
-    for (std::vector<GNECrossing*>::const_iterator it = myCrossings.begin(); it != myCrossings.end(); it++) {
-        (*it)->decRef();
-        if ((*it)->unreferenced()) {
-            delete *it;
-        }
-    }
-    myCrossings.clear();
-    if (!deleteOnly) {
+GNEJunction::rebuildGNECrossings() {
+    // drop existent GNECrossings
+    dropGNECrossings();
+    // rebuild GNECrossings only if create crossings and walkingAreas in net is enabled
+    if (myNet->getNetBuilder()->haveNetworkCrossings() == true) {
+        // build new NBNode::Crossings and walking areas and create GNECrossings
+        myNBNode.buildCrossingsAndWalkingAreas();
         const std::vector<NBNode::Crossing>& crossings = myNBNode.getCrossings();
         for (std::vector<NBNode::Crossing>::const_iterator it = crossings.begin(); it != crossings.end(); it++) {
-            myCrossings.push_back(new GNECrossing(*this, (*it).id));
-            myCrossings.back()->incRef();
+            myGNECrossings.push_back(new GNECrossing(this, (*it).id));
+            myGNECrossings.back()->incRef();
         }
     }
 }
@@ -169,7 +165,7 @@ GNEJunction::getCenteringBoundary() const {
 void
 GNEJunction::drawGL(const GUIVisualizationSettings& s) const {
     glPushName(getGlID());
-    SUMOReal exaggeration = gSelected.isSelected(getType(), getGlID()) ? s.selectionScale : 1;
+    double exaggeration = gSelected.isSelected(getType(), getGlID()) ? s.selectionScale : 1;
     exaggeration *= s.junctionSize.getExaggeration(s);
     if (s.scale * exaggeration * myMaxSize < 1.) {
         // draw something simple so that selection still works
@@ -199,6 +195,20 @@ GNEJunction::drawGL(const GUIVisualizationSettings& s) const {
                 }
                 glPopMatrix();
             }
+            // Check if a  buuble must be drawed over junction
+            if (myNet->getViewNet()->showJunctionAsBubbles()) {
+                setColor(s, true);
+                // recognize full transparency and simply don't draw
+                GLfloat color[4];
+                glGetFloatv(GL_CURRENT_COLOR, color);
+                if (color[3] != 0) {
+                    glPushMatrix();
+                    Position pos = myNBNode.getPosition();
+                    glTranslated(pos.x(), pos.y(), getType() + 0.05);
+                    GLHelper::drawFilledCircle(4 * exaggeration, 32);
+                    glPopMatrix();
+                }
+            }
         }
         if (drawBubble) {
             setColor(s, true);
@@ -219,14 +229,14 @@ GNEJunction::drawGL(const GUIVisualizationSettings& s) const {
             Position pos = myNBNode.getPosition();
             glTranslated(pos.x(), pos.y(), getType() + 0.1);
             glColor3d(1, 1, 1);
-            const SUMOReal halfWidth = 32 / s.scale;
-            const SUMOReal halfHeight = 64 / s.scale;
-            GUITexturesHelper::drawTexturedBox(GUITextureSubSys::getGif(GNETEXTURE_TLS), -halfWidth, -halfHeight, halfWidth, halfHeight);
+            const double halfWidth = 32 / s.scale;
+            const double halfHeight = 64 / s.scale;
+            GUITexturesHelper::drawTexturedBox(GUITextureSubSys::getTexture(GNETEXTURE_TLS), -halfWidth, -halfHeight, halfWidth, halfHeight);
             glPopMatrix();
         }
         // draw crossings
         if (s.editMode != GNE_MODE_TLS) {
-            for (std::vector<GNECrossing*>::const_iterator it = myCrossings.begin(); it != myCrossings.end(); it++) {
+            for (std::vector<GNECrossing*>::const_iterator it = myGNECrossings.begin(); it != myGNECrossings.end(); it++) {
                 (*it)->drawGL(s);
             }
         }
@@ -248,42 +258,103 @@ GNEJunction::getNBNode() const {
 }
 
 
-std::vector<GNEEdge*>
+Position
+GNEJunction::getPosition() const {
+    return myNBNode.getPosition();
+}
+
+
+std::vector<GNEJunction*>
+GNEJunction::getJunctionNeighbours() const {
+    // use set to avoid duplicates junctions
+    std::set<GNEJunction*> junctions;
+    for (std::vector<GNEEdge*>::const_iterator i = myGNEIncomingEdges.begin(); i != myGNEIncomingEdges.end(); i++) {
+        junctions.insert((*i)->getGNEJunctionSource());
+    }
+    for (std::vector<GNEEdge*>::const_iterator i = myGNEOutgoingEdges.begin(); i != myGNEOutgoingEdges.end(); i++) {
+        junctions.insert((*i)->getGNEJunctionDestiny());
+    }
+    return std::vector<GNEJunction*>(junctions.begin(), junctions.end());
+}
+
+
+void
+GNEJunction::addIncomingGNEEdge(GNEEdge* edge) {
+    // Check if incoming edge was already inserted
+    std::vector<GNEEdge*>::iterator i = std::find(myGNEIncomingEdges.begin(), myGNEIncomingEdges.end(), edge);
+    if (i != myGNEIncomingEdges.end()) {
+        throw InvalidArgument("Incoming " + toString(SUMO_TAG_EDGE) + " with ID '" + edge->getID() + "' was already inserted into " + toString(getTag()) + " with ID " + getID() + "'");
+    } else {
+        // Add edge into containers
+        myGNEIncomingEdges.push_back(edge);
+        myGNEEdges.push_back(edge);
+    }
+}
+
+
+void
+GNEJunction::addOutgoingGNEEdge(GNEEdge* edge) {
+    // Check if outgoing edge was already inserted
+    std::vector<GNEEdge*>::iterator i = std::find(myGNEOutgoingEdges.begin(), myGNEOutgoingEdges.end(), edge);
+    if (i != myGNEOutgoingEdges.end()) {
+        throw InvalidArgument("Outgoing " + toString(SUMO_TAG_EDGE) + " with ID '" + edge->getID() + "' was already inserted into " + toString(getTag()) + " with ID " + getID() + "'");
+    } else {
+        // Add edge into containers
+        myGNEOutgoingEdges.push_back(edge);
+        myGNEEdges.push_back(edge);
+    }
+}
+
+
+void
+GNEJunction::removeIncomingGNEEdge(GNEEdge* edge) {
+    // Check if incoming edge was already inserted
+    std::vector<GNEEdge*>::iterator i = std::find(myGNEIncomingEdges.begin(), myGNEIncomingEdges.end(), edge);
+    if (i == myGNEIncomingEdges.end()) {
+        throw InvalidArgument("Incoming " + toString(SUMO_TAG_EDGE) + " with ID '" + edge->getID() + "' doesn't found into " + toString(getTag()) + " with ID " + getID() + "'");
+    } else {
+        // remove edge from containers
+        myGNEIncomingEdges.erase(i);
+        myGNEEdges.erase(std::find(myGNEEdges.begin(), myGNEEdges.end(), edge));
+    }
+}
+
+
+void
+GNEJunction::removeOutgoingGNEEdge(GNEEdge* edge) {
+    // Check if outgoing edge was already inserted
+    std::vector<GNEEdge*>::iterator i = std::find(myGNEOutgoingEdges.begin(), myGNEOutgoingEdges.end(), edge);
+    if (i == myGNEOutgoingEdges.end()) {
+        throw InvalidArgument("Outgoing " + toString(SUMO_TAG_EDGE) + " with ID '" + edge->getID() + "' doesn't found into " + toString(getTag()) + " with ID " + getID() + "'");
+    } else {
+        // remove edge from containers
+        myGNEOutgoingEdges.erase(i);
+        myGNEEdges.erase(std::find(myGNEEdges.begin(), myGNEEdges.end(), edge));
+    }
+}
+
+
+const std::vector<GNEEdge*>&
 GNEJunction::getGNEEdges() const {
-    std::vector<GNEEdge*> edges;
-    // iterate over incoming edges
-    for (std::vector<NBEdge*>::const_iterator i = myNBNode.getIncomingEdges().begin(); i != myNBNode.getIncomingEdges().end(); i++) {
-        edges.push_back(myNet->retrieveEdge((*i)->getID()));
-    }
-    // iterate over outgoing edges
-    for (std::vector<NBEdge*>::const_iterator i = myNBNode.getOutgoingEdges().begin(); i != myNBNode.getOutgoingEdges().end(); i++) {
-        edges.push_back(myNet->retrieveEdge((*i)->getID()));
-    }
-    return edges;
+    return myGNEEdges;
 }
 
 
-std::vector<GNEEdge*>
+const std::vector<GNEEdge*>&
 GNEJunction::getGNEIncomingEdges() const {
-    std::vector<GNEEdge*> incomingEdges;
-    // iterate over incoming edges
-    for (std::vector<NBEdge*>::const_iterator i = myNBNode.getIncomingEdges().begin(); i != myNBNode.getIncomingEdges().end(); i++) {
-        incomingEdges.push_back(myNet->retrieveEdge((*i)->getID()));
-    }
-    return incomingEdges;
+    return myGNEIncomingEdges;
 }
 
 
-std::vector<GNEEdge*>
+const std::vector<GNEEdge*>&
 GNEJunction::getGNEOutgoingEdges() const {
-    std::vector<GNEEdge*> outgoingEdges;
-    // iterate over outgoing edges
-    for (std::vector<NBEdge*>::const_iterator i = myNBNode.getOutgoingEdges().begin(); i != myNBNode.getOutgoingEdges().end(); i++) {
-        outgoingEdges.push_back(myNet->retrieveEdge((*i)->getID()));
-    }
-    return outgoingEdges;
+    return myGNEOutgoingEdges;
 }
 
+const std::vector<GNECrossing*>&
+GNEJunction::getGNECrossings() const {
+    return myGNECrossings;
+}
 
 void
 GNEJunction::markAsCreateEdgeSource() {
@@ -303,6 +374,23 @@ GNEJunction::selectTLS(bool selected) {
 }
 
 
+void
+GNEJunction::recomputeNeighborsJunctions() {
+    std::set<GNEJunction*> neighborsJunctions;
+    // obtain all neighbors junctions
+    for (std::vector<GNEEdge*>::const_iterator i = myGNEIncomingEdges.begin(); i != myGNEIncomingEdges.end(); i++) {
+        neighborsJunctions.insert((*i)->getGNEJunctionSource());
+    }
+    for (std::vector<GNEEdge*>::const_iterator i = myGNEOutgoingEdges.begin(); i != myGNEOutgoingEdges.end(); i++) {
+        neighborsJunctions.insert((*i)->getGNEJunctionDestiny());
+    }
+    // recompute all neighbors junctions
+    //for(std::set<GNEJunction*>::iterator i = neighborsJunctions.begin(); i != neighborsJunctions.end(); i++) {
+    //    myNet->getNetBuilder()->computeSingleNode((*i)->getNBNode(), OptionsCont::getOptions());
+    //}
+}
+
+
 void
 GNEJunction::move(Position pos) {
     const Position orig = myNBNode.getPosition();
@@ -312,6 +400,10 @@ GNEJunction::move(Position pos) {
         GNEEdge* edge = myNet->retrieveEdge((*it)->getID());
         edge->updateJunctionPosition(this, orig);
     }
+    // recompute neighbors junctions
+    recomputeNeighborsJunctions();
+    // recompute junction
+    //myNet->getNetBuilder()->computeSingleNode(&myNBNode, OptionsCont::getOptions());
     // Update shapes without include connections, because the aren't showed in Move mode
     updateShapesAndGeometries();
 }
@@ -321,14 +413,19 @@ void
 GNEJunction::registerMove(GNEUndoList* undoList) {
     Position newPos = myNBNode.getPosition();
     std::string newPosValue = getAttribute(SUMO_ATTR_POSITION);
-    // actually the geometry is already up to date
-    // set the restore point to the end of the last change-set
-    setPosition(myOrigPos);
-    // do not execute the command to avoid changing the edge geometry twice
-    undoList->add(new GNEChange_Attribute(this, SUMO_ATTR_POSITION, newPosValue), false);
-    setPosition(newPos);
-    // Refresh element to avoid grabbing problems
-    myNet->refreshElement(this);
+    if (isValid(SUMO_ATTR_POSITION, newPosValue)) {
+        // actually the geometry is already up to date
+        // set the restore point to the end of the last change-set
+        setPosition(myOrigPos);
+        // do not execute the command to avoid changing the edge geometry twice
+        undoList->add(new GNEChange_Attribute(this, SUMO_ATTR_POSITION, newPosValue), false);
+        setPosition(newPos);
+        // Refresh element to avoid grabbing problems
+        myNet->refreshElement(this);
+    } else {
+        // tried to set an invalid position, revert back to the previous one
+        move(myOrigPos);
+    }
 }
 
 
@@ -337,56 +434,36 @@ GNEJunction::updateShapesAndGeometries() {
     // First declare three sets with all affected GNEJunctions, GNEEdges and GNEConnections
     std::set<GNEJunction*> affectedJunctions;
     std::set<GNEEdge*> affectedEdges;
-    // Fill sets
-    std::vector<GNEEdge*> GNEEdges = getGNEEdges();             // @Improve efficiency
-    std::vector<GNEEdge*> edgesNeighbor;
     // Iterate over GNEEdges
-    for (std::vector<GNEEdge*>::const_iterator i = GNEEdges.begin(); i != GNEEdges.end(); i++) {
+    for (std::vector<GNEEdge*>::const_iterator i = myGNEEdges.begin(); i != myGNEEdges.end(); i++) {
         // Add source and destiny junctions
-        affectedJunctions.insert((*i)->getGNEJunctionSource()); // @Improve efficiency
-        affectedJunctions.insert((*i)->getGNEJunctionDest());   // @Improve efficiency
+        affectedJunctions.insert((*i)->getGNEJunctionSource());
+        affectedJunctions.insert((*i)->getGNEJunctionDestiny());
         // Obtain neighbors of Junction source
-        edgesNeighbor = (*i)->getGNEJunctionSource()->getGNEEdges();    // @Improve efficiency
-        for (std::vector<GNEEdge*>::const_iterator j = edgesNeighbor.begin(); j != edgesNeighbor.end(); j++) {
+        for (std::vector<GNEEdge*>::const_iterator j = (*i)->getGNEJunctionSource()->getGNEEdges().begin(); j != (*i)->getGNEJunctionSource()->getGNEEdges().end(); j++) {
             affectedEdges.insert(*j);
         }
         // Obtain neighbors of Junction destiny
-        edgesNeighbor = (*i)->getGNEJunctionDest()->getGNEEdges();  // @Improve efficiency
-        for (std::vector<GNEEdge*>::const_iterator j = edgesNeighbor.begin(); j != edgesNeighbor.end(); j++) {
+        for (std::vector<GNEEdge*>::const_iterator j = (*i)->getGNEJunctionDestiny()->getGNEEdges().begin(); j != (*i)->getGNEJunctionDestiny()->getGNEEdges().end(); j++) {
             affectedEdges.insert(*j);
         }
     }
     // Iterate over affected Junctions
     for (std::set<GNEJunction*>::iterator i = affectedJunctions.begin(); i != affectedJunctions.end(); i++) {
-        // Check that Node doesn't have a custom shape
-        if ((*i)->getNBNode()->hasCustomShape() == false) {
-            // Set new shape depending of the representation
-            if (myNet->getViewNet()->showJunctionAsBubbles() == true) {
-                // Only save Position to draw bubble
-                (*i)->getNBNode()->myPoly.clear();
-                (*i)->getNBNode()->myPoly.push_back((*i)->getNBNode()->getPosition());
-            } else {
-                // Compute polygon
-                (*i)->getNBNode()->computeNodeShape(-1);
-            }
-            // Update geometry of Junction
-            (*i)->updateGeometry();
-        }
+        // Update geometry of Junction
+        (*i)->updateGeometry();
     }
     // Iterate over affected Edges
     for (std::set<GNEEdge*>::iterator i = affectedEdges.begin(); i != affectedEdges.end(); i++) {
-        if (myNet->getViewNet()->showJunctionAsBubbles() == true) {
-            // Only compute lane shapes
-            (*i)->getNBEdge()->computeLaneShapes();
-        } else {
-            // Compute full edge shape because this funcion is related to computeNodeShape
-            (*i)->getNBEdge()->computeEdgeShape();
-        }
         // Update edge geometry
         (*i)->updateGeometry();
     }
+    // Finally update geometry of this edge
+    updateGeometry();
     // Update view to show the new shapes
-    myNet->getViewNet()->update();
+    if (myNet->getViewNet()) {
+        myNet->getViewNet()->update();
+    }
 }
 
 
@@ -428,7 +505,7 @@ GNEJunction::setLogicValid(bool valid, GNEUndoList* undoList, const std::string&
         undoList->add(new GNEChange_Attribute(this, GNE_ATTR_MODIFICATION_STATUS, status), true);
         invalidateTLS(undoList);
     } else {
-        rebuildCrossings(false);
+        rebuildGNECrossings();
     }
 }
 
@@ -497,6 +574,19 @@ GNEJunction::isLogicValid() {
 }
 
 
+void
+GNEJunction::dropGNECrossings() {
+    // delete all GNECrossing
+    for (std::vector<GNECrossing*>::const_iterator it = myGNECrossings.begin(); it != myGNECrossings.end(); it++) {
+        (*it)->decRef();
+        if ((*it)->unreferenced()) {
+            delete *it;
+        }
+    }
+    myGNECrossings.clear();
+}
+
+
 std::string
 GNEJunction::getAttribute(SumoXMLAttr key) const {
     switch (key) {
@@ -524,7 +614,7 @@ GNEJunction::getAttribute(SumoXMLAttr key) const {
         case SUMO_ATTR_KEEP_CLEAR:
             return myNBNode.getKeepClear() ? "true" : "false";
         default:
-            throw InvalidArgument("junction attribute '" + toString(key) + "' not allowed");
+            throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
 }
 
@@ -545,8 +635,18 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value, GNEUndoList
             undoList->add(new GNEChange_Attribute(this, key, value), true);
             break;
         case SUMO_ATTR_TYPE: {
-            undoList->p_begin("change junction type");
+            undoList->p_begin("change " + toString(getTag()) + " type");
             if (NBNode::isTrafficLight(SUMOXMLDefinitions::NodeTypes.get(value))) {
+                if (getNBNode()->isTLControlled() &&
+                        // if switching changing from or to traffic_light_right_on_red we need to remove the old plan
+                        (getNBNode()->getType() == NODETYPE_TRAFFIC_LIGHT_RIGHT_ON_RED
+                         || SUMOXMLDefinitions::NodeTypes.get(value) == NODETYPE_TRAFFIC_LIGHT_RIGHT_ON_RED)
+                   ) {
+                    const std::set<NBTrafficLightDefinition*> tls = myNBNode.getControllingTLS();
+                    for (std::set<NBTrafficLightDefinition*>::iterator it = tls.begin(); it != tls.end(); it++) {
+                        undoList->add(new GNEChange_TLS(this, *it, false), true);
+                    }
+                }
                 if (!getNBNode()->isTLControlled()) {
                     // create new traffic light
                     undoList->add(new GNEChange_TLS(this, 0, true), true);
@@ -565,7 +665,7 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value, GNEUndoList
             break;
         }
         case SUMO_ATTR_TLID: {
-            undoList->p_begin("change tls id");
+            undoList->p_begin("change " + toString(SUMO_TAG_TRAFFIC_LIGHT) + " id");
             // junction is already controlled, remove from previous tls
             const std::set<NBTrafficLightDefinition*> tls = myNBNode.getControllingTLS();
             for (std::set<NBTrafficLightDefinition*>::iterator it = tls.begin(); it != tls.end(); it++) {
@@ -603,7 +703,7 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value, GNEUndoList
             break;
         }
         default:
-            throw InvalidArgument("junction attribute '" + toString(key) + "' not allowed");
+            throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
 }
 
@@ -623,13 +723,12 @@ GNEJunction::isValid(SumoXMLAttr key, const std::string& value) {
             break;
         case SUMO_ATTR_SHAPE: {
             bool ok = true;
-            PositionVector shape = GeomConvHelper::parseShapeReporting(
-                                       value, "user-supplied position", 0, ok, true);
+            PositionVector shape = GeomConvHelper::parseShapeReporting(value, "user-supplied position", 0, ok, true);
             return ok;
             break;
         }
         case SUMO_ATTR_RADIUS:
-            return canParse<SUMOReal>(value);
+            return canParse<double>(value);
             break;
         case SUMO_ATTR_TLTYPE:
             return myNBNode.isTLControlled() && SUMOXMLDefinitions::TrafficLightTypes.hasString(value);
@@ -639,7 +738,7 @@ GNEJunction::isValid(SumoXMLAttr key, const std::string& value) {
             return value == "true" || value == "false";
             break;
         default:
-            throw InvalidArgument("junction attribute '" + toString(key) + "' not allowed");
+            throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
 }
 
@@ -667,6 +766,10 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value) {
             bool ok;
             myOrigPos = GeomConvHelper::parseShapeReporting(value, "netedit-given", 0, ok, false)[0];
             move(myOrigPos);
+            // recompute neighbors junctions
+            recomputeNeighborsJunctions();
+            // recompute junction
+            //myNet->getNetBuilder()->computeSingleNode(&myNBNode, OptionsCont::getOptions());
             // Refresh element to avoid grabbing problems
             myNet->refreshElement(this);
             break;
@@ -674,8 +777,8 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value) {
             if (myLogicStatus == GUESSED && value != GUESSED) {
                 // clear guessed connections. previous connections will be restored
                 myNBNode.invalidateIncomingConnections();
-                std::vector<GNEEdge*> incomingEdges = getGNEIncomingEdges();
-                for (std::vector<GNEEdge*>::iterator i = incomingEdges.begin(); i != incomingEdges.end(); i++) {
+                // Clear GNEConnections of incoming edges
+                for (std::vector<GNEEdge*>::iterator i = myGNEIncomingEdges.begin(); i != myGNEIncomingEdges.end(); i++) {
                     (*i)->clearGNEConnections();
                 }
             }
@@ -688,7 +791,7 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value) {
             break;
         }
         case SUMO_ATTR_RADIUS:
-            myNBNode.setRadius(parse<SUMOReal>(value));
+            myNBNode.setRadius(parse<double>(value));
             break;
         case SUMO_ATTR_TLTYPE: {
             const std::set<NBTrafficLightDefinition*> tls = myNBNode.getControllingTLS();
@@ -701,7 +804,7 @@ GNEJunction::setAttribute(SumoXMLAttr key, const std::string& value) {
             myNBNode.setKeepClear(value == "true");
             break;
         default:
-            throw InvalidArgument("junction attribute '" + toString(key) + "' not allowed");
+            throw InvalidArgument(toString(getTag()) + " doesn't have an attribute of type '" + toString(key) + "'");
     }
 }
 
@@ -718,7 +821,7 @@ GNEJunction::setPosition(Position pos) {
 }
 
 
-SUMOReal
+double
 GNEJunction::getColorValue(const GUIVisualizationSettings& s, bool bubble) const {
     switch (s.junctionColorer.getActive()) {
         case 0:
@@ -799,18 +902,4 @@ GNEJunction::removeTrafficLight(NBTrafficLightDefinition* tlDef) {
     myNBNode.removeTrafficLight(tlDef);
 }
 
-void
-GNEJunction::updateCrossingAttributes(NBNode::Crossing crossing) {
-    EdgeSet edgeSet(crossing.edges.begin(), crossing.edges.end());
-    for (std::vector<NBNode::Crossing>::iterator it = myNBNode.myCrossings.begin(); it != myNBNode.myCrossings.end(); ++it) {
-        EdgeSet edgeSet2((*it).edges.begin(), (*it).edges.end());
-        if (edgeSet == edgeSet2) {
-            (*it).width = crossing.width;
-            (*it).priority = crossing.priority;
-            myNet->refreshElement(this);
-            break;
-        }
-    }
-}
-
 /****************************************************************************/
