@@ -2,12 +2,12 @@
 /// @file    GNETLSEditorFrame.cpp
 /// @author  Jakob Erdmann
 /// @date    May 2011
-/// @version $Id: GNETLSEditorFrame.cpp 21014 2016-06-21 09:02:22Z behrisch $
+/// @version $Id: GNETLSEditorFrame.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // The Widget for modifying traffic lights
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -28,20 +28,17 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_VERSION_H
-#include <version.h>
-#endif
-
 #include <iostream>
 #include <utils/foxtools/fxexdefs.h>
 #include <utils/foxtools/MFXUtils.h>
-#include <utils/common/TplConvert.h>
 #include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/gui/div/GUIIOGlobals.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
+#include <utils/gui/div/GUIDesigns.h>
 #include <utils/gui/globjects/GUIGlObjectStorage.h>
 #include <netbuild/NBTrafficLightDefinition.h>
 #include <netbuild/NBLoadedSUMOTLDef.h>
+
 #include "GNETLSEditorFrame.h"
 #include "GNEViewNet.h"
 #include "GNEViewParent.h"
@@ -53,10 +50,6 @@
 #include "GNEInternalLane.h"
 #include "GNEChange_TLS.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 // ===========================================================================
 // FOX callback mapping
 // ===========================================================================
@@ -77,7 +70,6 @@ FXDEFMAP(GNETLSEditorFrame) GNETLSEditorFrameMap[] = {
     FXMAPFUNC(SEL_DESELECTED, MID_GNE_PHASE_TABLE,        GNETLSEditorFrame::onCmdPhaseSwitch),
     FXMAPFUNC(SEL_CHANGED,    MID_GNE_PHASE_TABLE,        GNETLSEditorFrame::onCmdPhaseSwitch),
     FXMAPFUNC(SEL_REPLACED,   MID_GNE_PHASE_TABLE,        GNETLSEditorFrame::onCmdPhaseEdit),
-
     FXMAPFUNC(SEL_UPDATE,     MID_GNE_DEF_CREATE,         GNETLSEditorFrame::onUpdDefCreate),
     FXMAPFUNC(SEL_UPDATE,     MID_GNE_DEF_DELETE,         GNETLSEditorFrame::onUpdDefSwitch),
     FXMAPFUNC(SEL_UPDATE,     MID_GNE_DEF_SWITCH,         GNETLSEditorFrame::onUpdDefSwitch),
@@ -90,47 +82,59 @@ FXDEFMAP(GNETLSEditorFrame) GNETLSEditorFrameMap[] = {
 
 
 // Object implementation
-FXIMPLEMENT(GNETLSEditorFrame, FXScrollWindow, GNETLSEditorFrameMap, ARRAYNUMBER(GNETLSEditorFrameMap))
+FXIMPLEMENT(GNETLSEditorFrame, FXVerticalFrame, GNETLSEditorFrameMap, ARRAYNUMBER(GNETLSEditorFrameMap))
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
-GNETLSEditorFrame::GNETLSEditorFrame(FXComposite* parent, GNEViewNet* viewNet):
-    GNEFrame(parent, viewNet, "Edit Traffic Light"),
+GNETLSEditorFrame::GNETLSEditorFrame(FXHorizontalFrame* horizontalFrameParent, GNEViewNet* viewNet):
+    GNEFrame(horizontalFrameParent, viewNet, "Edit Traffic Light"),
     myTableFont(new FXFont(getApp(), "Courier New", 9)),
     myCurrentJunction(0),
     myHaveModifications(false),
     myEditedDef(0) {
-    // heading
-    myDescription = new FXLabel(myContentFrame, "", 0, JUSTIFY_LEFT);
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
+    // create groupbox for description
+    myGroupBoxJunction = new FXGroupBox(myContentFrame, "Junction", GUIDesignGroupBoxFrame);
 
-    // create tlDef button
-    new FXButton(myContentFrame, "Create TLS\t\tCreate a new traffic light program", 0, this, MID_GNE_DEF_CREATE,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
+    // create description label
+    myDescription = new FXLabel(myGroupBoxJunction, "No Junction Selected\n", 0, GUIDesignLabelLeft);
 
-    // delete tlDef button
-    new FXButton(myContentFrame,
-                 "Delete TLS\t\tDelete a traffic light program. If all programs are deleted the junction turns into a priority junction.",
-                 0, this, MID_GNE_DEF_DELETE, ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
+    // create groupbox for tl df
+    myGroupBoxTLSDef = new FXGroupBox(myContentFrame, "Traffic lights definition", GUIDesignGroupBoxFrame);
 
-    // definitions list
-    new FXLabel(myContentFrame, "Name, Program");
-    myDefBox = new FXListBox(myContentFrame, this, MID_GNE_DEF_SWITCH,
-                             FRAME_SUNKEN | FRAME_THICK | LISTBOX_NORMAL | LAYOUT_FIX_WIDTH);
+    // create create tlDef button
+    myNewTLProgram = new FXButton(myGroupBoxTLSDef, "Create TLS\t\tCreate a new traffic light program", 0, this, MID_GNE_DEF_CREATE, GUIDesignButton);
 
-    // offset control
-    new FXLabel(myContentFrame, "Offset");
-    myOffset = new FXTextField(myContentFrame, 6,
-                               this, MID_GNE_DEF_OFFSET, TEXTFIELD_NORMAL | TEXTFIELD_REAL, 0, 0, 0, 0, 4, 2, 0, 2);
+    // create delete tlDef button
+    myDeleteTLProgram = new FXButton(myGroupBoxTLSDef, "Delete TLS\t\tDelete a traffic light program. If all programs are deleted the junction turns into a priority junction.", 0, this, MID_GNE_DEF_DELETE, GUIDesignButton);
 
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
+    // create groupbox for phases
+    myGroupBoxAttributes = new FXGroupBox(myContentFrame, "Attributes", GUIDesignGroupBoxFrame);
 
-    // phase table
-    new FXLabel(myContentFrame, "Phases");
-    myPhaseTable = new FXTable(myContentFrame, this, MID_GNE_PHASE_TABLE, LAYOUT_FIX_HEIGHT | LAYOUT_FIX_WIDTH);
+    // Create matrix
+    myAttributeMatrix = new FXMatrix(myGroupBoxAttributes, 2, GUIDesignMatrixAttributes);
+
+    // create label for name
+    myNameLabel = new FXLabel(myAttributeMatrix, "Name", 0, GUIDesignLabelAttribute);
+
+    // create text field for name
+    myNameTextField = new FXTextField(myAttributeMatrix, GUIDesignTextFieldNCol, this, MID_GNE_DEF_SWITCH, GUIDesignTextField);
+
+    // create label for program
+    myProgramLabel = new FXLabel(myAttributeMatrix, "Program", 0, GUIDesignLabelAttribute);
+
+    // create combo box for program
+    myProgramComboBox = new FXComboBox(myAttributeMatrix, GUIDesignComboBoxNCol, this, MID_GNE_DEF_SWITCH, GUIDesignComboBoxAttribute);
+
+    // create offset control
+    myOffsetLabel = new FXLabel(myAttributeMatrix, "Offset", 0, GUIDesignLabelAttribute);
+    myOffset = new FXTextField(myAttributeMatrix, GUIDesignTextFieldNCol, this, MID_GNE_DEF_OFFSET, GUIDesignTextFieldReal);
+
+    // create groupbox for phases
+    myGroupBoxPhases = new FXGroupBox(myContentFrame, "Phases", GUIDesignGroupBoxFrame);
+
+    // create and configure phase table
+    myPhaseTable = new FXTable(myGroupBoxPhases, this, MID_GNE_PHASE_TABLE, GUIDesignTableLimitedHeight);
     myPhaseTable->setColumnHeaderMode(LAYOUT_FIX_HEIGHT);
     myPhaseTable->setColumnHeaderHeight(0);
     myPhaseTable->setRowHeaderMode(LAYOUT_FIX_WIDTH);
@@ -139,36 +143,29 @@ GNETLSEditorFrame::GNETLSEditorFrame(FXComposite* parent, GNEViewNet* viewNet):
     myPhaseTable->setFont(myTableFont);
     myPhaseTable->setHelpText("phase duration in seconds | phase state");
 
-    // total duration info
-    myCycleDuration = new FXLabel(myContentFrame, "");
+    // create total duration info label
+    myCycleDuration = new FXLabel(myGroupBoxPhases, "", 0, GUIDesignLabelLeft);
 
-    // insert new phase button
-    new FXButton(myContentFrame, "Copy Phase\t\tInsert duplicate phase after selected phase", 0, this, MID_GNE_PHASE_CREATE,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
+    // create new phase button
+    myInsertDuplicateButton = new FXButton(myGroupBoxPhases, "Copy Phase\t\tInsert duplicate phase after selected phase", 0, this, MID_GNE_PHASE_CREATE, GUIDesignButton);
+
+    // create delete phase button
+    myDeleteSelectedPhaseButton = new FXButton(myGroupBoxPhases, "Delete Phase\t\tDelete selected phase", 0, this, MID_GNE_PHASE_DELETE, GUIDesignButton);
+
+    // create groupbox for modifications
+    myGroupBoxModifications = new FXGroupBox(myContentFrame, "Modifications", GUIDesignGroupBoxFrame);
+
+    // create discard modifications buttons
+    myDiscardModificationsButtons = new FXButton(myGroupBoxModifications, "Cancel\t\tDiscard program modifications (Esc)", 0, this, MID_CANCEL, GUIDesignButton);
+
+    // create save modifications button
+    mySaveModificationsButtons = new FXButton(myGroupBoxModifications, "Save\t\tSave program modifications (Enter)", 0, this, MID_OK, GUIDesignButton);
 
-    // delete phase button
-    new FXButton(myContentFrame, "Delete Phase\t\tDelete selected phase", 0, this, MID_GNE_PHASE_DELETE,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
 
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
-    // buttons
-    // "Cancel"
-    new FXButton(myContentFrame, "Cancel\t\tDiscard program modifications (Esc)", 0, this, MID_CANCEL,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    // "OK"
-    new FXButton(myContentFrame, "Save\t\tSave program modifications (Enter)", 0, this, MID_OK,
-                 ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 3, 3);
-    new FXHorizontalSeparator(myContentFrame, SEPARATOR_GROOVE | LAYOUT_FILL_X, 0, 0, 0, 2, 2, 2, 4, 4);
     // "Add 'off' program"
     /*
     new FXButton(myContentFrame, "Add \"Off\"-Program\t\tAdds a program for switching off this traffic light",
-            0, this, MID_GNE_DEF_ADDOFF,
-            ICON_BEFORE_TEXT|LAYOUT_FILL_X|FRAME_THICK|FRAME_RAISED,
-            0, 0, 0, 0, 4, 4, 3, 3);
+            0, this, MID_GNE_DEF_ADDOFF, GUIDesignButton);
     */
 }
 
@@ -179,23 +176,6 @@ GNETLSEditorFrame::~GNETLSEditorFrame() {
 }
 
 
-void
-GNETLSEditorFrame::show() {
-    // Show Scroll window
-    FXScrollWindow::show();
-    // Show and update Frame Area in which this GNEFrame is placed
-    myViewNet->getViewParent()->showFramesArea();
-}
-
-
-void
-GNETLSEditorFrame::hide() {
-    // Hide ScrollWindow
-    FXScrollWindow::hide();
-    // Hide Frame Area in which this GNEFrame is placed
-    myViewNet->getViewParent()->hideFramesArea();
-}
-
 void
 GNETLSEditorFrame::editJunction(GNEJunction* junction) {
     if (myCurrentJunction == 0 || (!myHaveModifications && (junction != myCurrentJunction))) {
@@ -225,7 +205,7 @@ long
 GNETLSEditorFrame::onCmdOK(FXObject*, FXSelector, void*) {
     if (myCurrentJunction != 0) {
         if (myHaveModifications) {
-            NBTrafficLightDefinition* old = myDefinitions[myDefBox->getCurrentItem()];
+            NBTrafficLightDefinition* old = myDefinitions[myProgramComboBox->getCurrentItem()];
             std::vector<NBNode*> nodes = old->getNodes();
             for (std::vector<NBNode*>::iterator it = nodes.begin(); it != nodes.end(); it++) {
                 GNEJunction* junction = myViewNet->getNet()->retrieveJunction((*it)->getID());
@@ -266,7 +246,7 @@ GNETLSEditorFrame::onCmdDefDelete(FXObject*, FXSelector, void*) {
     if (changeType) {
         junction->setAttribute(SUMO_ATTR_TYPE, toString(NODETYPE_PRIORITY), myViewNet->getUndoList());
     } else {
-        NBTrafficLightDefinition* tlDef = myDefinitions[myDefBox->getCurrentItem()];
+        NBTrafficLightDefinition* tlDef = myDefinitions[myProgramComboBox->getCurrentItem()];
         myViewNet->getUndoList()->add(new GNEChange_TLS(junction, tlDef, false), true);
     }
     return 1;
@@ -276,8 +256,8 @@ GNETLSEditorFrame::onCmdDefDelete(FXObject*, FXSelector, void*) {
 long
 GNETLSEditorFrame::onCmdDefSwitch(FXObject*, FXSelector, void*) {
     assert(myCurrentJunction != 0);
-    assert((int)myDefinitions.size() == myDefBox->getNumItems());
-    NBTrafficLightDefinition* tlDef = myDefinitions[myDefBox->getCurrentItem()];
+    assert((int)myDefinitions.size() == myProgramComboBox->getNumItems());
+    NBTrafficLightDefinition* tlDef = myDefinitions[myProgramComboBox->getCurrentItem()];
     // logic may not have been recomputed yet. recompute to be sure
     NBTrafficLightLogicCont& tllCont = myViewNet->getNet()->getTLLogicCont();
     myViewNet->getNet()->computeJunction(myCurrentJunction);
@@ -376,7 +356,7 @@ GNETLSEditorFrame::onCmdGuess(FXObject*, FXSelector, void*) {
 
 long
 GNETLSEditorFrame::onCmdPhaseSwitch(FXObject*, FXSelector, void*) {
-    const unsigned int index = myPhaseTable->getCurrentRow();
+    const int index = myPhaseTable->getCurrentRow();
     const NBTrafficLightLogic::PhaseDefinition& phase = getPhases()[index];
     myPhaseTable->selectRow(index);
     // need not hold since links could have been deleted somewhere else and indices may be reused
@@ -399,8 +379,8 @@ long
 GNETLSEditorFrame::onCmdPhaseCreate(FXObject*, FXSelector, void*) {
     myHaveModifications = true;
     // allows insertion at first position by deselecting via arrow keys
-    unsigned int newIndex = myPhaseTable->getSelStartRow() + 1;
-    unsigned int oldIndex = MAX2(0, myPhaseTable->getSelStartRow());
+    int newIndex = myPhaseTable->getSelStartRow() + 1;
+    int oldIndex = MAX2(0, myPhaseTable->getSelStartRow());
     // copy current row
     const SUMOTime duration = getSUMOTime(myPhaseTable->getItemText(oldIndex, 0));
     const std::string state = myPhaseTable->getItemText(oldIndex, 1).text();
@@ -432,7 +412,7 @@ GNETLSEditorFrame::onCmdPhaseEdit(FXObject*, FXSelector, void* ptr) {
     FXString value = myPhaseTable->getItemText(tp->row, tp->col);
     if (tp->col == 0) {
         // duration edited
-        if (GNEAttributeCarrier::canParse<SUMOReal>(value.text())) {
+        if (GNEAttributeCarrier::canParse<double>(value.text())) {
             SUMOTime duration = getSUMOTime(value);
             if (duration > 0) {
                 myEditedDef->getLogic()->setPhaseDuration(tp->row, duration);
@@ -467,7 +447,7 @@ GNETLSEditorFrame::updateDescription() const {
         description = "No Junction Selected\n";
     } else {
         NBNode* nbn = myCurrentJunction->getNBNode();
-        description = "Junction '" + nbn->getID() + "'\n(";
+        description = "Current junction: " + nbn->getID() + "\n(";
         if (!nbn->isTLControlled()) {
             description += "uncontrolled, ";
         }
@@ -489,9 +469,10 @@ GNETLSEditorFrame::cleanup() {
     myEditedDef = 0;
     buildIinternalLanes(0); // only clears
     // clean up controls
+    myNameTextField->setText("");
     myOffset->setText("");
     myDefinitions.clear();
-    myDefBox->hide();
+    myProgramComboBox->hide();
     initPhaseTable(); // only clears when there are no definitions
     myCycleDuration->hide();
     updateDescription();
@@ -539,19 +520,20 @@ GNETLSEditorFrame::buildIinternalLanes(NBTrafficLightDefinition* tlDef) {
 void
 GNETLSEditorFrame::initDefinitions() {
     myDefinitions.clear();
-    myDefBox->clearItems();
+    myNameTextField->setText("");
+    myProgramComboBox->clearItems();
     assert(myCurrentJunction);
     NBNode* nbn = myCurrentJunction->getNBNode();
     std::set<NBTrafficLightDefinition*> tldefs = nbn->getControllingTLS();
     for (std::set<NBTrafficLightDefinition*>::iterator it = tldefs.begin(); it != tldefs.end(); it++) {
         myDefinitions.push_back(*it);
-        std::string item = (*it)->getID() + ", " + (*it)->getProgramID();
-        myDefBox->appendItem(item.c_str());
+        myNameTextField->setText((*it)->getID().c_str());
+        myProgramComboBox->appendItem((*it)->getProgramID().c_str());
     }
     if (myDefinitions.size() > 0) {
-        myDefBox->setCurrentItem(0);
-        myDefBox->setNumVisible(myDefBox->getNumItems());
-        myDefBox->show();
+        myProgramComboBox->setCurrentItem(0);
+        myProgramComboBox->setNumVisible(myProgramComboBox->getNumItems());
+        myProgramComboBox->show();
         onCmdDefSwitch(0, 0, 0);
     }
     updateDescription();
@@ -559,7 +541,7 @@ GNETLSEditorFrame::initDefinitions() {
 
 
 void
-GNETLSEditorFrame::initPhaseTable(unsigned int index) {
+GNETLSEditorFrame::initPhaseTable(int index) {
     myPhaseTable->setVisibleRows(1);
     myPhaseTable->setVisibleColumns(2);
     myPhaseTable->hide();
@@ -568,18 +550,13 @@ GNETLSEditorFrame::initPhaseTable(unsigned int index) {
         myPhaseTable->setTableSize((int)phases.size(), 2);
         myPhaseTable->setVisibleRows((int)phases.size());
         myPhaseTable->setVisibleColumns(2);
-        for (unsigned int row = 0; row < phases.size(); row++) {
+        for (int row = 0; row < (int)phases.size(); row++) {
             myPhaseTable->setItemText(row, 0, toString(STEPS2TIME(phases[row].duration)).c_str());
             myPhaseTable->setItemText(row, 1, phases[row].state.c_str());
             myPhaseTable->getItem(row, 1)->setJustify(FXTableItem::LEFT);
         }
         myPhaseTable->fitColumnsToContents(0, 2);
-        const int maxWidth = 140 - 4;
-        int desiredWidth = myPhaseTable->getColumnWidth(0) +
-                           myPhaseTable->getColumnWidth(1) + 3;
-        int spaceForScrollBar = desiredWidth > maxWidth ? 15 : 0;
-        myPhaseTable->setHeight((int)phases.size() * 21 + spaceForScrollBar); // experimental
-        myPhaseTable->setWidth(MIN2(desiredWidth, maxWidth));
+        myPhaseTable->setHeight((int)phases.size() * 21); // experimental
         myPhaseTable->setCurrentItem(index, 0);
         myPhaseTable->selectRow(index, true);
         myPhaseTable->show();
@@ -600,7 +577,7 @@ GNETLSEditorFrame::handleChange(GNEInternalLane* lane) {
     myHaveModifications = true;
     if (myViewNet->changeAllPhases()) {
         const std::vector<NBTrafficLightLogic::PhaseDefinition>& phases = getPhases();
-        for (unsigned int row = 0; row < phases.size(); row++) {
+        for (int row = 0; row < (int)phases.size(); row++) {
             myEditedDef->getLogic()->setPhaseState(row, lane->getTLIndex(), lane->getLinkState());
         }
     } else {
@@ -673,8 +650,8 @@ GNETLSEditorFrame::controlsEdge(GNEEdge& edge) const {
 
 SUMOTime
 GNETLSEditorFrame::getSUMOTime(const FXString& string) {
-    assert(GNEAttributeCarrier::canParse<SUMOReal>(string.text()));
-    return TIME2STEPS(GNEAttributeCarrier::parse<SUMOReal>(string.text()));
+    assert(GNEAttributeCarrier::canParse<double>(string.text()));
+    return TIME2STEPS(GNEAttributeCarrier::parse<double>(string.text()));
 }
 
 
