@@ -2,12 +2,12 @@
 /// @file    GNEViewNet.h
 /// @author  Jakob Erdmann
 /// @date    Feb 2011
-/// @version $Id: GNEViewNet.h 21131 2016-07-08 07:59:22Z behrisch $
+/// @version $Id: GNEViewNet.h 24109 2017-04-27 20:27:11Z behrisch $
 ///
 // A view on the network being edited (adapted from GUIViewTraffic)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -39,6 +39,7 @@
 #include <utils/shapes/Polygon.h>
 #include <utils/gui/windows/GUISUMOAbstractView.h>
 #include <utils/common/StringBijection.h>
+#include <utils/foxtools/MFXCheckableButton.h>
 
 // ===========================================================================
 // enum
@@ -61,7 +62,9 @@ enum EditMode {
     ///@brief mode for editing tls
     GNE_MODE_TLS,
     ///@brief Mode for editing additionals
-    GNE_MODE_ADDITIONAL
+    GNE_MODE_ADDITIONAL,
+    ///@brief Mode for editing crossing
+    GNE_MODE_CROSSING
 };
 
 // ===========================================================================
@@ -75,6 +78,8 @@ class GNEViewParent;
 class GNEUndoList;
 class GNEAdditional;
 class GNEPoly;
+class GNEPOI;
+class GNEFrame;
 
 // ===========================================================================
 // class definitions
@@ -112,8 +117,9 @@ public:
     /// @brief set color schieme
     bool setColorScheme(const std::string& name);
 
-    /// @brief overloaded handlers
+    /// @name overloaded handlers
     /// @{
+
     /// @brief called when user press mouse's left button
     long onLeftBtnPress(FXObject*, FXSelector, void*);
 
@@ -127,8 +133,37 @@ public:
     long onMouseMove(FXObject*, FXSelector, void*);
     /// @}
 
-    /// @brief sets edit mode via combo box
-    long onCmdChangeMode(FXObject*, FXSelector, void*);
+    /// @name set mode call backs
+    /// @{
+
+    /// @brief called when user press the button for create edge mode
+    long onCmdSetModeCreateEdge(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for move mode
+    long onCmdSetModeMove(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for delete mode
+    long onCmdSetModeDelete(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for inspect mode
+    long onCmdSetModeInspect(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for select mode
+    long onCmdSetModeSelect(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for connect mode
+    long onCmdSetModeConnect(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for traffic lights mode
+    long onCmdSetModeTLS(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for additional mode
+    long onCmdSetModeAdditional(FXObject*, FXSelector, void*);
+
+    /// @brief called when user press the button for crossing mode
+    long onCmdSetModeCrossing(FXObject*, FXSelector, void*);
+
+    /// @}
 
     /// @brief split edge at cursor position
     long onCmdSplitEdge(FXObject*, FXSelector, void*);
@@ -160,14 +195,57 @@ public:
     /// @brief duplicate selected lane
     long onCmdDuplicateLane(FXObject*, FXSelector, void*);
 
+    /// @brief restrict lane to pedestrians
+    long onCmdRestrictLaneSidewalk(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief restrict lane to bikes
+    long onCmdRestrictLaneBikelane(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief restrict lane to buslanes
+    long onCmdRestrictLaneBuslane(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief revert transformation
+    long onCmdRevertRestriction(FXObject*, FXSelector, void*);
+
+    /// @brief Add restricted lane for pedestrians
+    long onCmdAddRestrictedLaneSidewalk(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief Add restricted lane for bikes
+    long onCmdAddRestrictedLaneBikelane(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief Add restricted lane for buses
+    long onCmdAddRestrictedLaneBuslane(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief remove restricted lane for pedestrians
+    long onCmdRemoveRestrictedLaneSidewalk(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief remove restricted lane for bikes
+    long onCmdRemoveRestrictedLaneBikelane(FXObject*, FXSelector typeOfTransformation, void*);
+
+    /// @brief remove restricted lane for bus
+    long onCmdRemoveRestrictedLaneBuslane(FXObject*, FXSelector typeOfTransformation, void*);
+
     /// @brief input custom node shape
     long onCmdNodeShape(FXObject*, FXSelector, void*);
 
     /// @brief replace node by geometry
     long onCmdNodeReplace(FXObject*, FXSelector, void*);
 
-    /// @brief sets edit mode (from hotkey)
-    /// @param[in] selid An id MID_GNE_MODE_<foo> as defined in GUIAppEnum
+    /// @brief toogle show connections
+    long onCmdToogleShowConnection(FXObject*, FXSelector, void*);
+
+    /// @brief toogle selet edges
+    long onCmdToogleSelectEdges(FXObject*, FXSelector, void*);
+
+    /// @brief toogle show bubbles
+    long onCmdToogleShowBubbles(FXObject*, FXSelector, void*);
+
+    /// @brief toogle show grid
+    long onCmdShowGrid(FXObject*, FXSelector, void*);
+
+    /**@brief sets edit mode (from hotkey)
+     * @param[in] selid An id MID_GNE_MODE_<foo> as defined in GUIAppEnum
+     **/
     void setEditModeFromHotkey(FXushort selid);
 
     /// @brief abort current edition operation
@@ -179,6 +257,9 @@ public:
     /// @brief handle enter keypress
     void hotkeyEnter();
 
+    /// @brief handle focus frame keypress
+    void hotkeyFocusFrame();
+
     /// @brief store the position where a popup-menu was requested
     void markPopupPosition();
 
@@ -203,11 +284,14 @@ public:
     /// @brief whether inspection, selection and inversion should apply to edges or to lanes
     bool selectEdges();
 
+    /// @brief show connections over junctions
+    bool showConnections();
+
     /// @brief whether to autoselect nodes or to lanes
     bool autoSelectNodes();
 
     /// @brief set selection scaling
-    void setSelectionScaling(SUMOReal selectionScale);
+    void setSelectionScaling(double selectionScale);
 
     /// @brief update control contents after undo/redo or recompute
     void updateControls();
@@ -215,6 +299,12 @@ public:
     /// @brief change all phases
     bool changeAllPhases() const;
 
+    /// @brief return true if junction must be showed as bubbles
+    bool showJunctionAsBubbles() const;
+
+    /// @brief check if netedit is running in testing mode
+    bool isTestingModeEnabled() const;
+
 protected:
     /// @brief FOX needs this
     GNEViewNet() {}
@@ -238,14 +328,29 @@ private:
     /// @brief the previous edit mode used for toggling
     EditMode myPreviousEditMode;
 
+    /// @brief the current frame
+    GNEFrame* myCurrentFrame;
+
     /// @brief menu check to select only edges
-    FXMenuCheck* mySelectEdges;
+    FXMenuCheck* myMenuCheckSelectEdges;
+
+    /// @brief menu check to show connections
+    FXMenuCheck* myMenuCheckShowConnections;
 
     /// @brief menu check to extend to edge nodes
-    FXMenuCheck* myExtendToEdgeNodes;
+    FXMenuCheck* myMenuCheckExtendToEdgeNodes;
 
     /// @brief menu check to set change all phases
-    FXMenuCheck* myChangeAllPhases;
+    FXMenuCheck* myMenuCheckChangeAllPhases;
+
+    /// @brief show grid button
+    FXMenuCheck* myMenuCheckShowGrid;
+
+    /// @brief whether show connections has been activated once
+    bool myShowConnections;
+
+    /// @brief flag to check if select edges is enabled
+    bool mySelectEdges;
 
     /// @name the state-variables of the create-edge state-machine
     // @{
@@ -259,6 +364,13 @@ private:
 
     /// @name the state-variables of the move state-machine
     // @{
+
+    /// @brief whether we should warn about merging junctions
+    FXMenuCheck* myMenuCheckWarnAboutMerge;
+
+    /// @brief show connection as buuble in "Move" mode.
+    FXMenuCheck* myMenuCheckShowBubbleOverJunction;
+
     /// @brief the Junction to be moved.
     GNEJunction* myJunctionToMove;
 
@@ -268,20 +380,23 @@ private:
     /// @brief the poly of which geometry is being moved
     GNEPoly* myPolyToMove;
 
+    /// @brief the poi which is being moved
+    GNEPOI* myPoiToMove;
+
     /// @brief the stoppingPlace element which shape is being moved
     GNEAdditional* myAdditionalToMove;
 
-    /// @brief variable to save the firstposition of the additional before move
-    Position myAdditionalFirstPosition;
+    /// @brief variable for calculating moving offset of additionals
+    Position myAdditionalMovingReference;
+
+    /// @brief variable for saving additional position before moving
+    Position myOldAdditionalPosition;
 
     /// @brief position from which to move edge geometry
     Position myMoveSrc;
 
     /// @brief whether a selection is being moved
     bool myMoveSelection;
-
-    /// @brief whether we should warn about merging junctions
-    FXMenuCheck* myWarnAboutMerge;
     // @}
 
     /// @name state-variables of inspect-mode and select-mode
@@ -296,16 +411,45 @@ private:
     Position mySelCorner2;
     // @}
 
-    /// @name toolbar related stuff
-    /// @{
     /// @brief a reference to the toolbar in myParent
     FXToolBar* myToolbar;
 
-    /// @brief combo box for selecting the  edit mode
-    FXComboBox* myEditModesCombo;
+    /// @name buttons  for selecting the edit mode
+    /// @{
+    /// @brief chekable button for edit mode create edge
+    MFXCheckableButton* myEditModeCreateEdge;
+
+    /// @brief chekable button for edit mode move
+    MFXCheckableButton* myEditModeMove;
+
+    /// @brief chekable button for edit mode delete
+    MFXCheckableButton* myEditModeDelete;
+
+    /// @brief chekable button for edit mode inspect
+    MFXCheckableButton* myEditModeInspect;
+
+    /// @brief chekable button for edit mode select
+    MFXCheckableButton* myEditModeSelect;
+
+    /// @brief chekable button for edit mode connection
+    MFXCheckableButton* myEditModeConnection;
+
+    /// @brief chekable button for edit mode traffic light
+    MFXCheckableButton* myEditModeTrafficLight;
+
+    /// @brief chekable button for edit mode additional
+    MFXCheckableButton* myEditModeAdditional;
+
+    /// @brief chekable button for edit mode crossing
+    MFXCheckableButton* myEditModeCrossing;
+    /// @}
 
     /// @brief since we cannot switch on strings we map the mode names to an enum
+    /// @{
+    /// @brief stringBijection for edit mode names
     StringBijection<EditMode> myEditModeNames;
+
+    /// @brief stringBijection for edit additional mode names
     StringBijection<EditMode> myEditAdditionalModeNames;
     /// @}
 
@@ -318,7 +462,18 @@ private:
     /// @brief current polygon
     GNEPoly* myCurrentPoly;
 
-private:
+    /// @name variables for testing mode
+    /// @{
+    /// @brief flag to enable or disable testing mode
+    bool myTestingMode;
+
+    /// @brief Width of viewNet in testing mode
+    int myTestingWidth;
+
+    /// @brief Height of viewNet in testing mode
+    int myTestingHeight;
+    /// @}
+
     /// @brief set edit mode
     void setEditMode(EditMode mode);
 
@@ -334,6 +489,9 @@ private:
     /// @brief delete all currently selected edges
     void deleteSelectedEdges();
 
+    /// @brief delete all currently selected additionals
+    void deleteSelectedAdditionals();
+
     /// @brief try to merge moved junction with another junction in that spot return true if merging did take place
     bool mergeJunctions(GNEJunction* moved);
 
@@ -352,6 +510,18 @@ private:
     /// @brief remove the currently edited polygon
     void removeCurrentPoly();
 
+    /// @brief restrict lane
+    bool restrictLane(SUMOVehicleClass vclass);
+
+    /// @brief add restricted lane
+    bool addRestrictedLane(SUMOVehicleClass vclass);
+
+    /// @brief remove restricted lane
+    bool removeRestrictedLane(SUMOVehicleClass vclass);
+
+    /// @brief Auxiliar function used by onLeftBtnPress(...)
+    void processClick(FXEvent* e, void* data);
+
     /// @brief Invalidated copy constructor.
     GNEViewNet(const GNEViewNet&);
 
