@@ -3,13 +3,14 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
+/// @author  Gregor Laemmel
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NIFrame.cpp 21201 2016-07-19 11:57:22Z behrisch $
+/// @version $Id: NIFrame.cpp 23561 2017-03-20 15:03:10Z laemmel $
 ///
 // Sets and checks options for netimport
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -47,10 +48,6 @@
 #include "NIImporter_DlrNavteq.h"
 #include "NIFrame.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -151,13 +148,15 @@ NIFrame::fillOptions() {
     oc.doRegister("ignore-errors.edge-type", new Option_Bool(false));
     oc.addDescription("ignore-errors.edge-type", "Processing", "Continue on unknown edge types");
 
-    oc.doRegister("lanes-from-capacity.norm", new Option_Float((SUMOReal) 1800));
+    oc.doRegister("lanes-from-capacity.norm", new Option_Float((double) 1800));
     oc.addSynonyme("lanes-from-capacity.norm", "capacity-norm");
     oc.addDescription("lanes-from-capacity.norm", "Processing", "The factor for flow to no. lanes conversion");
 
     oc.doRegister("speed-in-kmh", new Option_Bool(false));
     oc.addDescription("speed-in-kmh", "Processing", "vmax is parsed as given in km/h (some)");
 
+    oc.doRegister("construction-date", new Option_String());
+    oc.addDescription("construction-date", "Processing", "Use YYYY-MM-DD date to determine the readiness of features under construction");
 
 
     // register xml options
@@ -258,11 +257,24 @@ NIFrame::fillOptions() {
     oc.doRegister("osm.layer-elevation", new Option_Float(0));
     oc.addDescription("osm.layer-elevation", "Processing", "Reconstruct (relative) elevation based on layer data. Each layer is raised by FLOAT m");
 
+    oc.doRegister("osm.layer-elevation.max-grade", new Option_Float(10));
+    oc.addDescription("osm.layer-elevation.max-grade", "Processing", "Maximum grade threshold in % at 50km/h when reconstrucing elevation based on layer data. The value is scaled according to road speed.");
+
+    oc.doRegister("osm.oneway-spread-right", new Option_Bool(false));
+    oc.addDescription("osm.oneway-spread-right", "Processing", "Whether one-way roads should be spread to the side instead of centered");
+
+    oc.doRegister("osm.stop-output.length", new Option_Float(100));
+    oc.addDescription("osm.stop-output.length", "Processing", "The default length of a bus/train stop in FLOAT m");
+
     // register opendrive options
     oc.doRegister("opendrive.import-all-lanes", new Option_Bool(false));
     oc.addDescription("opendrive.import-all-lanes", "Processing", "Imports all lane types");
     oc.doRegister("opendrive.ignore-widths", new Option_Bool(false));
     oc.addDescription("opendrive.ignore-widths", "Processing", "Whether lane widths shall be ignored.");
+    oc.doRegister("opendrive.curve-resolution", new Option_Float(2.0));
+    oc.addDescription("opendrive.curve-resolution", "Processing", "The geometry resolution in m when importing curved geometries as line segments.");
+    oc.doRegister("opendrive.advance-stopline", new Option_Float(12.0));
+    oc.addDescription("opendrive.advance-stopline", "Processing", "Allow stop lines to be built beyond the start of the junction if the geometries allow so");
 
     // register some additional options
     oc.doRegister("tls.discard-loaded", new Option_Bool(false));
@@ -319,6 +331,16 @@ NIFrame::checkOptions() {
             }
         }
     }
+    if (oc.isSet("opendrive-files")) {
+        if (oc.isDefault("tls.left-green.time")) {
+            // legacy behavior. see #2114
+            oc.set("tls.left-green.time", "0");
+        }
+        if (oc.isDefault("rectangular-lane-cut")) {
+            // a better interpretation of imported geometries
+            oc.set("rectangular-lane-cut", "true");
+        }
+    }
     return ok;
 }
 
