@@ -6,12 +6,12 @@
 /// @author  Thimor Bohn
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: NIImporter_ArcView.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NIImporter_ArcView.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Importer for networks stored in ArcView-shape format
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -53,12 +53,15 @@
 #include "NIImporter_ArcView.h"
 
 #ifdef HAVE_GDAL
+#if __GNUC__ > 3
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpedantic"
+#endif
 #include <ogrsf_frmts.h>
+#if __GNUC__ > 3
+#pragma GCC diagnostic pop
+#endif
 #endif
-
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
 
 
 // ===========================================================================
@@ -130,7 +133,7 @@ NIImporter_ArcView::load() {
     OGRDataSource* poDS = OGRSFDriverRegistrar::Open(mySHPName.c_str(), FALSE);
 #else
     GDALAllRegister();
-    GDALDataset* poDS = (GDALDataset*) GDALOpen(mySHPName.c_str(), GA_ReadOnly);
+    GDALDataset* poDS = (GDALDataset*)GDALOpenEx(mySHPName.c_str(), GDAL_OF_VECTOR | GA_ReadOnly, NULL, NULL, NULL);
 #endif
     if (poDS == NULL) {
         WRITE_ERROR("Could not open shape description '" + mySHPName + "'.");
@@ -192,9 +195,9 @@ NIImporter_ArcView::load() {
         } else if (poFeature->GetFieldIndex("ST_TYP_AFT") >= 0) {
             type = poFeature->GetFieldAsString("ST_TYP_AFT");
         }
-        SUMOReal width = myTypeCont.getWidth(type);
-        SUMOReal speed = getSpeed(*poFeature, id);
-        unsigned int nolanes = getLaneNo(*poFeature, id, speed);
+        double width = myTypeCont.getWidth(type);
+        double speed = getSpeed(*poFeature, id);
+        int nolanes = getLaneNo(*poFeature, id, speed);
         int priority = getPriority(*poFeature, id);
         if (nolanes == 0 || speed == 0) {
             if (myOptions.getBool("shapefile.use-defaults-on-failure")) {
@@ -202,20 +205,23 @@ NIImporter_ArcView::load() {
                 speed = myTypeCont.getSpeed("");
             } else {
                 OGRFeature::DestroyFeature(poFeature);
-                WRITE_ERROR("The description seems to be invalid. Please recheck usage of types.");
+                WRITE_ERROR("Required field 'nolanes' or 'speed' is missing (add fields or set option --shapefile.use-defaults-on-failure).");
                 return;
             }
         }
         if (mySpeedInKMH) {
-            speed = speed / (SUMOReal) 3.6;
+            speed = speed / (double) 3.6;
         }
 
 
         // read in the geometry
         OGRGeometry* poGeometry = poFeature->GetGeometryRef();
         OGRwkbGeometryType gtype = poGeometry->getGeometryType();
-        assert(gtype == wkbLineString);
-        UNUSED_PARAMETER(gtype); // ony used for assertion
+        if (gtype != wkbLineString) {
+            OGRFeature::DestroyFeature(poFeature);
+            WRITE_ERROR("Road geometry must be of type 'linestring'.");
+            return;
+        }
         OGRLineString* cgeom = (OGRLineString*) poGeometry;
         if (poCT != 0) {
             // try transform to wgs84
@@ -224,8 +230,8 @@ NIImporter_ArcView::load() {
 
         PositionVector shape;
         for (int j = 0; j < cgeom->getNumPoints(); j++) {
-            Position pos((SUMOReal) cgeom->getX(j), (SUMOReal) cgeom->getY(j));
-            if (!NBNetBuilder::transformCoordinates(pos)) {
+            Position pos((double) cgeom->getX(j), (double) cgeom->getY(j));
+            if (!NBNetBuilder::transformCoordinate(pos)) {
                 WRITE_WARNING("Unable to project coordinates for edge '" + id + "'.");
             }
             shape.push_back_noDoublePos(pos);
@@ -292,6 +298,11 @@ NIImporter_ArcView::load() {
         //
         OGRFeature::DestroyFeature(poFeature);
     }
+#if GDAL_VERSION_MAJOR < 2
+    OGRDataSource::DestroyDataSource(poDS);
+#else
+    GDALClose(poDS);
+#endif
     PROGRESS_DONE_MESSAGE();
 #else
     WRITE_ERROR("SUMO was compiled without GDAL support.");
@@ -299,7 +310,7 @@ NIImporter_ArcView::load() {
 }
 
 #ifdef HAVE_GDAL
-SUMOReal
+double
 NIImporter_ArcView::getSpeed(OGRFeature& poFeature, const std::string& edgeid) {
     if (myOptions.isSet("shapefile.type-id")) {
         return myTypeCont.getSpeed(poFeature.GetFieldAsString((char*)(myOptions.getString("shapefile.type-id").c_str())));
@@ -308,11 +319,11 @@ NIImporter_ArcView::getSpeed(OGRFeature& poFeature, const std::string& edgeid) {
     //  idea by John Michael Calandrino
     int index = poFeature.GetDefnRef()->GetFieldIndex("speed");
     if (index >= 0 && poFeature.IsFieldSet(index)) {
-        return (SUMOReal) poFeature.GetFieldAsDouble(index);
+        return (double) poFeature.GetFieldAsDouble(index);
     }
     index = poFeature.GetDefnRef()->GetFieldIndex("SPEED");
     if (index >= 0 && poFeature.IsFieldSet(index)) {
-        return (SUMOReal) poFeature.GetFieldAsDouble(index);
+        return (double) poFeature.GetFieldAsDouble(index);
     }
     // try to get the NavTech-information
     index = poFeature.GetDefnRef()->GetFieldIndex("SPEED_CAT");
@@ -324,25 +335,25 @@ NIImporter_ArcView::getSpeed(OGRFeature& poFeature, const std::string& edgeid) {
 }
 
 
-unsigned int
+int
 NIImporter_ArcView::getLaneNo(OGRFeature& poFeature, const std::string& edgeid,
-                              SUMOReal speed) {
+                              double speed) {
     if (myOptions.isSet("shapefile.type-id")) {
-        return (unsigned int) myTypeCont.getNumLanes(poFeature.GetFieldAsString((char*)(myOptions.getString("shapefile.type-id").c_str())));
+        return (int) myTypeCont.getNumLanes(poFeature.GetFieldAsString((char*)(myOptions.getString("shapefile.type-id").c_str())));
     }
     // try to get definitions as to be found in SUMO-XML-definitions
     //  idea by John Michael Calandrino
     int index = poFeature.GetDefnRef()->GetFieldIndex("nolanes");
     if (index >= 0 && poFeature.IsFieldSet(index)) {
-        return (unsigned int) poFeature.GetFieldAsInteger(index);
+        return (int) poFeature.GetFieldAsInteger(index);
     }
     index = poFeature.GetDefnRef()->GetFieldIndex("NOLANES");
     if (index >= 0 && poFeature.IsFieldSet(index)) {
-        return (unsigned int) poFeature.GetFieldAsInteger(index);
+        return (int) poFeature.GetFieldAsInteger(index);
     }
     index = poFeature.GetDefnRef()->GetFieldIndex("rnol");
     if (index >= 0 && poFeature.IsFieldSet(index)) {
-        return (unsigned int) poFeature.GetFieldAsInteger(index);
+        return (int) poFeature.GetFieldAsInteger(index);
     }
     index = poFeature.GetDefnRef()->GetFieldIndex("LANE_CAT");
     if (index >= 0 && poFeature.IsFieldSet(index)) {
