@@ -2,12 +2,12 @@
 /// @file    NIImporter_ITSUMO.h
 /// @author  Daniel Krajzewicz
 /// @date    2011-09-16
-/// @version $Id: NIImporter_ITSUMO.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NIImporter_ITSUMO.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Importer for networks stored in ITSUMO format
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -136,22 +136,22 @@ private:
 
         struct Lane {
         public:
-            Lane(const std::string& _id, unsigned int _idx, SUMOReal _v)
+            Lane(const std::string& _id, int _idx, double _v)
                 : id(_id), index(_idx), v(_v) {}
             std::string id;
-            unsigned int index;
-            SUMOReal v;
+            int index;
+            double v;
         };
 
         std::vector<Lane> myCurrentLanes;
 
         struct LaneSet {
         public:
-            LaneSet(const std::string& _id, const std::vector<Lane>& _lanes, SUMOReal _v, int _pos, NBNode* _from, NBNode* _to)
+            LaneSet(const std::string& _id, const std::vector<Lane>& _lanes, double _v, int _pos, NBNode* _from, NBNode* _to)
                 : id(_id), lanes(_lanes), v(_v), position(_pos), from(_from), to(_to) {}
             std::string id;
             std::vector<Lane> lanes;
-            SUMOReal v;
+            double v;
             int position;
             NBNode* from;
             NBNode* to;
