@@ -4,13 +4,14 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
+/// @author  Gregor Laemmel
 /// @date    Mon, 14.04.2008
-/// @version $Id: NIImporter_OpenStreetMap.h 21202 2016-07-19 13:40:35Z behrisch $
+/// @version $Id: NIImporter_OpenStreetMap.h 23648 2017-03-24 10:35:01Z laemmel $
 ///
 // Importer for networks stored in OpenStreetMap format
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -37,6 +38,7 @@
 #include <map>
 #include <utils/xml/SUMOSAXHandler.h>
 #include <utils/common/UtilExceptions.h>
+#include <utils/common/Parameterised.h>
 
 
 // ===========================================================================
@@ -81,18 +83,26 @@ protected:
      */
     struct NIOSMNode {
         NIOSMNode(long long int _id, double _lon, double _lat) :
-            id(_id), lon(_lon), lat(_lat), ele(0), tlsControlled(false), node(0) {}
+            id(_id), lon(_lon), lat(_lat), ele(0), tlsControlled(false), railwayCrossing(false), ptStopPostion(false), ptStopLength(0), node(0) {}
 
         /// @brief The node's id
         const long long int id;
         /// @brief The longitude the node is located at
-        const SUMOReal lon;
+        const double lon;
         /// @brief The latitude the node is located at
-        const SUMOReal lat;
+        const double lat;
         /// @brief The elevation of this node
-        SUMOReal ele;
+        double ele;
         /// @brief Whether this is a tls controlled junction
         bool tlsControlled;
+        /// @brief Whether this is a railway crossing
+        bool railwayCrossing;
+        /// @brief Whether this is a public transport stop position
+        bool ptStopPostion;
+        /// @brief The length of the pt stop
+        double ptStopLength;
+        /// @brief The name of the node
+        std::string name;
         /// @brief the NBNode that was instantiated
         NBNode* node;
 
@@ -116,7 +126,7 @@ protected:
 
     /** @brief An internal definition of a loaded edge
      */
-    struct Edge {
+    struct Edge : public Parameterised {
 
         Edge(long long int _id) :
             id(_id), myNoLanes(-1), myNoLanesForward(0), myMaxSpeed(MAXSPEED_UNGIVEN),
@@ -231,13 +241,13 @@ private:
                    const std::vector<long long int>& passed, NBNetBuilder& nb);
 
     /// @brief reconstruct elevation from layer info
-    void reconstructLayerElevation(SUMOReal layerElevation, NBNetBuilder& nb);
+    void reconstructLayerElevation(double layerElevation, NBNetBuilder& nb);
 
-    /// @brief collect neighboring nodes with their road distance
-    std::map<NBNode*, SUMOReal> getNeighboringNodes(NBNode* node, SUMOReal maxDist);
+    /// @brief collect neighboring nodes with their road distance and maximum between-speed. Search does not continue beyond knownElevation-nodes
+    std::map<NBNode*, std::pair<double, double> > getNeighboringNodes(NBNode* node, double maxDist, const std::set<NBNode*>& knownElevation);
 
 protected:
-    static const SUMOReal MAXSPEED_UNGIVEN;
+    static const double MAXSPEED_UNGIVEN;
     static const long long int INVALID_ID;
 
     /**
@@ -252,9 +262,8 @@ protected:
          * @param[in, out] uniqueNodes The nodes container for ensuring uniqueness
          * @param[in] options The options to use
          */
-        NodesHandler(std::map<long long int, NIOSMNode*>& toFill,
-                     std::set<NIOSMNode*, CompareNodes>& uniqueNodes,
-                     bool importElevation);
+        NodesHandler(std::map<long long int, NIOSMNode*>& toFill, std::set<NIOSMNode*,
+                     CompareNodes>& uniqueNodes, const OptionsCont& cont);
 
 
         /// @brief Destructor
@@ -305,6 +314,9 @@ protected:
         /// @brief whether elevation data should be imported
         const bool myImportElevation;
 
+        /// @brief the options
+        const OptionsCont& myOptionsCont;
+
 
     private:
         /** @brief invalidated copy constructor */
@@ -374,7 +386,7 @@ protected:
         std::vector<int> myParentElements;
 
         /// @brief A map of non-numeric speed descriptions to their numeric values
-        std::map<std::string, SUMOReal> mySpeedMap;
+        std::map<std::string, double> mySpeedMap;
 
     private:
         /** @brief invalidated copy constructor */
