@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NIXMLConnectionsHandler.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIXMLConnectionsHandler.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Importer for edge connections stored in XML
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -41,6 +41,7 @@
 // ===========================================================================
 class NBEdge;
 class NBEdgeCont;
+class NBNodeCont;
 class NBTrafficLightLogicCont;
 class MsgHandler;
 
@@ -60,7 +61,7 @@ public:
     /** @brief Constructor
      * @param[in] ec The edge container which includes the edges to change connections of
      */
-    NIXMLConnectionsHandler(NBEdgeCont& ec, NBTrafficLightLogicCont& tlc);
+    NIXMLConnectionsHandler(NBEdgeCont& ec, NBNodeCont& nc, NBTrafficLightLogicCont& tlc);
 
 
     /// @brief Destructor
@@ -137,10 +138,18 @@ private:
      */
     void addCrossing(const SUMOSAXAttributes& attrs);
 
+    /** @brief Parses a customShape and updates the referenced node
+     * @param[in] attrs The attributes to get the customShapes's values from
+     */
+    void addCustomShape(const SUMOSAXAttributes& attrs);
+
 private:
     /// @brief The edge container to fill
     NBEdgeCont& myEdgeCont;
 
+    /// @brief The edge container to fill
+    NBNodeCont& myNodeCont;
+
     /** @brief The traffic lights container to add built tls to (when
      * invalidating tls)  */
     NBTrafficLightLogicCont& myTLLogicCont;
