@@ -6,12 +6,12 @@
 /// @author  Walter Bamberger
 /// @author  Laura Bieker
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NIXMLEdgesHandler.cpp 21094 2016-07-03 13:57:51Z behrisch $
+/// @version $Id: NIXMLEdgesHandler.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // Importer for network edges stored in XML
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -55,10 +55,6 @@
 #include "NIXMLNodesHandler.h"
 #include "NIXMLEdgesHandler.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -202,10 +198,10 @@ NIXMLEdgesHandler::addEdge(const SUMOSAXAttributes& attrs) {
     // speed, priority and the number of lanes have now default values;
     // try to read the real values from the file
     if (attrs.hasAttribute(SUMO_ATTR_SPEED)) {
-        myCurrentSpeed = attrs.get<SUMOReal>(SUMO_ATTR_SPEED, myCurrentID.c_str(), ok);
+        myCurrentSpeed = attrs.get<double>(SUMO_ATTR_SPEED, myCurrentID.c_str(), ok);
     }
     if (myOptions.getBool("speed-in-kmh") && myCurrentSpeed != NBEdge::UNSPECIFIED_SPEED) {
-        myCurrentSpeed = myCurrentSpeed / (SUMOReal) 3.6;
+        myCurrentSpeed = myCurrentSpeed / (double) 3.6;
     }
     // try to get the number of lanes
     if (attrs.hasAttribute(SUMO_ATTR_NUMLANES)) {
@@ -217,11 +213,11 @@ NIXMLEdgesHandler::addEdge(const SUMOSAXAttributes& attrs) {
     }
     // try to get the width
     if (attrs.hasAttribute(SUMO_ATTR_WIDTH)) {
-        myCurrentWidth = attrs.get<SUMOReal>(SUMO_ATTR_WIDTH, myCurrentID.c_str(), ok);
+        myCurrentWidth = attrs.get<double>(SUMO_ATTR_WIDTH, myCurrentID.c_str(), ok);
     }
     // try to get the offset of the stop line from the intersection
     if (attrs.hasAttribute(SUMO_ATTR_ENDOFFSET)) {
-        myCurrentEndOffset = attrs.get<SUMOReal>(SUMO_ATTR_ENDOFFSET, myCurrentID.c_str(), ok);
+        myCurrentEndOffset = attrs.get<double>(SUMO_ATTR_ENDOFFSET, myCurrentID.c_str(), ok);
     }
     // try to get the street name
     if (attrs.hasAttribute(SUMO_ATTR_NAME)) {
@@ -248,11 +244,11 @@ NIXMLEdgesHandler::addEdge(const SUMOSAXAttributes& attrs) {
     // try to get the spread type
     myLanesSpread = tryGetLaneSpread(attrs);
     // try to get the length
-    myLength = attrs.getOpt<SUMOReal>(SUMO_ATTR_LENGTH, myCurrentID.c_str(), ok, myLength);
+    myLength = attrs.getOpt<double>(SUMO_ATTR_LENGTH, myCurrentID.c_str(), ok, myLength);
     // try to get the sidewalkWidth
-    mySidewalkWidth = attrs.getOpt<SUMOReal>(SUMO_ATTR_SIDEWALKWIDTH, myCurrentID.c_str(), ok, mySidewalkWidth);
+    mySidewalkWidth = attrs.getOpt<double>(SUMO_ATTR_SIDEWALKWIDTH, myCurrentID.c_str(), ok, mySidewalkWidth);
     // try to get the bikeLaneWidth
-    myBikeLaneWidth = attrs.getOpt<SUMOReal>(SUMO_ATTR_BIKELANEWIDTH, myCurrentID.c_str(), ok, myBikeLaneWidth);
+    myBikeLaneWidth = attrs.getOpt<double>(SUMO_ATTR_BIKELANEWIDTH, myCurrentID.c_str(), ok, myBikeLaneWidth);
     // insert the parsed edge into the edges map
     if (!ok) {
         return;
@@ -303,10 +299,6 @@ NIXMLEdgesHandler::addLane(const SUMOSAXAttributes& attrs) {
     } else {
         lane = attrs.get<int>(SUMO_ATTR_INDEX, myCurrentID.c_str(), ok);
     }
-    std::string allowed, disallowed, preferred;
-    allowed    = attrs.getOpt<std::string>(SUMO_ATTR_ALLOW, 0, ok, "");
-    disallowed = attrs.getOpt<std::string>(SUMO_ATTR_DISALLOW, 0, ok, "");
-    preferred  = attrs.getOpt<std::string>(SUMO_ATTR_PREFER, 0, ok, "");
     if (!ok) {
         return;
     }
@@ -315,20 +307,31 @@ NIXMLEdgesHandler::addLane(const SUMOSAXAttributes& attrs) {
         WRITE_ERROR("Lane index is larger than number of lanes (edge '" + myCurrentID + "').");
         return;
     }
-    // set information about allowed / disallowed vehicle classes
-    myCurrentEdge->setPermissions(parseVehicleClasses(allowed, disallowed), lane);
-    myCurrentEdge->setPreferredVehicleClass(parseVehicleClasses(preferred), lane);
+    // set information about allowed / disallowed vehicle classes (if specified)
+    if (attrs.hasAttribute(SUMO_ATTR_ALLOW) || attrs.hasAttribute(SUMO_ATTR_DISALLOW)) {
+        const std::string allowed = attrs.getOpt<std::string>(SUMO_ATTR_ALLOW, 0, ok, "");
+        const std::string disallowed = attrs.getOpt<std::string>(SUMO_ATTR_DISALLOW, 0, ok, "");
+        myCurrentEdge->setPermissions(parseVehicleClasses(allowed, disallowed), lane);
+    }
+    if (attrs.hasAttribute(SUMO_ATTR_PREFER)) {
+        const std::string preferred  = attrs.get<std::string>(SUMO_ATTR_PREFER, 0, ok);
+        myCurrentEdge->setPreferredVehicleClass(parseVehicleClasses(preferred), lane);
+    }
     // try to get the width
     if (attrs.hasAttribute(SUMO_ATTR_WIDTH)) {
-        myCurrentEdge->setLaneWidth(lane, attrs.get<SUMOReal>(SUMO_ATTR_WIDTH, myCurrentID.c_str(), ok));
+        myCurrentEdge->setLaneWidth(lane, attrs.get<double>(SUMO_ATTR_WIDTH, myCurrentID.c_str(), ok));
     }
     // try to get the end-offset (lane shortened due to pedestrian crossing etc..)
     if (attrs.hasAttribute(SUMO_ATTR_ENDOFFSET)) {
-        myCurrentEdge->setEndOffset(lane, attrs.get<SUMOReal>(SUMO_ATTR_ENDOFFSET, myCurrentID.c_str(), ok));
+        myCurrentEdge->setEndOffset(lane, attrs.get<double>(SUMO_ATTR_ENDOFFSET, myCurrentID.c_str(), ok));
     }
     // try to get lane specific speed (should not occur for german networks)
     if (attrs.hasAttribute(SUMO_ATTR_SPEED)) {
-        myCurrentEdge->setSpeed(lane, attrs.get<SUMOReal>(SUMO_ATTR_SPEED, myCurrentID.c_str(), ok));
+        myCurrentEdge->setSpeed(lane, attrs.get<double>(SUMO_ATTR_SPEED, myCurrentID.c_str(), ok));
+    }
+    // check whether this is an acceleration lane
+    if (attrs.hasAttribute(SUMO_ATTR_ACCELERATION)) {
+        myCurrentEdge->setAcceleration(lane, attrs.get<bool>(SUMO_ATTR_ACCELERATION, myCurrentID.c_str(), ok));
     }
 }
 
@@ -342,7 +345,7 @@ void NIXMLEdgesHandler::addSplit(const SUMOSAXAttributes& attrs) {
     }
     bool ok = true;
     Split e;
-    e.pos = attrs.get<SUMOReal>(SUMO_ATTR_POSITION, 0, ok);
+    e.pos = attrs.get<double>(SUMO_ATTR_POSITION, 0, ok);
     if (ok) {
         if (fabs(e.pos) > myCurrentEdge->getGeometry().length()) {
             WRITE_ERROR("Edge '" + myCurrentID + "' has a split at invalid position " + toString(e.pos) + ".");
@@ -376,8 +379,10 @@ void NIXMLEdgesHandler::addSplit(const SUMOSAXAttributes& attrs) {
         }
         e.speed = attrs.getOpt(SUMO_ATTR_SPEED, 0, ok, myCurrentEdge->getSpeed());
         if (attrs.hasAttribute(SUMO_ATTR_SPEED) && myOptions.getBool("speed-in-kmh")) {
-            e.speed /= (SUMOReal) 3.6;
+            e.speed /= (double) 3.6;
         }
+        e.idBefore = attrs.getOpt(SUMO_ATTR_ID_BEFORE, 0, ok, std::string(""));
+        e.idAfter = attrs.getOpt(SUMO_ATTR_ID_AFTER, 0, ok, std::string(""));
         if (!ok) {
             return;
         }
@@ -479,7 +484,17 @@ NIXMLEdgesHandler::deleteEdge(const SUMOSAXAttributes& attrs) {
                       myCurrentID + "'");
         return;
     }
-    myEdgeCont.extract(myDistrictCont, edge, true);
+    const int lane = attrs.getOpt<int>(SUMO_ATTR_INDEX, myCurrentID.c_str(), ok, -1);
+    if (lane < 0) {
+        myEdgeCont.extract(myDistrictCont, edge, true);
+    } else {
+        edge->removeFromConnections(0, lane, -1, false, true);
+        const EdgeVector incoming = edge->getIncomingEdges();
+        for (EdgeVector::const_iterator e = incoming.begin(); e != incoming.end(); ++e) {
+            (*e)->removeFromConnections(edge, -1, lane, false, true);
+        }
+        edge->deleteLane(lane, false);
+    }
 }
 
 
@@ -511,18 +526,18 @@ NIXMLEdgesHandler::myEndElement(int element) {
             std::vector<Split>::iterator i;
             NBEdge* e = myCurrentEdge;
             sort(mySplits.begin(), mySplits.end(), split_sorter());
-            unsigned int noLanesMax = e->getNumLanes();
+            int noLanesMax = e->getNumLanes();
             // compute the node positions and sort the lanes
             for (i = mySplits.begin(); i != mySplits.end(); ++i) {
                 sort((*i).lanes.begin(), (*i).lanes.end());
-                noLanesMax = MAX2(noLanesMax, (unsigned int)(*i).lanes.size());
+                noLanesMax = MAX2(noLanesMax, (int)(*i).lanes.size());
             }
             // split the edge
             std::vector<int> currLanes;
             for (int l = 0; l < e->getNumLanes(); ++l) {
                 currLanes.push_back(l);
             }
-            if (e->getNumLanes() != mySplits.back().lanes.size()) {
+            if (e->getNumLanes() != (int)mySplits.back().lanes.size()) {
                 // invalidate traffic light definitions loaded from a SUMO network
                 // XXX it would be preferable to reconstruct the phase definitions heuristically
                 e->getToNode()->invalidateTLS(myTLLogicCont);
@@ -531,8 +546,8 @@ NIXMLEdgesHandler::myEndElement(int element) {
                 e->invalidateConnections(true);
             }
 
-            std::string edgeid = e->getID();
-            SUMOReal seen = 0;
+            std::string firstID = "";
+            double seen = 0;
             for (i = mySplits.begin(); i != mySplits.end(); ++i) {
                 const Split& exp = *i;
                 assert(exp.lanes.size() != 0);
@@ -540,29 +555,33 @@ NIXMLEdgesHandler::myEndElement(int element) {
                     if (myNodeCont.insert(exp.node)) {
                         myNodeCont.markAsSplit(exp.node);
                         //  split the edge
-                        std::string pid = e->getID();
+                        std::string idBefore = exp.idBefore == "" ? e->getID() : exp.idBefore;
+                        std::string idAfter = exp.idAfter == "" ? exp.node->getID() : exp.idAfter;
+                        if (firstID == "") {
+                            firstID = idBefore;
+                        }
                         myEdgeCont.splitAt(myDistrictCont, e, exp.pos - seen, exp.node,
-                                           pid, exp.node->getID(), e->getNumLanes(), (unsigned int) exp.lanes.size(), exp.speed);
+                                           idBefore, idAfter, e->getNumLanes(), (int) exp.lanes.size(), exp.speed);
                         seen = exp.pos;
                         std::vector<int> newLanes = exp.lanes;
-                        NBEdge* pe = myEdgeCont.retrieve(pid);
-                        NBEdge* ne = myEdgeCont.retrieve(exp.node->getID());
+                        NBEdge* pe = myEdgeCont.retrieve(idBefore);
+                        NBEdge* ne = myEdgeCont.retrieve(idAfter);
                         // reconnect lanes
                         pe->invalidateConnections(true);
                         //  new on right
-                        unsigned int rightMostP = currLanes[0];
-                        unsigned int rightMostN = newLanes[0];
+                        int rightMostP = currLanes[0];
+                        int rightMostN = newLanes[0];
                         for (int l = 0; l < (int) rightMostP - (int) rightMostN; ++l) {
                             pe->addLane2LaneConnection(0, ne, l, NBEdge::L2L_VALIDATED, true);
                         }
                         //  new on left
-                        unsigned int leftMostP = currLanes.back();
-                        unsigned int leftMostN = newLanes.back();
+                        int leftMostP = currLanes.back();
+                        int leftMostN = newLanes.back();
                         for (int l = 0; l < (int) leftMostN - (int) leftMostP; ++l) {
                             pe->addLane2LaneConnection(pe->getNumLanes() - 1, ne, leftMostN - l - rightMostN, NBEdge::L2L_VALIDATED, true);
                         }
                         //  all other connected
-                        for (unsigned int l = 0; l < noLanesMax; ++l) {
+                        for (int l = 0; l < noLanesMax; ++l) {
                             if (find(currLanes.begin(), currLanes.end(), l) == currLanes.end()) {
                                 continue;
                             }
@@ -593,7 +612,7 @@ NIXMLEdgesHandler::myEndElement(int element) {
                 }
             }
             // patch lane offsets
-            e = myEdgeCont.retrieve(edgeid);
+            e = myEdgeCont.retrieve(firstID);
             if (mySplits.front().pos != 0) {
                 // add a dummy split at the beginning to ensure correct offset
                 Split start;
@@ -605,8 +624,8 @@ NIXMLEdgesHandler::myEndElement(int element) {
             }
             i = mySplits.begin();
             for (; i != mySplits.end(); ++i) {
-                unsigned int maxLeft = (*i).lanes.back();
-                SUMOReal offset = 0;
+                int maxLeft = (*i).lanes.back();
+                double offset = 0;
                 if (maxLeft < noLanesMax) {
                     if (e->getLaneSpreadFunction() == LANESPREAD_RIGHT) {
                         offset = SUMO_const_laneWidthAndOffset * (noLanesMax - 1 - maxLeft);
@@ -614,7 +633,7 @@ NIXMLEdgesHandler::myEndElement(int element) {
                         offset = SUMO_const_halfLaneAndOffset * (noLanesMax - 1 - maxLeft);
                     }
                 }
-                unsigned int maxRight = (*i).lanes.front();
+                int maxRight = (*i).lanes.front();
                 if (maxRight > 0 && e->getLaneSpreadFunction() == LANESPREAD_CENTER) {
                     offset -= SUMO_const_halfLaneAndOffset * maxRight;
                 }
@@ -628,6 +647,7 @@ NIXMLEdgesHandler::myEndElement(int element) {
                 }
             }
         }
+        myCurrentEdge = 0;
     }
 }
 
