@@ -5,12 +5,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NIXMLNodesHandler.cpp 18756 2015-08-31 19:16:33Z behrisch $
+/// @version $Id: NIXMLNodesHandler.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Importer for network nodes stored in XML
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -52,10 +52,6 @@
 #include "NIXMLNodesHandler.h"
 #include "NIImporter_SUMO.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -67,8 +63,8 @@ NIXMLNodesHandler::NIXMLNodesHandler(NBNodeCont& nc,
     myOptions(options),
     myNodeCont(nc),
     myTLLogicCont(tlc),
-    myLocation(0)
-{}
+    myLocation(0) {
+}
 
 
 NIXMLNodesHandler::~NIXMLNodesHandler() {
@@ -122,20 +118,20 @@ NIXMLNodesHandler::addNode(const SUMOSAXAttributes& attrs) {
         myPosition.set(0, 0, 0); // better to reset than to reuse the previous (z)-value
     }
     if (attrs.hasAttribute(SUMO_ATTR_X)) {
-        myPosition.set(attrs.get<SUMOReal>(SUMO_ATTR_X, myID.c_str(), ok), myPosition.y());
+        myPosition.set(attrs.get<double>(SUMO_ATTR_X, myID.c_str(), ok), myPosition.y());
         xOk = true;
         needConversion = true;
     }
     if (attrs.hasAttribute(SUMO_ATTR_Y)) {
-        myPosition.set(myPosition.x(), attrs.get<SUMOReal>(SUMO_ATTR_Y, myID.c_str(), ok));
+        myPosition.set(myPosition.x(), attrs.get<double>(SUMO_ATTR_Y, myID.c_str(), ok));
         yOk = true;
         needConversion = true;
     }
     if (attrs.hasAttribute(SUMO_ATTR_Z)) {
-        myPosition.set(myPosition.x(), myPosition.y(), attrs.get<SUMOReal>(SUMO_ATTR_Z, myID.c_str(), ok));
+        myPosition.set(myPosition.x(), myPosition.y(), attrs.get<double>(SUMO_ATTR_Z, myID.c_str(), ok));
     }
     if (xOk && yOk) {
-        if (needConversion && !NBNetBuilder::transformCoordinates(myPosition, true, myLocation)) {
+        if (needConversion && !NBNetBuilder::transformCoordinate(myPosition, true, myLocation)) {
             WRITE_ERROR("Unable to project coordinates for node '" + myID + "'.");
         }
     } else {
@@ -169,6 +165,7 @@ NIXMLNodesHandler::processNodeType(const SUMOSAXAttributes& attrs, NBNode* node,
             type = NODETYPE_UNKNOWN;
         }
     }
+    std::set<NBTrafficLightDefinition*> oldTLS;
     // check whether a prior node shall be modified
     if (node == 0) {
         node = new NBNode(nodeID, position, type);
@@ -176,21 +173,21 @@ NIXMLNodesHandler::processNodeType(const SUMOSAXAttributes& attrs, NBNode* node,
             throw ProcessError("Could not insert node though checked this before (id='" + nodeID + "').");
         }
     } else {
-        // remove previously set tls if this node is not controlled by a tls
-        std::set<NBTrafficLightDefinition*> tls = node->getControllingTLS();
-        node->removeTrafficLights();
-        for (std::set<NBTrafficLightDefinition*>::iterator i = tls.begin(); i != tls.end(); ++i) {
-            if ((*i)->getNodes().size() == 0) {
-                tlc.removeFully((*i)->getID());
-            }
-        }
         // patch information
+        oldTLS = node->getControllingTLS();
         node->reinit(position, type, updateEdgeGeometries);
     }
     // process traffic light definition
-    if (type == NODETYPE_TRAFFIC_LIGHT || type == NODETYPE_TRAFFIC_LIGHT_NOJUNCTION) {
+    if (NBNode::isTrafficLight(type)) {
         processTrafficLightDefinitions(attrs, node, tlc);
     }
+    // remove previously set tls if this node is not controlled by them
+    for (std::set<NBTrafficLightDefinition*>::iterator i = oldTLS.begin(); i != oldTLS.end(); ++i) {
+        if ((*i)->getNodes().size() == 0) {
+            tlc.removeFully((*i)->getID());
+        }
+    }
+
     // set optional shape
     PositionVector shape;
     if (attrs.hasAttribute(SUMO_ATTR_SHAPE)) {
@@ -202,7 +199,7 @@ NIXMLNodesHandler::processNodeType(const SUMOSAXAttributes& attrs, NBNode* node,
     }
     // set optional radius
     if (attrs.hasAttribute(SUMO_ATTR_RADIUS)) {
-        node->setRadius(attrs.get<SUMOReal>(SUMO_ATTR_RADIUS, nodeID.c_str(), ok));
+        node->setRadius(attrs.get<double>(SUMO_ATTR_RADIUS, nodeID.c_str(), ok));
     }
     // set optional keepClear flag
     if (attrs.hasAttribute(SUMO_ATTR_KEEP_CLEAR)) {
@@ -261,9 +258,20 @@ NIXMLNodesHandler::processTrafficLightDefinitions(const SUMOSAXAttributes& attrs
     // if no tl-id exists, we will build a tl with the node's id
     std::set<NBTrafficLightDefinition*> tlDefs;
     bool ok = true;
-    std::string tlID = attrs.getOpt<std::string>(SUMO_ATTR_TLID, 0, ok, "");
-    std::string typeS = attrs.getOpt<std::string>(SUMO_ATTR_TLTYPE, 0, ok,
-                        OptionsCont::getOptions().getString("tls.default-type"));
+
+    std::string oldTlID = "";
+    std::string oldTypeS = OptionsCont::getOptions().getString("tls.default-type");
+
+    if (currentNode->isTLControlled()) {
+        NBTrafficLightDefinition* oldDef = *(currentNode->getControllingTLS().begin());
+        oldTlID = oldDef->getID();
+        oldTypeS = toString(oldDef->getType());
+    }
+    std::string tlID = attrs.getOpt<std::string>(SUMO_ATTR_TLID, 0, ok, oldTlID);
+    std::string typeS = attrs.getOpt<std::string>(SUMO_ATTR_TLTYPE, 0, ok, oldTypeS);
+    if (tlID != oldTlID || typeS != oldTypeS) {
+        currentNode->removeTrafficLights();
+    }
     TrafficLightType type;
     if (SUMOXMLDefinitions::TrafficLightTypes.hasString(typeS)) {
         type = SUMOXMLDefinitions::TrafficLightTypes.get(typeS);
