@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    2011-10-05
-/// @version $Id: NIXMLTrafficLightsHandler.cpp 18169 2015-03-27 13:40:16Z behrisch $
+/// @version $Id: NIXMLTrafficLightsHandler.cpp 23879 2017-04-07 12:31:47Z namdre $
 ///
 // Importer for traffic lights stored in XML
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2011-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2011-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -53,10 +53,6 @@
 #include "NIImporter_SUMO.h"
 #include "NIXMLTrafficLightsHandler.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -67,8 +63,8 @@ NIXMLTrafficLightsHandler::NIXMLTrafficLightsHandler(
     myTLLCont(tlCont),
     myEdgeCont(ec),
     myCurrentTL(0),
-    myResetPhases(false)
-{}
+    myResetPhases(false) {
+}
 
 
 NIXMLTrafficLightsHandler::~NIXMLTrafficLightsHandler() {}
@@ -127,7 +123,7 @@ NIXMLTrafficLightsHandler::initTrafficLightLogic(const SUMOSAXAttributes& attrs,
     bool ok = true;
     std::string id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
     std::string programID = attrs.getOpt<std::string>(SUMO_ATTR_PROGRAMID, id.c_str(), ok, "<unknown>");
-    SUMOTime offset = attrs.hasAttribute(SUMO_ATTR_OFFSET) ? TIME2STEPS(attrs.get<SUMOReal>(SUMO_ATTR_OFFSET, id.c_str(), ok)) : 0;
+    SUMOTime offset = attrs.hasAttribute(SUMO_ATTR_OFFSET) ? TIME2STEPS(attrs.get<double>(SUMO_ATTR_OFFSET, id.c_str(), ok)) : 0;
     std::string typeS = attrs.getOpt<std::string>(SUMO_ATTR_TYPE, 0, ok,
                         OptionsCont::getOptions().getString("tls.default-type"));
     TrafficLightType type;
@@ -137,7 +133,7 @@ NIXMLTrafficLightsHandler::initTrafficLightLogic(const SUMOSAXAttributes& attrs,
         WRITE_ERROR("Unknown traffic light type '" + typeS + "' for tlLogic '" + id + "'.");
         return 0;
     }
-    // there are two scenarios to consider
+    // there are three scenarios to consider
     // 1) the tll.xml is loaded to update traffic lights defined in a net.xml:
     //   simply retrieve the loaded definitions and update them
     // 2) the tll.xml is loaded to define new traffic lights
@@ -156,11 +152,11 @@ NIXMLTrafficLightsHandler::initTrafficLightLogic(const SUMOSAXAttributes& attrs,
         if (oldDef == 0) {
             // case 2
             NBTrafficLightDefinition* newDef = dynamic_cast<NBOwnTLDef*>(myTLLCont.getDefinition(
-                        id, NBTrafficLightDefinition::DefaultProgramID));
+                                                   id, NBTrafficLightDefinition::DefaultProgramID));
             if (newDef == 0) {
                 // the default program may have already been replaced with a loaded program
                 newDef = dynamic_cast<NBLoadedSUMOTLDef*>(myTLLCont.getDefinition(
-                            id, NBTrafficLightDefinition::DefaultProgramID));
+                             id, NBTrafficLightDefinition::DefaultProgramID));
                 if (newDef == 0) {
                     WRITE_ERROR("Cannot load traffic light program for unknown id '" + id + "', programID '" + programID + "'.");
                     return 0;
@@ -186,10 +182,10 @@ NIXMLTrafficLightsHandler::initTrafficLightLogic(const SUMOSAXAttributes& attrs,
         } else {
             // case 3
             NBTrafficLightLogic* oldLogic = oldDef->getLogic();
-            NBTrafficLightLogic* newLogic = new NBTrafficLightLogic(id, programID, 
+            NBTrafficLightLogic* newLogic = new NBTrafficLightLogic(id, programID,
                     oldLogic->getNumLinks(), offset, type);
             loadedDef = new NBLoadedSUMOTLDef(oldDef, newLogic);
-            // copy nodes 
+            // copy nodes
             std::vector<NBNode*> nodes = oldDef->getNodes();
             for (std::vector<NBNode*>::iterator it = nodes.begin(); it != nodes.end(); it++) {
                 loadedDef->addNode(*it);
@@ -262,7 +258,10 @@ NIXMLTrafficLightsHandler::addTlConnection(const SUMOSAXAttributes& attrs) {
             }
         }
     } else {
-        WRITE_ERROR("The traffic light '" + tlID + "' is not known.");
+        SumoXMLNodeType type = from->getToNode()->getType();
+        if (type != NODETYPE_RAIL_CROSSING && type != NODETYPE_RAIL_SIGNAL) {
+            WRITE_ERROR("The traffic light '" + tlID + "' is not known.");
+        }
     }
 }
 
@@ -320,7 +319,7 @@ int
 NIXMLTrafficLightsHandler::retrieveLaneIndex(
     const SUMOSAXAttributes& attrs, SumoXMLAttr attr, NBEdge* edge, bool& ok) {
     int laneIndex = attrs.get<int>(attr, 0, ok);
-    if (edge->getNumLanes() <= (size_t) laneIndex) {
+    if (edge->getNumLanes() <= laneIndex) {
         WRITE_ERROR("Invalid lane index '" + toString(laneIndex) + "' for edge '" + edge->getID() + "'.");
         ok = false;
     }
