@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NIXMLTypesHandler.h 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id: NIXMLTypesHandler.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Importer for edge type information stored in XML
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -88,6 +88,9 @@ private:
     /// @brief The type container to fill
     NBTypeCont& myTypeCont;
 
+    /// @brief The currently parsed type
+    std::string myCurrentTypeID;
+
 
 private:
     /** @brief invalid copy constructor */
