@@ -2,12 +2,12 @@
 /// @file    NIVissimBoundedClusterObject.h
 /// @author  Daniel Krajzewicz
 /// @date    Sept 2002
-/// @version $Id: NIVissimBoundedClusterObject.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NIVissimBoundedClusterObject.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -50,7 +50,7 @@ public:
     NIVissimBoundedClusterObject();
     virtual ~NIVissimBoundedClusterObject();
     virtual void computeBounding() = 0;
-    bool crosses(const AbstractPoly& poly, SUMOReal offset = 0) const;
+    bool crosses(const AbstractPoly& poly, double offset = 0) const;
     void inCluster(int id);
     bool clustered() const;
     const Boundary& getBoundary() const;
