@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: NIVissimExtendedEdgePoint.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIVissimExtendedEdgePoint.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -56,10 +56,10 @@ public:
      * @param[in] assignedVehicles Vehicle (type) indices which should be regarded by this point
      */
     NIVissimExtendedEdgePoint(int edgeid, const std::vector<int>& lanes,
-                              SUMOReal position, const std::vector<int>& assignedVehicles);
+                              double position, const std::vector<int>& assignedVehicles);
     ~NIVissimExtendedEdgePoint();
     int getEdgeID() const;
-    SUMOReal getPosition() const;
+    double getPosition() const;
     Position getGeomPosition() const;
     const std::vector<int>& getLanes() const;
 
@@ -76,7 +76,7 @@ public:
 private:
     int myEdgeID;
     std::vector<int> myLanes;
-    SUMOReal myPosition;
+    double myPosition;
     std::vector<int> myAssignedVehicles;
 };
 
