@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: NIVissimNodeDef_Edges.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIVissimNodeDef_Edges.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -43,10 +43,6 @@
 #include "NIVissimDisturbance.h"
 #include "NIVissimConnection.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -110,12 +106,12 @@ NIVissimNodeDef_Edges::searchAndSetConnections() {
 */
 
 
-SUMOReal
+double
 NIVissimNodeDef_Edges::getEdgePosition(int edgeid) const {
     for (NIVissimNodeParticipatingEdgeVector::const_iterator i = myEdges.begin(); i != myEdges.end(); i++) {
         NIVissimNodeParticipatingEdge* edge = *i;
         if (edge->getID() == edgeid) {
-            return (edge->getFromPos() + edge->getToPos()) / (SUMOReal) 2.0;
+            return (edge->getFromPos() + edge->getToPos()) / (double) 2.0;
         }
     }
     return -1;
