@@ -2,12 +2,12 @@
 /// @file    NIVissimNodeDef_Edges.h
 /// @author  Daniel Krajzewicz
 /// @date    Sept 2002
-/// @version $Id: NIVissimNodeDef_Edges.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIVissimNodeDef_Edges.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -47,7 +47,7 @@ public:
                            const NIVissimNodeParticipatingEdgeVector& edges);
 //    virtual void computeBounding();
 //    virtual void searchAndSetConnections();
-    virtual SUMOReal getEdgePosition(int edgeid) const;
+    virtual double getEdgePosition(int edgeid) const;
 
     /**
      *
