@@ -2,12 +2,12 @@
 /// @file    NIVissimTrafficDescription.cpp
 /// @author  Daniel Krajzewicz
 /// @date    Sept 2002
-/// @version $Id: NIVissimTrafficDescription.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIVissimTrafficDescription.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -34,10 +34,6 @@
 #include "NIVissimVehicleClassVector.h"
 #include "NIVissimTrafficDescription.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // member function definitions
@@ -107,7 +103,7 @@ NIVissimTrafficDescription::clearDict() {
 
 
 
-SUMOReal
+double
 NIVissimTrafficDescription::meanSpeed(int id) {
     NIVissimTrafficDescription* i = dictionary(id);
     assert(i != 0);
@@ -115,13 +111,13 @@ NIVissimTrafficDescription::meanSpeed(int id) {
 }
 
 
-SUMOReal
+double
 NIVissimTrafficDescription::meanSpeed() const {
-    SUMOReal speed = 0;
+    double speed = 0;
     for (NIVissimVehicleClassVector::const_iterator i = myVehicleTypes.begin(); i != myVehicleTypes.end(); i++) {
         speed += (*i)->getSpeed();
     }
-    return speed / (SUMOReal) myVehicleTypes.size();
+    return speed / (double) myVehicleTypes.size();
 }
 
 
