@@ -3,12 +3,12 @@
 /// @author  Michael Behrisch
 /// @author  Daniel Krajzewicz
 /// @date    Sept 2002
-/// @version $Id: NIVissimVehTypeClass.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: NIVissimVehTypeClass.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -52,7 +52,7 @@ public:
     static bool dictionary(int id, NIVissimVehTypeClass* o);
     static NIVissimVehTypeClass* dictionary(int name);
     static void clearDict();
-    SUMOReal meanSpeed() const;
+    double meanSpeed() const;
 private:
     int myID;
     std::string myName;
