@@ -2,12 +2,12 @@
 /// @file    NIVissimVehicleClass.cpp
 /// @author  Daniel Krajzewicz
 /// @date    Sept 2002
-/// @version $Id: NIVissimVehicleClass.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NIVissimVehicleClass.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // -------------------
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -31,10 +31,6 @@
 
 #include "NIVissimVehicleClass.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 NIVissimVehicleClass::NIVissimVehicleClass(int vwish)
     : myVWish(vwish) {}
 
