@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Wed, 18 Dec 2002
-/// @version $Id: NIVissimSingleTypeParser_Richtungspfeildefinition.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NIVissimSingleTypeParser_Richtungspfeildefinition.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 //
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -35,10 +35,6 @@
 #include "../tempstructs/NIVissimSource.h"
 #include "NIVissimSingleTypeParser_Richtungspfeildefinition.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
