@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: NLEdgeControlBuilder.cpp 20550 2016-04-26 10:57:45Z namdre $
+/// @version $Id: NLEdgeControlBuilder.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Interface for building edges
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -46,10 +46,6 @@
 #include <utils/options/OptionsCont.h>
 #include <utils/iodevices/OutputDevice.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -82,10 +78,10 @@ NLEdgeControlBuilder::beginEdgeParsing(
 
 MSLane*
 NLEdgeControlBuilder::addLane(const std::string& id,
-                              SUMOReal maxSpeed, SUMOReal length,
-                              const PositionVector& shape, SUMOReal width,
-                              SVCPermissions permissions, int index) {
-    MSLane* lane = new MSLane(id, maxSpeed, length, myActiveEdge, myCurrentNumericalLaneID++, shape, width, permissions, index);
+                              double maxSpeed, double length,
+                              const PositionVector& shape, double width,
+                              SVCPermissions permissions, int index, bool isRampAccel) {
+    MSLane* lane = new MSLane(id, maxSpeed, length, myActiveEdge, myCurrentNumericalLaneID++, shape, width, permissions, index, isRampAccel);
     myLaneStorage->push_back(lane);
     return lane;
 }
@@ -121,10 +117,10 @@ NLEdgeControlBuilder::build() {
         for (MSEdgeVector::iterator i1 = myEdges.begin(); i1 != myEdges.end(); i1++) {
             MSEdge* edge = *i1;
             if (edge->isInternal()) {
-                if (edge->getNumSuccessors() != 1 || edge->getIncomingEdges().size() != 1) {
+                if (edge->getNumSuccessors() != 1 || edge->getNumPredecessors() != 1) {
                     throw ProcessError("Internal edge '" + edge->getID() + "' is not properly connected (probably a manually modified net.xml).");
                 }
-                if (edge->getSuccessors()[0]->isRoundabout() || edge->getIncomingEdges()[0]->isRoundabout()) {
+                if (edge->getSuccessors()[0]->isRoundabout() || edge->getPredecessors()[0]->isRoundabout()) {
                     edge->markAsRoundabout();
                 }
             }
