@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: NLEdgeControlBuilder.h 20550 2016-04-26 10:57:45Z namdre $
+/// @version $Id: NLEdgeControlBuilder.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Interface for building edges
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -101,9 +101,9 @@ public:
      * @see MSLane
      * @todo Definitely not a good way
      */
-    virtual MSLane* addLane(const std::string& id, SUMOReal maxSpeed,
-                            SUMOReal length, const PositionVector& shape,
-                            SUMOReal width, SVCPermissions permissions, int index);
+    virtual MSLane* addLane(const std::string& id, double maxSpeed,
+                            double length, const PositionVector& shape,
+                            double width, SVCPermissions permissions, int index, bool isRampAccel);
 
 
     /** @brief Adds a neighbor to the current lane
@@ -142,10 +142,10 @@ public:
 
 protected:
     /// @brief A running number for lane numbering
-    unsigned int myCurrentNumericalLaneID;
+    int myCurrentNumericalLaneID;
 
     /// @brief A running number for edge numbering
-    unsigned int myCurrentNumericalEdgeID;
+    int myCurrentNumericalEdgeID;
 
     /// @brief Temporary, internal storage for built edges
     MSEdgeVector myEdges;
