@@ -7,12 +7,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Thu, 17 Oct 2002
-/// @version $Id: NLTriggerBuilder.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NLTriggerBuilder.cpp 24010 2017-04-21 17:00:09Z behrisch $
 ///
 // Builds trigger objects for microsim
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -59,16 +59,12 @@
 #include <mesosim/MELoop.h>
 #include <mesosim/METriggeredCalibrator.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
 NLTriggerBuilder::NLTriggerBuilder()
-    : myHandler(0) {}
+    : myHandler(0), myParkingArea(0) {}
 
 
 NLTriggerBuilder::~NLTriggerBuilder() {}
@@ -107,9 +103,9 @@ NLTriggerBuilder::buildVaporizer(const SUMOSAXAttributes& attrs) {
     }
     if (end >= string2time(OptionsCont::getOptions().getString("begin"))) {
         Command* cb = new WrappingCommand< MSEdge >(e, &MSEdge::incVaporization);
-        MSNet::getInstance()->getBeginOfTimestepEvents()->addEvent(cb, begin, MSEventControl::ADAPT_AFTER_EXECUTION);
+        MSNet::getInstance()->getBeginOfTimestepEvents()->addEvent(cb, begin);
         Command* ce = new WrappingCommand< MSEdge >(e, &MSEdge::decVaporization);
-        MSNet::getInstance()->getBeginOfTimestepEvents()->addEvent(ce, end, MSEventControl::ADAPT_AFTER_EXECUTION);
+        MSNet::getInstance()->getBeginOfTimestepEvents()->addEvent(ce, end);
     }
 }
 
@@ -169,12 +165,12 @@ NLTriggerBuilder::parseAndBuildChargingStation(MSNet& net, const SUMOSAXAttribut
     MSLane* lane = getLane(attrs, "chargingStation", id);
 
     // get the positions
-    SUMOReal frompos = attrs.getOpt<SUMOReal>(SUMO_ATTR_STARTPOS, id.c_str(), ok, 0);
-    SUMOReal topos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ENDPOS, id.c_str(), ok, lane->getLength());
-    SUMOReal chrgpower = attrs.getOpt<SUMOReal>(SUMO_ATTR_CHARGINGPOWER, id.c_str(), ok, 0);
-    SUMOReal efficiency = attrs.getOpt<SUMOReal>(SUMO_ATTR_EFFICIENCY, id.c_str(), ok, 0);
-    SUMOReal chargeInTransit = attrs.getOpt<SUMOReal>(SUMO_ATTR_CHARGEINTRANSIT, id.c_str(), ok, 0);
-    SUMOReal ChargeDelay = attrs.getOpt<SUMOReal>(SUMO_ATTR_CHARGEDELAY, id.c_str(), ok, 0);
+    double frompos = attrs.getOpt<double>(SUMO_ATTR_STARTPOS, id.c_str(), ok, 0);
+    double topos = attrs.getOpt<double>(SUMO_ATTR_ENDPOS, id.c_str(), ok, lane->getLength());
+    double chargingPower = attrs.getOpt<double>(SUMO_ATTR_CHARGINGPOWER, id.c_str(), ok, 0);
+    double efficiency = attrs.getOpt<double>(SUMO_ATTR_EFFICIENCY, id.c_str(), ok, 0);
+    bool chargeInTransit = attrs.getOpt<bool>(SUMO_ATTR_CHARGEINTRANSIT, id.c_str(), ok, 0);
+    int ChargeDelay = attrs.getOpt<int>(SUMO_ATTR_CHARGEDELAY, id.c_str(), ok, 0);
 
     const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, id.c_str(), ok, false);
 
@@ -182,12 +178,8 @@ NLTriggerBuilder::parseAndBuildChargingStation(MSNet& net, const SUMOSAXAttribut
         throw InvalidArgument("Invalid position for Charging Station '" + id + "'.");
     }
 
-    // get the lines
-    std::vector<std::string> lines;
-    SUMOSAXAttributes::parseStringVector(attrs.getOpt<std::string>(SUMO_ATTR_LINES, id.c_str(), ok, "", false), lines);
-
     // build the Charging Station
-    buildChargingStation(net, id, lines, lane, frompos, topos, chrgpower, efficiency, chargeInTransit, ChargeDelay);
+    buildChargingStation(net, id, lane, frompos, topos, chargingPower, efficiency, chargeInTransit, ChargeDelay);
 }
 
 
@@ -199,11 +191,15 @@ NLTriggerBuilder::parseAndBuildStoppingPlace(MSNet& net, const SUMOSAXAttributes
     if (!ok) {
         throw ProcessError();
     }
+
+    //get the name, leave blank if not given
+    const std::string ptStopName = attrs.getOpt<std::string>(SUMO_ATTR_NAME, id.c_str(), ok, "");
+
     // get the lane
     MSLane* lane = getLane(attrs, toString(element), id);
     // get the positions
-    SUMOReal frompos = attrs.getOpt<SUMOReal>(SUMO_ATTR_STARTPOS, id.c_str(), ok, 0);
-    SUMOReal topos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ENDPOS, id.c_str(), ok, lane->getLength());
+    double frompos = attrs.getOpt<double>(SUMO_ATTR_STARTPOS, id.c_str(), ok, 0);
+    double topos = attrs.getOpt<double>(SUMO_ATTR_ENDPOS, id.c_str(), ok, lane->getLength());
     const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, id.c_str(), ok, false);
     if (!ok || !myHandler->checkStopPos(frompos, topos, lane->getLength(), POSITION_EPS, friendlyPos)) {
         throw InvalidArgument("Invalid position for " + toString(element) + " '" + id + "'.");
@@ -212,7 +208,7 @@ NLTriggerBuilder::parseAndBuildStoppingPlace(MSNet& net, const SUMOSAXAttributes
     std::vector<std::string> lines;
     SUMOSAXAttributes::parseStringVector(attrs.getOpt<std::string>(SUMO_ATTR_LINES, id.c_str(), ok, "", false), lines);
     // build the bus stop
-    buildStoppingPlace(net, id, lines, lane, frompos, topos, element);
+    buildStoppingPlace(net, id, lines, lane, frompos, topos, element, ptStopName);
 }
 
 
@@ -222,7 +218,7 @@ NLTriggerBuilder::addAccess(MSNet& /* net */, const SUMOSAXAttributes& attrs) {
     MSLane* lane = getLane(attrs, "access" , "");
     // get the positions
     bool ok = true;
-    SUMOReal pos = attrs.getOpt<SUMOReal>(SUMO_ATTR_POSITION, "access", ok, 0);
+    double pos = attrs.getOpt<double>(SUMO_ATTR_POSITION, "access", ok, 0);
     const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, "access", ok, false);
     if (!ok || !myHandler->checkStopPos(pos, pos, lane->getLength(), 0, friendlyPos)) {
         throw InvalidArgument("Invalid position for access in stop '" + myCurrentStop->getID() + "'.");
@@ -232,6 +228,61 @@ NLTriggerBuilder::addAccess(MSNet& /* net */, const SUMOSAXAttributes& attrs) {
 }
 
 
+void
+NLTriggerBuilder::parseAndBeginParkingArea(MSNet& net, const SUMOSAXAttributes& attrs) {
+    bool ok = true;
+    // get the id, throw if not given or empty...
+    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    if (!ok) {
+        throw ProcessError();
+    }
+    // get the lane
+    MSLane* lane = getLane(attrs, "parkingArea", id);
+    // get the positions
+    double frompos = attrs.getOpt<double>(SUMO_ATTR_STARTPOS, id.c_str(), ok, 0);
+    double topos = attrs.getOpt<double>(SUMO_ATTR_ENDPOS, id.c_str(), ok, lane->getLength());
+    const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, id.c_str(), ok, false);
+    unsigned int capacity = attrs.getOpt<int>(SUMO_ATTR_ROADSIDE_CAPACITY, id.c_str(), ok, 0);
+    double width = attrs.getOpt<double>(SUMO_ATTR_WIDTH, id.c_str(), ok, 0);
+    double length = attrs.getOpt<double>(SUMO_ATTR_LENGTH, id.c_str(), ok, 0);
+    double angle = attrs.getOpt<double>(SUMO_ATTR_ANGLE, id.c_str(), ok, 0);
+    if (!ok || !myHandler->checkStopPos(frompos, topos, lane->getLength(), POSITION_EPS, friendlyPos)) {
+        throw InvalidArgument("Invalid position for parking area '" + id + "'.");
+    }
+    // get the lines
+    std::vector<std::string> lines;
+    SUMOSAXAttributes::parseStringVector(attrs.getOpt<std::string>(SUMO_ATTR_LINES, id.c_str(), ok, "", false), lines);
+    // build the parking area
+    beginParkingArea(net, id, lines, lane, frompos, topos, capacity, width, length, angle);
+}
+
+
+
+void
+NLTriggerBuilder::parseAndAddLotEntry(const SUMOSAXAttributes& attrs) {
+    bool ok = true;
+    // Check for open parking area
+    if (myParkingArea == 0) {
+        throw ProcessError();
+    }
+    // get the positions
+    double x = attrs.get<double>(SUMO_ATTR_X, "", ok);
+    if (!ok) {
+        throw InvalidArgument("Invalid x position for lot entry.");
+    }
+    double y = attrs.get<double>(SUMO_ATTR_Y, "", ok);
+    if (!ok) {
+        throw InvalidArgument("Invalid y position for lot entry.");
+    }
+    double z = attrs.getOpt<double>(SUMO_ATTR_Z, "", ok, 0.);
+    double width = attrs.getOpt<double>(SUMO_ATTR_WIDTH, "", ok, myParkingArea->getWidth());
+    double length = attrs.getOpt<double>(SUMO_ATTR_LENGTH, "", ok, myParkingArea->getLength());
+    double angle = attrs.getOpt<double>(SUMO_ATTR_ANGLE, "", ok, myParkingArea->getAngle());
+    // add the lot entry
+    addLotEntry(x, y, z, width, length, angle);
+}
+
+
 void
 NLTriggerBuilder::parseAndBuildCalibrator(MSNet& net, const SUMOSAXAttributes& attrs,
         const std::string& base) {
@@ -243,7 +294,7 @@ NLTriggerBuilder::parseAndBuildCalibrator(MSNet& net, const SUMOSAXAttributes& a
     }
     // get the file name to read further definitions from
     MSLane* lane = getLane(attrs, "calibrator", id);
-    const SUMOReal pos = getPosition(attrs, lane, "calibrator", id);
+    const double pos = getPosition(attrs, lane, "calibrator", id);
     const SUMOTime freq = attrs.getOptSUMOTimeReporting(SUMO_ATTR_FREQUENCY, id.c_str(), ok, DELTA_T); // !!! no error handling
     std::string file = getFileName(attrs, base, true);
     std::string outfile = attrs.getOpt<std::string>(SUMO_ATTR_OUTPUT, id.c_str(), ok, "");
@@ -294,7 +345,7 @@ NLTriggerBuilder::parseAndBuildRerouter(MSNet& net, const SUMOSAXAttributes& att
     if (edges.size() == 0) {
         throw InvalidArgument("No edges found for MSTriggeredRerouter '" + id + "'.");
     }
-    SUMOReal prob = attrs.getOpt<SUMOReal>(SUMO_ATTR_PROB, id.c_str(), ok, 1);
+    double prob = attrs.getOpt<double>(SUMO_ATTR_PROB, id.c_str(), ok, 1);
     bool off = attrs.getOpt<bool>(SUMO_ATTR_OFF, id.c_str(), ok, false);
     if (!ok) {
         throw InvalidArgument("Could not parse MSTriggeredRerouter '" + id + "'.");
@@ -322,7 +373,7 @@ NLTriggerBuilder::buildLaneSpeedTrigger(MSNet& /*net*/, const std::string& id,
 
 METriggeredCalibrator*
 NLTriggerBuilder::buildMECalibrator(MSNet& /*net*/, const std::string& id,
-                                    const MSEdge* edge, SUMOReal pos,
+                                    const MSEdge* edge, double pos,
                                     const std::string& file,
                                     const std::string& outfile,
                                     const SUMOTime freq, MSRouteProbe* probe) {
@@ -332,7 +383,7 @@ NLTriggerBuilder::buildMECalibrator(MSNet& /*net*/, const std::string& id,
 
 MSCalibrator*
 NLTriggerBuilder::buildCalibrator(MSNet& /*net*/, const std::string& id,
-                                  MSEdge* edge, SUMOReal pos,
+                                  MSEdge* edge, double pos,
                                   const std::string& file,
                                   const std::string& outfile,
                                   const SUMOTime freq, const MSRouteProbe* probe) {
@@ -343,16 +394,15 @@ NLTriggerBuilder::buildCalibrator(MSNet& /*net*/, const std::string& id,
 MSTriggeredRerouter*
 NLTriggerBuilder::buildRerouter(MSNet&, const std::string& id,
                                 MSEdgeVector& edges,
-                                SUMOReal prob, const std::string& file, bool off) {
+                                double prob, const std::string& file, bool off) {
     return new MSTriggeredRerouter(id, edges, prob, file, off);
 }
 
 
 void
-NLTriggerBuilder::buildStoppingPlace(MSNet& net, const std::string& id,
-                                     const std::vector<std::string>& lines,
-                                     MSLane* lane, SUMOReal frompos, SUMOReal topos, const SumoXMLTag element) {
-    myCurrentStop = new MSStoppingPlace(id, lines, *lane, frompos, topos);
+NLTriggerBuilder::buildStoppingPlace(MSNet& net, std::string id, std::vector<std::string> lines, MSLane* lane,
+                                     double frompos, double topos, const SumoXMLTag element, std::string ptStopName) {
+    myCurrentStop = new MSStoppingPlace(id, lines, *lane, frompos, topos, ptStopName);
     const bool success = element == SUMO_TAG_CONTAINER_STOP ? net.addContainerStop(myCurrentStop) : net.addBusStop(myCurrentStop);
     if (!success) {
         delete myCurrentStop;
@@ -362,11 +412,48 @@ NLTriggerBuilder::buildStoppingPlace(MSNet& net, const std::string& id,
 
 
 void
-NLTriggerBuilder::buildChargingStation(MSNet& net, const std::string& id,
-                                       const std::vector<std::string>& lines,
-                                       MSLane* lane, SUMOReal frompos, SUMOReal topos, SUMOReal chrgpower, SUMOReal efficiency, SUMOReal chargeInTransit, SUMOReal ChargeDelay) {
+NLTriggerBuilder::beginParkingArea(MSNet& net, const std::string& id,
+                                   const std::vector<std::string>& lines,
+                                   MSLane* lane, double frompos, double topos,
+                                   unsigned int capacity,
+                                   double width, double length, double angle) {
+    // Close previous parking area if there are not lots inside
 
-    MSChargingStation* chargingStation = new MSChargingStation(id, lines, *lane, frompos, topos, chrgpower, efficiency, chargeInTransit, ChargeDelay);
+    MSParkingArea* stop = new MSParkingArea(id, lines, *lane, frompos, topos, capacity, width, length, angle);
+    if (!net.addParkingArea(stop)) {
+        delete stop;
+        throw InvalidArgument("Could not build parking area '" + id + "'; probably declared twice.");
+    } else {
+        myParkingArea = stop;
+    }
+}
+
+
+void
+NLTriggerBuilder::addLotEntry(double x, double y, double z,
+                              double width, double length, double angle) {
+    if (myParkingArea != 0) {
+        myParkingArea->addLotEntry(x, y, z, width, length, angle);
+    } else {
+        throw InvalidArgument("Could not add lot entry outside a parking area.");
+    }
+}
+
+
+void
+NLTriggerBuilder::endParkingArea() {
+    if (myParkingArea != 0) {
+        myParkingArea = 0;
+    } else {
+        throw InvalidArgument("Could not end a parking area that is not opened.");
+    }
+}
+
+
+void
+NLTriggerBuilder::buildChargingStation(MSNet& net, const std::string& id, MSLane* lane, double frompos, double topos,
+                                       double chargingPower, double efficiency, bool chargeInTransit, int ChargeDelay) {
+    MSChargingStation* chargingStation = new MSChargingStation(id, *lane, frompos, topos, chargingPower, efficiency, chargeInTransit, ChargeDelay);
 
     if (!net.addChargingStation(chargingStation)) {
         delete chargingStation;
@@ -409,12 +496,12 @@ NLTriggerBuilder::getLane(const SUMOSAXAttributes& attrs,
 }
 
 
-SUMOReal
+double
 NLTriggerBuilder::getPosition(const SUMOSAXAttributes& attrs,
                               MSLane* lane,
                               const std::string& tt, const std::string& tid) {
     bool ok = true;
-    SUMOReal pos = attrs.get<SUMOReal>(SUMO_ATTR_POSITION, 0, ok);
+    double pos = attrs.get<double>(SUMO_ATTR_POSITION, 0, ok);
     const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, 0, ok, false);
     if (!ok) {
         throw InvalidArgument("Error on parsing a position information.");
@@ -424,7 +511,7 @@ NLTriggerBuilder::getPosition(const SUMOSAXAttributes& attrs,
     }
     if (pos > lane->getLength()) {
         if (friendlyPos) {
-            pos = lane->getLength() - (SUMOReal) 0.1;
+            pos = lane->getLength() - (double) 0.1;
         } else {
             throw InvalidArgument("The position of " + tt + " '" + tid + "' lies beyond the lane's '" + lane->getID() + "' length.");
         }
