@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 04.05.2011
-/// @version $Id: NWWriter_SUMO.h 20550 2016-04-26 10:57:45Z namdre $
+/// @version $Id: NWWriter_SUMO.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Exporter writing networks using the SUMO format
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -126,7 +126,6 @@ protected:
 
     /** @brief Writes a lane (<lane ...) of an edge
      * @param[in] into The device to write the edge into
-     * @param[in] eID The ID of the edge
      * @param[in] lID The ID of the lane
      * @param[in] origID The original ID of the edge in the input
      * @param[in] length Lane's length
@@ -134,12 +133,13 @@ protected:
      * @param[in] origNames Whether original names shall be written as parameter
      * @param[in] oppositeID The ID of the opposite lane for overtaking
      * @param[in] node The node to check for custom shape data
+     * @param[in] accelRamp whether this lane is an acceleration lane
      */
-    static void writeLane(OutputDevice& into, const std::string& eID, const std::string& lID,
-                          SUMOReal speed, SVCPermissions permissions, SVCPermissions preferred,
-                          SUMOReal endOffset, SUMOReal width, PositionVector shape,
-                          const std::string& origID, SUMOReal length, unsigned int index, bool origNames,
-                          const std::string& oppositeID, const NBNode* node = 0);
+    static void writeLane(OutputDevice& into, const std::string& lID,
+                          double speed, SVCPermissions permissions, SVCPermissions preferred,
+                          double endOffset, double width, PositionVector shape,
+                          const std::string& origID, double length, int index, bool origNames,
+                          const std::string& oppositeID, const NBNode* node = 0, bool accelRamp = false);
 
 
     /** @brief Writes a junction (<junction ...)
