@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    19.01.2012
-/// @version $Id: GUIOSGView.cpp 21851 2016-10-31 12:20:12Z behrisch $
+/// @version $Id: GUIOSGView.cpp 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // An OSG-based 3D view on the simulation
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -38,6 +38,8 @@
 // osg may include windows.h somewhere so we need to guard against macro pollution
 #ifdef WIN32
 #define NOMINMAX
+#pragma warning(push)
+#pragma warning(disable: 4127) // do not warn about constant conditional expression
 #endif
 #include <osgViewer/Viewer>
 #include <osgViewer/ViewerEventHandlers>
@@ -48,6 +50,7 @@
 #include <osg/ShapeDrawable>
 #ifdef WIN32
 #undef NOMINMAX
+#pragma warning(pop)
 #endif
 #include <utils/gui/windows/GUISUMOAbstractView.h>
 #include <utils/gui/windows/GUIPerspectiveChanger.h>
@@ -86,10 +89,6 @@
 #include "GUIOSGBuilder.h"
 #include "GUIOSGView.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 FXDEFMAP(GUIOSGView) GUIOSGView_Map[] = {
     //________Message_Type_________        ___ID___                        ________Message_Handler________
@@ -282,7 +281,7 @@ GUIOSGView::recenterView() {
 
 
 void
-GUIOSGView::centerTo(GUIGlID id, bool /* applyZoom */, SUMOReal /* zoomDist */) {
+GUIOSGView::centerTo(GUIGlID id, bool /* applyZoom */, double /* zoomDist */) {
     startTrack(id);
 }
 
@@ -316,7 +315,7 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
             if (d.filename.length() == 6 && d.filename.substr(0, 5) == "light") {
                 GUIOSGBuilder::buildLight(d, *myRoot);
             } else if (d.filename.length() > 3 && d.filename.substr(0, 3) == "tl:") {
-                const int linkStringIdx = d.filename.find(':', 3);
+                const int linkStringIdx = (int)d.filename.find(':', 3);
                 GUINet* net = (GUINet*) MSNet::getInstance();
                 try {
                     MSTLLogicControl::TLSLogicVariants& vars = net->getTLSControl().get(d.filename.substr(3, linkStringIdx - 3));
@@ -326,10 +325,10 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
                     }
                     const MSLink* const l = vars.getActive()->getLinksAt(linkIdx)[0];
                     osg::Switch* switchNode = new osg::Switch();
-                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myGreenLight, osg::Vec4(0., 1., 0., .3)), false);
-                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myYellowLight, osg::Vec4(1., 1., 0., .3)), false);
-                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myRedLight, osg::Vec4(1., 0., 0., .3)), false);
-                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myRedYellowLight, osg::Vec4(1., .5, 0., .3)), false);
+                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myGreenLight, osg::Vec4d(0., 1., 0., .3)), false);
+                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myYellowLight, osg::Vec4d(1., 1., 0., .3)), false);
+                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myRedLight, osg::Vec4d(1., 0., 0., .3)), false);
+                    switchNode->addChild(GUIOSGBuilder::getTrafficLight(d, d.layer < 0 ? 0 : myRedYellowLight, osg::Vec4d(1., .5, 0., .3)), false);
                     myRoot->addChild(switchNode);
                     vars.addSwitchCommand(new Command_TLSChange(l, switchNode));
                 } catch (NumberFormatException&) {
@@ -355,11 +354,11 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
             myRoot->addChild(myVehicles[veh].pos);
         }
         osg::PositionAttitudeTransform* n = myVehicles[veh].pos;
-        n->setPosition(osg::Vec3(veh->getPosition().x(), veh->getPosition().y(), veh->getPosition().z()));
-        const SUMOReal dir = veh->getAngle() + PI / 2.;
-        const SUMOReal slope = veh->getSlope();
-        n->setAttitude(osg::Quat(dir, osg::Vec3(0, 0, 1)) *
-                       osg::Quat(osg::DegreesToRadians(slope), osg::Vec3(0, 1, 0)));
+        n->setPosition(osg::Vec3d(veh->getPosition().x(), veh->getPosition().y(), veh->getPosition().z()));
+        const double dir = veh->getAngle() + PI / 2.;
+        const double slope = veh->getSlope();
+        n->setAttitude(osg::Quat(dir, osg::Vec3d(0, 0, 1)) *
+                       osg::Quat(osg::DegreesToRadians(slope), osg::Vec3d(0, 1, 0)));
         /*
         osg::ref_ptr<osg::AnimationPath> path = new osg::AnimationPath;
         // path->setLoopMode( osg::AnimationPath::NO_LOOPING );
@@ -372,7 +371,7 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
         n->setUpdateCallback(new osg::AnimationPathCallback(path));
         */
         const RGBColor& col = myVisualizationSettings->vehicleColorer.getScheme().getColor(veh->getColorValue(myVisualizationSettings->vehicleColorer.getActive()));
-        myVehicles[veh].geom->setColor(osg::Vec4(col.red() / 255., col.green() / 255., col.blue() / 255., col.alpha() / 255.));
+        myVehicles[veh].geom->setColor(osg::Vec4d(col.red() / 255., col.green() / 255., col.blue() / 255., col.alpha() / 255.));
         myVehicles[veh].lights->setValue(0, veh->signalSet(MSVehicle::VEH_SIGNAL_BLINKER_RIGHT | MSVehicle::VEH_SIGNAL_BLINKER_EMERGENCY));
         myVehicles[veh].lights->setValue(1, veh->signalSet(MSVehicle::VEH_SIGNAL_BLINKER_LEFT | MSVehicle::VEH_SIGNAL_BLINKER_EMERGENCY));
         myVehicles[veh].lights->setValue(2, veh->signalSet(MSVehicle::VEH_SIGNAL_BRAKELIGHT));
@@ -387,7 +386,7 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
         lookAt[0] = myTracked->getPosition().x();
         lookAt[1] = myTracked->getPosition().y();
         lookAt[2] = myTracked->getPosition().z();
-        const SUMOReal angle = myTracked->getAngle();
+        const double angle = myTracked->getAngle();
         lookFrom[0] = lookAt[0] + 50. * cos(angle);
         lookFrom[1] = lookAt[1] + 50. * sin(angle);
         lookFrom[2] = lookAt[2] + 10.;
@@ -405,9 +404,9 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
         }
         osg::PositionAttitudeTransform* n = myPersons[person].pos;
         const Position pos = person->getPosition();
-        n->setPosition(osg::Vec3(pos.x(), pos.y(), pos.z()));
-        const SUMOReal dir = person->getAngle() + PI / 2.;
-        n->setAttitude(osg::Quat(dir, osg::Vec3(0, 0, 1)));
+        n->setPosition(osg::Vec3d(pos.x(), pos.y(), pos.z()));
+        const double dir = person->getAngle() + PI / 2.;
+        n->setAttitude(osg::Quat(dir, osg::Vec3d(0, 0, 1)));
     }
     if (myAdapter->makeCurrent()) {
         myViewer->frame();
@@ -516,7 +515,7 @@ GUIOSGView::onGamingClick(Position pos) {
     MSTLLogicControl& tlsControl = MSNet::getInstance()->getTLSControl();
     const std::vector<MSTrafficLightLogic*>& logics = tlsControl.getAllLogics();
     MSTrafficLightLogic* minTll = 0;
-    SUMOReal minDist = std::numeric_limits<SUMOReal>::infinity();
+    double minDist = std::numeric_limits<double>::infinity();
     for (std::vector<MSTrafficLightLogic*>::const_iterator i = logics.begin(); i != logics.end(); ++i) {
         // get the logic
         MSTrafficLightLogic* tll = (*i);
@@ -585,7 +584,7 @@ long GUIOSGView::onLeftBtnPress(FXObject* sender, FXSelector sel, void* ptr) {
     handle(this, FXSEL(SEL_FOCUS_SELF, 0), ptr);
 
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseButtonPress(event->click_x, event->click_y, 1);
+    myAdapter->getEventQueue()->mouseButtonPress((float)event->click_x, (float)event->click_y, 1);
     if (myApp->isGaming()) {
         onGamingClick(getPositionInformation());
     }
@@ -595,7 +594,7 @@ long GUIOSGView::onLeftBtnPress(FXObject* sender, FXSelector sel, void* ptr) {
 
 long GUIOSGView::onLeftBtnRelease(FXObject* sender, FXSelector sel, void* ptr) {
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseButtonRelease(event->click_x, event->click_y, 1);
+    myAdapter->getEventQueue()->mouseButtonRelease((float)event->click_x, (float)event->click_y, 1);
 
     return FXGLCanvas::onLeftBtnRelease(sender, sel, ptr);
 }
@@ -604,14 +603,14 @@ long GUIOSGView::onMiddleBtnPress(FXObject* sender, FXSelector sel, void* ptr) {
     handle(this, FXSEL(SEL_FOCUS_SELF, 0), ptr);
 
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseButtonPress(event->click_x, event->click_y, 2);
+    myAdapter->getEventQueue()->mouseButtonPress((float)event->click_x, (float)event->click_y, 2);
 
     return FXGLCanvas::onMiddleBtnPress(sender, sel, ptr);
 }
 
 long GUIOSGView::onMiddleBtnRelease(FXObject* sender, FXSelector sel, void* ptr) {
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseButtonRelease(event->click_x, event->click_y, 2);
+    myAdapter->getEventQueue()->mouseButtonRelease((float)event->click_x, (float)event->click_y, 2);
 
     return FXGLCanvas::onMiddleBtnRelease(sender, sel, ptr);
 }
@@ -620,14 +619,14 @@ long GUIOSGView::onRightBtnPress(FXObject* sender, FXSelector sel, void* ptr) {
     handle(this, FXSEL(SEL_FOCUS_SELF, 0), ptr);
 
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseButtonPress(event->click_x, event->click_y, 3);
+    myAdapter->getEventQueue()->mouseButtonPress((float)event->click_x, (float)event->click_y, 3);
 
     return FXGLCanvas::onRightBtnPress(sender, sel, ptr);
 }
 
 long GUIOSGView::onRightBtnRelease(FXObject* sender, FXSelector sel, void* ptr) {
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseButtonRelease(event->click_x, event->click_y, 3);
+    myAdapter->getEventQueue()->mouseButtonRelease((float)event->click_x, (float)event->click_y, 3);
 
     return FXGLCanvas::onRightBtnRelease(sender, sel, ptr);
 }
@@ -635,7 +634,7 @@ long GUIOSGView::onRightBtnRelease(FXObject* sender, FXSelector sel, void* ptr)
 long
 GUIOSGView::onMouseMove(FXObject* sender, FXSelector sel, void* ptr) {
     FXEvent* event = (FXEvent*)ptr;
-    myAdapter->getEventQueue()->mouseMotion(event->win_x, event->win_y);
+    myAdapter->getEventQueue()->mouseMotion((float)event->win_x, (float)event->win_y);
 
     return FXGLCanvas::onMotion(sender, sel, ptr);
 }
