@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: PCLoaderArcView.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: PCLoaderArcView.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A reader of pois and polygons from shape files
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -42,12 +42,15 @@
 #include <polyconvert/PCPolyContainer.h>
 
 #ifdef HAVE_GDAL
+#if __GNUC__ > 3
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpedantic"
+#endif
 #include <ogrsf_frmts.h>
+#if __GNUC__ > 3
+#pragma GCC diagnostic pop
+#endif
 #endif
-
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
 
 
 // ===========================================================================
@@ -79,7 +82,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
     std::string prefix = oc.getString("prefix");
     std::string type = oc.getString("type");
     RGBColor color = RGBColor::parseColor(oc.getString("color"));
-    SUMOReal layer = oc.getFloat("layer");
+    double layer = oc.getFloat("layer");
     std::string idField = oc.getString("shapefile.id-column");
     bool useRunningID = oc.getBool("shapefile.use-running-id");
     // start parsing
@@ -95,7 +98,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
     OGRDataSource* poDS = OGRSFDriverRegistrar::Open(shpName.c_str(), FALSE);
 #else
     GDALAllRegister();
-    GDALDataset* poDS = (GDALDataset*) GDALOpen(shpName.c_str(), GA_ReadOnly);
+    GDALDataset* poDS = (GDALDataset*) GDALOpenEx(shpName.c_str(), GDAL_OF_VECTOR | GA_ReadOnly, NULL, NULL, NULL);
 #endif
     if (poDS == NULL) {
         throw ProcessError("Could not open shape description '" + shpName + "'.");
@@ -147,7 +150,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
         switch (gtype) {
             case wkbPoint: {
                 OGRPoint* cgeom = (OGRPoint*) poGeometry;
-                Position pos((SUMOReal) cgeom->getX(), (SUMOReal) cgeom->getY());
+                Position pos((double) cgeom->getX(), (double) cgeom->getY());
                 if (!geoConvHelper.x2cartesian(pos)) {
                     WRITE_ERROR("Unable to project coordinates for POI '" + id + "'.");
                 }
@@ -162,7 +165,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                 OGRLineString* cgeom = (OGRLineString*) poGeometry;
                 PositionVector shape;
                 for (int j = 0; j < cgeom->getNumPoints(); j++) {
-                    Position pos((SUMOReal) cgeom->getX(j), (SUMOReal) cgeom->getY(j));
+                    Position pos((double) cgeom->getX(j), (double) cgeom->getY(j));
                     if (!geoConvHelper.x2cartesian(pos)) {
                         WRITE_ERROR("Unable to project coordinates for polygon '" + id + "'.");
                     }
@@ -179,7 +182,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                 OGRLinearRing* cgeom = ((OGRPolygon*) poGeometry)->getExteriorRing();
                 PositionVector shape;
                 for (int j = 0; j < cgeom->getNumPoints(); j++) {
-                    Position pos((SUMOReal) cgeom->getX(j), (SUMOReal) cgeom->getY(j));
+                    Position pos((double) cgeom->getX(j), (double) cgeom->getY(j));
                     if (!geoConvHelper.x2cartesian(pos)) {
                         WRITE_ERROR("Unable to project coordinates for polygon '" + id + "'.");
                     }
@@ -195,7 +198,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                 OGRMultiPoint* cgeom = (OGRMultiPoint*) poGeometry;
                 for (int i = 0; i < cgeom->getNumGeometries(); ++i) {
                     OGRPoint* cgeom2 = (OGRPoint*) cgeom->getGeometryRef(i);
-                    Position pos((SUMOReal) cgeom2->getX(), (SUMOReal) cgeom2->getY());
+                    Position pos((double) cgeom2->getX(), (double) cgeom2->getY());
                     std::string tid = id + "#" + toString(i);
                     if (!geoConvHelper.x2cartesian(pos)) {
                         WRITE_ERROR("Unable to project coordinates for POI '" + tid + "'.");
@@ -215,7 +218,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                     PositionVector shape;
                     std::string tid = id + "#" + toString(i);
                     for (int j = 0; j < cgeom2->getNumPoints(); j++) {
-                        Position pos((SUMOReal) cgeom2->getX(j), (SUMOReal) cgeom2->getY(j));
+                        Position pos((double) cgeom2->getX(j), (double) cgeom2->getY(j));
                         if (!geoConvHelper.x2cartesian(pos)) {
                             WRITE_ERROR("Unable to project coordinates for polygon '" + tid + "'.");
                         }
@@ -236,7 +239,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                     PositionVector shape;
                     std::string tid = id + "#" + toString(i);
                     for (int j = 0; j < cgeom2->getNumPoints(); j++) {
-                        Position pos((SUMOReal) cgeom2->getX(j), (SUMOReal) cgeom2->getY(j));
+                        Position pos((double) cgeom2->getX(j), (double) cgeom2->getY(j));
                         if (!geoConvHelper.x2cartesian(pos)) {
                             WRITE_ERROR("Unable to project coordinates for polygon '" + tid + "'.");
                         }
@@ -270,6 +273,11 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
         }
         OGRFeature::DestroyFeature(poFeature);
     }
+#if GDAL_VERSION_MAJOR < 2
+    OGRDataSource::DestroyDataSource(poDS);
+#else
+    GDALClose(poDS);
+#endif
     PROGRESS_DONE_MESSAGE();
 #else
     WRITE_ERROR("SUMO was compiled without GDAL support.");
