@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Thu, 02.11.2006
-/// @version $Id: PCNetProjectionLoader.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: PCNetProjectionLoader.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A reader for a SUMO network's projection description
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -50,10 +50,6 @@
 #include <utils/xml/SUMOXMLDefinitions.h>
 #include "PCNetProjectionLoader.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -93,8 +89,8 @@ PCNetProjectionLoader::load(const std::string& file, int shift) {
 PCNetProjectionLoader::PCNetProjectionLoader(int shift) :
     SUMOSAXHandler("sumo-network"),
     myFoundLocation(false),
-    myShift(shift)
-{}
+    myShift(shift) {
+}
 
 
 PCNetProjectionLoader::~PCNetProjectionLoader() {}
@@ -113,7 +109,8 @@ PCNetProjectionLoader::myStartElement(int element,
     Boundary origBoundary = attrs.get<Boundary>(SUMO_ATTR_ORIG_BOUNDARY, 0, myFoundLocation);
     std::string proj = attrs.get<std::string>(SUMO_ATTR_ORIG_PROJ, 0, myFoundLocation);
     if (myFoundLocation) {
-        Position networkOffset = s[0];
+        OptionsCont& oc = OptionsCont::getOptions();
+        Position networkOffset = s[0] + Position(oc.getFloat("offset.x"), oc.getFloat("offset.y"));
         GeoConvHelper::init(proj, networkOffset, origBoundary, convBoundary, myShift);
     }
 }
