@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Mon, 05 Dec 2005
-/// @version $Id: PCTypeMap.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: PCTypeMap.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A storage for type mappings
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2005-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2005-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -71,7 +71,7 @@ public:
         /// @brief The prefix to use
         std::string prefix;
         /// @brief The layer to use
-        int layer;
+        double layer;
         /// @brief Information whether polygons of this type shall be discarded
         bool discard;
         /// @brief Information whether polygons of this type can be filled
@@ -92,7 +92,7 @@ public:
      * @return Whether the type could been added (was not known before)
      */
     bool add(const std::string& id, const std::string& newid, const std::string& color,
-             const std::string& prefix, int layer, bool discard, bool allowFill);
+             const std::string& prefix, double layer, bool discard, bool allowFill);
 
 
     /** @brief Returns a type definition
