@@ -7,12 +7,12 @@
 /// @author  Melanie Knocke
 /// @author  Yun-Pang Floetteroed
 /// @date    Sept 2002
-/// @version $Id: ROEdge.h 20550 2016-04-26 10:57:45Z namdre $
+/// @version $Id: ROEdge.h 24122 2017-04-28 12:50:58Z namdre $
 ///
 // A basic edge for routing applications
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -105,7 +105,7 @@ public:
      * @param[in] to The node the edge ends at
      * @param[in] index The numeric id of the edge
      */
-    ROEdge(const std::string& id, RONode* from, RONode* to, unsigned int index, const int priority);
+    ROEdge(const std::string& id, RONode* from, RONode* to, int index, const int priority);
 
 
     /// Destructor
@@ -146,7 +146,7 @@ public:
     /** @brief Sets the vehicle class specific speed limits of the edge
      * @param[in] restrictions The restrictions for the edge
      */
-    inline void setRestrictions(const std::map<SUMOVehicleClass, SUMOReal>* restrictions) {
+    inline void setRestrictions(const std::map<SUMOVehicleClass, double>* restrictions) {
         myRestrictions = restrictions;
     }
 
@@ -195,14 +195,14 @@ public:
     /** @brief Returns the length of the edge
      * @return This edge's length
      */
-    SUMOReal getLength() const {
+    double getLength() const {
         return myLength;
     }
 
     /** @brief Returns the index (numeric id) of the edge
      * @return This edge's numerical id
      */
-    unsigned int getNumericalID() const {
+    int getNumericalID() const {
         return myIndex;
     }
 
@@ -210,7 +210,31 @@ public:
     /** @brief Returns the speed allowed on this edge
      * @return The speed allowed on this edge
      */
-    SUMOReal getSpeed() const {
+    double getSpeedLimit() const {
+        return mySpeed;
+    }
+
+    /// @brief return a lower bound on shape.length() / myLength that is
+    // sufficient for the astar air-distance heuristic
+    double getLengthGeometryFactor() const {
+        if (myFromJunction != 0 && myToJunction != 0) {
+            return MAX2(1.0, myFromJunction->getPosition().distanceTo(myToJunction->getPosition()) / myLength);
+        } else {
+            return 1.0;
+        }
+    }
+
+    /** @brief Returns the lane's maximum speed, given a vehicle's speed limit adaptation
+     * @param[in] The vehicle to return the adapted speed limit for
+     * @return This lane's resulting max. speed
+     */
+    inline double getVClassMaxSpeed(SUMOVehicleClass vclass) const {
+        if (myRestrictions != 0) {
+            std::map<SUMOVehicleClass, double>::const_iterator r = myRestrictions->find(vclass);
+            if (r != myRestrictions->end()) {
+                return r->second;
+            }
+        }
         return mySpeed;
     }
 
@@ -218,8 +242,8 @@ public:
     /** @brief Returns the number of lanes this edge has
      * @return This edge's number of lanes
      */
-    unsigned int getLaneNo() const {
-        return (unsigned int) myLanes.size();
+    int getLaneNo() const {
+        return (int) myLanes.size();
     }
 
 
@@ -264,7 +288,7 @@ public:
      * @param[in] timeBegin The begin time of the interval the given value is valid for [s]
      * @param[in] timeEnd The end time of the interval the given value is valid for [s]
      */
-    void addEffort(SUMOReal value, SUMOReal timeBegin, SUMOReal timeEnd);
+    void addEffort(double value, double timeBegin, double timeEnd);
 
 
     /** @brief Adds a travel time value
@@ -273,7 +297,7 @@ public:
      * @param[in] timeBegin The begin time of the interval the given value is valid for [s]
      * @param[in] timeEnd The end time of the interval the given value is valid for [s]
      */
-    void addTravelTime(SUMOReal value, SUMOReal timeBegin, SUMOReal timeEnd);
+    void addTravelTime(double value, double timeBegin, double timeEnd);
 
 
     /** @brief Returns the number of edges this edge is connected to
@@ -283,7 +307,7 @@ public:
      *
      * @return The number of edges following this edge
      */
-    unsigned int getNumSuccessors() const;
+    int getNumSuccessors() const;
 
 
     /** @brief Returns the following edges
@@ -307,7 +331,7 @@ public:
      *
      * @return The number of edges reaching into this edge
      */
-    unsigned int getNumPredecessors() const;
+    int getNumPredecessors() const;
 
 
     /** @brief Returns the edge at the given position from the list of incoming edges
@@ -326,7 +350,7 @@ public:
      * @return The effort needed by the given vehicle to pass the edge at the given time
      * @todo Recheck whether the vehicle's maximum speed is considered
      */
-    SUMOReal getEffort(const ROVehicle* const veh, SUMOReal time) const;
+    double getEffort(const ROVehicle* const veh, double time) const;
 
 
     /** @brief Returns whether a travel time for this edge was loaded
@@ -334,7 +358,7 @@ public:
      * @param[in] time The time for which the travel time shall be returned [s]
      * @return whether a value was loaded
      */
-    bool hasLoadedTravelTime(SUMOReal time) const;
+    bool hasLoadedTravelTime(double time) const;
 
 
     /** @brief Returns the travel time for this edge
@@ -343,7 +367,7 @@ public:
      * @param[in] time The time for which the travel time shall be returned [s]
      * @return The travel time needed by the given vehicle to pass the edge at the given time
      */
-    SUMOReal getTravelTime(const ROVehicle* const veh, SUMOReal time) const;
+    double getTravelTime(const ROVehicle* const veh, double time) const;
 
 
     /** @brief Returns the effort for the given edge
@@ -354,7 +378,7 @@ public:
      * @return The effort needed by the given vehicle to pass the edge at the given time
      * @todo Recheck whether the vehicle's maximum speed is considered
      */
-    static inline SUMOReal getEffortStatic(const ROEdge* const edge, const ROVehicle* const veh, SUMOReal time) {
+    static inline double getEffortStatic(const ROEdge* const edge, const ROVehicle* const veh, double time) {
         return edge->getEffort(veh, time);
     }
 
@@ -366,7 +390,7 @@ public:
      * @param[in] time The time for which the travel time shall be returned [s]
      * @return The traveltime needed by the given vehicle to pass the edge at the given time
      */
-    static inline SUMOReal getTravelTimeStatic(const ROEdge* const edge, const ROVehicle* const veh, SUMOReal time) {
+    static inline double getTravelTimeStatic(const ROEdge* const edge, const ROVehicle* const veh, double time) {
         return edge->getTravelTime(veh, time);
     }
 
@@ -376,38 +400,38 @@ public:
      * @param[in] veh The vehicle for which the effort on this edge shall be retrieved
      * @param[in] time The time for which the effort shall be returned [s]
      */
-    inline SUMOReal getMinimumTravelTime(const ROVehicle* const veh) const {
+    inline double getMinimumTravelTime(const ROVehicle* const veh) const {
         return myLength / MIN2(veh->getType()->maxSpeed, veh->getChosenSpeedFactor() * mySpeed);
     }
 
 
     template<PollutantsInterface::EmissionType ET>
-    static SUMOReal getEmissionEffort(const ROEdge* const edge, const ROVehicle* const veh, SUMOReal time) {
-        SUMOReal ret = 0;
+    static double getEmissionEffort(const ROEdge* const edge, const ROVehicle* const veh, double time) {
+        double ret = 0;
         if (!edge->getStoredEffort(time, ret)) {
             const SUMOVTypeParameter* const type = veh->getType();
-            const SUMOReal vMax = MIN2(type->maxSpeed, edge->mySpeed);
-            const SUMOReal accel = type->getCFParam(SUMO_ATTR_ACCEL, SUMOVTypeParameter::getDefaultAccel(type->vehicleClass)) * type->getCFParam(SUMO_ATTR_SIGMA, SUMOVTypeParameter::getDefaultImperfection(type->vehicleClass)) / 2.;
+            const double vMax = MIN2(type->maxSpeed, edge->mySpeed);
+            const double accel = type->getCFParam(SUMO_ATTR_ACCEL, SUMOVTypeParameter::getDefaultAccel(type->vehicleClass)) * type->getCFParam(SUMO_ATTR_SIGMA, SUMOVTypeParameter::getDefaultImperfection(type->vehicleClass)) / 2.;
             ret = PollutantsInterface::computeDefault(type->emissionClass, ET, vMax, accel, 0, edge->getTravelTime(veh, time)); // @todo: give correct slope
         }
         return ret;
     }
 
 
-    static SUMOReal getNoiseEffort(const ROEdge* const edge, const ROVehicle* const veh, SUMOReal time);
+    static double getNoiseEffort(const ROEdge* const edge, const ROVehicle* const veh, double time);
     //@}
 
 
     /// @brief optimistic distance heuristic for use in routing
-    SUMOReal getDistanceTo(const ROEdge* other) const;
+    double getDistanceTo(const ROEdge* other) const;
 
 
     /** @brief Returns all ROEdges */
     static const ROEdgeVector& getAllEdges();
 
     /// @brief Returns the number of edges
-    static size_t dictSize() {
-        return myEdges.size();
+    static int dictSize() {
+        return (int)myEdges.size();
     };
 
     static void setGlobalOptions(const bool interpolate) {
@@ -442,7 +466,7 @@ protected:
      * @param[in] time The tim for which the effort shall be returned
      * @return Whether the effort is given
      */
-    bool getStoredEffort(SUMOReal time, SUMOReal& ret) const;
+    bool getStoredEffort(double time, double& ret) const;
 
 
 
@@ -452,25 +476,25 @@ protected:
     RONode* myToJunction;
 
     /// @brief The index (numeric id) of the edge
-    const unsigned int myIndex;
+    const int myIndex;
 
     /// @brief The edge priority (road class)
     const int myPriority;
 
     /// @brief The maximum speed allowed on this edge
-    SUMOReal mySpeed;
+    double mySpeed;
 
     /// @brief The length of the edge
-    SUMOReal myLength;
+    double myLength;
 
 
     /// @brief Container storing passing time varying over time for the edge
-    mutable ValueTimeLine<SUMOReal> myTravelTimes;
+    mutable ValueTimeLine<double> myTravelTimes;
     /// @brief Information whether the time line shall be used instead of the length value
     bool myUsingTTTimeLine;
 
     /// @brief Container storing passing time varying over time for the edge
-    mutable ValueTimeLine<SUMOReal> myEfforts;
+    mutable ValueTimeLine<double> myEfforts;
     /// @brief Information whether the time line shall be used instead of the length value
     bool myUsingETimeLine;
 
@@ -492,7 +516,7 @@ protected:
     EdgeFunc myFunc;
 
     /// The vClass speed restrictions for this edge
-    const std::map<SUMOVehicleClass, SUMOReal>* myRestrictions;
+    const std::map<SUMOVehicleClass, double>* myRestrictions;
 
     /// @brief This edge's lanes
     std::vector<ROLane*> myLanes;
