@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: ROFrame.cpp 18620 2015-08-11 08:28:58Z namdre $
+/// @version $Id: ROFrame.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Sets and checks options for routing
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -42,10 +42,6 @@
 #include <utils/common/SUMOTime.h>
 #include "ROFrame.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -153,10 +149,8 @@ ROFrame::fillOptions(OptionsCont& oc, bool forDuarouter) {
     oc.doRegister("bulk-routing", new Option_Bool(false));
     oc.addDescription("bulk-routing", "Processing", "Aggregate routing queries with the same origin");
 
-#ifdef HAVE_FOX
     oc.doRegister("routing-threads", new Option_Integer(0));
     oc.addDescription("routing-threads", "Processing", "The number of parallel execution threads used for routing");
-#endif
 
     // register defaults options
     oc.doRegister("departlane", new Option_String());
@@ -199,9 +193,15 @@ ROFrame::checkOptions(OptionsCont& oc) {
     }
     //
     if (oc.getInt("max-alternatives") < 2) {
-        WRITE_ERROR("At least two alternatives should be enabled");
+        WRITE_ERROR("At least two alternatives should be enabled.");
         return false;
     }
+#ifndef HAVE_FOX
+    if (oc.getInt("routing-threads") > 1) {
+        WRITE_ERROR("Parallel routing is only possible when compiled with Fox.");
+        return false;
+    }
+#endif
     return true;
 }
 
