@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: ROLane.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: ROLane.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A single lane the router may use
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -34,7 +34,12 @@
 #include <vector>
 #include <utils/common/Named.h>
 #include <utils/common/SUMOVehicleClass.h>
-#include "ROEdge.h"
+
+
+// ===========================================================================
+// class declarations
+// ===========================================================================
+class ROEdge;
 
 
 // ===========================================================================
@@ -58,9 +63,9 @@ public:
      * @param[in] maxSpeed The maximum speed allowed on the lane
      * @param[in] permissions Vehicle classes that may pass this lane
      */
-    ROLane(const std::string& id, ROEdge* edge, SUMOReal length, SUMOReal maxSpeed, SVCPermissions permissions) :
-        Named(id), myEdge(edge), myLength(length), myMaxSpeed(maxSpeed), myPermissions(permissions)
-    {}
+    ROLane(const std::string& id, ROEdge* edge, double length, double maxSpeed, SVCPermissions permissions) :
+        Named(id), myEdge(edge), myLength(length), myMaxSpeed(maxSpeed), myPermissions(permissions) {
+    }
 
 
     /// @brief Destructor
@@ -70,7 +75,7 @@ public:
     /** @brief Returns the length of the lane
      * @return The length of this lane
      */
-    SUMOReal getLength() const {
+    double getLength() const {
         return myLength;
     }
 
@@ -78,7 +83,7 @@ public:
     /** @brief Returns the maximum speed allowed on this lane
      * @return The maximum speed allowed on this lane
      */
-    SUMOReal getSpeed() const {
+    double getSpeed() const {
         return myMaxSpeed;
     }
 
@@ -86,7 +91,7 @@ public:
     /** @brief Returns the list of allowed vehicle classes
      * @return The list of vehicle classes allowed on this lane
      */
-    inline SVCPermissions getPermissions() {
+    inline SVCPermissions getPermissions() const {
         return myPermissions;
     }
 
@@ -120,10 +125,10 @@ private:
     ROEdge* myEdge;
 
     /// @brief The length of the lane
-    SUMOReal myLength;
+    double myLength;
 
     /// @brief The maximum speed allowed on the lane
-    SUMOReal myMaxSpeed;
+    double myMaxSpeed;
 
     /// @brief The encoding of allowed vehicle classes
     SVCPermissions myPermissions;
