@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: ROLoader.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: ROLoader.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Loader for networks and route imports
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -135,7 +135,7 @@ protected:
          * @see SAXWeightsHandler::EdgeFloatTimeLineRetriever::addEdgeWeight
          */
         void addEdgeWeight(const std::string& id,
-                           SUMOReal val, SUMOReal beg, SUMOReal end) const;
+                           double val, double beg, double end) const;
 
     private:
         /// @brief The network edges shall be obtained from
@@ -166,7 +166,7 @@ protected:
          * @see SAXWeightsHandler::EdgeFloatTimeLineRetriever::addEdgeWeight
          */
         void addEdgeWeight(const std::string& id,
-                           SUMOReal val, SUMOReal beg, SUMOReal end) const;
+                           double val, double beg, double end) const;
 
     private:
         /// @brief The network edges shall be obtained from
@@ -177,7 +177,7 @@ protected:
 
 
 protected:
-    void writeStats(SUMOTime time, SUMOTime start, int absNo, bool endGiven);
+    void writeStats(const SUMOTime time, const SUMOTime start, const SUMOTime absNo, bool endGiven);
 
 
 private:
