@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: RORouteDef.cpp 21038 2016-06-27 06:15:50Z namdre $
+/// @version $Id: RORouteDef.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Base class for a vehicle's route definition
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -48,10 +48,6 @@
 #include "RORouteDef.h"
 #include "ROVehicle.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 // ===========================================================================
 // static members
 // ===========================================================================
@@ -60,7 +56,7 @@ bool RORouteDef::myUsingJTRR(false);
 // ===========================================================================
 // method definitions
 // ===========================================================================
-RORouteDef::RORouteDef(const std::string& id, const unsigned int lastUsed,
+RORouteDef::RORouteDef(const std::string& id, const int lastUsed,
                        const bool tryRepair, const bool mayBeDisconnected) :
     Named(StringUtils::convertUmlaute(id)),
     myPrecomputed(0), myLastUsed(lastUsed), myTryRepair(tryRepair), myMayBeDisconnected(mayBeDisconnected) {
@@ -152,7 +148,7 @@ RORouteDef::preComputeCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router
         repairCurrentRoute(router, begin, veh, oldEdges, edges);
         // check whether the same route was already used
         int cheapest = -1;
-        for (unsigned int i = 0; i < myAlternatives.size(); i++) {
+        for (int i = 0; i < (int)myAlternatives.size(); i++) {
             if (edges == myAlternatives[i]->getEdgeVector()) {
                 cheapest = i;
                 break;
@@ -176,7 +172,7 @@ RORouteDef::repairCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
     MsgHandler* mh = (OptionsCont::getOptions().getBool("ignore-errors") ?
                       MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance());
     ConstROEdgeVector mandatory;
-    const size_t initialSize = oldEdges.size();
+    const int initialSize = (int)oldEdges.size();
     if (initialSize == 1) {
         if (myUsingJTRR) {
             /// only ROJTRRouter is supposed to handle this type of input
@@ -288,7 +284,7 @@ RORouteDef::addAlternative(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
             delete myAlternatives[0];
             myAlternatives[0] = current;
         }
-        const SUMOReal costs = router.recomputeCosts(current->getEdgeVector(), veh, begin);
+        const double costs = router.recomputeCosts(current->getEdgeVector(), veh, begin);
         if (costs < 0) {
             throw ProcessError("Route '" + getID() + "' (vehicle '" + veh->getID() + "') is not valid.");
         }
@@ -300,11 +296,11 @@ RORouteDef::addAlternative(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
         myAlternatives.push_back(current);
     }
     // recompute the costs and (when a new route was added) scale the probabilities
-    const SUMOReal scale = SUMOReal(myAlternatives.size() - 1) / SUMOReal(myAlternatives.size());
+    const double scale = double(myAlternatives.size() - 1) / double(myAlternatives.size());
     for (std::vector<RORoute*>::iterator i = myAlternatives.begin(); i != myAlternatives.end(); i++) {
         RORoute* alt = *i;
         // recompute the costs for all routes
-        const SUMOReal newCosts = router.recomputeCosts(alt->getEdgeVector(), veh, begin);
+        const double newCosts = router.recomputeCosts(alt->getEdgeVector(), veh, begin);
         if (newCosts < 0.) {
             throw ProcessError("Route '" + current->getID() + "' (vehicle '" + veh->getID() + "') is not valid.");
         }
@@ -312,7 +308,7 @@ RORouteDef::addAlternative(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
         if (myNewRoute) {
             if (*i == current) {
                 // set initial probability and costs
-                alt->setProbability((SUMOReal)(1.0 / (SUMOReal) myAlternatives.size()));
+                alt->setProbability((double)(1.0 / (double) myAlternatives.size()));
                 alt->setCosts(newCosts);
             } else {
                 // rescale probs for all others
@@ -334,7 +330,7 @@ RORouteDef::addAlternative(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
             }
         }
     }
-    if (myAlternatives.size() > RouteCostCalculator<RORoute, ROEdge, ROVehicle>::getCalculator().getMaxRouteNumber()) {
+    if ((int)myAlternatives.size() > RouteCostCalculator<RORoute, ROEdge, ROVehicle>::getCalculator().getMaxRouteNumber()) {
         // only keep the routes with highest probability
         sort(myAlternatives.begin(), myAlternatives.end(), ComparatorProbability());
         for (std::vector<RORoute*>::iterator i = myAlternatives.begin() + RouteCostCalculator<RORoute, ROEdge, ROVehicle>::getCalculator().getMaxRouteNumber(); i != myAlternatives.end(); i++) {
@@ -342,7 +338,7 @@ RORouteDef::addAlternative(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
         }
         myAlternatives.erase(myAlternatives.begin() + RouteCostCalculator<RORoute, ROEdge, ROVehicle>::getCalculator().getMaxRouteNumber(), myAlternatives.end());
         // rescale probabilities
-        SUMOReal newSum = 0;
+        double newSum = 0;
         for (std::vector<RORoute*>::iterator i = myAlternatives.begin(); i != myAlternatives.end(); i++) {
             newSum += (*i)->getProbability();
         }
@@ -354,7 +350,7 @@ RORouteDef::addAlternative(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
     }
 
     // find the route to use
-    SUMOReal chosen = RandHelper::rand();
+    double chosen = RandHelper::rand();
     int pos = 0;
     for (std::vector<RORoute*>::iterator i = myAlternatives.begin(); i != myAlternatives.end() - 1; i++, pos++) {
         chosen -= (*i)->getProbability();
@@ -378,7 +374,7 @@ RORouteDef::writeXMLDefinition(OutputDevice& dev, const ROVehicle* const veh,
                                bool asAlternatives, bool withExitTimes) const {
     if (asAlternatives) {
         dev.openTag(SUMO_TAG_ROUTE_DISTRIBUTION).writeAttr(SUMO_ATTR_LAST, myLastUsed);
-        for (size_t i = 0; i != myAlternatives.size(); i++) {
+        for (int i = 0; i != (int)myAlternatives.size(); i++) {
             myAlternatives[i]->writeXMLDefinition(dev, veh, true, withExitTimes);
         }
         dev.closeTag();
@@ -416,9 +412,9 @@ RORouteDef::copy(const std::string& id, const SUMOTime stopOffset) const {
 }
 
 
-SUMOReal
+double
 RORouteDef::getOverallProb() const {
-    SUMOReal sum = 0.;
+    double sum = 0.;
     for (std::vector<RORoute*>::const_iterator i = myAlternatives.begin(); i != myAlternatives.end(); i++) {
         sum += (*i)->getProbability();
     }
