@@ -5,12 +5,12 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: RORouteHandler.cpp 21236 2016-07-25 14:24:30Z namdre $
+/// @version $Id: RORouteHandler.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Parser and container for routes during their loading
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -53,10 +53,6 @@
 #include "RORouteDef.h"
 #include "RORouteHandler.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -182,16 +178,16 @@ RORouteHandler::myStartElement(int element,
         case SUMO_TAG_WALK: {
             bool ok = true;
             const char* const objId = myVehicleParameter->id.c_str();
-            const SUMOTime duration = attrs.getOptSUMOTimeReporting(SUMO_ATTR_DURATION, objId, ok, -1);
+            const double duration = attrs.getOpt<double>(SUMO_ATTR_DURATION, objId, ok, -1);
             if (attrs.hasAttribute(SUMO_ATTR_DURATION) && duration <= 0) {
                 throw ProcessError("Non-positive walking duration for  '" + myVehicleParameter->id + "'.");
             }
-            const SUMOReal speed = attrs.getOpt<SUMOReal>(SUMO_ATTR_SPEED, objId, ok, -1.);
+            const double speed = attrs.getOpt<double>(SUMO_ATTR_SPEED, objId, ok, -1.);
             if (attrs.hasAttribute(SUMO_ATTR_SPEED) && speed <= 0) {
                 throw ProcessError("Non-positive walking speed for  '" + myVehicleParameter->id + "'.");
             }
-            const SUMOReal departPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_DEPARTPOS, objId, ok, std::numeric_limits<SUMOReal>::infinity());
-            const SUMOReal arrivalPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ARRIVALPOS, objId, ok, std::numeric_limits<SUMOReal>::infinity());
+            const double departPos = attrs.getOpt<double>(SUMO_ATTR_DEPARTPOS, objId, ok, std::numeric_limits<double>::infinity());
+            const double arrivalPos = attrs.getOpt<double>(SUMO_ATTR_ARRIVALPOS, objId, ok, std::numeric_limits<double>::infinity());
             const std::string busStop = attrs.getOpt<std::string>(SUMO_ATTR_BUS_STOP, objId, ok, "");
             if (!ok) {
                 break;
@@ -263,7 +259,7 @@ RORouteHandler::openVehicleTypeDistribution(const SUMOSAXAttributes& attrs) {
             StringTokenizer st(vTypes);
             while (st.hasNext()) {
                 SUMOVTypeParameter* type = myNet.getVehicleTypeSecure(st.next());
-                myCurrentVTypeDistribution->add(1., type);
+                myCurrentVTypeDistribution->add(type, 1.);
             }
         }
     }
@@ -323,13 +319,13 @@ RORouteHandler::openRoute(const SUMOSAXAttributes& attrs) {
     if (myCurrentAlternatives != 0 && !attrs.hasAttribute(SUMO_ATTR_PROB)) {
         WRITE_WARNING("No probability for a route in '" + rid + "', using default.");
     }
-    myActiveRouteProbability = attrs.getOpt<SUMOReal>(SUMO_ATTR_PROB, myActiveRouteID.c_str(), ok, DEFAULT_VEH_PROB);
+    myActiveRouteProbability = attrs.getOpt<double>(SUMO_ATTR_PROB, myActiveRouteID.c_str(), ok, DEFAULT_VEH_PROB);
     if (ok && myActiveRouteProbability < 0) {
         myErrorOutput->inform("Invalid probability for route '" + myActiveRouteID + "'.");
     }
     myActiveRouteColor = attrs.hasAttribute(SUMO_ATTR_COLOR) ? new RGBColor(attrs.get<RGBColor>(SUMO_ATTR_COLOR, myActiveRouteID.c_str(), ok)) : 0;
     ok = true;
-    myCurrentCosts = attrs.getOpt<SUMOReal>(SUMO_ATTR_COST, myActiveRouteID.c_str(), ok, -1);
+    myCurrentCosts = attrs.getOpt<double>(SUMO_ATTR_COST, myActiveRouteID.c_str(), ok, -1);
     if (ok && myCurrentCosts != -1 && myCurrentCosts < 0) {
         myErrorOutput->inform("Invalid cost for route '" + myActiveRouteID + "'.");
     }
@@ -343,7 +339,7 @@ RORouteHandler::myEndElement(int element) {
         case SUMO_TAG_VTYPE:
             if (myNet.addVehicleType(myCurrentVType)) {
                 if (myCurrentVTypeDistribution != 0) {
-                    myCurrentVTypeDistribution->add(myCurrentVType->defaultProbability, myCurrentVType);
+                    myCurrentVTypeDistribution->add(myCurrentVType, myCurrentVType->defaultProbability);
                 }
             }
             myCurrentVType = 0;
@@ -485,6 +481,9 @@ RORouteHandler::closeVehicle() {
         // fix the type id in case we used a distribution
         myVehicleParameter->vtypeid = type->id;
     }
+    if (type->vehicleClass == SVC_PEDESTRIAN) {
+        WRITE_WARNING("Vehicle type '" + type->id + "' with vClass=pedestrian should only be used for persons and not for vehicle '" + myVehicleParameter->id + "'.");
+    }
     // get the route
     RORouteDef* route = myNet.getRouteDef(myVehicleParameter->routeid);
     if (route == 0) {
@@ -623,11 +622,21 @@ RORouteHandler::addStop(const SUMOSAXAttributes& attrs) {
         stop.endPos = containerstop->endPos;
         stop.startPos = containerstop->startPos;
         edge = myNet.getEdge(stop.lane.substr(0, stop.lane.rfind('_')));
+    } // try to parse the assigned parking area
+    else if (stop.parkingarea != "") {
+        const SUMOVehicleParameter::Stop* parkingarea = myNet.getParkingArea(stop.parkingarea);
+        if (parkingarea == 0) {
+            myErrorOutput->inform("Unknown parking area '" + stop.parkingarea + "'" + errorSuffix);
+        }
+        stop.lane = parkingarea->lane;
+        stop.endPos = parkingarea->endPos;
+        stop.startPos = parkingarea->startPos;
+        edge = myNet.getEdge(stop.lane.substr(0, stop.lane.rfind('_')));
     } else {
         // no, the lane and the position should be given
         stop.lane = attrs.getOpt<std::string>(SUMO_ATTR_LANE, 0, ok, "");
         if (!ok || stop.lane == "") {
-            myErrorOutput->inform("A stop must be placed on a bus stop, a container stop or a lane" + errorSuffix);
+            myErrorOutput->inform("A stop must be placed on a bus stop, a container stop, a parking area or a lane" + errorSuffix);
             return;
         }
         edge = myNet.getEdge(stop.lane.substr(0, stop.lane.rfind('_')));
@@ -635,8 +644,8 @@ RORouteHandler::addStop(const SUMOSAXAttributes& attrs) {
             myErrorOutput->inform("The lane '" + stop.lane + "' for a stop is not known" + errorSuffix);
             return;
         }
-        stop.endPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ENDPOS, 0, ok, edge->getLength());
-        stop.startPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_STARTPOS, 0, ok, stop.endPos - 2 * POSITION_EPS);
+        stop.endPos = attrs.getOpt<double>(SUMO_ATTR_ENDPOS, 0, ok, edge->getLength());
+        stop.startPos = attrs.getOpt<double>(SUMO_ATTR_STARTPOS, 0, ok, stop.endPos - 2 * POSITION_EPS);
         const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, 0, ok, false);
         if (!ok || !checkStopPos(stop.startPos, stop.endPos, edge->getLength(), POSITION_EPS, friendlyPos)) {
             myErrorOutput->inform("Invalid start or end position for stop" + errorSuffix);
@@ -702,8 +711,8 @@ RORouteHandler::addPersonTrip(const SUMOSAXAttributes& attrs) {
                               + "\n The route can not be build.");
         ok = false;
     }
-    const SUMOReal departPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_DEPARTPOS, id, ok, 0);
-    const SUMOReal arrivalPos = attrs.getOpt<SUMOReal>(SUMO_ATTR_ARRIVALPOS, id, ok, -NUMERICAL_EPS);
+    const double departPos = attrs.getOpt<double>(SUMO_ATTR_DEPARTPOS, id, ok, 0);
+    const double arrivalPos = attrs.getOpt<double>(SUMO_ATTR_ARRIVALPOS, id, ok, -NUMERICAL_EPS);
     SVCPermissions modeSet = 0;
     for (StringTokenizer st(modes); st.hasNext();) {
         const std::string mode = st.next();
@@ -717,8 +726,9 @@ RORouteHandler::addPersonTrip(const SUMOSAXAttributes& attrs) {
             throw InvalidArgument("Unknown person mode '" + mode + "'.");
         }
     }
+    double walkFactor = attrs.getOpt<double>(SUMO_ATTR_WALKFACTOR, id, ok, OptionsCont::getOptions().getFloat("persontrip.walkfactor"));
     if (ok) {
-        myActivePerson->addTrip(from, to, modeSet, types, departPos, arrivalPos, busStop);
+        myActivePerson->addTrip(from, to, modeSet, types, departPos, arrivalPos, busStop, walkFactor);
     }
     return ok;
 }
