@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: ROVehicle.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: ROVehicle.h 23362 2017-03-14 09:16:46Z behrisch $
 ///
 // A vehicle as used by router
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -38,15 +38,16 @@
 #include <utils/common/SUMOTime.h>
 #include <utils/vehicle/SUMOVehicleParameter.h>
 #include <utils/vehicle/SUMOVTypeParameter.h>
+#include "RORoutable.h"
 
 
 // ===========================================================================
 // class declarations
 // ===========================================================================
-class RORouteDef;
 class OutputDevice;
 class ROEdge;
 class RONet;
+class RORouteDef;
 
 
 // ===========================================================================
@@ -56,7 +57,7 @@ class RONet;
  * @class ROVehicle
  * @brief A vehicle as used by router
  */
-class ROVehicle {
+class ROVehicle : public RORoutable {
 public:
     /** @brief Constructor
      *
@@ -66,7 +67,7 @@ public:
      */
     ROVehicle(const SUMOVehicleParameter& pars,
               RORouteDef* route, const SUMOVTypeParameter* type,
-              const RONet* net);
+              const RONet* net, MsgHandler* errorHandler = 0);
 
 
     /// @brief Destructor
@@ -79,114 +80,80 @@ public:
      *
      * @todo Why not return a reference?
      */
-    RORouteDef* getRouteDefinition() const {
+    inline RORouteDef* getRouteDefinition() const {
         return myRoute;
     }
 
 
-    /** @brief Returns the type of the vehicle
+    /** @brief Returns the definition of the vehicle parameter
      *
-     * @return The vehicle's type
-     *
-     * @todo Why not return a reference?
+     * @return The vehicle's parameter
      */
-    const SUMOVTypeParameter* getType() const {
-        return myType;
+    inline const SUMOVehicleParameter& getParameter() const {
+        return myParameter;
     }
 
 
-    /** @brief Returns the id of the vehicle
+    /** @brief Returns the first edge the vehicle takes
      *
-     * @return The id of the vehicle
+     * @return The vehicle's departure edge
      */
-    const std::string& getID() const {
-        return myParameter.id;
-    }
+    const ROEdge* getDepartEdge() const;
 
 
+    void computeRoute(const RORouterProvider& provider,
+                      const bool removeLoops, MsgHandler* errorHandler);
+
     /** @brief Returns the time the vehicle starts at, 0 for triggered vehicles
      *
      * @return The vehicle's depart time
      */
-    SUMOTime getDepartureTime() const {
-        return MAX2(0, myParameter.depart);
+    inline SUMOTime getDepartureTime() const {
+        return MAX2(SUMOTime(0), myParameter.depart);
     }
 
-    /** @brief Returns the time the vehicle starts at, -1 for triggered vehicles
-     *
-     * @return The vehicle's depart time
-     */
-    SUMOTime getDepart() const {
-        return myParameter.depart;
-    }
 
-    const std::vector<const ROEdge*>& getStopEdges() const {
+    inline const ConstROEdgeVector& getStopEdges() const {
         return myStopEdges;
     }
 
-    /// @brief Returns the vehicle's maximum speed
-    SUMOReal getMaxSpeed() const;
-
-
-    inline SUMOVehicleClass getVClass() const {
-        return getType() != 0 ? getType()->vehicleClass : SVC_IGNORING;
-    }
-
     /** @brief Returns an upper bound for the speed factor of this vehicle
      *
      * @return the maximum speed factor
      */
-    inline SUMOReal getChosenSpeedFactor() const {
-        return SUMOReal(2. * getType()->speedDev + 1.) * getType()->speedFactor;
+    inline double getChosenSpeedFactor() const {
+        return getType()->speedFactor.getMax();
     }
 
 
     /** @brief Saves the complete vehicle description.
      *
-     * Saves the vehicle type if it was not saved before.
-     * Saves the vehicle route if it was not saved before.
-     * Saves the vehicle itself.
+     * Saves the vehicle itself including the route and stops.
      *
-     * @param[in] os The routes - output device to store the vehicle's description into
-     * @param[in] altos The route alternatives - output device to store the vehicle's description into
-     * @param[in] typeos The types - output device to store the vehicle types into
-     * @param[in] withExitTimes whether exit times for the edges shall be written
+     * @param[in] os The routes or alternatives output device to store the vehicle's description into
+     * @param[in] typeos The types - output device to store types into
+     * @param[in] asAlternatives Whether the route shall be saved as route alternatives
+     * @param[in] options to find out about defaults and whether exit times for the edges shall be written
      * @exception IOError If something fails (not yet implemented)
      */
-    void saveAllAsXML(OutputDevice& os, OutputDevice* const altos,
-                      OutputDevice* const typeos, bool withExitTimes) const;
+    void saveAsXML(OutputDevice& os, OutputDevice* const typeos, bool asAlternatives, OptionsCont& options) const;
 
-    inline void setRoutingSuccess(const bool val) {
-        myRoutingSuccess = val;
-    }
 
-    inline bool getRoutingSuccess() const {
-        return myRoutingSuccess;
-    }
 private:
     /** @brief Adds a stop to this vehicle
      *
      * @param[in] stopPar the stop paramters
      * @param[in] net     pointer to the network, used for edge retrieval
      */
-    void addStop(const SUMOVehicleParameter::Stop& stopPar, const RONet* net);
-
-
-protected:
-    /// @brief The vehicle's parameter
-    SUMOVehicleParameter myParameter;
-
-    /// @brief The type of the vehicle
-    const SUMOVTypeParameter* const myType;
+    void addStop(const SUMOVehicleParameter::Stop& stopPar,
+                 const RONet* net, MsgHandler* errorHandler);
 
+private:
     /// @brief The route the vehicle takes
     RORouteDef* const myRoute;
 
     /// @brief The edges where the vehicle stops
-    std::vector<const ROEdge*> myStopEdges;
-
-    /// @brief Whether the last routing was successful
-    bool myRoutingSuccess;
+    ConstROEdgeVector myStopEdges;
 
 
 private:
@@ -202,4 +169,3 @@ private:
 #endif
 
 /****************************************************************************/
-
