@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    07.05.2009
-/// @version $Id: TraCIServerAPI_Lane.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: TraCIServerAPI_Lane.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // APIs for getting/setting lane values via TraCI
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2009-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2009-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -88,7 +88,7 @@ public:
     public:
         /// @brief Constructor
         StoringVisitor(std::set<std::string>& ids, const PositionVector& shape,
-                       const SUMOReal range, const int domain)
+                       const double range, const int domain)
             : myIDs(ids), myShape(shape), myRange(range), myDomain(domain) {}
 
         /// @brief Destructor
@@ -100,7 +100,7 @@ public:
         /// @brief The container
         std::set<std::string>& myIDs;
         const PositionVector& myShape;
-        const SUMOReal myRange;
+        const double myRange;
         const int myDomain;
 
     private:
