@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Sept 2002
-/// @version $Id: TraCIServerAPI_Simulation.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: TraCIServerAPI_Simulation.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // APIs for getting/setting edge values via TraCI
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -42,13 +42,10 @@
 #include <microsim/MSLane.h>
 #include <microsim/MSVehicle.h>
 #include <microsim/MSStateHandler.h>
+#include <traci-server/lib/TraCI.h>
 #include "TraCIConstants.h"
 #include "TraCIServerAPI_Simulation.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -264,17 +261,17 @@ TraCIServerAPI_Simulation::writeVehicleStateIDs(TraCIServer& server, tcpip::Stor
 }
 
 
-std::pair<MSLane*, SUMOReal>
+std::pair<MSLane*, double>
 TraCIServerAPI_Simulation::convertCartesianToRoadMap(Position pos) {
-    std::pair<MSLane*, SUMOReal> result;
+    std::pair<MSLane*, double> result;
     std::vector<std::string> allEdgeIds;
-    SUMOReal minDistance = std::numeric_limits<SUMOReal>::max();
+    double minDistance = std::numeric_limits<double>::max();
 
     allEdgeIds = MSNet::getInstance()->getEdgeControl().getEdgeNames();
     for (std::vector<std::string>::iterator itId = allEdgeIds.begin(); itId != allEdgeIds.end(); itId++) {
         const std::vector<MSLane*>& allLanes = MSEdge::dictionary((*itId))->getLanes();
         for (std::vector<MSLane*>::const_iterator itLane = allLanes.begin(); itLane != allLanes.end(); itLane++) {
-            const SUMOReal newDistance = (*itLane)->getShape().distance(pos);
+            const double newDistance = (*itLane)->getShape().distance2D(pos);
             if (newDistance < minDistance) {
                 minDistance = newDistance;
                 result.first = (*itLane);
@@ -287,30 +284,13 @@ TraCIServerAPI_Simulation::convertCartesianToRoadMap(Position pos) {
 }
 
 
-const MSLane*
-TraCIServerAPI_Simulation::getLaneChecking(std::string roadID, int laneIndex, SUMOReal pos) {
-    const MSEdge* edge = MSEdge::dictionary(roadID);
-    if (edge == 0) {
-        throw TraCIException("Unknown edge " + roadID);
-    }
-    if (laneIndex < 0 || laneIndex >= (int)edge->getLanes().size()) {
-        throw TraCIException("Invalid lane index for " + roadID);
-    }
-    const MSLane* lane = edge->getLanes()[laneIndex];
-    if (pos < 0 || pos > lane->getLength()) {
-        throw TraCIException("Position on lane invalid");
-    }
-    return lane;
-}
-
-
 bool
 TraCIServerAPI_Simulation::commandPositionConversion(TraCIServer& server, tcpip::Storage& inputStorage,
         tcpip::Storage& outputStorage, int commandId) {
-    std::pair<MSLane*, SUMOReal> roadPos;
+    std::pair<MSLane*, double> roadPos;
     Position cartesianPos;
     Position geoPos;
-    SUMOReal z = 0;
+    double z = 0;
 
     // actual position type that will be converted
     int srcPosType = inputStorage.readUnsignedByte();
@@ -320,8 +300,8 @@ TraCIServerAPI_Simulation::commandPositionConversion(TraCIServer& server, tcpip:
         case POSITION_3D:
         case POSITION_LON_LAT:
         case POSITION_LON_LAT_ALT: {
-            SUMOReal x = inputStorage.readDouble();
-            SUMOReal y = inputStorage.readDouble();
+            double x = inputStorage.readDouble();
+            double y = inputStorage.readDouble();
             if (srcPosType != POSITION_2D && srcPosType != POSITION_LON_LAT) {
                 z = inputStorage.readDouble();
             }
@@ -336,11 +316,11 @@ TraCIServerAPI_Simulation::commandPositionConversion(TraCIServer& server, tcpip:
         break;
         case POSITION_ROADMAP: {
             std::string roadID = inputStorage.readString();
-            SUMOReal pos = inputStorage.readDouble();
+            double pos = inputStorage.readDouble();
             int laneIdx = inputStorage.readUnsignedByte();
             try {
                 // convert edge,offset,laneIdx to cartesian position
-                cartesianPos = geoPos = getLaneChecking(roadID, laneIdx, pos)->getShape().positionAtOffset(pos);
+                cartesianPos = geoPos = TraCI::getLaneChecking(roadID, laneIdx, pos)->getShape().positionAtOffset(pos);
                 z = cartesianPos.z();
                 GeoConvHelper::getFinal().cartesian2geo(geoPos);
             } catch (TraCIException& e) {
@@ -402,8 +382,8 @@ TraCIServerAPI_Simulation::commandDistanceRequest(TraCIServer& server, tcpip::St
         tcpip::Storage& outputStorage, int commandId) {
     Position pos1;
     Position pos2;
-    std::pair<const MSLane*, SUMOReal> roadPos1;
-    std::pair<const MSLane*, SUMOReal> roadPos2;
+    std::pair<const MSLane*, double> roadPos1;
+    std::pair<const MSLane*, double> roadPos2;
 
     // read position 1
     int posType = inputStorage.readUnsignedByte();
@@ -412,7 +392,7 @@ TraCIServerAPI_Simulation::commandDistanceRequest(TraCIServer& server, tcpip::St
             try {
                 std::string roadID = inputStorage.readString();
                 roadPos1.second = inputStorage.readDouble();
-                roadPos1.first = getLaneChecking(roadID, inputStorage.readUnsignedByte(), roadPos1.second);
+                roadPos1.first = TraCI::getLaneChecking(roadID, inputStorage.readUnsignedByte(), roadPos1.second);
                 pos1 = roadPos1.first->getShape().positionAtOffset(roadPos1.second);
             } catch (TraCIException& e) {
                 server.writeStatusCmd(commandId, RTYPE_ERR, e.what());
@@ -421,8 +401,8 @@ TraCIServerAPI_Simulation::commandDistanceRequest(TraCIServer& server, tcpip::St
             break;
         case POSITION_2D:
         case POSITION_3D: {
-            SUMOReal p1x = inputStorage.readDouble();
-            SUMOReal p1y = inputStorage.readDouble();
+            double p1x = inputStorage.readDouble();
+            double p1y = inputStorage.readDouble();
             pos1.set(p1x, p1y);
         }
         if (posType == POSITION_3D) {
@@ -442,7 +422,7 @@ TraCIServerAPI_Simulation::commandDistanceRequest(TraCIServer& server, tcpip::St
             try {
                 std::string roadID = inputStorage.readString();
                 roadPos2.second = inputStorage.readDouble();
-                roadPos2.first = getLaneChecking(roadID, inputStorage.readUnsignedByte(), roadPos2.second);
+                roadPos2.first = TraCI::getLaneChecking(roadID, inputStorage.readUnsignedByte(), roadPos2.second);
                 pos2 = roadPos2.first->getShape().positionAtOffset(roadPos2.second);
             } catch (TraCIException& e) {
                 server.writeStatusCmd(commandId, RTYPE_ERR, e.what());
@@ -451,8 +431,8 @@ TraCIServerAPI_Simulation::commandDistanceRequest(TraCIServer& server, tcpip::St
             break;
         case POSITION_2D:
         case POSITION_3D: {
-            SUMOReal p2x = inputStorage.readDouble();
-            SUMOReal p2y = inputStorage.readDouble();
+            double p2x = inputStorage.readDouble();
+            double p2y = inputStorage.readDouble();
             pos2.set(p2x, p2y);
         }
         if (posType == POSITION_3D) {
@@ -468,7 +448,7 @@ TraCIServerAPI_Simulation::commandDistanceRequest(TraCIServer& server, tcpip::St
     // read distance type
     int distType = inputStorage.readUnsignedByte();
 
-    SUMOReal distance = 0.0;
+    double distance = 0.0;
     if (distType == REQUEST_DRIVINGDIST) {
         // compute driving distance
         if ((roadPos1.first == roadPos2.first) && (roadPos1.second <= roadPos2.second)) {
