@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    07.05.2009
-/// @version $Id: TraCIServerAPI_TLS.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: TraCIServerAPI_TLS.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // APIs for getting/setting traffic light values via TraCI
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2009-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2009-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -40,10 +40,6 @@
 #include <microsim/traffic_lights/MSSimpleTrafficLightLogic.h>
 #include "TraCIServerAPI_TLS.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -94,11 +90,11 @@ TraCIServerAPI_TLS::processGet(TraCIServer& server, tcpip::Storage& inputStorage
                 std::vector<MSTrafficLightLogic*> logics = vars.getAllLogics();
                 tempMsg.writeUnsignedByte(TYPE_COMPOUND);
                 tcpip::Storage tempContent;
-                unsigned int cnt = 0;
+                int cnt = 0;
                 tempContent.writeUnsignedByte(TYPE_INTEGER);
                 tempContent.writeInt((int) logics.size());
                 ++cnt;
-                for (unsigned int i = 0; i < logics.size(); ++i) {
+                for (int i = 0; i < (int)logics.size(); ++i) {
                     MSTrafficLightLogic* logic = logics[i];
                     tempContent.writeUnsignedByte(TYPE_STRING);
                     tempContent.writeString(logic->getProgramID());
@@ -132,7 +128,7 @@ TraCIServerAPI_TLS::processGet(TraCIServer& server, tcpip::Storage& inputStorage
                         tempContent.writeInt((int)phase.maxDuration);
                         ++cnt; // not implemented
                         const std::string& state = phase.getState();
-                        //unsigned int linkNo = (unsigned int)(vars.getActive()->getLinks().size());
+                        //int linkNo = (int)(vars.getActive()->getLinks().size());
                         tempContent.writeUnsignedByte(TYPE_STRING);
                         tempContent.writeString(state);
                         ++cnt;
@@ -161,19 +157,19 @@ TraCIServerAPI_TLS::processGet(TraCIServer& server, tcpip::Storage& inputStorage
                 //
                 tempMsg.writeUnsignedByte(TYPE_COMPOUND);
                 tcpip::Storage tempContent;
-                unsigned int cnt = 0;
+                int cnt = 0;
                 tempContent.writeUnsignedByte(TYPE_INTEGER);
-                unsigned int no = (unsigned int) lanes.size();
+                int no = (int) lanes.size();
                 tempContent.writeInt((int) no);
-                for (unsigned int i = 0; i < no; ++i) {
+                for (int i = 0; i < no; ++i) {
                     const MSTrafficLightLogic::LaneVector& llanes = lanes[i];
                     const MSTrafficLightLogic::LinkVector& llinks = links[i];
                     // number of links controlled by this signal (signal i)
                     tempContent.writeUnsignedByte(TYPE_INTEGER);
-                    unsigned int no2 = (unsigned int) llanes.size();
+                    int no2 = (int) llanes.size();
                     tempContent.writeInt((int) no2);
                     ++cnt;
-                    for (unsigned int j = 0; j < no2; ++j) {
+                    for (int j = 0; j < no2; ++j) {
                         MSLink* link = llinks[j];
                         std::vector<std::string> def;
                         // incoming lane
@@ -181,11 +177,7 @@ TraCIServerAPI_TLS::processGet(TraCIServer& server, tcpip::Storage& inputStorage
                         // approached non-internal lane (if any)
                         def.push_back(link->getLane() != 0 ? link->getLane()->getID() : "");
                         // approached "via", internal lane (if any)
-#ifdef HAVE_INTERNAL_LANES
                         def.push_back(link->getViaLane() != 0 ? link->getViaLane()->getID() : "");
-#else
-                        def.push_back("");
-#endif
                         tempContent.writeUnsignedByte(TYPE_STRINGLIST);
                         tempContent.writeStringList(def);
                         ++cnt;
@@ -227,7 +219,7 @@ TraCIServerAPI_TLS::processGet(TraCIServer& server, tcpip::Storage& inputStorage
                 MSTrafficLightLogic* tls = vars.getActive();
                 const std::string& state = tls->getCurrentPhaseDef().getState();
                 const std::map<std::string, std::string>& params = tls->getMap();
-                unsigned int num = 0;
+                int num = 0;
                 for (std::map<std::string, std::string>::const_iterator i = params.begin(); i != params.end(); ++i) {
                     if ("connection:" == (*i).first.substr(0, 11)) {
                         ++num;
@@ -245,7 +237,7 @@ TraCIServerAPI_TLS::processGet(TraCIServer& server, tcpip::Storage& inputStorage
                     tempMsg.writeString((*i).second); // foreign id
                     std::string connection = (*i).first.substr(11);
                     std::string from, to;
-                    size_t b = connection.find("->");
+                    const std::string::size_type b = connection.find("->");
                     if (b == std::string::npos) {
                         from = connection;
                     } else {
