@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    07.05.2009
-/// @version $Id: TraCIServerAPI_VehicleType.h 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id: TraCIServerAPI_VehicleType.h 24108 2017-04-27 18:43:30Z behrisch $
 ///
 // APIs for getting/setting vehicle type values via TraCI
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -33,7 +33,7 @@
 
 #ifndef NO_TRACI
 
-#include "TraCIException.h"
+#include "TraCIDefs.h"
 #include "TraCIServer.h"
 #include <foreign/tcpip/storage.h>
 
@@ -63,7 +63,7 @@ public:
      * @param[in] v The vehicle type to get the value from
      * @param[out] tempMsg The storage to write the result to
      */
-    static bool getVariable(const int variable, const MSVehicleType& v, tcpip::Storage& tempMsg);
+    static bool getVariable(const int variable, const std::string& v, tcpip::Storage& tempMsg);
 
 
     /** @brief Processes a set value command (Command 0xc5: Change Vehicle Type State)
@@ -79,7 +79,7 @@ public:
     /** @brief Processes a set value for the given type
      */
     static bool setVariable(const int cmd, const int variable,
-                            MSVehicleType& v, TraCIServer& server,
+                            const std::string& id, TraCIServer& server,
                             tcpip::Storage& inputStorage, tcpip::Storage& outputStorage);
 
 
