@@ -5,12 +5,12 @@
 /// @author  Axel Wegener
 /// @author  Michael Behrisch
 /// @date    2008/04/07
-/// @version $Id: TraCITestClient.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: TraCITestClient.h 24028 2017-04-24 05:10:18Z behrisch $
 ///
 /// A test execution class
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -26,12 +26,17 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
+#ifdef _MSC_VER
+#include <windows_config.h>
+#else
+#include <config.h>
+#endif
+
 #include <string>
 #include <sstream>
 #include <vector>
 
 #include <foreign/tcpip/socket.h>
-#include <utils/common/SUMOTime.h>
 #include <utils/traci/TraCIAPI.h>
 
 
@@ -118,7 +123,7 @@ protected:
      * @param[in] varNo The number of subscribed variables
      * @param[in] defFile The stream to read variable values from
      */
-    void commandSubscribeContextVariable(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, int domain, SUMOReal range, int varNo, std::ifstream& defFile);
+    void commandSubscribeContextVariable(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, int domain, double range, int varNo, std::ifstream& defFile);
     /// @}
 
 
@@ -143,7 +148,7 @@ private:
     /// @name Results validation methods
     /// @{
 
-    /** @brief Validates whether the given message is a valid answer to CMD_SIMSTEP2
+    /** @brief Validates whether the given message is a valid answer to CMD_SIMSTEP
      * @param[in] inMsg The storage contain the message to validate
      * @return Whether the message is valid
      */
