@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: Named.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: Named.h 23307 2017-03-10 07:52:34Z behrisch $
 ///
 // Base class for objects which have an id.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -31,6 +31,7 @@
 #include <config.h>
 #endif
 
+#include <iostream>
 #include <string>
 #include <set>
 
@@ -53,6 +54,11 @@ public:
     /// @brief Destructor
     virtual ~Named() { }
 
+    /// @brief get an identifier for Named-like object which may be Null
+    template<class T>
+    static std::string getIDSecure(const T* obj, const std::string& fallBack = "NULL") {
+        return obj == 0 ? fallBack : obj->getID();
+    }
 
     /** @brief Returns the id
      * @return The stored id
@@ -71,6 +77,7 @@ public:
 
 
     /// @brief Function-object for stable sorting in containers
+    // @note Numbers of different lengths will not be ordered by alphanumerical sorting
     struct ComparatorIdLess {
         bool operator()(Named* const a, Named* const b) const {
             return a->getID() < b->getID();
@@ -78,6 +85,7 @@ public:
     };
 
     /// @brief Function-object for stable sorting of objects acting like Named without being derived (SUMOVehicle)
+    // @note Numbers of different lenghts will not be ordered by alphanumerical sorting
     template <class NamedLike>
     struct NamedLikeComparatorIdLess {
         bool operator()(const NamedLike* const a, const NamedLike* const b) const {
