@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Fri, 29.04.2005
-/// @version $Id: SUMOTime.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SUMOTime.cpp 22797 2017-01-31 14:53:07Z namdre $
 ///
 // Variables, methods, and tools for internal time representation
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -31,14 +31,13 @@
 #include <sstream>
 #include "SUMOTime.h"
 #include "TplConvert.h"
+#include "StdDefs.h"
 
 
 // ===========================================================================
 // type definitions
 // ===========================================================================
-#ifdef HAVE_SUBSECOND_TIMESTEPS
 SUMOTime DELTA_T = 1000;
-#endif
 
 
 // ===========================================================================
@@ -62,7 +61,7 @@ time2string(SUMOTime t) {
     // 123456 -> "12.34"
     std::ostringstream oss;
     oss.setf(oss.fixed);
-    oss.precision(OUTPUT_ACCURACY);
+    oss.precision(gPrecision);
     oss << STEPS2TIME(t);
     return oss.str();
 }
