@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Fri, 29.04.2005
-/// @version $Id: StdDefs.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: StdDefs.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 //
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2005-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2005-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -32,8 +32,7 @@
 #else
 #include <config.h>
 #endif
-
-#include <utils/xml/SUMOXMLDefinitions.h>
+#include <string>
 
 /* avoiding compiler warning unreferenced parameter */
 #define UNUSED_PARAMETER(x)  ((void)(x))
@@ -46,19 +45,15 @@ class RGBColor;
 /* -------------------------------------------------------------------------
  * some constant defaults used by SUMO
  * ----------------------------------------------------------------------- */
-const SUMOReal SUMO_const_laneWidth = (SUMOReal) 3.2;
-const SUMOReal SUMO_const_halfLaneWidth = (SUMOReal) 1.6;
-const SUMOReal SUMO_const_quarterLaneWidth = (SUMOReal) 0.8;
-const SUMOReal SUMO_const_laneOffset = (SUMOReal) .1;
-const SUMOReal SUMO_const_laneWidthAndOffset = (SUMOReal) 3.3;
-const SUMOReal SUMO_const_halfLaneAndOffset = (SUMOReal)(3.2 / 2. + .1);
+const double SUMO_const_laneWidth = (double) 3.2;
+const double SUMO_const_halfLaneWidth = (double) 1.6;
+const double SUMO_const_quarterLaneWidth = (double) 0.8;
+const double SUMO_const_laneOffset = (double) .1;
+const double SUMO_const_laneWidthAndOffset = (double) 3.3;
+const double SUMO_const_halfLaneAndOffset = (double)(3.2 / 2. + .1);
 
 /// @brief the speed threshold at which vehicles are considered as halting
-const SUMOReal SUMO_const_haltingSpeed = (SUMOReal) 0.1;
-
-/* @brief map from LinkState to color constants (see above)
- */
-const RGBColor& getLinkColor(const LinkState& ls);
+const double SUMO_const_haltingSpeed = (double) 0.1;
 
 
 /* -------------------------------------------------------------------------
@@ -112,9 +107,17 @@ ISNAN(T a) {
     return d != d;
 }
 
+
+/// the precision for floating point outputs
+extern int gPrecision;
+extern int gPrecisionGeo; // for lon,lat
+
+
 /// @brief global utility flags for debugging
 extern bool gDebugFlag1;
 extern bool gDebugFlag2;
+extern bool gDebugFlag3;
+extern bool gDebugFlag4;
 
 extern std::string gDebugSelectedVehicle;
 
