@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Tue, 29.05.2005
-/// @version $Id: SysUtils.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SysUtils.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A few system-specific functions
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2005-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2005-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -38,10 +38,6 @@
 #undef NOMINMAX
 #endif
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // member method definitions
@@ -73,9 +69,7 @@ SysUtils::getWindowsTicks() {
 
 unsigned long
 SysUtils::runHiddenCommand(const std::string& cmd) {
-#ifndef WIN32
-    return (unsigned long)system(cmd.c_str());
-#else
+#ifdef _MSC_VER
     // code inspired by http://www.codeproject.com/Articles/2537/Running-console-applications-silently
     STARTUPINFO StartupInfo;
     PROCESS_INFORMATION ProcessInfo;
@@ -107,6 +101,8 @@ SysUtils::runHiddenCommand(const std::string& cmd) {
 
     delete args;
     return rc;
+#else
+    return (unsigned long)system(cmd.c_str());
 #endif
 }
 
