@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Mon, 23.06.2003
-/// @version $Id: SystemFrame.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SystemFrame.h 22797 2017-01-31 14:53:07Z namdre $
 ///
 // A set of actions common to all applications
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -72,6 +72,8 @@ public:
      */
     static void addReportOptions(OptionsCont& oc);
 
+    /// @brief checks shared options and sets StdDefs
+    static bool checkOptions();
 
     /** @brief Closes all of an applications subsystems
      *
