@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: Distribution_Points.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: Distribution_Points.h 23362 2017-03-14 09:16:46Z behrisch $
 ///
 // The description of a distribution by a curve
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -31,8 +31,8 @@
 #include <config.h>
 #endif
 
+#include "RandomDistributor.h"
 #include "Distribution.h"
-#include <utils/geom/PositionVector.h>
 
 
 // ===========================================================================
@@ -41,38 +41,34 @@
 /**
  * @class Distribution_Points
  * A description of a distribution that uses a set of points in a 2d-space
- *  to describe the values (each points x-value) and theri possibilities
+ *  to describe the values (each points x-value) and their possibilities
  *  (each points y-value)
  */
 class Distribution_Points :
-    public Distribution {
+    public Distribution, public RandomDistributor<double> {
 public:
     /// Constructor
-    Distribution_Points(const std::string& id,
-                        const PositionVector& points, bool interpolating = false);
+    Distribution_Points(const std::string& id);
 
     /// Destructor
     virtual ~Distribution_Points();
 
+    /** @brief Draw a sample of the distribution.
+    *
+    * A random sample is drawn according to the assigned probabilities.
+    *
+    * @param[in] which The random number generator to use; the static one will be used if 0 is passed
+    * @return the drawn member
+    */
+    double sample(MTRand* which = 0) const {
+        return get(which);
+    }
+
     /// Returns the maximum value of this distribution
-    SUMOReal getMax() const;
-
-    size_t getAreaNo() const;
-    SUMOReal getAreaBegin(size_t index) const;
-    SUMOReal getAreaEnd(size_t index) const;
-    SUMOReal getAreaPerc(size_t index) const;
-
-
-protected:
-    /// The list of points that describe the distribution
-    PositionVector myPoints;
-
-    mutable bool myProbabilitiesAreComputed;
-
-    mutable std::vector<SUMOReal> myProbabilities;
-
-    bool myInterpolateDist;
+    double getMax() const;
 
+    /// Returns the string representation of this distribution
+    std::string toStr(std::streamsize accuracy) const;
 };
 
 
