@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 10.05.2004
-/// @version $Id: HelpersHBEFA3.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: HelpersHBEFA3.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Helper methods for HBEFA3-based emission computation
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -35,10 +35,6 @@
 #include <algorithm>
 #include "HelpersHBEFA3.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static definitions
@@ -474,7 +470,7 @@ HelpersHBEFA3::HelpersHBEFA3() : PollutantsInterface::Helper("HBEFA3") {
     for (int i = 0; i < 12; i++) {
         myEmissionClassStrings.insert(heavy[i], index | PollutantsInterface::HEAVY_BIT);
         std::transform(heavy[i].begin(), heavy[i].end(), heavy[i].begin(), tolower);
-        myEmissionClassStrings.addAlias(heavy[i], index);
+        myEmissionClassStrings.addAlias(heavy[i], index | PollutantsInterface::HEAVY_BIT);
         index++;
     }
     myEmissionClassStrings.addAlias("unknown", myEmissionClassStrings.get("PC_G_EU4"));
