@@ -4,12 +4,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    2004-03-19
-/// @version $Id: FXThreadEvent.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: FXThreadEvent.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 //
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -53,12 +53,9 @@ using namespace FX;
 #include "fxexdefs.h"
 #include "FXThreadEvent.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
 // ===========================================================================
 // used namespaces
 // ===========================================================================
-#endif // _DEBUG
 using namespace FXEX;
 namespace FXEX {
 
