@@ -2,12 +2,12 @@
 /// @file    MFXCheckableButton.cpp
 /// @author  Daniel Krajzewicz
 /// @date    2004-03-19
-/// @version $Id: MFXCheckableButton.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: MFXCheckableButton.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // missing_desc
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -30,10 +30,6 @@
 
 #include "MFXCheckableButton.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 FXDEFMAP(MFXCheckableButton) MFXCheckableButtonMap[] = {
     FXMAPFUNC(SEL_PAINT, 0, MFXCheckableButton::onPaint),
