@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    2006-08-01
-/// @version $Id: GeoConvHelper.cpp 18171 2015-03-27 14:50:44Z behrisch $
+/// @version $Id: GeoConvHelper.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // static methods for processing the coordinates conversion for the current net
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -41,10 +41,6 @@
 #include <utils/iodevices/OutputDevice.h>
 #include "GeoConvHelper.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static member variables
@@ -251,7 +247,7 @@ GeoConvHelper::cartesian2geo(Position& cartesian) const {
     //!!! check pj_errno
     p.u *= RAD_TO_DEG;
     p.v *= RAD_TO_DEG;
-    cartesian.set((SUMOReal) p.u, (SUMOReal) p.v);
+    cartesian.set((double) p.u, (double) p.v);
 #endif
 }
 
@@ -311,7 +307,7 @@ GeoConvHelper::x2cartesian(Position& from, bool includeInBoundary) {
         if (pj_transform(myInverseProjection, myGeoProjection, 1, 1, &x, &y, NULL)) {
             WRITE_WARNING("Could not transform (" + toString(x) + "," + toString(y) + ")");
         }
-        from.set(SUMOReal(x * RAD_TO_DEG), SUMOReal(y * RAD_TO_DEG));
+        from.set(double(x * RAD_TO_DEG), double(y * RAD_TO_DEG));
     }
 #endif
     // perform conversion
@@ -357,7 +353,7 @@ GeoConvHelper::x2cartesian_const(Position& from) const {
             double ys = y;
             x *= 111320. * cos(DEG2RAD(ys));
             y *= 111136.;
-            from.set((SUMOReal)x, (SUMOReal)y);
+            from.set((double)x, (double)y);
             //!!! recheck whether the axes are mirrored
             from.add(myOffset);
         }
@@ -367,7 +363,7 @@ GeoConvHelper::x2cartesian_const(Position& from) const {
         return false;
     }
     if (myProjectionMethod != SIMPLE) {
-        from.set((SUMOReal)x, (SUMOReal)y);
+        from.set((double)x, (double)y);
         from.add(myOffset);
     }
     return true;
@@ -375,7 +371,7 @@ GeoConvHelper::x2cartesian_const(Position& from) const {
 
 
 void
-GeoConvHelper::moveConvertedBy(SUMOReal x, SUMOReal y) {
+GeoConvHelper::moveConvertedBy(double x, double y) {
     myOffset.add(x, y);
     myConvBoundary.moveby(x, y);
 }
@@ -412,7 +408,7 @@ GeoConvHelper::getProjString() const {
 
 
 void
-GeoConvHelper::computeFinal() {
+GeoConvHelper::computeFinal(bool lefthand) {
     if (myNumLoaded == 0) {
         myFinal = myProcessing;
     } else  {
@@ -425,6 +421,10 @@ GeoConvHelper::computeFinal() {
                       // the new boundary (updated during loading)
                       myProcessing.getConvBoundary());
     }
+    if (lefthand) {
+        myFinal.myOffset.mul(1, -1);
+        myFinal.myConvBoundary.flipY();
+    }
 }
 
 
@@ -451,7 +451,7 @@ GeoConvHelper::writeLocation(OutputDevice& into) {
     into.writeAttr(SUMO_ATTR_NET_OFFSET, myFinal.getOffsetBase());
     into.writeAttr(SUMO_ATTR_CONV_BOUNDARY, myFinal.getConvBoundary());
     if (myFinal.usingGeoProjection()) {
-        into.setPrecision(GEO_OUTPUT_ACCURACY);
+        into.setPrecision(gPrecisionGeo);
     }
     into.writeAttr(SUMO_ATTR_ORIG_BOUNDARY, myFinal.getOrigBoundary());
     if (myFinal.usingGeoProjection()) {
