@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    2006-08-01
-/// @version $Id: GeoConvHelper.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GeoConvHelper.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // static methods for processing the coordinates conversion for the current net
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -147,7 +147,7 @@ public:
     bool usingInverseGeoProjection() const;
 
     /// Shifts the converted boundary by the given amounts
-    void moveConvertedBy(SUMOReal x, SUMOReal y);
+    void moveConvertedBy(double x, double y);
 
     /// Returns the original boundary
     const Boundary& getOrigBoundary() const;
