@@ -5,12 +5,12 @@
 /// @author  Axel Wegener
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: Position.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: Position.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A position in the 2D- or 3D-world
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -45,158 +45,177 @@
  */
 class Position {
 public:
-    /// default constructor
+    /// @brief default constructor
     Position() : myX(0.0), myY(0.0), myZ(0.0) { }
 
-    /// parametrised constructor
-    Position(SUMOReal x, SUMOReal y)
+    /// @brief parametrised constructor
+    Position(double x, double y)
         : myX(x), myY(y), myZ(0) { }
 
-    /// parametrised constructor
-    Position(SUMOReal x, SUMOReal y, SUMOReal z)
+    /// @brief parametrised constructor
+    Position(double x, double y, double z)
         : myX(x), myY(y), myZ(z) { }
 
-    /// Destructor
+    /// @brief Destructor
     ~Position() { }
 
-    /// Returns the x-position
-    SUMOReal x() const {
+    /// @brief Returns the x-position
+    double x() const {
         return myX;
     }
 
-    /// Returns the y-position
-    SUMOReal y() const {
+    /// @brief Returns the y-position
+    double y() const {
         return myY;
     }
 
-    /// Returns the z-position
-    SUMOReal z() const {
+    /// @brief Returns the z-position
+    double z() const {
         return myZ;
     }
 
-    ///
-    void set(SUMOReal x, SUMOReal y) {
+    /// @brief set position x
+    void setx(double x) {
+        myX = x;
+    }
+
+    /// @brief set position y
+    void sety(double y) {
+        myY = y;
+    }
+
+    /// @brief set position z
+    void setz(double z) {
+        myZ = z;
+    }
+
+    /// @brief set positions x and y
+    void set(double x, double y) {
         myX = x;
         myY = y;
     }
 
-    ///
-    void set(SUMOReal x, SUMOReal y, SUMOReal z) {
+    /// @brief set positions x, y and z
+    void set(double x, double y, double z) {
         myX = x;
         myY = y;
         myZ = z;
     }
 
-    ///
+    /// @brief set position with another position
     void set(const Position& pos) {
         myX = pos.myX;
         myY = pos.myY;
         myZ = pos.myZ;
     }
 
-
-    /// Multiplies both positions with the given value
-    void mul(SUMOReal val) {
+    /// @brief Multiplies both positions with the given value
+    void mul(double val) {
         myX *= val;
         myY *= val;
         myZ *= val;
     }
 
-    /// Multiplies position with the given values
-    void mul(SUMOReal mx, SUMOReal my) {
+    /// @brief Multiplies position with the given values
+    void mul(double mx, double my) {
         myX *= mx;
         myY *= my;
     }
 
-    /// Multiplies position with the given values
-    void mul(SUMOReal mx, SUMOReal my, SUMOReal mz) {
+    /// @brief Multiplies position with the given values
+    void mul(double mx, double my, double mz) {
         myX *= mx;
         myY *= my;
         myZ *= mz;
     }
 
-    /// Adds the given position to this one
+    /// @brief Adds the given position to this one
     void add(const Position& pos) {
         myX += pos.myX;
         myY += pos.myY;
         myZ += pos.myZ;
     }
 
-    /// Adds the given position to this one
-    void add(SUMOReal dx, SUMOReal dy) {
+    /// @brief Adds the given position to this one
+    void add(double dx, double dy) {
         myX += dx;
         myY += dy;
     }
 
-    /// Adds the given position to this one
-    void add(SUMOReal dx, SUMOReal dy, SUMOReal dz) {
+    /// @brief Adds the given position to this one
+    void add(double dx, double dy, double dz) {
         myX += dx;
         myY += dy;
         myZ += dz;
     }
 
-    /// Substracts the given position from this one
-    void sub(SUMOReal dx, SUMOReal dy) {
+    /// @brief Substracts the given position from this one
+    void sub(double dx, double dy) {
         myX -= dx;
         myY -= dy;
     }
 
-    /// Substracts the given position from this one
-    void sub(SUMOReal dx, SUMOReal dy, SUMOReal dz) {
+    /// @brief Substracts the given position from this one
+    void sub(double dx, double dy, double dz) {
         myX -= dx;
         myY -= dy;
         myZ -= dz;
     }
 
-    /// Substracts the given position from this one
+    /// @brief Substracts the given position from this one
     void sub(const Position& pos) {
         myX -= pos.myX;
         myY -= pos.myY;
         myZ -= pos.myZ;
     }
 
+    /// @brief
     void norm2d() {
-        SUMOReal val = sqrt(myX * myX + myY * myY);
+        double val = sqrt(myX * myX + myY * myY);
         myX = myX / val;
         myY = myY / val;
     }
 
-    /// Prints to the output
+    /// @brief output operator
     friend std::ostream& operator<<(std::ostream& os, const Position& p) {
         os << p.x() << "," << p.y();
-        if (p.z() != SUMOReal(0.0)) {
+        if (p.z() != double(0.0)) {
             os << "," << p.z();
         }
         return os;
     }
 
+    /// @brief add operator
     Position operator+(const Position& p2) const {
         return Position(myX + p2.myX,  myY + p2.myY, myZ + p2.myZ);
     }
 
+    /// @brief sub operator
     Position operator-(const Position& p2) const {
         return Position(myX - p2.myX,  myY - p2.myY, myZ - p2.myZ);
     }
 
     /// @brief keep the direction but modify the length of the (location) vector to length * scalar
-    Position operator*(SUMOReal scalar) const {
+    Position operator*(double scalar) const {
         return Position(myX * scalar, myY * scalar, myZ * scalar);
     }
 
     /// @brief keep the direction but modify the length of the (location) vector to length + scalar
-    Position operator+(SUMOReal offset) const {
-        const SUMOReal length = distanceTo(Position(0, 0, 0));
+    Position operator+(double offset) const {
+        const double length = distanceTo(Position(0, 0, 0));
         if (length == 0) {
             return *this;
         }
-        const SUMOReal scalar = (length + offset) / length;
+        const double scalar = (length + offset) / length;
         return Position(myX * scalar, myY * scalar, myZ * scalar);
     }
 
+    /// @brief comparation operator
     bool operator==(const Position& p2) const {
         return myX == p2.myX && myY == p2.myY && myZ == p2.myZ;
     }
 
+    /// @brief difference  operator
     bool operator!=(const Position& p2) const {
         return myX != p2.myX || myY != p2.myY || myZ != p2.myZ;
     }
@@ -212,39 +231,36 @@ public:
         }
     }
 
-    bool almostSame(const Position& p2, SUMOReal maxDiv = POSITION_EPS) const {
+    /// @brief checki if two position is almost the sme as other
+    bool almostSame(const Position& p2, double maxDiv = POSITION_EPS) const {
         return distanceTo(p2) < maxDiv;
     }
 
-
     /// @brief returns the euclidean distance in 3 dimension
-    inline SUMOReal distanceTo(const Position& p2) const {
+    inline double distanceTo(const Position& p2) const {
         return sqrt(distanceSquaredTo(p2));
     }
 
-
-    inline SUMOReal distanceSquaredTo(const Position& p2) const {
+    /// @brief returns the square of the distance to another position
+    inline double distanceSquaredTo(const Position& p2) const {
         return (myX - p2.myX) * (myX - p2.myX) + (myY - p2.myY) * (myY - p2.myY) + (myZ - p2.myZ) * (myZ - p2.myZ);
     }
 
-
     /// @brief returns the euclidean distance in the x-y-plane
-    inline SUMOReal distanceTo2D(const Position& p2) const {
+    inline double distanceTo2D(const Position& p2) const {
         return sqrt(distanceSquaredTo2D(p2));
     }
 
-
-    inline SUMOReal distanceSquaredTo2D(const Position& p2) const {
+    /// @brief returns the square of the distance to another position (Only using x and y positions)
+    inline double distanceSquaredTo2D(const Position& p2) const {
         return (myX - p2.myX) * (myX - p2.myX) + (myY - p2.myY) * (myY - p2.myY);
     }
 
-
     /// @brief returns the angle in the plane of the vector pointing from here to the other position
-    inline SUMOReal angleTo2D(const Position& other) const {
+    inline double angleTo2D(const Position& other) const {
         return atan2(other.myY - myY, other.myX - myX);
     }
 
-
     /// @brief returns the cross product between this point and the second one
     Position crossProduct(const Position& pos) {
         return Position(
@@ -254,22 +270,22 @@ public:
     }
 
     /// @brief returns the dot product (scalar product) between this point and the second one
-    inline SUMOReal dotProduct(const Position& pos) {
+    inline double dotProduct(const Position& pos) {
         return myX * pos.myX + myY * pos.myY + myZ * pos.myZ;
     }
 
+    /// @brief used to indicate that a position is valid
     static const Position INVALID;
 
 private:
-    /// The x-position
-    SUMOReal myX;
+    /// @brief  The x-position
+    double myX;
 
-    /// The y-position
-    SUMOReal myY;
-
-    /// The z-position
-    SUMOReal myZ;
+    /// @brief  The y-position
+    double myY;
 
+    /// @brief  The z-position
+    double myZ;
 };
 
 
