@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: GUIParameterTableWindow.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUIParameterTableWindow.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // The window that holds the table of an object's parameter
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -76,7 +76,7 @@ public:
      * @param[in] noRows Number of rows to allocate
      */
     GUIParameterTableWindow(GUIMainWindow& app,
-                            GUIGlObject& o, size_t noRows);
+                            GUIGlObject& o, int noRows);
 
 
     /// @brief Destructor
@@ -122,13 +122,13 @@ public:
     void mkItem(const char* name, bool dynamic, ValueSource<int>* src);
 
 
-    /** @brief Adds a row which obtains its value from an SUMOReal-ValueSource
+    /** @brief Adds a row which obtains its value from an double-ValueSource
      *
      * @param[in] name The name of the row entry
      * @param[in] dynamic Information whether the entry is dynamic
      * @param[in] src The value source to use
      */
-    void mkItem(const char* name, bool dynamic, ValueSource<SUMOReal>* src);
+    void mkItem(const char* name, bool dynamic, ValueSource<double>* src);
 
 
     /** @brief Adds a row which shows a string-value
@@ -171,14 +171,14 @@ public:
     void mkItem(const char* name, bool dynamic, long long int value);
 
 
-    /** @brief Adds a row which shows a SUMOReal-value
+    /** @brief Adds a row which shows a double-value
      *
      * @param[in] name The name of the row entry
      * @param[in] dynamic Information whether the entry is dynamic
      * @param[in] value The value to show
      * @todo the dynamic-parameter is obsolete
      */
-    void mkItem(const char* name, bool dynamic, SUMOReal value);
+    void mkItem(const char* name, bool dynamic, double value);
 
 
     /// @}
