@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIGLObjectPopupMenu.cpp 18756 2015-08-31 19:16:33Z behrisch $
+/// @version $Id: GUIGLObjectPopupMenu.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // The popup menu of a globject
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -42,10 +42,6 @@
 #include <utils/common/ToString.h>
 #include "GUIGLObjectPopupMenu.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 #define DEBUG_VEHICLE_GUI_SELECTION 1
 
 // ===========================================================================
@@ -55,9 +51,11 @@ FXDEFMAP(GUIGLObjectPopupMenu) GUIGLObjectPopupMenuMap[] = {
     FXMAPFUNC(SEL_COMMAND,  MID_CENTER,                  GUIGLObjectPopupMenu::onCmdCenter),
     FXMAPFUNC(SEL_COMMAND,  MID_COPY_NAME,               GUIGLObjectPopupMenu::onCmdCopyName),
     FXMAPFUNC(SEL_COMMAND,  MID_COPY_TYPED_NAME,         GUIGLObjectPopupMenu::onCmdCopyTypedName),
+    FXMAPFUNC(SEL_COMMAND,  MID_COPY_EDGE_NAME,          GUIGLObjectPopupMenu::onCmdCopyEdgeName),
     FXMAPFUNC(SEL_COMMAND,  MID_COPY_CURSOR_POSITION,    GUIGLObjectPopupMenu::onCmdCopyCursorPosition),
     FXMAPFUNC(SEL_COMMAND,  MID_COPY_CURSOR_GEOPOSITION, GUIGLObjectPopupMenu::onCmdCopyCursorGeoPosition),
     FXMAPFUNC(SEL_COMMAND,  MID_SHOWPARS,                GUIGLObjectPopupMenu::onCmdShowPars),
+    FXMAPFUNC(SEL_COMMAND,  MID_SHOWTYPEPARS,            GUIGLObjectPopupMenu::onCmdShowTypePars),
     FXMAPFUNC(SEL_COMMAND,  MID_ADDSELECT,               GUIGLObjectPopupMenu::onCmdAddSelected),
     FXMAPFUNC(SEL_COMMAND,  MID_REMOVESELECT,            GUIGLObjectPopupMenu::onCmdRemoveSelected)
 };
@@ -69,15 +67,38 @@ FXIMPLEMENT(GUIGLObjectPopupMenu, FXMenuPane, GUIGLObjectPopupMenuMap, ARRAYNUMB
 // ===========================================================================
 // method definitions
 // ===========================================================================
-GUIGLObjectPopupMenu::GUIGLObjectPopupMenu(GUIMainWindow& app,
-        GUISUMOAbstractView& parent,
-        GUIGlObject& o)
-    : FXMenuPane(&parent), myParent(&parent), myObject(&o),
-      myApplication(&app), myNetworkPosition(parent.getPositionInformation()) {
+GUIGLObjectPopupMenu::GUIGLObjectPopupMenu(GUIMainWindow& app, GUISUMOAbstractView& parent, GUIGlObject& o) :
+    FXMenuPane(&parent),
+    myParent(&parent),
+    myObject(&o),
+    myApplication(&app),
+    myNetworkPosition(parent.getPositionInformation()) {
 }
 
 
-GUIGLObjectPopupMenu::~GUIGLObjectPopupMenu() {}
+GUIGLObjectPopupMenu::~GUIGLObjectPopupMenu() {
+    // Delete MenuPaneChilds
+    for (std::vector<FXMenuPane*>::iterator i = myMenuPanes.begin(); i != myMenuPanes.end(); i++) {
+        delete(*i);
+    }
+}
+
+
+void
+GUIGLObjectPopupMenu::insertMenuPaneChild(FXMenuPane* child) {
+    // Check that MenuPaneChild isn't NULL
+    if (child == NULL) {
+        throw ProcessError("MenuPaneChild cannot be NULL");
+    }
+    // Check that MenuPaneChild wasn't already inserted
+    for (std::vector<FXMenuPane*>::iterator i = myMenuPanes.begin(); i != myMenuPanes.end(); i++) {
+        if ((*i) == child) {
+            throw ProcessError("MenuPaneChild already inserted");
+        }
+    }
+    // Insert MenuPaneChild
+    myMenuPanes.push_back(child);
+}
 
 
 long
@@ -102,6 +123,14 @@ GUIGLObjectPopupMenu::onCmdCopyTypedName(FXObject*, FXSelector, void*) {
 }
 
 
+long
+GUIGLObjectPopupMenu::onCmdCopyEdgeName(FXObject*, FXSelector, void*) {
+    assert(myObject->getType() == GLO_LANE);
+    GUIUserIO::copyToClipboard(*myParent->getApp(), myObject->getParentName());
+    return 1;
+}
+
+
 long
 GUIGLObjectPopupMenu::onCmdCopyCursorPosition(FXObject*, FXSelector, void*) {
     GUIUserIO::copyToClipboard(*myParent->getApp(), toString(myNetworkPosition));
@@ -114,7 +143,7 @@ GUIGLObjectPopupMenu::onCmdCopyCursorGeoPosition(FXObject*, FXSelector, void*) {
     Position pos = myNetworkPosition;
     GeoConvHelper::getFinal().cartesian2geo(pos);
     // formated for pasting into google maps
-    const std::string posString = toString(pos.y(), GEO_OUTPUT_ACCURACY) + ", " + toString(pos.x(), GEO_OUTPUT_ACCURACY);
+    const std::string posString = toString(pos.y(), gPrecisionGeo) + ", " + toString(pos.x(), gPrecisionGeo);
     GUIUserIO::copyToClipboard(*myParent->getApp(), posString);
     return 1;
 }
@@ -122,7 +151,15 @@ GUIGLObjectPopupMenu::onCmdCopyCursorGeoPosition(FXObject*, FXSelector, void*) {
 
 long
 GUIGLObjectPopupMenu::onCmdShowPars(FXObject*, FXSelector, void*) {
-    myObject->getParameterWindow(*myApplication, *myParent); // !!! showParameterWindow would be more appropriate
+    myObject->getParameterWindow(*myApplication, *myParent);
+    return 1;
+}
+
+
+
+long
+GUIGLObjectPopupMenu::onCmdShowTypePars(FXObject*, FXSelector, void*) {
+    myObject->getTypeParameterWindow(*myApplication, *myParent);
     return 1;
 }
 
