@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    2004
-/// @version $Id: GUIGlObject_AbstractAdd.cpp 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id: GUIGlObject_AbstractAdd.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Base class for additional objects (detectors etc.)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -33,13 +33,10 @@
 #include "GUIGlObject_AbstractAdd.h"
 #include <cassert>
 #include <iostream>
+#include <algorithm>
 #include <utils/gui/div/GLHelper.h>
 #include <foreign/polyfonts/polyfonts.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static member definitions
