@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    08.10.2009
-/// @version $Id: GUIShapeContainer.cpp 20801 2016-05-28 05:31:30Z behrisch $
+/// @version $Id: GUIShapeContainer.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Storage for geometrical objects extended by mutexes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -37,10 +37,6 @@
 #include <utils/shapes/PointOfInterest.h>
 #include <utils/shapes/Polygon.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -54,8 +50,8 @@ GUIShapeContainer::~GUIShapeContainer() {}
 
 bool
 GUIShapeContainer::addPOI(const std::string& id, const std::string& type,
-                          const RGBColor& color, SUMOReal layer, SUMOReal angle, const std::string& imgFile,
-                          const Position& pos, SUMOReal width, SUMOReal height, bool ignorePruning) {
+                          const RGBColor& color, double layer, double angle, const std::string& imgFile,
+                          const Position& pos, double width, double height, bool /* ignorePruning */) {
     GUIPointOfInterest* p = new GUIPointOfInterest(id, type, color, pos, layer, angle, imgFile, width, height);
     AbstractMutex::ScopedLocker locker(myLock);
     if (!myPOIs.add(id, p)) {
@@ -70,9 +66,9 @@ GUIShapeContainer::addPOI(const std::string& id, const std::string& type,
 
 bool
 GUIShapeContainer::addPolygon(const std::string& id, const std::string& type,
-                              const RGBColor& color, SUMOReal layer,
-                              SUMOReal angle, const std::string& imgFile,
-                              const PositionVector& shape, bool fill, bool ignorePruning) {
+                              const RGBColor& color, double layer,
+                              double angle, const std::string& imgFile,
+                              const PositionVector& shape, bool fill, bool /* ignorePruning */) {
     GUIPolygon* p = new GUIPolygon(id, type, color, shape, fill, layer, angle, imgFile);
     AbstractMutex::ScopedLocker locker(myLock);
     if (!myPolygons.add(id, p)) {
