@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2006
-/// @version $Id: GUITexturesHelper.h 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: GUITexturesHelper.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Global storage for textures; manages and draws them
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2006-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2006-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -48,18 +48,18 @@ public:
     /// @brief return maximum number of pixels in x and y direction
     static int getMaxTextureSize();
 
-    /// Adds a texture to use
+    /// @brief Adds a texture to use
     static GUIGlID add(FXImage* i);
 
-    /// Draws a named texture as a box with the given size
-    static void drawTexturedBox(int which, SUMOReal size);
+    /// @brief Draws a named texture as a box with the given size
+    static void drawTexturedBox(int which, double size);
 
-    /// Draws a named texture as a rectangle with the given sizes
-    static void drawTexturedBox(int which,
-                                SUMOReal sizeX1, SUMOReal sizeY1, SUMOReal sizeX2, SUMOReal sizeY2);
+    /// @brief Draws a named texture as a rectangle with the given sizes
+    static void drawTexturedBox(int which, double sizeX1, double sizeY1, double sizeX2, double sizeY2);
 
-    /// @brief return texture id for the given filename (initialize on first use)
-    // @note return -1 on failure
+    /**@brief return texture id for the given filename (initialize on first use)
+     * @note return -1 on failure
+     */
     static int getTextureID(const std::string& filename, const bool mirrorX = false);
 
     /// @brief clears loaded textures
@@ -81,7 +81,6 @@ private:
 
     /// @brief whether textures are drawn
     static bool myAllowTextures;
-
 };
 
 
