@@ -4,12 +4,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Fri, 24. Apr 2009
-/// @version $Id: GUISettingsHandler.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: GUISettingsHandler.h 23341 2017-03-13 10:11:12Z behrisch $
 ///
 // The handler for parsing gui settings from xml.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -33,7 +33,7 @@
 #endif
 
 #include <utils/xml/SUMOSAXHandler.h>
-#include <utils/common/RandomDistributor.h>
+#include <utils/distribution/RandomDistributor.h>
 
 
 // ===========================================================================
@@ -85,15 +85,7 @@ public:
     /** @brief Sets the viewport which has been parsed
      * @param[in] parent the view for which the viewport has to be set
      */
-    void setViewport(GUISUMOAbstractView* view) const;
-
-
-    /** @brief Sets the viewport which has been parsed
-     * @param[out] zoom Variable to store the loaded zoom into
-     * @param[out] xoff Variable to store the loaded x-offset into
-     * @param[out] yoff Variable to store the loaded y-offset into
-     */
-    void setViewport(Position& lookFrom, Position& lookAt) const;
+    void applyViewport(GUISUMOAbstractView* view) const;
 
 
     /** @brief Makes a snapshot if it has been parsed
@@ -118,7 +110,7 @@ public:
     /** @brief Returns the parsed delay
      * @return the parsed delay
      */
-    SUMOReal getDelay() const;
+    double getDelay() const;
 
 
     /** @brief Returns the parsed breakpoints
@@ -141,7 +133,7 @@ public:
     }
 
     RandomDistributor<std::string> getEventDistribution(const std::string& id);
-    SUMOReal getJamSoundTime() {
+    double getJamSoundTime() {
         return myJamSoundTime;
     }
 
@@ -153,7 +145,7 @@ private:
     std::string myViewType;
 
     /// @brief The delay loaded
-    SUMOReal myDelay;
+    double myDelay;
 
     /// @brief The viewport loaded, zoom is stored in z coordinate
     Position myLookFrom;
@@ -181,7 +173,7 @@ private:
 
     /// @brief The parsed event distributions
     std::map<std::string, RandomDistributor<std::string> > myEventDistributions;
-    SUMOReal myJamSoundTime;
+    double myJamSoundTime;
 
 private:
 
