@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Fri, 19 Jul 2002
-/// @version $Id: NamedColumnsParser.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: NamedColumnsParser.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // A parser to retrieve information from a table with known columns
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -175,7 +175,7 @@ private:
 
 private:
     /** @brief The map's definition of column item names to their positions within the table */
-    typedef std::map<std::string, size_t> PosMap;
+    typedef std::map<std::string, int> PosMap;
 
     /// @brief The map of column item names to their positions within the table
     PosMap myDefinitionsMap;
