@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    2005-09-15
-/// @version $Id: BinaryInputDevice.cpp 21182 2016-07-18 06:46:01Z behrisch $
+/// @version $Id: BinaryInputDevice.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Encapsulates binary reading operations on a file
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2005-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2005-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -35,10 +35,6 @@
 #include "BinaryFormatter.h"
 #include "BinaryInputDevice.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 // ===========================================================================
 // constants definitions
 // ===========================================================================
@@ -121,14 +117,14 @@ operator>>(BinaryInputDevice& os, int& i) {
 
 
 BinaryInputDevice&
-operator>>(BinaryInputDevice& os, SUMOReal& f) {
+operator>>(BinaryInputDevice& os, double& f) {
     int t = os.checkType(BinaryFormatter::BF_FLOAT);
     if (t == BinaryFormatter::BF_SCALED2INT) {
         int v;
         os.myStream.read((char*) &v, sizeof(int));
         f = v / 100.;
     } else {
-        os.myStream.read((char*) &f, sizeof(SUMOReal));
+        os.myStream.read((char*) &f, sizeof(double));
     }
     return os;
 }
@@ -208,7 +204,7 @@ operator>>(BinaryInputDevice& os, std::vector< std::vector<int> >& v) {
 BinaryInputDevice&
 operator>>(BinaryInputDevice& os, Position& p) {
     int t = os.checkType(BinaryFormatter::BF_POSITION_2D);
-    SUMOReal x, y, z = 0;
+    double x, y, z = 0;
     if (t == BinaryFormatter::BF_SCALED2INT_POSITION_2D || t == BinaryFormatter::BF_SCALED2INT_POSITION_2D) {
         int v;
         os.myStream.read((char*) &v, sizeof(int));
@@ -220,10 +216,10 @@ operator>>(BinaryInputDevice& os, Position& p) {
             z = v / 100.;
         }
     } else {
-        os.myStream.read((char*) &x, sizeof(SUMOReal));
-        os.myStream.read((char*) &y, sizeof(SUMOReal));
+        os.myStream.read((char*) &x, sizeof(double));
+        os.myStream.read((char*) &y, sizeof(double));
         if (t == BinaryFormatter::BF_POSITION_3D) {
-            os.myStream.read((char*) &z, sizeof(SUMOReal));
+            os.myStream.read((char*) &z, sizeof(double));
         }
     }
     p.set(x, y, z);
