@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    2004
-/// @version $Id: OutputDevice_COUT.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: OutputDevice_COUT.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // An output device that encapsulates cout
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2004-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -32,10 +32,6 @@
 #include <iostream>
 #include "OutputDevice_COUT.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static member definitions
