@@ -3,12 +3,12 @@
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    2012
-/// @version $Id: PlainXMLFormatter.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: PlainXMLFormatter.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Static storage of an output device and its base (abstract) implementation
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2012-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -33,15 +33,11 @@
 #include <utils/options/OptionsCont.h>
 #include "PlainXMLFormatter.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // member method definitions
 // ===========================================================================
-PlainXMLFormatter::PlainXMLFormatter(const unsigned int defaultIndentation)
+PlainXMLFormatter::PlainXMLFormatter(const int defaultIndentation)
     : myDefaultIndentation(defaultIndentation), myHavePendingOpener(false) {
 }
 
@@ -59,15 +55,12 @@ PlainXMLFormatter::writeHeader(std::ostream& into, const SumoXMLTag& rootElement
 
 bool
 PlainXMLFormatter::writeXMLHeader(std::ostream& into, const std::string& rootElement,
-                                  const std::string& attrs, const std::string& comment) {
+                                  const std::map<SumoXMLAttr, std::string>& attrs) {
     if (myXMLStack.empty()) {
         OptionsCont::getOptions().writeXMLHeader(into);
-        if (comment != "") {
-            into << comment << "\n";
-        }
         openTag(into, rootElement);
-        if (attrs != "") {
-            into << " " << attrs;
+        for (std::map<SumoXMLAttr, std::string>::const_iterator it = attrs.begin(); it != attrs.end(); ++it) {
+            writeAttr(into, it->first, it->second);
         }
         into << ">\n";
         myHavePendingOpener = false;
