@@ -4,12 +4,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Mon, 17 Dec 2001
-/// @version $Id: Option.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: Option.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Classes representing a single program option (with different types)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -43,7 +43,7 @@
 // ===========================================================================
 /**
  * @typedef IntVector
- * @brief Definition of a vector of unsigned ints
+ * @brief Definition of a vector of ints
  */
 typedef std::vector<int> IntVector;
 
@@ -93,7 +93,7 @@ public:
     void unSet();
 
 
-    /** @brief Returns the stored SUMOReal value
+    /** @brief Returns the stored double value
      *
      * Option_Float returns the stored real number in this method's reimplementation.
      *  All other option classes do not override this method which throws an InvalidArgument-exception.
@@ -101,7 +101,7 @@ public:
      * @return Returns the stored real number if being an instance of Option_Float
      * @exception InvalidArgument If the class is not an instance of Option_Float
      */
-    virtual SUMOReal getFloat() const;
+    virtual double getFloat() const;
 
 
     /** @brief Returns the stored integer value
@@ -312,13 +312,6 @@ private:
  */
 class Option_Integer : public Option {
 public:
-    /** @brief Constructor for an option with no default value
-     *
-     * Calls Option(false)
-     */
-    Option_Integer();
-
-
     /** @brief Constructor for an option with a default value
      *
      * Calls Option(true)
@@ -458,20 +451,13 @@ protected:
  * ----------------------------------------------------------------------- */
 class Option_Float : public Option {
 public:
-    /** @brief Constructor for an option with no default value
-     *
-     * Calls Option(false)
-     */
-    Option_Float();
-
-
     /** @brief Constructor for an option with a default value
      *
      * Calls Option(true)
      *
      * @param[in] value This option's default value
      */
-    Option_Float(SUMOReal value);
+    Option_Float(double value);
 
 
     /** @brief Copy constructor */
@@ -486,27 +472,27 @@ public:
     Option_Float& operator=(const Option_Float& s);
 
 
-    /** @brief Returns the stored SUMOReal value
-     * @see SUMOReal Option::getFloat()
+    /** @brief Returns the stored double value
+     * @see double Option::getFloat()
      * @return Returns the stored real number
      */
-    SUMOReal getFloat() const;
+    double getFloat() const;
 
 
-    /** @brief Stores the given value after parsing it into a SUMOReal
+    /** @brief Stores the given value after parsing it into a double
      *
-     *  The value is converted into a SUMOReal and stored in "myValue".
+     *  The value is converted into a double and stored in "myValue".
      *  Then, "markSet" is called in order to know that a value has been set.
      *
      * The method returns whether the value could be set (the return value from
      *  "markSet").
      *
-     * If the string could not be converted into a SUMOReal, an InvalidArgument
+     * If the string could not be converted into a double, an InvalidArgument
      *  is thrown.
      *
      * @see bool Option::set(std::string v)
      * @return Whether the new value could be set
-     * @exception InvalidArgument If the value could not be converted into a SUMOReal
+     * @exception InvalidArgument If the value could not be converted into a double
      */
     bool set(const std::string& v);
 
@@ -523,7 +509,7 @@ public:
 
 private:
     /** the value, valid only when the base-classes "myAmSet"-member is true */
-    SUMOReal       myValue;
+    double       myValue;
 
 };
 
@@ -533,13 +519,6 @@ private:
  * ----------------------------------------------------------------------- */
 class Option_Bool : public Option {
 public:
-    /** @brief Constructor for an option with no default value
-     *
-     * Calls Option(false)
-     */
-    Option_Bool();
-
-
     /** @brief Constructor for an option with a default value
      *
      * Calls Option(true)
