@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
 /// @date    Mon, 17 Dec 2001
-/// @version $Id: OptionsCont.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: OptionsCont.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A storage for options (typed value containers)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -51,10 +51,6 @@
 #include <utils/xml/SUMOSAXAttributes.h>
 #include <sstream>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static member definitions
@@ -73,7 +69,7 @@ OptionsCont::getOptions() {
 
 OptionsCont::OptionsCont()
     : myAddresses(), myValues(), myDeprecatedSynonymes(), myHaveInformedAboutDeprecatedDivider(false) {
-    myCopyrightNotices.push_back("Copyright (C) 2001-2016 DLR and contributors; http://sumo.dlr.de");
+    myCopyrightNotices.push_back("Copyright (C) 2001-2017 DLR and contributors; http://sumo.dlr.de");
 }
 
 
@@ -216,7 +212,7 @@ OptionsCont::getString(const std::string& name) const {
 }
 
 
-SUMOReal
+double
 OptionsCont::getFloat(const std::string& name) const {
     Option* o = getSecure(name);
     return o->getFloat();
@@ -339,13 +335,18 @@ OptionsCont::relocateFiles(const std::string& configuration) const {
             StringTokenizer st((*i)->getString(), ";, ", true);
             std::string conv;
             while (st.hasNext()) {
-                if (conv.length() != 0) {
-                    conv += ',';
-                }
                 std::string tmp = st.next();
+                // Test whether this is a whitespace string and disregard item if so.
+                // This may stem, e.g., from separating filenames by ', ' in the configuration file
+                if (tmp.find_first_not_of("\t ") == std::string::npos) {
+                    continue;
+                }
                 if (!FileHelpers::isAbsolute(tmp)) {
                     tmp = FileHelpers::getConfigurationRelative(configuration, tmp);
                 }
+                if (conv.length() != 0) {
+                    conv += ',';
+                }
                 conv += StringUtils::urlDecode(tmp);
             }
             if (conv != (*i)->getString()) {
@@ -532,10 +533,10 @@ OptionsCont::addOptionSubTopic(const std::string& topic) {
 
 void
 OptionsCont::splitLines(std::ostream& os, std::string what,
-                        size_t offset, size_t nextOffset) {
+                        int offset, int nextOffset) {
     while (what.length() > 0) {
-        if (what.length() > 79 - offset) {
-            size_t splitPos = what.rfind(';', 79 - offset);
+        if ((int)what.length() > 79 - offset) {
+            std::string::size_type splitPos = what.rfind(';', 79 - offset);
             if (splitPos == std::string::npos) {
                 splitPos = what.rfind(' ', 79 - offset);
             } else {
@@ -544,7 +545,7 @@ OptionsCont::splitLines(std::ostream& os, std::string what,
             if (splitPos != std::string::npos) {
                 os << what.substr(0, splitPos) << std::endl;
                 what = what.substr(splitPos);
-                for (size_t r = 0; r < nextOffset + 1; ++r) {
+                for (int r = 0; r < nextOffset + 1; ++r) {
                     os << ' ';
                 }
             } else {
@@ -680,14 +681,14 @@ OptionsCont::printHelp(std::ostream& os) {
     // print the options
     // check their sizes first
     //  we want to know how large the largest not-too-large-entry will be
-    size_t tooLarge = 40;
-    size_t maxSize = 0;
+    int tooLarge = 40;
+    int maxSize = 0;
     for (i = mySubTopics.begin(); i != mySubTopics.end(); ++i) {
         const std::vector<std::string>& entries = mySubTopicEntries[*i];
         for (j = entries.begin(); j != entries.end(); ++j) {
             Option* o = getSecure(*j);
             // name, two leading spaces and "--"
-            size_t csize = (*j).length() + 2 + 4;
+            int csize = (int)j->length() + 2 + 4;
             // abbreviation length ("-X, "->4chars) if any
             std::vector<std::string> synonymes = getSynonymes(*j);
             if (find_if(synonymes.begin(), synonymes.end(), abbreviation_finder()) != synonymes.end()) {
@@ -695,7 +696,7 @@ OptionsCont::printHelp(std::ostream& os) {
             }
             // the type name
             if (!o->isBool()) {
-                csize += 1 + o->getTypeName().length();
+                csize += 1 + (int)o->getTypeName().length();
             }
             // divider
             csize += 2;
@@ -710,7 +711,7 @@ OptionsCont::printHelp(std::ostream& os) {
         const std::vector<std::string>& entries = mySubTopicEntries[*i];
         for (j = entries.begin(); j != entries.end(); ++j) {
             // start length computation
-            size_t csize = (*j).length() + 2;
+            int csize = (int)j->length() + 2;
             Option* o = getSecure(*j);
             os << "  ";
             // write abbreviation if given
@@ -728,15 +729,15 @@ OptionsCont::printHelp(std::ostream& os) {
             // write the type if not a bool option
             if (!o->isBool()) {
                 os << ' ' << o->getTypeName();
-                csize += 1 + o->getTypeName().length();
+                csize += 1 + (int)o->getTypeName().length();
             }
             csize += 2;
             // write the description formatting it
             os << "  ";
-            for (size_t r = maxSize; r > csize; --r) {
+            for (int r = maxSize; r > csize; --r) {
                 os << ' ';
             }
-            size_t offset = csize > tooLarge ? csize : maxSize;
+            int offset = csize > tooLarge ? csize : maxSize;
             splitLines(os, o->getDescription(), offset, maxSize);
         }
         os << std::endl;
@@ -757,10 +758,19 @@ OptionsCont::printHelp(std::ostream& os) {
 
 
 void
-OptionsCont::writeConfiguration(std::ostream& os, bool filled,
-                                bool complete, bool addComments) const {
+OptionsCont::writeConfiguration(std::ostream& os, const bool filled,
+                                const bool complete, const bool addComments,
+                                const bool maskDoubleHyphen) const {
     os << "<?xml version=\"1.0\"" << SUMOSAXAttributes::ENCODING << "?>\n\n";
-    os << "<configuration xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/" << myAppName << "Configuration.xsd\">" << std::endl << std::endl;
+    os << "<configuration xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/";
+    if (myAppName == "sumo-gui") {
+        os << "sumo";
+    } else if (myAppName == "netedit") {
+        os << "netconvert";
+    } else {
+        os << myAppName;
+    }
+    os << "Configuration.xsd\">" << std::endl << std::endl;
     for (std::vector<std::string>::const_iterator i = mySubTopics.begin(); i != mySubTopics.end(); ++i) {
         std::string subtopic = *i;
         if (subtopic == "Configuration" && !complete) {
@@ -781,12 +791,12 @@ OptionsCont::writeConfiguration(std::ostream& os, bool filled,
             }
             // add the comment if wished
             if (addComments) {
-                os << "        <!-- " << StringUtils::escapeXML(o->getDescription()) << " -->" << std::endl;
+                os << "        <!-- " << StringUtils::escapeXML(o->getDescription(), maskDoubleHyphen) << " -->" << std::endl;
             }
             // write the option and the value (if given)
             os << "        <" << *j << " value=\"";
             if (o->isSet() && (filled || o->isDefault())) {
-                os << o->getValueString();
+                os << StringUtils::escapeXML(o->getValueString(), maskDoubleHyphen);
             }
             if (complete) {
                 std::vector<std::string> synonymes = getSynonymes(*j);
@@ -873,7 +883,7 @@ OptionsCont::writeXMLHeader(std::ostream& os) {
     time(&rawtime);
     strftime(buffer, 80, "<!-- generated on %c by ", localtime(&rawtime));
     os << buffer << myFullName << "\n";
-    writeConfiguration(os, true, false, false);
+    writeConfiguration(os, true, false, false, true);
     os << "-->\n\n";
 }
 
