@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
 /// @date    Mon, 17 Dec 2001
-/// @version $Id: OptionsCont.h 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: OptionsCont.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // A storage for options (typed value containers)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -22,15 +22,6 @@
 /****************************************************************************/
 #ifndef OptionsCont_h
 #define OptionsCont_h
-// ===========================================================================
-// compiler pragmas
-// ===========================================================================
-#ifdef _MSC_VER
-#pragma warning(disable: 4786)
-#pragma warning(disable: 4503)
-#endif
-
-
 // ===========================================================================
 // included modules
 // ===========================================================================
@@ -192,9 +183,11 @@ public:
      * @param[in] filled Whether only set (and not default) options shall be written
      * @param[in] complete Whether all options shall be written
      * @param[in] addComments Whether comments (option descriptions) shall be written
+     * @param[in] maskDoubleHyphen Whether -- in input shall be converted to &#45;&#45; (semantically equivalent but allowed in XML comments)
      */
-    void writeConfiguration(std::ostream& os, bool filled,
-                            bool complete, bool addComments) const;
+    void writeConfiguration(std::ostream& os, const bool filled,
+                            const bool complete, const bool addComments,
+                            const bool maskDoubleHyphen = false) const;
 
 
     /** @brief Writes the xml schema for the configuration
@@ -442,17 +435,17 @@ public:
     std::string getString(const std::string& name) const;
 
 
-    /** @brief Returns the SUMOReal-value of the named option (only for Option_Float)
+    /** @brief Returns the double-value of the named option (only for Option_Float)
      *
-     * This method returns the SUMOReal-value of an existing SUMOReal-option.
-     * If the named option does not exist or is not a SUMOReal-option, an
+     * This method returns the double-value of an existing double-option.
+     * If the named option does not exist or is not a double-option, an
      *  InvalidArgument is thrown.
      *
-     * @param[in] name The name of the option to return the SUMOReal-value of
-     * @return The SUMOReal-value of the named, existing SUMOReal-option
-     * @exception InvalidArgument If the option does not exist or is not a SUMOReal-option
+     * @param[in] name The name of the option to return the double-value of
+     * @return The double-value of the named, existing double-option
+     * @exception InvalidArgument If the option does not exist or is not a double-option
      */
-    SUMOReal getFloat(const std::string& name) const;
+    double getFloat(const std::string& name) const;
 
 
     /** @brief Returns the int-value of the named option (only for Option_Integer)
@@ -709,7 +702,7 @@ private:
      * @todo Describe parameter
      */
     void splitLines(std::ostream& os, std::string what,
-                    size_t offset, size_t nextOffset);
+                    int offset, int nextOffset);
 
 
 private:
