@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 17 Dec 2001
-/// @version $Id: OptionsLoader.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: OptionsLoader.cpp 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // A SAX-Handler for loading options
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -92,7 +92,7 @@ void OptionsLoader::setValue(const std::string& key,
 
 void OptionsLoader::characters(const XMLCh* const chars,
                                const XERCES3_SIZE_t length) {
-    myValue = myValue + TplConvert::_2str(chars, (unsigned int) length);
+    myValue = myValue + TplConvert::_2str(chars, (int) length);
 }
 
 
