@@ -3,12 +3,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Oct 2012
-/// @version $Id: Shape.cpp 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id: Shape.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // A 2D- or 3D-Shape
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2012-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -31,26 +31,22 @@
 
 #include "Shape.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 // ===========================================================================
 // static member definitions
 // ===========================================================================
 const std::string Shape::DEFAULT_TYPE = "";
-const SUMOReal Shape::DEFAULT_LAYER = 128;
-const SUMOReal Shape::DEFAULT_ANGLE = 0;
+const double Shape::DEFAULT_LAYER = 128;
+const double Shape::DEFAULT_ANGLE = 0;
 const std::string Shape::DEFAULT_IMG_FILE = "";
-const SUMOReal Shape::DEFAULT_IMG_WIDTH = 1;
-const SUMOReal Shape::DEFAULT_IMG_HEIGHT = 1;
+const double Shape::DEFAULT_IMG_WIDTH = 1;
+const double Shape::DEFAULT_IMG_HEIGHT = 1;
 
 // ===========================================================================
 // member definitions
 // ===========================================================================
 Shape::Shape(const std::string& id, const std::string& type,
-             const RGBColor& color, SUMOReal layer,
-             SUMOReal angle, const std::string& imgFile) :
+             const RGBColor& color, double layer,
+             double angle, const std::string& imgFile) :
     Named(id),
     myType(type),
     myColor(color),
