@@ -5,12 +5,12 @@
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: ShapeContainer.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: ShapeContainer.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Storage for geometrical objects, sorted by the layers they are in
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -46,10 +46,6 @@
 #include <utils/common/ToString.h>
 #include <utils/common/StdDefs.h>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -60,28 +56,18 @@ ShapeContainer::~ShapeContainer() {}
 
 bool
 ShapeContainer::addPolygon(const std::string& id, const std::string& type,
-                           const RGBColor& color, SUMOReal layer,
-                           SUMOReal angle, const std::string& imgFile,
-                           const PositionVector& shape, bool fill) {
-    Polygon* p = new Polygon(id, type, color, shape, fill, layer, angle, imgFile);
-    if (!myPolygons.add(id, p)) {
-        delete p;
-        return false;
-    }
-    return true;
+                           const RGBColor& color, double layer,
+                           double angle, const std::string& imgFile,
+                           const PositionVector& shape, bool fill, bool ignorePruning) {
+    return add(new SUMO::Polygon(id, type, color, shape, fill, layer, angle, imgFile), ignorePruning);
 }
 
 
 bool
 ShapeContainer::addPOI(const std::string& id, const std::string& type,
-                       const RGBColor& color, SUMOReal layer, SUMOReal angle, const std::string& imgFile,
-                       const Position& pos, SUMOReal width, SUMOReal height) {
-    PointOfInterest* p = new PointOfInterest(id, type, color, pos, layer, angle, imgFile, width, height);
-    if (!myPOIs.add(id, p)) {
-        delete p;
-        return false;
-    }
-    return true;
+                       const RGBColor& color, double layer, double angle, const std::string& imgFile,
+                       const Position& pos, double width, double height, bool ignorePruning) {
+    return add(new PointOfInterest(id, type, color, pos, layer, angle, imgFile, width, height), ignorePruning);
 }
 
 
@@ -109,11 +95,32 @@ ShapeContainer::movePOI(const std::string& id, const Position& pos) {
 
 void
 ShapeContainer::reshapePolygon(const std::string& id, const PositionVector& shape) {
-    Polygon* p = myPolygons.get(id);
+    SUMO::Polygon* p = myPolygons.get(id);
     if (p != 0) {
         p->setShape(shape);
     }
 }
 
+
+bool
+ShapeContainer::add(SUMO::Polygon* poly, bool /* ignorePruning */) {
+    if (!myPolygons.add(poly->getID(), poly)) {
+        delete poly;
+        return false;
+    }
+    return true;
+}
+
+
+bool
+ShapeContainer::add(PointOfInterest* poi, bool /* ignorePruning */) {
+    if (!myPOIs.add(poi->getID(), poi)) {
+        delete poi;
+        return false;
+    }
+    return true;
+}
+
+
 /****************************************************************************/
 
