@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 25 July 2005
-/// @version $Id: DijkstraRouterTT.h 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: DijkstraRouterTT.h 23581 2017-03-21 13:22:47Z behrisch $
 ///
 // Dijkstra shortest path algorithm using travel time
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -71,7 +71,7 @@ template<class E, class V, class PF>
 class DijkstraRouterTT : public SUMOAbstractRouter<E, V>, public PF {
 
 public:
-    typedef SUMOReal(* Operation)(const E* const, const V* const, SUMOReal);
+    typedef double(* Operation)(const E* const, const V* const, double);
 
     /**
      * @struct EdgeInfo
@@ -82,13 +82,13 @@ public:
     public:
         /// Constructor
         EdgeInfo(const E* e)
-            : edge(e), traveltime(std::numeric_limits<SUMOReal>::max()), prev(0), visited(false) {}
+            : edge(e), traveltime(std::numeric_limits<double>::max()), prev(0), visited(false) {}
 
         /// The current edge
         const E* edge;
 
         /// Effort to reach the edge
-        SUMOReal traveltime;
+        double traveltime;
 
         /// The previous edge
         EdgeInfo* prev;
@@ -97,7 +97,7 @@ public:
         bool visited;
 
         inline void reset() {
-            traveltime = std::numeric_limits<SUMOReal>::max();
+            traveltime = std::numeric_limits<double>::max();
             visited = false;
         }
     };
@@ -130,7 +130,7 @@ public:
         SUMOAbstractRouter<E, V>(operation, "DijkstraRouterTT"),
         myErrorMsgHandler(unbuildIsWarning ?  MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance()) {
         for (typename std::vector<EdgeInfo>::const_iterator i = edgeInfos.begin(); i != edgeInfos.end(); ++i) {
-            myEdgeInfos.push_back(*i);
+            myEdgeInfos.push_back(EdgeInfo(i->edge));
         }
     }
 
@@ -161,16 +161,19 @@ public:
         assert(from != 0 && (vehicle == 0 || to != 0));
         // check whether from and to can be used
         if (PF::operator()(from, vehicle)) {
-            myErrorMsgHandler->inform("Vehicle  '" + vehicle->getID() + "' is not allowed on from edge '" + from->getID() + "'.");
+            myErrorMsgHandler->inform("Vehicle '" + vehicle->getID() + "' is not allowed on source edge '" + from->getID() + "'.");
             return false;
         }
         if (PF::operator()(to, vehicle)) {
-            myErrorMsgHandler->inform("Vehicle  '" + vehicle->getID() + "' is not allowed on to edge '" + to->getID() + "'.");
+            myErrorMsgHandler->inform("Vehicle '" + vehicle->getID() + "' is not allowed on destination edge '" + to->getID() + "'.");
             return false;
         }
         this->startQuery();
+#ifdef DijkstraRouterTT_DEBUG_QUERY
+        std::cout << "DEBUG: starting search for '" << vehicle->getID() << "' time: " << STEPS2TIME(msTime) << "\n";
+#endif
         const SUMOVehicleClass vClass = vehicle == 0 ? SVC_IGNORING : vehicle->getVClass();
-        const SUMOReal time = STEPS2TIME(msTime);
+        const double time = STEPS2TIME(msTime);
         if (this->myBulkMode) {
             const EdgeInfo& toInfo = myEdgeInfos[to->getNumericalID()];
             if (toInfo.visited) {
@@ -198,7 +201,7 @@ public:
                 buildPathFrom(minimumInfo, into);
                 this->endQuery(num_visited);
 #ifdef DijkstraRouterTT_DEBUG_QUERY_PERF
-                std::cout << "visited " + toString(num_visited) + " edges (final path length: " + toString(into.size()) + ")\n";
+                std::cout << "visited " + toString(num_visited) + " edges (final path length=" + toString(into.size()) + " edges=" + toString(into) + ")\n";
 #endif
                 return true;
             }
@@ -213,7 +216,7 @@ public:
             }
             std::cout << "\n";
 #endif
-            const SUMOReal traveltime = minimumInfo->traveltime + this->getEffort(minEdge, vehicle, time + minimumInfo->traveltime);
+            const double traveltime = minimumInfo->traveltime + this->getEffort(minEdge, vehicle, time + minimumInfo->traveltime);
             // check all ways from the node with the minimal length
             const std::vector<E*>& successors = minEdge->getSuccessors(vClass);
             for (typename std::vector<E*>::const_iterator it = successors.begin(); it != successors.end(); ++it) {
@@ -223,11 +226,11 @@ public:
                 if (PF::operator()(follower, vehicle)) {
                     continue;
                 }
-                const SUMOReal oldEffort = followerInfo->traveltime;
+                const double oldEffort = followerInfo->traveltime;
                 if (!followerInfo->visited && traveltime < oldEffort) {
                     followerInfo->traveltime = traveltime;
                     followerInfo->prev = minimumInfo;
-                    if (oldEffort == std::numeric_limits<SUMOReal>::max()) {
+                    if (oldEffort == std::numeric_limits<double>::max()) {
                         myFrontierList.push_back(followerInfo);
                         push_heap(myFrontierList.begin(), myFrontierList.end(), myComparator);
                     } else {
@@ -240,7 +243,7 @@ public:
         }
         this->endQuery(num_visited);
 #ifdef DijkstraRouterTT_DEBUG_QUERY_PERF
-        std::cout << "visited " + toString(num_visited) + " edges (final path length: " + toString(into.size()) + ")\n";
+        std::cout << "visited " + toString(num_visited) + " edges (unsuccesful path length: " + toString(into.size()) + ")\n";
 #endif
         if (to != 0) {
             myErrorMsgHandler->inform("No connection between edge '" + from->getID() + "' and edge '" + to->getID() + "' found.");
@@ -249,9 +252,9 @@ public:
     }
 
 
-    SUMOReal recomputeCosts(const std::vector<const E*>& edges, const V* const v, SUMOTime msTime) const {
-        const SUMOReal time = STEPS2TIME(msTime);
-        SUMOReal costs = 0;
+    double recomputeCosts(const std::vector<const E*>& edges, const V* const v, SUMOTime msTime) const {
+        const double time = STEPS2TIME(msTime);
+        double costs = 0;
         for (typename std::vector<const E*>::const_iterator i = edges.begin(); i != edges.end(); ++i) {
             if (PF::operator()(*i, v)) {
                 return -1;
@@ -272,7 +275,7 @@ public:
         std::copy(tmp.rbegin(), tmp.rend(), std::back_inserter(edges));
     }
 
-    const EdgeInfo& getEdgeInfo(size_t index) const {
+    const EdgeInfo& getEdgeInfo(int index) const {
         return myEdgeInfos[index];
     }
 
