@@ -2,12 +2,12 @@
 /// @file    PedestrianRouter.h
 /// @author  Jakob Erdmann
 /// @date    Mon, 03 March 2014
-/// @version $Id: PedestrianRouter.h 21206 2016-07-20 08:08:35Z behrisch $
+/// @version $Id: PedestrianRouter.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // The Pedestrian Router builds a special network and delegates to a SUMOAbstractRouter.
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -86,7 +86,7 @@ public:
 
     /** @brief Builds the route between the given edges using the minimum effort at the given time
         The definition of the effort depends on the wished routing scheme */
-    bool compute(const E* from, const E* to, SUMOReal departPos, SUMOReal arrivalPos, SUMOReal speed,
+    bool compute(const E* from, const E* to, double departPos, double arrivalPos, double speed,
                  SUMOTime msTime, const N* onlyNode, std::vector<const E*>& into, bool allEdges = false) {
         //startQuery();
         if (getSidewalk<E, L>(from) == 0) {
@@ -110,7 +110,7 @@ public:
             }
         }
 #ifdef PedestrianRouter_DEBUG_ROUTES
-        SUMOReal time = msTime;
+        double time = msTime;
         for (int i = 0; i < intoPed.size(); ++i) {
             time += myInternalRouter->getEffort(intoPed[i], &trip, time);
         }
@@ -134,7 +134,7 @@ public:
         throw ProcessError("Do not use this method");
     }
 
-    SUMOReal recomputeCosts(const std::vector<const E*>&, const _IntermodalTrip* const, SUMOTime) const {
+    double recomputeCosts(const std::vector<const E*>&, const _IntermodalTrip* const, SUMOTime) const {
         throw ProcessError("Do not use this method");
     }
 
