@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Fri, 30 Mar 2007
-/// @version $Id: SAXWeightsHandler.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SAXWeightsHandler.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // An XML-handler for network weights
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2007-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2007-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -39,10 +39,6 @@
 #include <utils/xml/SUMOSAXHandler.h>
 #include "SAXWeightsHandler.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -90,8 +86,8 @@ void SAXWeightsHandler::myStartElement(int element,
     switch (element) {
         case SUMO_TAG_INTERVAL: {
             bool ok = true;
-            myCurrentTimeBeg = attrs.get<SUMOReal>(SUMO_ATTR_BEGIN, 0, ok);
-            myCurrentTimeEnd = attrs.get<SUMOReal>(SUMO_ATTR_END, 0, ok);
+            myCurrentTimeBeg = attrs.get<double>(SUMO_ATTR_BEGIN, 0, ok);
+            myCurrentTimeEnd = attrs.get<double>(SUMO_ATTR_END, 0, ok);
         }
         break;
         case SUMO_TAG_EDGE: {
@@ -156,7 +152,7 @@ SAXWeightsHandler::myEndElement(int element) {
         for (i = myDefinitions.begin(); i != myDefinitions.end(); ++i) {
             if ((*i)->myHadAttribute) {
                 (*i)->myDestination.addEdgeWeight(myCurrentEdgeID,
-                                                  (*i)->myAggValue / (SUMOReal)(*i)->myNoLanes,
+                                                  (*i)->myAggValue / (double)(*i)->myNoLanes,
                                                   myCurrentTimeBeg, myCurrentTimeEnd);
             }
         }
