@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: SUMORouteHandler.h 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SUMORouteHandler.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Parser for routes during their loading
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -67,8 +67,8 @@ public:
     SUMOTime getLastDepart() const;
 
     /// check start and end position of a stop
-    static bool checkStopPos(SUMOReal& startPos, SUMOReal& endPos, const SUMOReal laneLength,
-                             const SUMOReal minLength, const bool friendlyPos);
+    static bool checkStopPos(double& startPos, double& endPos, const double laneLength,
+                             const double minLength, const bool friendlyPos);
 
     /// @brief returns the first departure time that was ever read
     SUMOTime getFirstDepart() const {
@@ -128,6 +128,9 @@ protected:
     /// Ends the processing of a person
     virtual void closePerson() = 0;
 
+    /// Ends the processing of a container
+    virtual void closeContainer() = 0;
+
     /// Ends the processing of a flow
     virtual void closeFlow() = 0;
 
@@ -147,7 +150,7 @@ protected:
     bool parseStop(SUMOVehicleParameter::Stop& stop, const SUMOSAXAttributes& attrs, std::string errorSuffix, MsgHandler* const errorOutput);
 
 protected:
-    /// @brief Parameter of the current vehicle, trip, person, or flow
+    /// @brief Parameter of the current vehicle, trip, person, container or flow
     SUMOVehicleParameter* myVehicleParameter;
 
     /// @brief The insertion time of the vehicle read last
@@ -160,13 +163,13 @@ protected:
     std::string myActiveRouteRefID;
 
     /// @brief The probability of the current route
-    SUMOReal myActiveRouteProbability;
+    double myActiveRouteProbability;
 
     /// @brief The currently parsed route's color
     const RGBColor* myActiveRouteColor;
 
     /// @brief The currently parsed route costs
-    SUMOReal myCurrentCosts;
+    double myCurrentCosts;
 
     /// @brief List of the stops on the parsed route
     std::vector<SUMOVehicleParameter::Stop> myActiveRouteStops;
@@ -186,6 +189,9 @@ protected:
     /// @brief the first read departure time
     SUMOTime myFirstDepart;
 
+    /// @brief where stop edges can be inserted into the current route (-1 means no insertion)
+    int myInsertStopEdgesAt;
+
 private:
     /// @brief Invalidated copy constructor
     SUMORouteHandler(const SUMORouteHandler& s);
