@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: SUMOSAXAttributesImpl_Binary.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SUMOSAXAttributesImpl_Binary.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
-// Encapsulated Xerces-SAX-attributes
+// Encapsulated xml-attributes that are retrieved from the sumo-binary-xml format (already typed)
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -39,10 +39,7 @@
 #include <utils/iodevices/BinaryFormatter.h>
 #include <utils/iodevices/BinaryInputDevice.h>
 #include "SUMOSAXAttributesImpl_Binary.h"
-
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
+#include "SUMOSAXAttributesImpl_Cached.h"
 
 
 // ===========================================================================
@@ -51,10 +48,17 @@
 SUMOSAXAttributesImpl_Binary::SUMOSAXAttributesImpl_Binary(
     const std::map<int, std::string>& predefinedTagsMML,
     const std::string& objectType,
-    BinaryInputDevice* in) : SUMOSAXAttributes(objectType), myAttrIds(predefinedTagsMML) {
+    BinaryInputDevice* in, const char version) : SUMOSAXAttributes(objectType), myAttrIds(predefinedTagsMML) {
     while (in->peek() == BinaryFormatter::BF_XML_ATTRIBUTE) {
-        unsigned char attr;
-        *in >> attr;
+        int attr;
+        unsigned char attrByte;
+        *in >> attrByte;
+        attr = attrByte;
+        if (version > 1) {
+            in->putback(BinaryFormatter::BF_BYTE);
+            *in >> attrByte;
+            attr += 256 * attrByte;
+        }
         int type = in->peek();
         switch (type) {
             case BinaryFormatter::BF_BYTE:
@@ -148,7 +152,7 @@ SUMOSAXAttributesImpl_Binary::SUMOSAXAttributesImpl_Binary(
                 break;
             }
             default:
-                throw ProcessError("Invalid binary file");
+                throw ProcessError("Binary file is invalid, attribute type is unknown.");
         }
         myAttrs.insert(attr);
     }
@@ -185,7 +189,7 @@ SUMOSAXAttributesImpl_Binary::getInt(int id) const {
 }
 
 
-SUMOLong
+long long int
 SUMOSAXAttributesImpl_Binary::getLong(int /* id */) const {
     throw NumberFormatException();
 }
@@ -212,17 +216,17 @@ SUMOSAXAttributesImpl_Binary::getStringSecure(int id,
 }
 
 
-SUMOReal
+double
 SUMOSAXAttributesImpl_Binary::getFloat(int id) const {
-    const std::map<int, SUMOReal>::const_iterator i = myFloatValues.find(id);
+    const std::map<int, double>::const_iterator i = myFloatValues.find(id);
     if (i == myFloatValues.end()) {
-        return TplConvert::_2SUMOReal(getString(id).c_str());
+        return TplConvert::_2double(getString(id).c_str());
     }
     return i->second;
 }
 
 
-SUMOReal
+double
 SUMOSAXAttributesImpl_Binary::getFloat(const std::string& /* id */) const {
     throw ProcessError("not implemented for binary data");
 }
@@ -330,5 +334,31 @@ SUMOSAXAttributesImpl_Binary::serialize(std::ostream& os) const {
 }
 
 
+SUMOSAXAttributes*
+SUMOSAXAttributesImpl_Binary::clone() const {
+    std::map<std::string, std::string> attrs;
+    for (std::map<int, char>::const_iterator it = myCharValues.begin(); it != myCharValues.end(); ++it) {
+        const std::string attrName = myAttrIds.find(it->first)->second;
+        attrs[attrName] = toString(it->second);
+    }
+    for (std::map<int, int>::const_iterator it = myIntValues.begin(); it != myIntValues.end(); ++it) {
+        const std::string attrName = myAttrIds.find(it->first)->second;
+        attrs[attrName] = toString(it->second);
+    }
+    for (std::map<int, double>::const_iterator it = myFloatValues.begin(); it != myFloatValues.end(); ++it) {
+        const std::string attrName = myAttrIds.find(it->first)->second;
+        attrs[attrName] = toString(it->second);
+    }
+    for (std::map<int, std::string>::const_iterator it = myStringValues.begin(); it != myStringValues.end(); ++it) {
+        const std::string attrName = myAttrIds.find(it->first)->second;
+        attrs[attrName] = it->second;
+    }
+    for (std::map<int, PositionVector>::const_iterator it = myPositionVectors.begin(); it != myPositionVectors.end(); ++it) {
+        const std::string attrName = myAttrIds.find(it->first)->second;
+        attrs[attrName] = toString(it->second);
+    }
+    return new SUMOSAXAttributesImpl_Cached(attrs, myAttrIds, getObjectType());
+}
+
 /****************************************************************************/
 
