@@ -4,12 +4,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: SUMOSAXAttributesImpl_Xerces.cpp 17235 2014-11-03 10:53:02Z behrisch $
+/// @version $Id: SUMOSAXAttributesImpl_Xerces.cpp 23529 2017-03-18 10:22:36Z behrisch $
 ///
 // Encapsulated Xerces-SAX-attributes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2002-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -35,16 +35,14 @@
 #include <xercesc/sax2/DefaultHandler.hpp>
 #include <xercesc/util/XercesVersion.hpp>
 #include <xercesc/util/TransService.hpp>
+#include <xercesc/util/TranscodingException.hpp>
 #include <utils/common/RGBColor.h>
 #include <utils/common/StringTokenizer.h>
 #include <utils/common/TplConvert.h>
 #include <utils/geom/Boundary.h>
 #include <utils/geom/PositionVector.h>
 #include "SUMOSAXAttributesImpl_Xerces.h"
-
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
+#include "SUMOSAXAttributesImpl_Cached.h"
 
 
 // ===========================================================================
@@ -86,7 +84,7 @@ SUMOSAXAttributesImpl_Xerces::getInt(int id) const {
 }
 
 
-SUMOLong
+long long int
 SUMOSAXAttributesImpl_Xerces::getLong(int id) const {
     return TplConvert::_2long(getAttributeValueSecure(id));
 }
@@ -105,8 +103,12 @@ SUMOSAXAttributesImpl_Xerces::getString(int id) const {
         // TranscodeToStr and debug_new interact badly in this case;
         return "";
     } else {
-        XERCES_CPP_NAMESPACE::TranscodeToStr utf8(utf16, "UTF-8");
-        return TplConvert::_2str(utf8.str(), (unsigned)utf8.length());
+        try {
+            XERCES_CPP_NAMESPACE::TranscodeToStr utf8(utf16, "UTF-8");
+            return TplConvert::_2str(utf8.str(), (unsigned)utf8.length());
+        } catch (XERCES_CPP_NAMESPACE::TranscodingException e) {
+            return "?";
+        }
     }
 #endif
 }
@@ -126,16 +128,20 @@ SUMOSAXAttributesImpl_Xerces::getStringSecure(int id,
         // TranscodeToStr and debug_new interact badly in this case;
         return "";
     } else {
-        XERCES_CPP_NAMESPACE::TranscodeToStr utf8(utf16, "UTF-8");
-        return TplConvert::_2strSec(utf8.str(), (unsigned)utf8.length(), str);
+        try {
+            XERCES_CPP_NAMESPACE::TranscodeToStr utf8(utf16, "UTF-8");
+            return TplConvert::_2strSec(utf8.str(), (unsigned)utf8.length(), str);
+        } catch (XERCES_CPP_NAMESPACE::TranscodingException e) {
+            return "?";
+        }
     }
 #endif
 }
 
 
-SUMOReal
+double
 SUMOSAXAttributesImpl_Xerces::getFloat(int id) const {
-    return TplConvert::_2SUMOReal(getAttributeValueSecure(id));
+    return TplConvert::_2double(getAttributeValueSecure(id));
 }
 
 
@@ -147,10 +153,10 @@ SUMOSAXAttributesImpl_Xerces::getAttributeValueSecure(int id) const {
 }
 
 
-SUMOReal
+double
 SUMOSAXAttributesImpl_Xerces::getFloat(const std::string& id) const {
     XMLCh* t = XERCES_CPP_NAMESPACE::XMLString::transcode(id.c_str());
-    SUMOReal result = TplConvert::_2SUMOReal(myAttrs.getValue(t));
+    double result = TplConvert::_2double(myAttrs.getValue(t));
     XERCES_CPP_NAMESPACE::XMLString::release(&t);
     return result;
 }
@@ -216,12 +222,12 @@ SUMOSAXAttributesImpl_Xerces::getShape(int attr) const {
         if (pos.size() != 2 && pos.size() != 3) {
             throw FormatException("shape format");
         }
-        SUMOReal x = TplConvert::_2SUMOReal(pos.next().c_str());
-        SUMOReal y = TplConvert::_2SUMOReal(pos.next().c_str());
+        double x = TplConvert::_2double(pos.next().c_str());
+        double y = TplConvert::_2double(pos.next().c_str());
         if (pos.size() == 2) {
             shape.push_back(Position(x, y));
         } else {
-            SUMOReal z = TplConvert::_2SUMOReal(pos.next().c_str());
+            double z = TplConvert::_2double(pos.next().c_str());
             shape.push_back(Position(x, y, z));
         }
     }
@@ -236,10 +242,10 @@ SUMOSAXAttributesImpl_Xerces::getBoundary(int attr) const {
     if (st.size() != 4) {
         throw FormatException("boundary format");
     }
-    const SUMOReal xmin = TplConvert::_2SUMOReal(st.next().c_str());
-    const SUMOReal ymin = TplConvert::_2SUMOReal(st.next().c_str());
-    const SUMOReal xmax = TplConvert::_2SUMOReal(st.next().c_str());
-    const SUMOReal ymax = TplConvert::_2SUMOReal(st.next().c_str());
+    const double xmin = TplConvert::_2double(st.next().c_str());
+    const double ymin = TplConvert::_2double(st.next().c_str());
+    const double xmax = TplConvert::_2double(st.next().c_str());
+    const double ymax = TplConvert::_2double(st.next().c_str());
     return Boundary(xmin, ymin, xmax, ymax);
 }
 
@@ -271,5 +277,14 @@ SUMOSAXAttributesImpl_Xerces::serialize(std::ostream& os) const {
 }
 
 
+SUMOSAXAttributes*
+SUMOSAXAttributesImpl_Xerces::clone() const {
+    std::map<std::string, std::string> attrs;
+    for (int i = 0; i < (int)myAttrs.getLength(); ++i) {
+        attrs[TplConvert::_2str(myAttrs.getLocalName(i))] = TplConvert::_2str(myAttrs.getValue(i));
+    }
+    return new SUMOSAXAttributesImpl_Cached(attrs, myPredefinedTagsMML, getObjectType());
+}
+
 /****************************************************************************/
 
