@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Mon, 07.04.2008
-/// @version $Id: SUMOVehicleParserHelper.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: SUMOVehicleParserHelper.cpp 23709 2017-03-29 12:44:12Z namdre $
 ///
 // Helper methods for parsing vehicle attributes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2008-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2008-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -41,15 +41,12 @@
 #include <utils/options/OptionsCont.h>
 #include "SUMOVehicleParserHelper.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // static members
 // ===========================================================================
 SUMOVehicleParserHelper::CFAttrMap SUMOVehicleParserHelper::allowedCFModelAttrs;
+SUMOVehicleParserHelper::LCAttrMap SUMOVehicleParserHelper::allowedLCModelAttrs;
 
 
 // ===========================================================================
@@ -108,7 +105,7 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
     }
     if (attrs.hasAttribute(SUMO_ATTR_VEHSPERHOUR)) {
         ret->setParameter |= VEHPARS_PERIODFREQ_SET;
-        const SUMOReal vph = attrs.get<SUMOReal>(SUMO_ATTR_VEHSPERHOUR, id.c_str(), ok);
+        const double vph = attrs.get<double>(SUMO_ATTR_VEHSPERHOUR, id.c_str(), ok);
         if (ok && vph <= 0) {
             delete ret;
             throw ProcessError("Invalid repetition rate in the definition of flow '" + id + "'.");
@@ -118,7 +115,7 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
         }
     }
     if (attrs.hasAttribute(SUMO_ATTR_PROB)) {
-        ret->repetitionProbability = attrs.get<SUMOReal>(SUMO_ATTR_PROB, id.c_str(), ok);
+        ret->repetitionProbability = attrs.get<double>(SUMO_ATTR_PROB, id.c_str(), ok);
         if (ok && (ret->repetitionProbability <= 0 || ret->repetitionProbability > 1)) {
             delete ret;
             throw ProcessError("Invalid repetition probability in the definition of flow '" + id + "'.");
@@ -140,9 +137,9 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
     if (attrs.hasAttribute(SUMO_ATTR_END)) {
         ret->repetitionEnd = attrs.getSUMOTimeReporting(SUMO_ATTR_END, id.c_str(), ok);
     }
-    if (ok && ret->repetitionEnd <= ret->depart) {
+    if (ok && ret->repetitionEnd < ret->depart) {
         delete ret;
-        throw ProcessError("Flow '" + id + "' ends before or at its begin time.");
+        throw ProcessError("Flow '" + id + "' ends before its begin time.");
     }
     if (attrs.hasAttribute(SUMO_ATTR_NUMBER)) {
         ret->repetitionNumber = attrs.get<int>(SUMO_ATTR_NUMBER, id.c_str(), ok);
@@ -171,7 +168,8 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
             if (ret->repetitionEnd == SUMOTime_MAX) {
                 ret->repetitionNumber = std::numeric_limits<int>::max();
             } else {
-                ret->repetitionNumber = MAX2(1, (int)(((SUMOReal)(ret->repetitionEnd - ret->depart)) / ret->repetitionOffset + 0.5));
+                const double repLength = (double)(ret->repetitionEnd - ret->depart);
+                ret->repetitionNumber = (int)ceil(repLength / ret->repetitionOffset);
             }
         }
     }
@@ -265,6 +263,14 @@ SUMOVehicleParserHelper::parseCommonAttributes(const SUMOSAXAttributes& attrs,
             throw ProcessError(error);
         }
     }
+    // parse lateral depart position information
+    if (attrs.hasAttribute(SUMO_ATTR_DEPARTPOS_LAT)) {
+        ret->setParameter |= VEHPARS_DEPARTPOSLAT_SET;
+        const std::string helper = attrs.get<std::string>(SUMO_ATTR_DEPARTPOS_LAT, ret->id.c_str(), ok);
+        if (!SUMOVehicleParameter::parseDepartPosLat(helper, element, ret->id, ret->departPosLat, ret->departPosLatProcedure, error)) {
+            throw ProcessError(error);
+        }
+    }
     // parse depart speed information
     if (attrs.hasAttribute(SUMO_ATTR_DEPARTSPEED)) {
         ret->setParameter |= VEHPARS_DEPARTSPEED_SET;
@@ -290,6 +296,14 @@ SUMOVehicleParserHelper::parseCommonAttributes(const SUMOSAXAttributes& attrs,
             throw ProcessError(error);
         }
     }
+    // parse lateral arrival position information
+    if (attrs.hasAttribute(SUMO_ATTR_ARRIVALPOS_LAT)) {
+        ret->setParameter |= VEHPARS_ARRIVALPOSLAT_SET;
+        std::string helper = attrs.get<std::string>(SUMO_ATTR_ARRIVALPOS_LAT, ret->id.c_str(), ok);
+        if (!SUMOVehicleParameter::parseArrivalPosLat(helper, element, ret->id, ret->arrivalPosLat, ret->arrivalPosLatProcedure, error)) {
+            throw ProcessError(error);
+        }
+    }
     // parse arrival speed information
     if (attrs.hasAttribute(SUMO_ATTR_ARRIVALSPEED)) {
         ret->setParameter |= VEHPARS_ARRIVALSPEED_SET;
@@ -332,24 +346,24 @@ SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const
         vtype->setParameter |= VTYPEPARS_VEHICLECLASS_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_LENGTH)) {
-        vtype->length = attrs.get<SUMOReal>(SUMO_ATTR_LENGTH, vtype->id.c_str(), ok);
+        vtype->length = attrs.get<double>(SUMO_ATTR_LENGTH, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_LENGTH_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_MINGAP)) {
-        vtype->minGap = attrs.get<SUMOReal>(SUMO_ATTR_MINGAP, vtype->id.c_str(), ok);
+        vtype->minGap = attrs.get<double>(SUMO_ATTR_MINGAP, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_MINGAP_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_MAXSPEED)) {
-        vtype->maxSpeed = attrs.get<SUMOReal>(SUMO_ATTR_MAXSPEED, vtype->id.c_str(), ok);
+        vtype->maxSpeed = attrs.get<double>(SUMO_ATTR_MAXSPEED, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_MAXSPEED_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_SPEEDFACTOR)) {
-        vtype->speedFactor = attrs.get<SUMOReal>(SUMO_ATTR_SPEEDFACTOR, vtype->id.c_str(), ok);
+        vtype->speedFactor = Distribution_Parameterized(attrs.get<std::string>(SUMO_ATTR_SPEEDFACTOR, vtype->id.c_str(), ok));
         vtype->setParameter |= VTYPEPARS_SPEEDFACTOR_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_SPEEDDEV)) {
-        vtype->speedDev = attrs.get<SUMOReal>(SUMO_ATTR_SPEEDDEV, vtype->id.c_str(), ok);
-        vtype->setParameter |= VTYPEPARS_SPEEDDEVIATION_SET;
+        vtype->speedFactor.getParameter()[1] = attrs.get<double>(SUMO_ATTR_SPEEDDEV, vtype->id.c_str(), ok);
+        vtype->setParameter |= VTYPEPARS_SPEEDFACTOR_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_EMISSIONCLASS)) {
         vtype->emissionClass = parseEmissionClass(attrs, vtype->id);
@@ -357,18 +371,18 @@ SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const
     }
     if (attrs.hasAttribute(SUMO_ATTR_IMPATIENCE)) {
         if (attrs.get<std::string>(SUMO_ATTR_IMPATIENCE, vtype->id.c_str(), ok) == "off") {
-            vtype->impatience = -std::numeric_limits<SUMOReal>::max();
+            vtype->impatience = -std::numeric_limits<double>::max();
         } else {
-            vtype->impatience = attrs.get<SUMOReal>(SUMO_ATTR_IMPATIENCE, vtype->id.c_str(), ok);
+            vtype->impatience = attrs.get<double>(SUMO_ATTR_IMPATIENCE, vtype->id.c_str(), ok);
         }
         vtype->setParameter |= VTYPEPARS_IMPATIENCE_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_WIDTH)) {
-        vtype->width = attrs.get<SUMOReal>(SUMO_ATTR_WIDTH, vtype->id.c_str(), ok);
+        vtype->width = attrs.get<double>(SUMO_ATTR_WIDTH, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_WIDTH_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_HEIGHT)) {
-        vtype->height = attrs.get<SUMOReal>(SUMO_ATTR_HEIGHT, vtype->id.c_str(), ok);
+        vtype->height = attrs.get<double>(SUMO_ATTR_HEIGHT, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_HEIGHT_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_GUISHAPE)) {
@@ -393,14 +407,18 @@ SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const
         vtype->color = RGBColor::YELLOW;
     }
     if (attrs.hasAttribute(SUMO_ATTR_PROB)) {
-        vtype->defaultProbability = attrs.get<SUMOReal>(SUMO_ATTR_PROB, vtype->id.c_str(), ok);
+        vtype->defaultProbability = attrs.get<double>(SUMO_ATTR_PROB, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_PROBABILITY_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_LANE_CHANGE_MODEL)) {
-        const std::string lcmS = attrs.get<std::string>(SUMO_ATTR_LANE_CHANGE_MODEL, vtype->id.c_str(), ok);
+        vtype->setParameter |= VTYPEPARS_LANE_CHANGE_MODEL_SET;
+        std::string lcmS = attrs.get<std::string>(SUMO_ATTR_LANE_CHANGE_MODEL, vtype->id.c_str(), ok);
+        if (lcmS == "JE2013") {
+            WRITE_WARNING("Lane change model 'JE2013' is deprecated. Using default model instead.");
+            lcmS = "default";
+        }
         if (SUMOXMLDefinitions::LaneChangeModels.hasString(lcmS)) {
             vtype->lcModel = SUMOXMLDefinitions::LaneChangeModels.get(lcmS);
-            vtype->setParameter |= VTYPEPARS_LANE_CHANGE_MODEL_SET;
         } else {
             WRITE_ERROR("Unknown lane change model '" + lcmS + "' when parsing vtype '" + vtype->id + "'");
             throw ProcessError();
@@ -432,7 +450,26 @@ SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const
         vtype->loadingDuration = attrs.getSUMOTimeReporting(SUMO_ATTR_LOADING_DURATION, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_LOADING_DURATION;
     }
+    if (attrs.hasAttribute(SUMO_ATTR_MAXSPEED_LAT)) {
+        vtype->maxSpeedLat = attrs.get<double>(SUMO_ATTR_MAXSPEED_LAT, vtype->id.c_str(), ok);
+        vtype->setParameter |= VTYPEPARS_MAXSPEED_LAT_SET;
+    }
+    if (attrs.hasAttribute(SUMO_ATTR_MINGAP_LAT)) {
+        vtype->minGapLat = attrs.get<double>(SUMO_ATTR_MINGAP_LAT, vtype->id.c_str(), ok);
+        vtype->setParameter |= VTYPEPARS_MINGAP_LAT_SET;
+    }
+    if (attrs.hasAttribute(SUMO_ATTR_LATALIGNMENT)) {
+        const std::string alignS = attrs.get<std::string>(SUMO_ATTR_LATALIGNMENT, vtype->id.c_str(), ok);
+        if (SUMOXMLDefinitions::LateralAlignments.hasString(alignS)) {
+            vtype->latAlignment = SUMOXMLDefinitions::LateralAlignments.get(alignS);
+            vtype->setParameter |= VTYPEPARS_LATALIGNMENT_SET;
+        } else {
+            WRITE_ERROR("Unknown lateral alignment '" + alignS + "' when parsing vtype '" + vtype->id + "'");
+            throw ProcessError();
+        }
+    }
     parseVTypeEmbedded(*vtype, vtype->cfModel, attrs, true);
+    parseLCParams(*vtype, vtype->lcModel, attrs);
     if (!ok) {
         delete vtype;
         throw ProcessError();
@@ -468,8 +505,8 @@ SUMOVehicleParserHelper::parseVTypeEmbedded(SUMOVTypeParameter& into,
     bool ok = true;
     for (std::set<SumoXMLAttr>::const_iterator it = cf_it->second.begin(); it != cf_it->second.end(); it++) {
         if (attrs.hasAttribute(*it)) {
-            into.cfParameter[*it] = attrs.get<SUMOReal>(*it, into.id.c_str(), ok);
-            if (*it == SUMO_ATTR_TAU && TIME2STEPS(into.cfParameter[*it]) < DELTA_T) {
+            into.cfParameter[*it] = attrs.get<std::string>(*it, into.id.c_str(), ok);
+            if (*it == SUMO_ATTR_TAU && string2time(into.cfParameter[*it]) < DELTA_T) {
                 WRITE_WARNING("Value of tau=" + toString(into.cfParameter[*it])
                               + " in car following model '" + toString(into.cfModel) + "' lower than simulation step size may cause collisions");
             }
@@ -488,15 +525,25 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> krausParams;
         krausParams.insert(SUMO_ATTR_ACCEL);
         krausParams.insert(SUMO_ATTR_DECEL);
+        krausParams.insert(SUMO_ATTR_APPARENTDECEL);
+        krausParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         krausParams.insert(SUMO_ATTR_SIGMA);
         krausParams.insert(SUMO_ATTR_TAU);
         allowedCFModelAttrs[SUMO_TAG_CF_KRAUSS] = krausParams;
         allowedCFModelAttrs[SUMO_TAG_CF_KRAUSS_ORIG1] = krausParams;
         allowedCFModelAttrs[SUMO_TAG_CF_KRAUSS_PLUS_SLOPE] = krausParams;
 
+        allowedCFModelAttrs[SUMO_TAG_CF_KRAUSSX] = krausParams;
+        allowedCFModelAttrs[SUMO_TAG_CF_KRAUSSX].insert(SUMO_ATTR_TMP1);
+        allowedCFModelAttrs[SUMO_TAG_CF_KRAUSSX].insert(SUMO_ATTR_TMP2);
+        allowedCFModelAttrs[SUMO_TAG_CF_KRAUSSX].insert(SUMO_ATTR_TMP3);
+        allowedCFModelAttrs[SUMO_TAG_CF_KRAUSSX].insert(SUMO_ATTR_TMP4);
+        allowedCFModelAttrs[SUMO_TAG_CF_KRAUSSX].insert(SUMO_ATTR_TMP5);
+
         std::set<SumoXMLAttr> smartSKParams;
         smartSKParams.insert(SUMO_ATTR_ACCEL);
         smartSKParams.insert(SUMO_ATTR_DECEL);
+        smartSKParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         smartSKParams.insert(SUMO_ATTR_SIGMA);
         smartSKParams.insert(SUMO_ATTR_TAU);
         smartSKParams.insert(SUMO_ATTR_TMP1);
@@ -509,6 +556,7 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> daniel1Params;
         daniel1Params.insert(SUMO_ATTR_ACCEL);
         daniel1Params.insert(SUMO_ATTR_DECEL);
+        daniel1Params.insert(SUMO_ATTR_EMERGENCYDECEL);
         daniel1Params.insert(SUMO_ATTR_SIGMA);
         daniel1Params.insert(SUMO_ATTR_TAU);
         daniel1Params.insert(SUMO_ATTR_TMP1);
@@ -521,6 +569,7 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> pwagParams;
         pwagParams.insert(SUMO_ATTR_ACCEL);
         pwagParams.insert(SUMO_ATTR_DECEL);
+        pwagParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         pwagParams.insert(SUMO_ATTR_SIGMA);
         pwagParams.insert(SUMO_ATTR_TAU);
         pwagParams.insert(SUMO_ATTR_CF_PWAGNER2009_TAULAST);
@@ -530,6 +579,7 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> idmParams;
         idmParams.insert(SUMO_ATTR_ACCEL);
         idmParams.insert(SUMO_ATTR_DECEL);
+        idmParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         idmParams.insert(SUMO_ATTR_TAU);
         idmParams.insert(SUMO_ATTR_CF_IDM_DELTA);
         idmParams.insert(SUMO_ATTR_CF_IDM_STEPPING);
@@ -538,6 +588,7 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> idmmParams;
         idmmParams.insert(SUMO_ATTR_ACCEL);
         idmmParams.insert(SUMO_ATTR_DECEL);
+        idmmParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         idmmParams.insert(SUMO_ATTR_TAU);
         idmmParams.insert(SUMO_ATTR_CF_IDMM_ADAPT_FACTOR);
         idmmParams.insert(SUMO_ATTR_CF_IDMM_ADAPT_TIME);
@@ -547,6 +598,7 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> bkernerParams;
         bkernerParams.insert(SUMO_ATTR_ACCEL);
         bkernerParams.insert(SUMO_ATTR_DECEL);
+        bkernerParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         bkernerParams.insert(SUMO_ATTR_TAU);
         bkernerParams.insert(SUMO_ATTR_K);
         bkernerParams.insert(SUMO_ATTR_CF_KERNER_PHI);
@@ -555,14 +607,57 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
         std::set<SumoXMLAttr> wiedemannParams;
         wiedemannParams.insert(SUMO_ATTR_ACCEL);
         wiedemannParams.insert(SUMO_ATTR_DECEL);
+        wiedemannParams.insert(SUMO_ATTR_EMERGENCYDECEL);
         wiedemannParams.insert(SUMO_ATTR_CF_WIEDEMANN_SECURITY);
         wiedemannParams.insert(SUMO_ATTR_CF_WIEDEMANN_ESTIMATION);
         allowedCFModelAttrs[SUMO_TAG_CF_WIEDEMANN] = wiedemannParams;
+
+        std::set<SumoXMLAttr> railParamms;
+        railParamms.insert(SUMO_ATTR_TRAIN_TYPE);
+        allowedCFModelAttrs[SUMO_TAG_CF_RAIL] = railParamms;
     }
     return allowedCFModelAttrs;
 }
 
 
+void
+SUMOVehicleParserHelper::parseLCParams(SUMOVTypeParameter& into, LaneChangeModel model, const SUMOSAXAttributes& attrs) {
+    if (allowedLCModelAttrs.size() == 0) {
+        // init static map
+        std::set<SumoXMLAttr> lc2013Params;
+        lc2013Params.insert(SUMO_ATTR_LCA_STRATEGIC_PARAM);
+        lc2013Params.insert(SUMO_ATTR_LCA_COOPERATIVE_PARAM);
+        lc2013Params.insert(SUMO_ATTR_LCA_SPEEDGAIN_PARAM);
+        lc2013Params.insert(SUMO_ATTR_LCA_KEEPRIGHT_PARAM);
+        lc2013Params.insert(SUMO_ATTR_LCA_EXPERIMENTAL1);
+        allowedLCModelAttrs[LCM_LC2013] = lc2013Params;
+
+        std::set<SumoXMLAttr> sl2015Params = lc2013Params;
+        sl2015Params.insert(SUMO_ATTR_LCA_PUSHY);
+        sl2015Params.insert(SUMO_ATTR_LCA_SUBLANE_PARAM);
+        sl2015Params.insert(SUMO_ATTR_LCA_ASSERTIVE);
+        allowedLCModelAttrs[LCM_SL2015] = sl2015Params;
+
+        std::set<SumoXMLAttr> noParams;
+        allowedLCModelAttrs[LCM_DK2008] = noParams;
+
+        // default model may be either LC2013 or SL2013
+        // we allow both sets (sl2015 is a superset of lc2013Params)
+        allowedLCModelAttrs[LCM_DEFAULT] = sl2015Params;
+    }
+    bool ok = true;
+    std::set<SumoXMLAttr> allowed = allowedLCModelAttrs[model];
+    for (std::set<SumoXMLAttr>::const_iterator it = allowed.begin(); it != allowed.end(); it++) {
+        if (attrs.hasAttribute(*it)) {
+            into.lcParameter[*it] = attrs.get<std::string>(*it, into.id.c_str(), ok);
+        }
+    }
+    if (!ok) {
+        throw ProcessError();
+    }
+}
+
+
 SUMOVehicleClass
 SUMOVehicleParserHelper::parseVehicleClass(const SUMOSAXAttributes& attrs,
         const std::string& id) {
