@@ -4,13 +4,13 @@
 @author  Daniel Krajzewicz
 @author  Michael Behrisch
 @date    2007-10-25
-@version $Id: inputs.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: inputs.py 22608 2017-01-17 06:28:54Z behrisch $
 
 This script is to retrieve the assignment parameters, the OD districts and the matrix from the input files. 
 Moreover, the link travel time for district connectors will be estimated.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2007-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2007-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -18,8 +18,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import print_function
 
 # read the analyzed matrix
+
+
 def getMatrix(net, verbose, matrix, matrixSum, demandscale=None):
     matrixPshort = []
     startVertices = []
@@ -27,10 +30,10 @@ def getMatrix(net, verbose, matrix, matrixSum, demandscale=None):
     Pshort_EffCells = 0
     periodList = []
     if verbose:
-        print 'matrix:', str(matrix)
+        print('matrix:', str(matrix))
     odpairs = 0
     origins = 0
-    dest= 0
+    dest = 0
     currentMatrixSum = 0.0
     skipCount = 0
     zones = 0
@@ -77,33 +80,36 @@ def getMatrix(net, verbose, matrix, matrixSum, demandscale=None):
                             smallDemandNum += 1
     begintime = int(periodList[0])
     assignPeriod = int(periodList[1]) - begintime
-    smallDemandRatio = float(smallDemandNum)/float(Pshort_EffCells)
-    
+    smallDemandRatio = float(smallDemandNum) / float(Pshort_EffCells)
+
     if verbose:
-        print 'Number of zones:', zones
-        print 'Number of origins:', origins
-        print 'Number of destinations:', dest
-        print 'begintime:', begintime
-        print 'currentMatrixSum:', currentMatrixSum
-        print 'Effective O-D Cells:', Pshort_EffCells
-        print 'number of start Vertices:', net.getstartCounts()
-        print 'number of end Vertices):', net.getendCounts()
-        print 'smallDemandRatio):', smallDemandRatio
-    
+        print('Number of zones:', zones)
+        print('Number of origins:', origins)
+        print('Number of destinations:', dest)
+        print('begintime:', begintime)
+        print('currentMatrixSum:', currentMatrixSum)
+        print('Effective O-D Cells:', Pshort_EffCells)
+        print('number of start Vertices:', net.getstartCounts())
+        print('number of end Vertices):', net.getendCounts())
+        print('smallDemandRatio):', smallDemandRatio)
+
     return matrixPshort, startVertices, endVertices, currentMatrixSum, begintime, assignPeriod, Pshort_EffCells, matrixSum, smallDemandRatio
 
 # estimate the travel times on the district connectors
-# assumption: all vehilces can reach the access links within 20 min (1200 sec) from the respective traffic zone
+# assumption: all vehilces can reach the access links within 20 min (1200
+# sec) from the respective traffic zone
+
+
 def getConnectionTravelTime(startVertices, endVertices):
     for vertex in startVertices:
         weightList = []
         for edge in vertex.getOutgoing():
-           weightList.append(float(edge.ratio))
+            weightList.append(float(edge.ratio))
         if len(weightList) > 0:
             minWeight = min(weightList)
 
         for edge in vertex.getOutgoing():
-            edge.freeflowtime = (float(edge.ratio)/minWeight) * 1200.
+            edge.freeflowtime = (float(edge.ratio) / minWeight) * 1200.
             edge.actualtime = edge.freeflowtime
 
     for vertex in endVertices:
@@ -114,5 +120,5 @@ def getConnectionTravelTime(startVertices, endVertices):
             minWeight = min(weightList)
 
         for edge in vertex.getIncoming():
-            edge.freeflowtime = (float(edge.ratio)/minWeight) * 1200.
+            edge.freeflowtime = (float(edge.ratio) / minWeight) * 1200.
             edge.actualtime = edge.freeflowtime
