@@ -1,5 +1,5 @@
 /*   
-    Copyright (C) 2014 Mario Krumnow, Dresden University of Technology
+    Copyright (C) 2017 Mario Krumnow, Dresden University of Technology
 
     This file is part of TraaS.
 
@@ -25,7 +25,7 @@ package de.tudresden.ws.container;
  *
  */
 
-public class SumoBoundingBox {
+public class SumoBoundingBox implements SumoObject {
 	
 	public double x_min;
 	public double y_min;
@@ -49,5 +49,9 @@ public class SumoBoundingBox {
 		
 	}
 	
+	public String toString(){
+		return this.x_min +"#"+this.y_min+"#"+this.x_max+"#"+this.y_max;
+	}
+	
 	
 }
