@@ -1,5 +1,5 @@
 /*   
-    Copyright (C) 2014 Mario Krumnow, Dresden University of Technology
+    Copyright (C) 2017 Mario Krumnow, Dresden University of Technology
 
     This file is part of TraaS.
 
@@ -24,7 +24,7 @@ package de.tudresden.ws.container;
  *
  */
 
-public class SumoColor {
+public class SumoColor implements SumoObject {
 
 	public byte r;
 	public byte g;
@@ -45,4 +45,9 @@ public class SumoColor {
 		this.a = (byte) a;
 	}
 	
+	public String toString(){
+		return r+"#"+g+"#"+b+"#"+a;
+	}
+	
+	
 }
