@@ -1,5 +1,5 @@
 /*   
-    Copyright (C) 2014 Mario Krumnow, Dresden University of Technology
+    Copyright (C) 2017 Mario Krumnow, Dresden University of Technology
 
     This file is part of TraaS.
 
@@ -24,7 +24,7 @@ package de.tudresden.ws.container;
  *
  */
 
-public class SumoTLSPhase {
+public class SumoTLSPhase implements SumoObject {
 
 	public int duration;
 	public int duration1;
@@ -58,4 +58,8 @@ public class SumoTLSPhase {
 		
 	}
 	
+	public String toString(){
+		return this.phasedef+"#"+this.duration+"#"+this.duration1+"#"+this.duration2;
+	}
+	
 }
