@@ -4,12 +4,12 @@
 @author  Daniel Krajzewicz
 @author  Michael Behrisch
 @date    2007-06-28
-@version $Id: detector.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: detector.py 23692 2017-03-28 13:27:23Z behrisch $
 
 <documentation missing>
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2007-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2007-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -17,12 +17,15 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 import sys
 
 from xml.sax import make_parser, handler
 
 MAX_POS_DEVIATION = 10
 
+
 class DetectorGroupData:
 
     def __init__(self, pos, isValid, id=None):
@@ -32,7 +35,7 @@ class DetectorGroupData:
         self.totalFlow = 0
         self.avgSpeed = 0
         self.entryCount = 0
-        if id != None:
+        if id is not None:
             self.ids.append(id)
 
     def addDetFlow(self, flow, speed):
@@ -40,7 +43,8 @@ class DetectorGroupData:
         self.totalFlow += flow
         count = self.entryCount
         if flow > 0:
-            self.avgSpeed = (self.avgSpeed * oldFlow + speed * flow) / self.totalFlow
+            self.avgSpeed = (
+                self.avgSpeed * oldFlow + speed * flow) / self.totalFlow
         self.entryCount += 1
 
     def clearFlow(self):
@@ -64,7 +68,7 @@ class DetectorReader(handler.ContentHandler):
 
     def addDetector(self, id, pos, edge):
         if id in self._det2edge:
-            print >> sys.stderr, "Warning! Detector %s already known." % id
+            print("Warning! Detector %s already known." % id, file=sys.stderr)
             return
         if not edge in self._edge2DetData:
             self._edge2DetData[edge] = []
@@ -78,11 +82,12 @@ class DetectorReader(handler.ContentHandler):
                     haveGroup = True
                     break
             if not haveGroup:
-                self._edge2DetData[edge].append(DetectorGroupData(pos, True, id))
+                self._edge2DetData[edge].append(
+                    DetectorGroupData(pos, True, id))
         self._det2edge[id] = edge
 
     def startElement(self, name, attrs):
-        if name == 'detectorDefinition':
+        if name == 'detectorDefinition' or name == 'e1Detector':
             self.addDetector(attrs['id'], float(attrs['pos']),
                              self._laneMap.get(attrs['lane'], self._currentEdge))
         elif name == 'group':
@@ -111,7 +116,7 @@ class DetectorReader(handler.ContentHandler):
             for group in groupList:
                 group.clearFlow()
 
-    def readFlows(self, flowFile, det="Detector", flow="qPKW", speed=None, time=None, timeVal=None):
+    def readFlows(self, flowFile, det="Detector", flow="qPKW", speed=None, time=None, timeVal=None, timeMax=None):
         detIdx = -1
         flowIdx = -1
         speedIdx = -1
@@ -129,10 +134,18 @@ class DetectorReader(handler.ContentHandler):
                     if time in flowDef:
                         timeIdx = flowDef.index(time)
                 elif flowIdx != -1:
-                    if timeIdx == -1 or timeVal is None or float(flowDef[timeIdx]) == timeVal:
+                    if timeIdx == -1 or timeVal is None:
+                        timeIsValid = True
+                    else:
+                        curTime = float(flowDef[timeIdx])
+                        timeIsValid = (timeMax is None and curTime == timeVal) or (
+                            curTime >= timeVal and curTime < timeMax)
+                    if timeIsValid:
                         hadFlow = True
                         if speedIdx != -1:
-                            self.addFlow(flowDef[detIdx], float(flowDef[flowIdx]), float(flowDef[speedIdx]))
+                            self.addFlow(
+                                flowDef[detIdx], float(flowDef[flowIdx]), float(flowDef[speedIdx]))
                         else:
-                            self.addFlow(flowDef[detIdx], float(flowDef[flowIdx]))
+                            self.addFlow(
+                                flowDef[detIdx], float(flowDef[flowIdx]))
         return hadFlow
