@@ -5,12 +5,12 @@
 @author  Jakob Erdmann
 @author  Michael Behrisch
 @date    2007-06-28
-@version $Id: flowFromRoutes.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: flowFromRoutes.py 23688 2017-03-28 12:16:12Z behrisch $
 
 This script recreates a flow file from routes and emitters.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2007-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2007-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -18,17 +18,25 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
-import math, string, sys
+from __future__ import absolute_import
+from __future__ import print_function
+import math
+import string
+import sys
+import os
 
 from xml.sax import saxutils, make_parser, handler
 from optparse import OptionParser
 
 import detector
 
+
 class LaneMap:
+
     def get(self, key, default):
         return key[0:-2]
 
+
 class DetectorRouteEmitterReader(handler.ContentHandler):
 
     def __init__(self, detFile):
@@ -37,22 +45,47 @@ class DetectorRouteEmitterReader(handler.ContentHandler):
         self._edgeFlow = {}
         self._parser = make_parser()
         self._parser.setContentHandler(self)
-        
-    def addEdgeFlow(self, edge, flow):
-        if not edge in self._edgeFlow:
-            self._edgeFlow[edge] = 0
-        self._edgeFlow[edge] += flow
+        self._begin = None
+        self._end = None
+
+    def reset(self, start, end):
+        self._routes = {}
+        self._edgeFlow = {}
+        self._begin = 60 * start
+        self._end = 60 * end
+
+    def addRouteFlow(self, route, flow):
+        for edge in self._routes[route]:
+            if not edge in self._edgeFlow:
+                self._edgeFlow[edge] = 0
+            self._edgeFlow[edge] += flow
 
     def startElement(self, name, attrs):
         if name == 'route':
-            if attrs.has_key('id'):
+            if 'id' in attrs:
                 self._routes[attrs['id']] = attrs['edges'].split()
         if name == 'vehicle':
-            for edge in self._routes[attrs['route']]:
-                self.addEdgeFlow(edge, 1)
+            if self._begin is None or float(attrs['depart']) >= self._begin:
+                self.addRouteFlow(attrs['route'], 1)
+        if name == 'flow':
+            if 'route' in attrs:
+                if self._begin is None or float(attrs['begin']) >= self._begin and float(attrs['end']) <= self._end:
+                    self.addRouteFlow(attrs['route'], float(attrs['number']))
+        if name == 'routeDistribution':
+            if 'routes' in attrs:
+                routes = attrs['routes'].split()
+                nums = attrs['probabilities'].split()
+                for r, n in zip(routes, nums):
+                    self.addRouteFlow(r, float(n))
 
-    def readDetFlows(self, flowFile):
-        self._detReader.readFlows(flowFile)
+    def readDetFlows(self, flowFile, flowCol):
+        if self._begin is None:
+            return self._detReader.readFlows(flowFile, flow=flowCol)
+        else:
+            return self._detReader.readFlows(flowFile, flow=options.flowcol, time="Time", timeVal=self._begin / 60, timeMax=self._end / 60)
+
+    def clearFlows(self):
+        self._detReader.clearFlows()
 
     def calcStatistics(self):
         rSum = 0
@@ -75,21 +108,27 @@ class DetectorRouteEmitterReader(handler.ContentHandler):
                         if dFlow > 0:
                             sumSquaredPercent += dev * dev / dFlow / dFlow
                         n += 1
-        print '# avgRouteFlow avgDetFlow avgDev RMSE RMSPE'
-        print '#', rSum/n, dSum/n, sumAbsDev/n, math.sqrt(sumSquaredDev/n), math.sqrt(sumSquaredPercent/n)
+        if self._begin is not None:
+            print('# interval', self._begin)
+        print('# avgRouteFlow avgDetFlow avgDev RMSE RMSPE')
+        print('#', rSum / n, dSum / n, sumAbsDev / n,
+              math.sqrt(sumSquaredDev / n), math.sqrt(sumSquaredPercent / n))
 
     def printFlows(self, includeDets):
         if includeDets:
-            print '# detNames RouteFlow DetFlow'
+            print('# detNames RouteFlow DetFlow')
         else:
-            print '# detNames RouteFlow'
+            print('# detNames RouteFlow')
         output = []
         for edge, detData in self._detReader._edge2DetData.iteritems():
             detString = []
             dFlow = []
             for group in detData:
                 if group.isValid:
-                    detString.append(string.join(sorted(group.ids), ';'))
+                    groupName = os.path.commonprefix(group.ids)
+                    if groupName == "":
+                        groupName = ';'.join(sorted(group.ids))
+                    detString.append(groupName)
                     dFlow.append(group.totalFlow)
             rFlow = len(detString) * [self._edgeFlow.get(edge, 0)]
             if includeDets:
@@ -99,10 +138,10 @@ class DetectorRouteEmitterReader(handler.ContentHandler):
         if includeDets:
             for group, rflow, dflow in sorted(output):
                 if dflow > 0 or options.respectzero:
-                    print group, rflow, dflow
+                    print(group, rflow, dflow, (rflow - dflow) / dflow)
         else:
             for group, flow in sorted(output):
-                print group, flow
+                print(group, flow)
 
 
 optParser = OptionParser()
@@ -114,10 +153,13 @@ optParser.add_option("-e", "--emitters", dest="emitfile",
                      help="read emitters from FILE (mandatory)", metavar="FILE")
 optParser.add_option("-f", "--detector-flow-file", dest="flowfile",
                      help="read detector flows to compare to from FILE", metavar="FILE")
+optParser.add_option("-c", "--flow-column", dest="flowcol", default="qPKW",
+                     help="which column contains flows", metavar="STRING")
 optParser.add_option("-z", "--respect-zero", action="store_true", dest="respectzero",
                      default=False, help="respect detectors without data (or with permanent zero) with zero flow")
 optParser.add_option("-D", "--dfrouter-style", action="store_true", dest="dfrstyle",
                      default=False, help="emitter files in dfrouter style (explicit routes)")
+optParser.add_option("-i", "--interval", type="int", help="aggregation interval in minutes")
 optParser.add_option("-v", "--verbose", action="store_true", dest="verbose",
                      default=False, help="tell me what you are doing")
 (options, args) = optParser.parse_args()
@@ -126,17 +168,36 @@ if not options.detfile or not options.routefile or not options.emitfile:
     sys.exit()
 parser = make_parser()
 if options.verbose:
-    print "Reading detectors"
+    print("Reading detectors")
 reader = DetectorRouteEmitterReader(options.detfile)
 parser.setContentHandler(reader)
-if options.verbose:
-    print "Reading routes"
-parser.parse(options.routefile)
-if options.verbose:
-    print "Reading emitters"
-parser.parse(options.emitfile)
-if options.flowfile:
-    reader.readDetFlows(options.flowfile)
-reader.printFlows(bool(options.flowfile))
-if options.flowfile:
-    reader.calcStatistics()
+if options.interval:
+    haveFlows = True
+    start = 0
+    while haveFlows:
+        reader.reset(start, start + options.interval)
+        if options.verbose:
+            print("Reading routes")
+        parser.parse(options.routefile)
+        if options.verbose:
+            print("Reading flows")
+        if options.flowfile:
+            haveFlows = reader.readDetFlows(options.flowfile, options.flowcol)
+        if haveFlows:
+            reader.printFlows(bool(options.flowfile))
+            if options.flowfile:
+                reader.calcStatistics()
+            reader.clearFlows()
+        start += options.interval
+else:
+    if options.verbose:
+        print("Reading routes")
+    parser.parse(options.routefile)
+    if options.verbose:
+        print("Reading emitters")
+    parser.parse(options.emitfile)
+    if options.flowfile:
+        reader.readDetFlows(options.flowfile, options.flowcol)
+    reader.printFlows(bool(options.flowfile))
+    if options.flowfile:
+        reader.calcStatistics()
