@@ -5,14 +5,14 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2007-07-26
-@version $Id: districtMapper.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: districtMapper.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Maps the geometry of the districts of two networks by calculating 
 translation and scale parameters from junctions which have been 
 identified by the user as reference points.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2007-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2007-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -20,6 +20,8 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 import math
 from xml.sax import make_parser, handler
 from optparse import OptionParser
@@ -36,6 +38,7 @@ def parseShape(shape):
 
 # All members are "private".
 class JunctionPositionsReader(handler.ContentHandler):
+
     def __init__(self):
         self._xPos = {}
         self._yPos = {}
@@ -58,9 +61,9 @@ class JunctionPositionsReader(handler.ContentHandler):
         return ret
 
 
-
 # All members are "private".
 class DistrictMapper(handler.ContentHandler):
+
     def __init__(self):
         self._haveDistrict = False
         self._parsingDistrictShape = False
@@ -69,10 +72,10 @@ class DistrictMapper(handler.ContentHandler):
         self._shape = ""
 
     def startElement(self, name, attrs):
-        if name == 'taz':    
+        if name == 'taz':
             self._haveDistrict = True
             self._currentID = attrs['id']
-            if attrs.has_key('shape'):
+            if 'shape' in attrs:
                 self._shape = attrs['shape']
         elif name == 'shape' and self._haveDistrict:
             self._parsingDistrictShape = True
@@ -82,7 +85,7 @@ class DistrictMapper(handler.ContentHandler):
             self._shape += content
 
     def endElement(self, name):
-        if name == 'taz':    
+        if name == 'taz':
             self._haveDistrict = False
             if self._shape != '':
                 self._districtShapes[self._currentID] = parseShape(self._shape)
@@ -95,8 +98,8 @@ class DistrictMapper(handler.ContentHandler):
             shape = self._districtShapes[district]
             nshape = []
             for i in range(0, len(shape)):
-                nx = ((shape[i][0]-xoff1) * xscale + xoff2)
-                ny = ((shape[i][1]-yoff1) * yscale + yoff2)
+                nx = ((shape[i][0] - xoff1) * xscale + xoff2)
+                ny = ((shape[i][1] - yoff1) * yscale + yoff2)
                 nshape.append((nx, ny))
             self._districtShapes[district] = nshape
 
@@ -115,12 +118,12 @@ class DistrictMapper(handler.ContentHandler):
             for district in self._districtShapes:
                 shape = self._districtShapes[district]
                 shapeStr = " ".join(["%s,%s" % s for s in shape])
-                fd.write('   <poly id="%s" color="%s" shape="%s"/>\n' % (district, color, shapeStr))
+                fd.write('   <poly id="%s" color="%s" shape="%s"/>\n' %
+                         (district, color, shapeStr))
             fd.write("</shapes>\n")
             fd.close()
 
 
-        
 if __name__ == "__main__":
     optParser = OptionParser()
     optParser.add_option("-v", "--verbose", action="store_true",
@@ -142,15 +145,16 @@ if __name__ == "__main__":
     (options, args) = optParser.parse_args()
     if not options.netfile1 or not options.netfile2 or not options.junctions1 or not options.junctions2:
         optParser.print_help()
-        optParser.exit("Error! Providing two networks and junction lists is mandatory")
+        optParser.exit(
+            "Error! Providing two networks and junction lists is mandatory")
     parser = make_parser()
     if options.verbose:
-        print "Reading net#1"
+        print("Reading net#1")
     reader1 = JunctionPositionsReader()
     parser.setContentHandler(reader1)
     parser.parse(options.netfile1)
     if options.verbose:
-        print "Reading net#2"
+        print("Reading net#2")
     reader2 = JunctionPositionsReader()
     parser.setContentHandler(reader2)
     parser.parse(options.netfile2)
@@ -179,5 +183,6 @@ if __name__ == "__main__":
     reader = DistrictMapper()
     parser.setContentHandler(reader)
     parser.parse(options.netfile1)
-    reader.convertShapes(xmin1, xmin2, width1/width2, ymin1, ymin2, height1/height2)
+    reader.convertShapes(
+        xmin1, xmin2, width1 / width2, ymin1, ymin2, height1 / height2)
     reader.writeResults(options.output, options.color, options.polyoutput)
