@@ -5,13 +5,13 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2011-10-04
-@version $Id: netdiff.py 20482 2016-04-18 20:49:42Z behrisch $
+@version $Id: netdiff.py 23250 2017-03-07 13:50:55Z behrisch $
 
 Reads two networks (source, dest) and tries to produce the minimal plain-xml input
 which can be loaded with netconvert alongside source to create dest
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2016 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -91,6 +91,11 @@ ATTRIBUTE_NAMES = {
 DEFAULT_VALUES = defaultdict(lambda: "")
 DEFAULT_VALUES['width'] = "-1"
 DEFAULT_VALUES['offset'] = "0"
+DEFAULT_VALUES['spreadType'] = "right"
+DEFAULT_VALUES['customShape'] = "false"
+DEFAULT_VALUES['keepClear'] = "true"
+DEFAULT_VALUES['contPos'] = "-1"
+DEFAULT_VALUES['visibility'] = "-1"
 RESET = 0
 
 
@@ -230,7 +235,7 @@ class AttributeStore:
     def diff(self, name, sourceValue, destValue):
         if sourceValue == destValue:
             return None
-        elif destValue == None:
+        elif destValue is None:
             return DEFAULT_VALUES[name]
         else:
             return destValue
@@ -321,7 +326,7 @@ class AttributeStore:
         file.write(item)
 
     def attr_string(self, names, values):
-        return ' '.join(['%s="%s"' % (n, v) for n, v in sorted(zip(names, values)) if v != None])
+        return ' '.join(['%s="%s"' % (n, v) for n, v in sorted(zip(names, values)) if v is not None])
 
     def id_string(self, tag, id):
         idattrs = IDATTRS[tag]
