@@ -4,7 +4,7 @@
 @author  Daniel Krajzewicz
 @author  Michael Behrisch
 @date    2009-08-01
-@version $Id: xmlconnections_mapEdges.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: xmlconnections_mapEdges.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Reads edge id replacements from "edgemap.txt"; the format of this file is
  <OLD_EDGE_ID>-><NEW_EDGE_ID>
@@ -14,7 +14,7 @@ The result is written to <CONNECTIONS>.mod.xml
 Call: xmlconnections_mapEdges.py <CONNECTIONS>
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2009-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2009-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -22,31 +22,33 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 
 import sys
 
 if len(sys.argv) < 2:
-    print "Usage: " + sys.argv[0] + " <CONNECTIONS>"
+    print("Usage: " + sys.argv[0] + " <CONNECTIONS>")
     sys.exit()
 
 # read map
 mmap = {}
 fdi = open("edgemap.txt")
 for line in fdi:
-	if line.find("->")<0:
-		continue
-	(orig, dest) = line.strip().split("->")
-	dest = dest.split(",")
-	mmap[orig] = dest
+    if line.find("->") < 0:
+        continue
+    (orig, dest) = line.strip().split("->")
+    dest = dest.split(",")
+    mmap[orig] = dest
 fdi.close()
 
 fdi = open(sys.argv[1])
-fdo = open(sys.argv[1]+".mod.xml", "w")
+fdo = open(sys.argv[1] + ".mod.xml", "w")
 for line in fdi:
-	for orig in mmap:
-		line = line.replace('from="'+orig+'"', 'from="'+mmap[orig][-1]+'"')
-		line = line.replace('to="'+orig+'"', 'to="'+mmap[orig][0]+'"')
-	fdo.write(line)
+    for orig in mmap:
+        line = line.replace(
+            'from="' + orig + '"', 'from="' + mmap[orig][-1] + '"')
+        line = line.replace('to="' + orig + '"', 'to="' + mmap[orig][0] + '"')
+    fdo.write(line)
 fdi.close()
 fdo.close()
-		
