@@ -4,14 +4,14 @@
 @author  Daniel Krajzewicz
 @author  Michael Behrisch
 @date    2009-08-01
-@version $Id: xmlnodes_applyOffset.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: xmlnodes_applyOffset.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Applies a given offset to edges given in an xml-node-file.
 The results are written into <XMLNODES>.mod.xml.
 Call: xmlnodes_applyOffset.py <XMLNODES> <X-OFFSET> <Y-OFFSET>
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2009-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2009-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -19,16 +19,22 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 
-import os, string, sys, StringIO
+import os
+import string
+import sys
 from xml.sax import saxutils, make_parser, handler
 
+
 class XMLNodesReader(handler.ContentHandler):
+
     def __init__(self, outFileName, xoff, yoff):
         self._out = open(outFileName, 'w')
         self._xoff = xoff
         self._yoff = yoff
-        
+
     def endDocument(self):
         self._out.close()
 
@@ -36,9 +42,11 @@ class XMLNodesReader(handler.ContentHandler):
         self._out.write('<' + name)
         for (key, value) in attrs.items():
             if key == "x":
-                self._out.write(' %s="%s"' % (key, saxutils.escape(str(float(value)+self._xoff))))
+                self._out.write(
+                    ' %s="%s"' % (key, saxutils.escape(str(float(value) + self._xoff))))
             elif key == "y":
-                self._out.write(' %s="%s"' % (key, saxutils.escape(str(float(value)+self._yoff))))
+                self._out.write(
+                    ' %s="%s"' % (key, saxutils.escape(str(float(value) + self._yoff))))
             else:
                 self._out.write(' %s="%s"' % (key, saxutils.escape(value)))
         self._out.write('>')
@@ -48,19 +56,19 @@ class XMLNodesReader(handler.ContentHandler):
 
     def characters(self, content):
         self._out.write(saxutils.escape(content))
-                    
+
     def ignorableWhitespace(self, content):
         self._out.write(content)
-        
+
     def processingInstruction(self, target, data):
         self._out.write('<?%s %s?>' % (target, data))
 
 
-            
 if len(sys.argv) < 4:
-    print "Usage: " + sys.argv[0] + " <XMLNODES> <X-OFFSET> <Y-OFFSET>"
+    print("Usage: " + sys.argv[0] + " <XMLNODES> <X-OFFSET> <Y-OFFSET>")
     sys.exit()
 parser = make_parser()
-reader = XMLNodesReader(sys.argv[1]+".mod.xml", float(sys.argv[2]), float(sys.argv[3]))
+reader = XMLNodesReader(
+    sys.argv[1] + ".mod.xml", float(sys.argv[2]), float(sys.argv[3]))
 parser.setContentHandler(reader)
 parser.parse(sys.argv[1])
