@@ -6,12 +6,12 @@
 @author  Daniel Krajzewicz
 @author  Michael Behrisch
 @date    2008-04-17
-@version $Id: GenerateTaxiRoutesMain.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: GenerateTaxiRoutesMain.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Main of GenerateTaxiRoutes.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2008-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2008-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -19,14 +19,17 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
+from __future__ import print_function
 
-from GenerateTaxiRoutes import *
+from .GenerateTaxiRoutes import *
 
-def main():        
-    print "start program"
+
+def main():
+    print("start program")
     readFCD()
-    writeRoutes()    
-    print "end"
+    writeRoutes()
+    print("end")
 
-#start the program
+# start the program
 main()
