@@ -5,12 +5,12 @@
 @author  Jakob Erdmann
 @author  Michael Behrisch
 @date    2010-03-06
-@version $Id: randomTrips.py 20482 2016-04-18 20:49:42Z behrisch $
+@version $Id: randomTrips.py 23999 2017-04-21 09:04:47Z behrisch $
 
 Generates random trips for the given network.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2010-2016 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2010-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -36,6 +36,7 @@ SUMO_HOME = os.environ.get('SUMO_HOME',
 sys.path.append(os.path.join(SUMO_HOME, 'tools'))
 import sumolib
 import route2trips
+from sumolib.miscutils import euclidean
 
 DUAROUTER = sumolib.checkBinary('duarouter')
 
@@ -60,6 +61,8 @@ def get_options(args=None):
                          help="generates weights files for visualisation")
     optParser.add_option("--pedestrians", action="store_true",
                          default=False, help="create a person file with pedestrian trips instead of vehicle trips")
+    optParser.add_option("--persontrips", action="store_true",
+                         default=False, help="create a person file with person trips instead of vehicle trips")
     optParser.add_option("--prefix", dest="tripprefix",
                          default="", help="prefix for the trip ids")
     optParser.add_option("-t", "--trip-attributes", dest="tripattrs",
@@ -81,20 +84,25 @@ def get_options(args=None):
                          default=1.0, help="multiply weight of fringe edges by <FLOAT> (default 1")
     optParser.add_option("--fringe-threshold", type="float", dest="fringe_threshold",
                          default=0.0, help="only consider edges with speed above <FLOAT> as fringe edges (default 0)")
+    optParser.add_option("--allow-fringe", dest="allow_fringe", action="store_true",
+                         default=False, help="Allow departing on edges that leave the network and arriving on edges that enter the network (via turnarounds or as 1-edge trips")
     optParser.add_option("--min-distance", type="float", dest="min_distance",
                          default=0.0, help="require start and end edges for each trip to be at least <FLOAT> m appart")
     optParser.add_option("--max-distance", type="float", dest="max_distance",
                          default=None, help="require start and end edges for each trip to be at most <FLOAT> m appart (default 0 which disables any checks)")
     optParser.add_option("-i", "--intermediate", type="int",
                          default=0, help="generates the given number of intermediate way points")
+    optParser.add_option("--flows", type="int",
+                         default=0, help="generates INT flows that together output vehicles with the specified period")
     optParser.add_option("--maxtries", type="int",
                          default=100, help="number of attemps for finding a trip which meets the distance constraints")
     optParser.add_option("--binomial", type="int", metavar="N",
                          help="If this is set, the number of departures per seconds will be drawn from a binomial distribution with n=N and p=PERIOD/N where PERIOD is the argument given to option --period. Tnumber of attemps for finding a trip which meets the distance constraints")
     optParser.add_option(
-        "-c", "--vclass", help="only from and to edges which permit <vClass>")
+        "-c", "--vclass", "--edge-permission", default="passenger",
+        help="only from and to edges which permit the given vehicle class")
     optParser.add_option(
-        "--vehicle-class", help="The vehicle class assigned to the generated trips")
+        "--vehicle-class", help="The vehicle class assigned to the generated trips (adds a standard vType definition to the output file).")
     optParser.add_option("--validate", default=False, action="store_true",
                          help="Whether to produce trip output that is already checked for connectivity")
     optParser.add_option("-v", "--verbose", action="store_true",
@@ -102,21 +110,26 @@ def get_options(args=None):
     (options, args) = optParser.parse_args(args=args)
     if not options.netfile:
         optParser.print_help()
-        sys.exit()
+        sys.exit(1)
+
+    if options.persontrips:
+        options.pedestrians = True
 
     if options.pedestrians:
         options.vclass = 'pedestrian'
+        if options.flows > 0:
+            print("Error: Person flows are not supported yet", file=sys.stderr)
+            sys.exit(1)
 
     if options.validate and options.routefile is None:
         options.routefile = "routes.rou.xml"
+
+    if options.period <= 0:
+        print("Error: Period must be positive", file=sys.stderr)
+        sys.exit(1)
     return options
 
 
-# euclidean distance between two coordinates in the plane
-def euclidean(a, b):
-    return math.sqrt((a[0] - b[0]) ** 2 + (a[1] - b[1]) ** 2)
-
-
 class InvalidGenerator(Exception):
     pass
 
@@ -224,10 +237,12 @@ class LoadedProps:
 
 def buildTripGenerator(net, options):
     try:
+        forbidden_source_fringe = None if options.allow_fringe else "_outgoing"
+        forbidden_sink_fringe = None if options.allow_fringe else "_incoming"
         source_generator = RandomEdgeGenerator(
-            net, get_prob_fun(options, "_incoming", "_outgoing"))
+            net, get_prob_fun(options, "_incoming", forbidden_source_fringe))
         sink_generator = RandomEdgeGenerator(
-            net, get_prob_fun(options, "_outgoing", "_incoming"))
+            net, get_prob_fun(options, "_outgoing", forbidden_sink_fringe))
         if options.weightsprefix:
             if os.path.isfile(options.weightsprefix + SOURCE_SUFFIX):
                 source_generator = RandomEdgeGenerator(
@@ -236,8 +251,8 @@ def buildTripGenerator(net, options):
                 sink_generator = RandomEdgeGenerator(
                     net, LoadedProps(options.weightsprefix + SINK_SUFFIX))
     except InvalidGenerator:
-        print(
-            "Error: no valid edges for generating source or destination", file=sys.stderr)
+        print("Error: no valid edges for generating source or destination. Try using option --allow-fringe",
+              file=sys.stderr)
         return None
 
     try:
@@ -254,7 +269,8 @@ def buildTripGenerator(net, options):
         else:
             via_generator = None
 
-    return RandomTripGenerator(source_generator, sink_generator, via_generator, options.intermediate, options.pedestrians)
+    return RandomTripGenerator(
+        source_generator, sink_generator, via_generator, options.intermediate, options.pedestrians)
 
 
 def is_walk_attribute(attr):
@@ -264,6 +280,33 @@ def is_walk_attribute(attr):
     return False
 
 
+def is_persontrip_attribute(attr):
+    for cand in ['vTypes', 'modes']:
+        if cand in attr:
+            return True
+    return False
+
+
+def split_trip_attributes(tripattrs):
+    # figure out which of the tripattrs belong to the <person> and which
+    # belong to the <walk> or <persontrip>
+    personattrs = []
+    otherattrs = []
+    for a in tripattrs.split():
+        if is_walk_attribute(a) or is_persontrip_attribute(a):
+            otherattrs.append(a)
+        else:
+            personattrs.append(a)
+    return prependSpace(' '.join(personattrs)), prependSpace(' '.join(otherattrs))
+
+
+def prependSpace(s):
+    if len(s) == 0 or s[0] == " ":
+        return s
+    else:
+        return " " + s
+
+
 def main(options):
     if options.seed:
         random.seed(options.seed)
@@ -279,12 +322,10 @@ def main(options):
     idx = 0
 
     if options.pedestrians:
-        # figure out which of the tripattrs belong to the <person> and which
-        # belong to the <walk>
-        walkattrs = ' '.join(
-            [a for a in options.tripattrs.split() if is_walk_attribute(a)])
-        personattrs = ' '.join(
-            [a for a in options.tripattrs.split() if not is_walk_attribute(a)])
+        personattrs, otherattrs = split_trip_attributes(options.tripattrs)
+    options.tripattrs = prependSpace(options.tripattrs)
+
+    vias = {}
 
     def generate_one(idx):
         label = "%s%s" % (options.tripprefix, idx)
@@ -293,16 +334,30 @@ def main(options):
                 options.min_distance, options.max_distance, options.maxtries)
             via = ""
             if len(intermediate) > 0:
-                via = 'via="%s" ' % ' '.join(
+                via = ' via="%s" ' % ' '.join(
                     [e.getID() for e in intermediate])
+                if options.validate:
+                    vias[label] = via
             if options.pedestrians:
                 fouttrips.write(
-                    '    <person id="%s" depart="%.2f" %s>\n' % (label, depart, personattrs))
-                fouttrips.write(
-                    '        <walk from="%s" to="%s" %s/>\n' % (source_edge.getID(), sink_edge.getID(), walkattrs))
+                    '    <person id="%s" depart="%.2f"%s>\n' % (label, depart, personattrs))
+                if options.persontrips:
+                    fouttrips.write(
+                        '        <personTrip from="%s" to="%s"%s/>\n' % (source_edge.getID(), sink_edge.getID(), otherattrs))
+                else:
+                    fouttrips.write(
+                        '        <walk from="%s" to="%s"%s/>\n' % (source_edge.getID(), sink_edge.getID(), otherattrs))
                 fouttrips.write('    </person>\n')
+            elif options.flows > 0:
+                if options.binomial:
+                    for j in range(options.binomial):
+                        fouttrips.write('    <flow id="%s#%s" begin="%s" end="%s" probability="%s" from="%s" to="%s"%s%s/>\n' % (
+                            label, j, options.begin, options.end, 1.0 / options.period / options.binomial, source_edge.getID(), sink_edge.getID(), via, options.tripattrs))
+                else:
+                    fouttrips.write('    <flow id="%s" begin="%s" end="%s" period="%s" from="%s" to="%s"%s%s/>\n' % (
+                        label, options.begin, options.end, options.period * options.flows, source_edge.getID(), sink_edge.getID(), via, options.tripattrs))
             else:
-                fouttrips.write('    <trip id="%s" depart="%.2f" from="%s" to="%s" %s%s/>\n' % (
+                fouttrips.write('    <trip id="%s" depart="%.2f" from="%s" to="%s"%s%s/>\n' % (
                     label, depart, source_edge.getID(), sink_edge.getID(), via, options.tripattrs))
         except Exception as exc:
             print(exc, file=sys.stderr)
@@ -310,28 +365,32 @@ def main(options):
 
     with open(options.tripfile, 'w') as fouttrips:
         sumolib.writeXMLHeader(
-            fouttrips, "$Id: randomTrips.py 20482 2016-04-18 20:49:42Z behrisch $")
-        fouttrips.write("<trips>\n")
+            fouttrips, "$Id: randomTrips.py 23999 2017-04-21 09:04:47Z behrisch $", "routes")
         if options.vehicle_class:
             fouttrips.write('    <vType id="%s" vClass="%s" />\n' %
                             (options.vehicle_class, options.vehicle_class))
             options.tripattrs += ' type="%s"' % options.vehicle_class
         depart = options.begin
         if trip_generator:
-            while depart < options.end:
-                if options.binomial is None:
-                    # generate with constant spacing
+            if options.flows == 0:
+                while depart < options.end:
+                    if options.binomial is None:
+                        # generate with constant spacing
+                        idx = generate_one(idx)
+                        depart += options.period
+                    else:
+                        # draw n times from a bernouli distribution
+                        # for an average arrival rate of 1 / period
+                        prob = 1.0 / options.period / options.binomial
+                        for i in range(options.binomial):
+                            if random.random() < prob:
+                                idx = generate_one(idx)
+                        depart += 1
+            else:
+                for i in range(options.flows):
                     idx = generate_one(idx)
-                    depart += options.period
-                else:
-                    # draw n times from a bernouli distribution
-                    # for an average arrival rate of 1 / period
-                    prob = 1.0 / options.period / options.binomial
-                    for i in range(options.binomial):
-                        if random.random() < prob:
-                            idx = generate_one(idx)
-                    depart += 1
-        fouttrips.write("</trips>\n")
+
+        fouttrips.write("</routes>\n")
 
     if options.routefile:
         args = [DUAROUTER, '-n', options.netfile, '-t', options.tripfile, '-o', options.routefile, '--ignore-errors',
@@ -343,7 +402,8 @@ def main(options):
 
     if options.validate:
         print("calling route2trips")
-        route2trips.main([options.routefile], outfile=options.tripfile)
+        route2trips.main([options.routefile], outfile=options.tripfile,
+                         vias=vias, calledBy=" via randomTrips.py")
 
     if options.weights_outprefix:
         trip_generator.source_generator.write_weights(
