@@ -6,12 +6,12 @@
 @author  Michael Behrisch
 @author  Jakob Erdmann
 @date    2011-11-28
-@version $Id: edge.py 20433 2016-04-13 08:00:14Z behrisch $
+@version $Id: edge.py 23247 2017-03-07 13:46:58Z behrisch $
 
 This file contains a Python-representation of a single edge.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2016 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -20,6 +20,7 @@ the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
 from .connection import Connection
+from .lane import addJunctionPos
 
 
 class Edge:
@@ -41,7 +42,11 @@ class Edge:
         self._incoming = {}
         self._outgoing = {}
         self._shape = None
-        self._cachedShapeWithJunctions = None
+        self._shapeWithJunctions = None
+        self._shape3D = None
+        self._shapeWithJunctions3D = None
+        self._rawShape = None
+        self._rawShape3D = None
         self._function = function
         self._tls = None
         self._name = name
@@ -50,6 +55,11 @@ class Edge:
         return self._name
 
     def isSpecial(self):
+        """ Check if the edge has a special function.
+
+        Returns False if edge's function is 'normal', else False, e.g. for
+        internal edges or connector edges """
+
         return self._function != ""
 
     def getFunction(self):
@@ -76,9 +86,8 @@ class Edge:
             self._incoming[conn._from] = []
         self._incoming[conn._from].append(conn)
 
-    def setShape(self, shape):
-        self._shape = shape
-        self._cachedShapeWithJunctions = None
+    def setRawShape(self, shape):
+        self._rawShape3D = shape
 
     def getID(self):
         return self._id
@@ -89,24 +98,33 @@ class Edge:
     def getOutgoing(self):
         return self._outgoing
 
+    def getRawShape(self):
+        """Return the shape that was used in netconvert for building this edge (2D)."""
+        if self._shape is None:
+            self.rebuildShape()
+        return self._rawShape
+
+    def getRawShape3D(self):
+        """Return the shape that was used in netconvert for building this edge (3D)."""
+        if self._shape is None:
+            self.rebuildShape()
+        return self._rawShape3D
+
     def getShape(self, includeJunctions=False):
-        if not self._shape:
-            if self._cachedShapeWithJunctions == None:
-                self._cachedShapeWithJunctions = [
-                    self._from._coord, self._to._coord]
-            return self._cachedShapeWithJunctions
+        """Return the 2D shape that is the average of all lane shapes (segment-wise)"""
+        if self._shape is None:
+            self.rebuildShape()
         if includeJunctions:
-            if self._cachedShapeWithJunctions == None:
-                if self._from._coord != self._shape[0]:
-                    self._cachedShapeWithJunctions = [
-                        self._from._coord] + self._shape
-                else:
-                    self._cachedShapeWithJunctions = list(self._shape)
-                if self._to._coord != self._shape[-1]:
-                    self._cachedShapeWithJunctions += [self._to._coord]
-            return self._cachedShapeWithJunctions
+            return self._shapeWithJunctions
         return self._shape
 
+    def getShape3D(self, includeJunctions=False):
+        if self._shape is None:
+            self.rebuildShape()
+        if includeJunctions:
+            return self._shapeWithJunctions3D
+        return self._shape3D
+
     def getBoundingBox(self, includeJunctions=True):
         s = self.getShape(includeJunctions)
         xmin = s[0][0]
@@ -121,6 +139,18 @@ class Edge:
         assert(xmin != xmax or ymin != ymax)
         return (xmin, ymin, xmax, ymax)
 
+    def getClosestLanePosDist(self, point, perpendicular=False):
+        minDist = 1e400
+        minIdx = None
+        minPos = None
+        for i, l in enumerate(self._lanes):
+            pos, dist = l.getClosestLanePosAndDist(point, perpendicular)
+            if dist < minDist:
+                minDist = dist
+                minIdx = i
+                minPos = pos
+        return minIdx, minPos, minDist
+
     def getSpeed(self):
         return self._speed
 
@@ -134,25 +164,37 @@ class Edge:
         return self._lanes
 
     def rebuildShape(self):
-        noShapes = len(self._lanes)
-        if noShapes % 2 == 1:
-            self.setShape(self._lanes[int(noShapes / 2)]._shape)
+        numLanes = len(self._lanes)
+        if numLanes % 2 == 1:
+            self._shape3D = self._lanes[int(numLanes / 2)].getShape3D()
         else:
-            shape = []
+            self._shape3D = []
             minLen = -1
             for l in self._lanes:
                 if minLen == -1 or minLen > len(l.getShape()):
                     minLen = len(l._shape)
-            for i in range(0, minLen):
+            for i in range(minLen):
                 x = 0.
                 y = 0.
-                for j in range(0, len(self._lanes)):
-                    x = x + self._lanes[j]._shape[i][0]
-                    y = y + self._lanes[j]._shape[i][1]
-                x = x / float(len(self._lanes))
-                y = y / float(len(self._lanes))
-                shape.append([x, y])
-            self.setShape(shape)
+                z = 0.
+                for l in self._lanes:
+                    x += l.getShape3D()[i][0]
+                    y += l.getShape3D()[i][1]
+                    z += l.getShape3D()[i][2]
+                self._shape3D.append(
+                    (x / float(numLanes), y / float(numLanes), z / float(numLanes)))
+
+        self._shapeWithJunctions3D = addJunctionPos(self._shape3D,
+                                                    self._from.getCoord3D(), self._to.getCoord3D())
+
+        if self._rawShape3D == []:
+            self._rawShape3D = [self._from.getCoord3D(), self._to.getCoord3D()]
+
+        # 2d - versions
+        self._shape = [(x, y) for x, y, z in self._shape3D]
+        self._shapeWithJunctions = [(x, y)
+                                    for x, y, z in self._shapeWithJunctions3D]
+        self._rawShape = [(x, y) for x, y, z in self._rawShape3D]
 
     def getLength(self):
         return self._lanes[0].getLength()
@@ -183,4 +225,7 @@ class Edge:
         return False
 
     def __repr__(self):
-        return '<edge id="%s" from="%s" to="%s"/>' % (self._id, self._from.getID(), self._to.getID())
+        if self.getFunction() == '':
+            return '<edge id="%s" from="%s" to="%s"/>' % (self._id, self._from.getID(), self._to.getID())
+        else:
+            return '<edge id="%s" function="%s"/>' % (self._id, self.getFunction())
