@@ -4,12 +4,12 @@
 @author  Jakob Erdmann
 @author  Michael Behrisch
 @date    2012-12-04
-@version $Id: __init__.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: __init__.py 22608 2017-01-17 06:28:54Z behrisch $
 
 This file includes all sensor structures.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2012-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -17,5 +17,6 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
 
-import inductive_loop
+from . import inductive_loop
