@@ -4,12 +4,12 @@
 @author  Melanie Knocke
 @author  Michael Behrisch
 @date    2012-12-04
-@version $Id: polygon.py 18756 2015-08-31 19:16:33Z behrisch $
+@version $Id: polygon.py 24072 2017-04-26 13:26:58Z behrisch $
 
 Library for reading and storing polygons.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2012-2015 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -17,6 +17,7 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
 
 from xml.sax import handler, parse
 from .. import color
@@ -46,21 +47,21 @@ class Polygon:
         assert(xmin != xmax or ymin != ymax)
         return xmin, ymin, xmax, ymax
 
+    def getShapeString(self):
+        return " ".join([",".join(map(str, e)) for e in self.shape])
+
     def toXML(self):
-        s = []
-        for e in self.shape:
-            s.append("%s,%s" % (e[0], e[1]))
         ret = '<poly id="%s"' % self.id
-        if type is not None:
+        if self.type is not None:
             ret += ' type="%s"' % self.type
-        if color is not None:
+        if self.color is not None:
             ret += ' color="%s"' % self.color.toXML()
-        if layer is not None:
+        if self.layer is not None:
             ret += ' layer="%s"' % self.layer
-        if fill is not None:
+        if self.fill is not None:
             ret += ' fill="%s"' % self.fill
-        if shape is not None:
-            ret += ' shape="%s"' % (" ".join(s))
+        if self.shape is not None:
+            ret += ' shape="%s"' % self.getShapeString()
         if len(self.attributes) == 0:
             ret += '/>'
         else:
@@ -70,6 +71,12 @@ class Polygon:
             ret += '</poly>'
         return ret
 
+    def __lt__(self, other):
+        return self.id < other.id
+        
+    def __repr__(self):
+        return self.toXML()
+
 
 class PolygonReader(handler.ContentHandler):
 
@@ -94,7 +101,7 @@ class PolygonReader(handler.ContentHandler):
             self._id2poly[poly.id] = poly
             self._polys.append(poly)
             self._lastPoly = poly
-        if name == 'param' and self._lastPoly != None:
+        if name == 'param' and self._lastPoly is not None:
             self._lastPoly.attributes[attrs['key']] = attrs['value']
 
     def endElement(self, name):
