@@ -9,12 +9,12 @@
 @author  Laura Bieker
 @author  Daniel Krajzewicz
 @date    2011-03-09
-@version $Id: _vehicle.py 20482 2016-04-18 20:49:42Z behrisch $
+@version $Id: _vehicle.py 23953 2017-04-16 16:19:38Z behrisch $
 
 Python implementation of the TraCI interface.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2016 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -57,67 +57,97 @@ def _readLeader(result):
     return None
 
 
-_RETURN_VALUE_FUNC = {tc.VAR_SPEED:           Storage.readDouble,
+def _readNextTLS(result):
+    result.read("!iB")  # numCompounds, TYPE_INT
+    numTLS = result.read("!i")[0]
+    nextTLS = []
+    for i in range(numTLS):
+        result.read("!B")
+        tlsID = result.readString()
+        tlsIndex, dist, state = result.read("!BiBdBB")[1::2]
+        nextTLS.append((tlsID, tlsIndex, dist, chr(state)))
+    return nextTLS
+
+
+_RETURN_VALUE_FUNC = {tc.VAR_SPEED: Storage.readDouble,
                       tc.VAR_SPEED_WITHOUT_TRACI: Storage.readDouble,
                       tc.VAR_POSITION: lambda result: result.read("!dd"),
-                      tc.VAR_ANGLE:           Storage.readDouble,
-                      tc.VAR_ROAD_ID:         Storage.readString,
-                      tc.VAR_LANE_ID:         Storage.readString,
-                      tc.VAR_LANE_INDEX:      Storage.readInt,
-                      tc.VAR_TYPE:            Storage.readString,
-                      tc.VAR_ROUTE_ID:        Storage.readString,
-                      tc.VAR_ROUTE_INDEX:     Storage.readInt,
+                      tc.VAR_POSITION3D: lambda result: result.read("!ddd"),
+                      tc.VAR_ANGLE: Storage.readDouble,
+                      tc.VAR_ROAD_ID: Storage.readString,
+                      tc.VAR_LANE_ID: Storage.readString,
+                      tc.VAR_LANE_INDEX: Storage.readInt,
+                      tc.VAR_TYPE: Storage.readString,
+                      tc.VAR_ROUTE_ID: Storage.readString,
+                      tc.VAR_ROUTE_INDEX: Storage.readInt,
                       tc.VAR_COLOR: lambda result: result.read("!BBBB"),
-                      tc.VAR_LANEPOSITION:    Storage.readDouble,
-                      tc.VAR_CO2EMISSION:     Storage.readDouble,
-                      tc.VAR_COEMISSION:      Storage.readDouble,
-                      tc.VAR_HCEMISSION:      Storage.readDouble,
-                      tc.VAR_PMXEMISSION:     Storage.readDouble,
-                      tc.VAR_NOXEMISSION:     Storage.readDouble,
+                      tc.VAR_LANEPOSITION: Storage.readDouble,
+                      tc.VAR_CO2EMISSION: Storage.readDouble,
+                      tc.VAR_COEMISSION: Storage.readDouble,
+                      tc.VAR_HCEMISSION: Storage.readDouble,
+                      tc.VAR_PMXEMISSION: Storage.readDouble,
+                      tc.VAR_NOXEMISSION: Storage.readDouble,
                       tc.VAR_FUELCONSUMPTION: Storage.readDouble,
-                      tc.VAR_NOISEEMISSION:   Storage.readDouble,
+                      tc.VAR_NOISEEMISSION: Storage.readDouble,
+                      tc.VAR_ELECTRICITYCONSUMPTION: Storage.readDouble,
+                      tc.VAR_PERSON_NUMBER: Storage.readInt,
                       tc.VAR_EDGE_TRAVELTIME: Storage.readDouble,
-                      tc.VAR_EDGE_EFFORT:     Storage.readDouble,
+                      tc.VAR_EDGE_EFFORT: Storage.readDouble,
                       tc.VAR_ROUTE_VALID: lambda result: bool(result.read("!B")[0]),
-                      tc.VAR_EDGES:           Storage.readStringList,
-                      tc.VAR_SIGNALS:         Storage.readInt,
-                      tc.VAR_LENGTH:          Storage.readDouble,
-                      tc.VAR_MAXSPEED:        Storage.readDouble,
-                      tc.VAR_ALLOWED_SPEED:   Storage.readDouble,
-                      tc.VAR_VEHICLECLASS:    Storage.readString,
-                      tc.VAR_SPEED_FACTOR:    Storage.readDouble,
+                      tc.VAR_EDGES: Storage.readStringList,
+                      tc.VAR_SIGNALS: Storage.readInt,
+                      tc.VAR_LENGTH: Storage.readDouble,
+                      tc.VAR_MAXSPEED: Storage.readDouble,
+                      tc.VAR_ALLOWED_SPEED: Storage.readDouble,
+                      tc.VAR_VEHICLECLASS: Storage.readString,
+                      tc.VAR_SPEED_FACTOR: Storage.readDouble,
                       tc.VAR_SPEED_DEVIATION: Storage.readDouble,
-                      tc.VAR_EMISSIONCLASS:   Storage.readString,
-                      tc.VAR_WAITING_TIME:    Storage.readDouble,
-                      tc.VAR_WIDTH:           Storage.readDouble,
-                      tc.VAR_MINGAP:          Storage.readDouble,
-                      tc.VAR_SHAPECLASS:      Storage.readString,
-                      tc.VAR_ACCEL:           Storage.readDouble,
-                      tc.VAR_DECEL:           Storage.readDouble,
-                      tc.VAR_IMPERFECTION:    Storage.readDouble,
-                      tc.VAR_TAU:             Storage.readDouble,
-                      tc.VAR_BEST_LANES:      _readBestLanes,
-                      tc.VAR_LEADER:          _readLeader,
-                      tc.DISTANCE_REQUEST:    Storage.readDouble,
+                      tc.VAR_EMISSIONCLASS: Storage.readString,
+                      tc.VAR_WAITING_TIME: Storage.readDouble,
+                      tc.VAR_SPEEDSETMODE: Storage.readInt,
+                      tc.VAR_SLOPE: Storage.readDouble,
+                      tc.VAR_WIDTH: Storage.readDouble,
+                      tc.VAR_HEIGHT: Storage.readDouble,
+                      tc.VAR_LINE: Storage.readString,
+                      tc.VAR_VIA: Storage.readStringList,
+                      tc.VAR_MINGAP: Storage.readDouble,
+                      tc.VAR_SHAPECLASS: Storage.readString,
+                      tc.VAR_ACCEL: Storage.readDouble,
+                      tc.VAR_DECEL: Storage.readDouble,
+                      tc.VAR_IMPERFECTION: Storage.readDouble,
+                      tc.VAR_TAU: Storage.readDouble,
+                      tc.VAR_BEST_LANES: _readBestLanes,
+                      tc.VAR_LEADER: _readLeader,
+                      tc.VAR_NEXT_TLS: _readNextTLS,
+                      tc.VAR_LANEPOSITION_LAT: Storage.readDouble,
+                      tc.VAR_MAXSPEED_LAT: Storage.readDouble,
+                      tc.VAR_MINGAP_LAT: Storage.readDouble,
+                      tc.VAR_LATALIGNMENT: Storage.readString,
+                      tc.DISTANCE_REQUEST: Storage.readDouble,
                       tc.VAR_STOPSTATE: lambda result: result.read("!B")[0],
-                      tc.VAR_DISTANCE:        Storage.readDouble}
+                      tc.VAR_DISTANCE: Storage.readDouble}
 
 
 class VehicleDomain(Domain):
-
-    DEPART_TRIGGERED = -1
-    DEPART_CONTAINER_TRIGGERED = -2
-    DEPART_NOW = -3
-
-    DEPART_SPEED_RANDOM = -2
-    DEPART_SPEED_MAX = -3
-
-    STOP_DEFAULT = 0
-    STOP_PARKING = 1
-    STOP_TRIGGERED = 2
-    STOP_CONTAINER_TRIGGERED = 4
-    STOP_BUS_STOP = 8
-    STOP_CONTAINER_STOP = 16
+    # imported for backwards compatibility
+    STOP_DEFAULT = tc.STOP_DEFAULT
+    STOP_PARKING = tc.STOP_PARKING
+    STOP_TRIGGERED = tc.STOP_TRIGGERED
+    STOP_CONTAINER_TRIGGERED = tc.STOP_CONTAINER_TRIGGERED
+    STOP_BUS_STOP = tc.STOP_BUS_STOP
+    STOP_CONTAINER_STOP = tc.STOP_CONTAINER_STOP
+    STOP_CHARGING_STATION = tc.STOP_CHARGING_STATION
+    STOP_PARKING_AREA = tc.STOP_PARKING_AREA
+    DEPART_TRIGGERED = tc.DEPARTFLAG_TRIGGERED
+    DEPART_CONTAINER_TRIGGERED = tc.DEPARTFLAG_CONTAINER_TRIGGERED
+    DEPART_NOW = tc.DEPARTFLAG_NOW
+    DEPART_SPEED_RANDOM = tc.DEPARTFLAG_SPEED_RANDOM
+    DEPART_SPEED_MAX = tc.DEPARTFLAG_SPEED_MAX
+    DEPART_LANE_RANDOM = tc.DEPARTFLAG_LANE_RANDOM
+    DEPART_LANE_FREE = tc.DEPARTFLAG_LANE_FREE
+    DEPART_LANE_ALLOWED_FREE = tc.DEPARTFLAG_LANE_ALLOWED_FREE
+    DEPART_LANE_BEST_FREE = tc.DEPARTFLAG_LANE_BEST_FREE
+    DEPART_LANE_FIRST_ALLOWED = tc.DEPARTFLAG_LANE_FIRST_ALLOWED
 
     def __init__(self):
         Domain.__init__(self, "vehicle", tc.CMD_GET_VEHICLE_VARIABLE, tc.CMD_SET_VEHICLE_VARIABLE,
@@ -134,8 +164,8 @@ class VehicleDomain(Domain):
 
     def getSpeedWithoutTraCI(self, vehID):
         """getSpeedWithoutTraCI(string) -> double
-
-        .
+        Returns the speed that the vehicle would drive if not speed-influencing
+        command such as setSpeed or slowDown was given.
         """
         return self._getUniversal(tc.VAR_SPEED_WITHOUT_TRACI, vehID)
 
@@ -146,10 +176,17 @@ class VehicleDomain(Domain):
         """
         return self._getUniversal(tc.VAR_POSITION, vehID)
 
+    def getPosition3D(self, vehID):
+        """getPosition3D(string) -> (double, double, double)
+
+        Returns the position of the named vehicle within the last step [m,m,m].
+        """
+        return self._getUniversal(tc.VAR_POSITION3D, vehID)
+
     def getAngle(self, vehID):
         """getAngle(string) -> double
 
-        Returns the angle in degrees of the named vehicle within the last step. 
+        Returns the angle in degrees of the named vehicle within the last step.
         """
         return self._getUniversal(tc.VAR_ANGLE, vehID)
 
@@ -266,10 +303,18 @@ class VehicleDomain(Domain):
         """
         return self._getUniversal(tc.VAR_NOISEEMISSION, vehID)
 
+    def getElectricityConsumption(self, vehID):
+        """getElectricityConsumption(string) -> double
+
+        Returns the electricity consumption in ml for the last time step.
+        """
+        return self._getUniversal(tc.VAR_ELECTRICITYCONSUMPTION, vehID)
+
     def getPersonNumber(self, vehID):
         """getPersonNumber(string) -> integer
-
-        .
+        Returns the total number of persons which includes those defined
+        using attribute 'personNumber' as well as <person>-objects which are riding in
+        this vehicle.
         """
         return self._getUniversal(tc.VAR_PERSON_NUMBER, vehID)
 
@@ -298,6 +343,10 @@ class VehicleDomain(Domain):
         return self._connection._checkResult(tc.CMD_GET_VEHICLE_VARIABLE, tc.VAR_EDGE_EFFORT, vehID).readDouble()
 
     def isRouteValid(self, vehID):
+        """isRouteValid(string) -> bool
+        Returns whether the current vehicle route is connected for the vehicle
+        class of the given vehicle.
+        """
         return self._getUniversal(tc.VAR_ROUTE_VALID, vehID)
 
     def getSignals(self, vehID):
@@ -321,6 +370,34 @@ class VehicleDomain(Domain):
         """
         return self._getUniversal(tc.VAR_MAXSPEED, vehID)
 
+    def getLateralLanePosition(self, vehID):
+        """getLateralLanePosition(string) -> double
+
+        Returns The lateral position of the vehicle on its current lane measured in m.
+        """
+        return self._getUniversal(tc.VAR_LANEPOSITION_LAT, vehID)
+
+    def getMaxSpeedLat(self, vehID):
+        """getMaxSpeedLat(string) -> double
+
+        Returns the maximum lateral speed in m/s of this vehicle.
+        """
+        return self._getUniversal(tc.VAR_MAXSPEED_LAT, vehID)
+
+    def getLateralAlignment(self, vehID):
+        """getLateralAlignment(string) -> string
+
+        Returns The preferred lateral alignment of the vehicle
+        """
+        return self._getUniversal(tc.VAR_LATALIGNMENT, vehID)
+
+    def getMinGapLat(self, vehID):
+        """getMinGapLat(string) -> double
+
+        Returns The desired lateral gap of this vehicle at 50km/h in m
+        """
+        return self._getUniversal(tc.VAR_MINGAP_LAT, vehID)
+
     def getAllowedSpeed(self, vehID):
         """getAllowedSpeed(string) -> double
 
@@ -360,10 +437,22 @@ class VehicleDomain(Domain):
         """getWaitingTime() -> double
         The waiting time of a vehicle is defined as the time (in seconds) spent with a
         speed below 0.1m/s since the last time it was faster than 0.1m/s.
-        (basically, the waiting time of a vehicle is reset to 0 every time it moves). 
+        (basically, the waiting time of a vehicle is reset to 0 every time it moves).
         """
         return self._getUniversal(tc.VAR_WAITING_TIME, vehID)
 
+    def getSpeedMode(self, vehID):
+        """getSpeedMode -> int
+        The speed mode of a vehicle
+        """
+        return self._getUniversal(tc.VAR_SPEEDSETMODE, vehID)
+
+    def getSlope(self, vehID):
+        """getSlope -> double
+        The slope at the current position of the vehicle in degrees
+        """
+        return self._getUniversal(tc.VAR_SLOPE, vehID)
+
     def getWidth(self, vehID):
         """getWidth(string) -> double
 
@@ -371,6 +460,27 @@ class VehicleDomain(Domain):
         """
         return self._getUniversal(tc.VAR_WIDTH, vehID)
 
+    def getHeight(self, vehID):
+        """getHeight(string) -> double
+
+        Returns the height in m of this vehicle.
+        """
+        return self._getUniversal(tc.VAR_HEIGHT, vehID)
+
+    def getLine(self, vehID):
+        """getLine(string) -> string
+
+        Returns the line information of this vehicle.
+        """
+        return self._getUniversal(tc.VAR_LINE, vehID)
+
+    def getVia(self, vehID):
+        """getVia(string) -> list(string)
+
+        Returns the ids of via edges for this vehicle
+        """
+        return self._getUniversal(tc.VAR_VIA, vehID)
+
     def getMinGap(self, vehID):
         """getMinGap(string) -> double
 
@@ -414,7 +524,7 @@ class VehicleDomain(Domain):
         return self._getUniversal(tc.VAR_TAU, vehID)
 
     def getBestLanes(self, vehID):
-        """getBestLanes(string) -> 
+        """getBestLanes(string) ->
 
         Information about the wish to use subsequent edges' lanes.
         """
@@ -425,12 +535,20 @@ class VehicleDomain(Domain):
 
         Return the leading vehicle id together with the distance.
         The dist parameter defines the maximum lookahead, 0 calculates a lookahead from the brake gap.
+        Note that the returned leader may be farther away than the given dist.
         """
         self._connection._beginMessage(
             tc.CMD_GET_VEHICLE_VARIABLE, tc.VAR_LEADER, vehID, 1 + 8)
         self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, dist)
         return _readLeader(self._connection._checkResult(tc.CMD_GET_VEHICLE_VARIABLE, tc.VAR_LEADER, vehID))
 
+    def getNextTLS(self, vehID):
+        """getNextTLS(string) ->
+
+        Return list of upcoming traffic lights [(tlsID, tlsIndex, distance, state), ...]
+        """
+        return self._getUniversal(tc.VAR_NEXT_TLS, vehID)
+
     def subscribeLeader(self, vehID, dist=0., begin=0, end=2**31 - 1):
         """subscribeLeader(string, double) -> None
 
@@ -443,7 +561,7 @@ class VehicleDomain(Domain):
     def getDrivingDistance(self, vehID, edgeID, pos, laneID=0):
         """getDrivingDistance(string, string, double, integer) -> double
 
-        .
+        Return the distance to the given edge and position along the vehicles route.
         """
         self._connection._beginMessage(tc.CMD_GET_VEHICLE_VARIABLE, tc.DISTANCE_REQUEST,
                                        vehID, 1 + 4 + 1 + 4 + len(edgeID) + 8 + 1 + 1)
@@ -456,7 +574,7 @@ class VehicleDomain(Domain):
     def getDrivingDistance2D(self, vehID, x, y):
         """getDrivingDistance2D(string, double, double) -> integer
 
-        .
+        Return the distance to the given network position along the vehicles route.
         """
         self._connection._beginMessage(
             tc.CMD_GET_VEHICLE_VARIABLE, tc.DISTANCE_REQUEST, vehID, 1 + 4 + 1 + 8 + 8 + 1)
@@ -512,6 +630,35 @@ class VehicleDomain(Domain):
         """
         return (self.getStopState(vehID) & 32) == 32
 
+    def getLaneChangeState(self, vehID, direction):
+        """getLaneChangeState(string, int) -> (int, int)
+        Return the lane change state for the vehicle
+        """
+        self._connection._beginMessage(
+            tc.CMD_GET_VEHICLE_VARIABLE, tc.CMD_CHANGELANE, vehID, 1 + 4)
+        self._connection._string += struct.pack("!Bi", tc.TYPE_INTEGER, direction)
+        result = self._connection._checkResult(tc.CMD_GET_VEHICLE_VARIABLE, tc.CMD_CHANGELANE, vehID)
+        return result.read("!iBiBi")[2::2]  # ignore num compounds and type int
+
+    def couldChangeLane(self, vehID, direction):
+        """couldChangeLane(string, int) -> bool
+        Return whether the vehicle could change lanes in the specified direction
+        """
+        state = self.getLaneChangeState(vehID, direction)[0]
+        return state != tc.LCA_UNKNOWN and (state & tc.LCA_BLOCKED == 0)
+
+    def wantsAndCouldChangeLane(self, vehID, direction):
+        """wantsAndCouldChangeLane(string, int) -> bool
+        Return whether the vehicle wants to and could change lanes in the specified direction
+        """
+        state = self.getLaneChangeState(vehID, direction)[0]
+        if state & tc.LCA_BLOCKED == 0:
+            if direction == -1:
+                return state & tc.LCA_RIGHT != 0
+            if direction == 1:
+                return state & tc.LCA_LEFT != 0
+        return False
+
     def setMaxSpeed(self, vehID, speed):
         """setMaxSpeed(string, double) -> None
 
@@ -520,7 +667,16 @@ class VehicleDomain(Domain):
         self._connection._sendDoubleCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_MAXSPEED, vehID, speed)
 
-    def setStop(self, vehID, edgeID, pos=1., laneIndex=0, duration=2**31 - 1, flags=STOP_DEFAULT, startPos=tc.INVALID_DOUBLE_VALUE, until=-1):
+    def setMaxSpeedLat(self, vehID, speed):
+        """setMaxSpeedLat(string, double) -> None
+
+        Sets the maximum lateral speed in m/s for this vehicle.
+        """
+        self._connection._sendDoubleCmd(
+            tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_MAXSPEED_LAT, vehID, speed)
+
+    def setStop(self, vehID, edgeID, pos=1., laneIndex=0, duration=2**31 - 1,
+                flags=tc.STOP_DEFAULT, startPos=tc.INVALID_DOUBLE_VALUE, until=-1):
         """setStop(string, string, double, integer, integer, integer, double, integer) -> None
 
         Adds or modifies a stop with the given parameters. The duration and the until attribute are
@@ -536,23 +692,41 @@ class VehicleDomain(Domain):
                                                 tc.TYPE_DOUBLE, startPos, tc.TYPE_INTEGER, until)
         self._connection._sendExact()
 
-    def setBusStop(self, vehID, stopID, duration=2**31 - 1, until=-1, flags=STOP_DEFAULT):
+    def setBusStop(self, vehID, stopID, duration=2**31 - 1, until=-1, flags=tc.STOP_DEFAULT):
         """setBusStop(string, string, integer, integer, integer) -> None
 
         Adds or modifies a bus stop with the given parameters. The duration and the until attribute are
         in milliseconds.
         """
         self.setStop(vehID, stopID, duration=duration,
-                     until=until, flags=flags | self.STOP_BUS_STOP)
+                     until=until, flags=flags | tc.STOP_BUS_STOP)
 
-    def setContainerStop(self, vehID, stopID, duration=2**31 - 1, until=-1, flags=STOP_DEFAULT):
+    def setContainerStop(self, vehID, stopID, duration=2**31 - 1, until=-1, flags=tc.STOP_DEFAULT):
         """setContainerStop(string, string, integer, integer, integer) -> None
 
         Adds or modifies a container stop with the given parameters. The duration and the until attribute are
         in milliseconds.
         """
         self.setStop(vehID, stopID, duration=duration, until=until,
-                     flags=flags | self.STOP_CONTAINER_STOP)
+                     flags=flags | tc.STOP_CONTAINER_STOP)
+
+    def setChargingStationStop(self, vehID, stopID, duration=2**31 - 1, until=-1, flags=tc.STOP_DEFAULT):
+        """setChargingStationStop(string, string, integer, integer, integer) -> None
+
+        Adds or modifies a stop at a chargingStation with the given parameters. The duration and the until attribute are
+        in milliseconds.
+        """
+        self.setStop(vehID, stopID, duration=duration, until=until,
+                     flags=flags | tc.STOP_CHARGING_STATION)
+
+    def setParkingAreaStop(self, vehID, stopID, duration=2**31 - 1, until=-1, flags=tc.STOP_PARKING):
+        """setParkingAreaStop(string, string, integer, integer, integer) -> None
+
+        Adds or modifies a stop at a parkingArea with the given parameters. The duration and the until attribute are
+        in milliseconds.
+        """
+        self.setStop(vehID, stopID, duration=duration, until=until,
+                     flags=flags | tc.STOP_PARKING_AREA)
 
     def resume(self, vehID):
         """resume(string) -> None
@@ -565,13 +739,32 @@ class VehicleDomain(Domain):
         self._connection._sendExact()
 
     def changeLane(self, vehID, laneIndex, duration):
+        """changeLane(string, int, int) -> None
+
+        Forces a lane change to the lane with the given index; if successful,
+        the lane will be chosen for the given amount of time (in ms).
+        """
         self._connection._beginMessage(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.CMD_CHANGELANE, vehID, 1 + 4 + 1 + 1 + 1 + 4)
         self._connection._string += struct.pack(
             "!BiBBBi", tc.TYPE_COMPOUND, 2, tc.TYPE_BYTE, laneIndex, tc.TYPE_INTEGER, duration)
         self._connection._sendExact()
 
+    def changeSublane(self, vehID, latDist):
+        """changeLane(string, double) -> None
+        Forces a lateral change by the given amount (negative values indicate changing to the right, positive to the left)
+        This will override any other lane change motivations but conform to
+        safety-constraints as configured by laneChangeMode.
+        """
+        self._connection._sendDoubleCmd(
+            tc.CMD_SET_VEHICLE_VARIABLE, tc.CMD_CHANGESUBLANE, vehID, latDist)
+
     def slowDown(self, vehID, speed, duration):
+        """slowDown(string, double, int) -> None
+
+        Changes the speed smoothly to the given value over the given amount
+        of time in ms (can also be used to increase speed).
+        """
         self._connection._beginMessage(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.CMD_SLOWDOWN, vehID, 1 + 4 + 1 + 8 + 1 + 4)
         self._connection._string += struct.pack(
@@ -579,6 +772,10 @@ class VehicleDomain(Domain):
         self._connection._sendExact()
 
     def changeTarget(self, vehID, edgeID):
+        """changeTarget(string, string) -> None
+
+        The vehicle's destination edge is set to the given edge id. The route is rebuilt.
+        """
         self._connection._sendStringCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.CMD_CHANGETARGET, vehID, edgeID)
 
@@ -620,7 +817,9 @@ class VehicleDomain(Domain):
     def setAdaptedTraveltime(self, vehID, begTime, endTime, edgeID, time):
         """setAdaptedTraveltime(string, double, string, double) -> None
 
-        .
+        Inserts the information about the travel time of edge "edgeID" valid
+        from begin time to end time into the vehicle's internal edge weights
+        container. .
         """
         self._connection._beginMessage(tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_EDGE_TRAVELTIME,
                                        vehID, 1 + 4 + 1 + 4 + 1 + 4 + 1 + 4 + len(edgeID) + 1 + 8)
@@ -633,7 +832,9 @@ class VehicleDomain(Domain):
     def setEffort(self, vehID, begTime, endTime, edgeID, effort):
         """setEffort(string, double, string, double) -> None
 
-        .
+        Inserts the information about the effort of edge "edgeID" valid from
+        begin time to end time into the vehicle's internal edge weights
+        container.
         """
         self._connection._beginMessage(tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_EDGE_EFFORT,
                                        vehID, 1 + 4 + 1 + 4 + 1 + 4 + 1 + 4 + len(edgeID) + 1 + 4)
@@ -643,17 +844,26 @@ class VehicleDomain(Domain):
         self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, effort)
         self._connection._sendExact()
 
+    LAST_TRAVEL_TIME_UPDATE = -1
+
     def rerouteTraveltime(self, vehID, currentTravelTimes=True):
         """rerouteTraveltime(string, bool) -> None Reroutes a vehicle. If
         currentTravelTimes is True (default) then the current traveltime of the
-        edges is loaded and used for rerouting. If currentTravelTimes is False,
-        travel times loaded from a weight file are used. In the absence of loaded
-        weights, the minimum travel time is used (speed limit). 
+        edges is loaded and used for rerouting. If currentTravelTimes is False
+        custom travel times are used. The various functions and options for
+        customizing travel times are described at http://sumo.dlr.de/wiki/Simulation/Routing
+
+        When rerouteTravelTime has been called once with option
+        currentTravelTimes=True, all edge weights are set to the current travel
+        times at the time of that call (even for subsequent simulation steps).
         """
         if currentTravelTimes:
-            for edge in self._connection.edge.getIDList():
-                self._connection.edge.adaptTraveltime(
-                    edge, self._connection.edge.getTraveltime(edge))
+            time = self._connection.simulation.getCurrentTime()
+            if time != self.LAST_TRAVEL_TIME_UPDATE:
+                self.LAST_TRAVEL_TIME_UPDATE = time
+                for edge in self._connection.edge.getIDList():
+                    self._connection.edge.adaptTraveltime(
+                        edge, self._connection.edge.getTraveltime(edge))
         self._connection._beginMessage(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.CMD_REROUTE_TRAVELTIME, vehID, 1 + 4)
         self._connection._string += struct.pack("!Bi", tc.TYPE_COMPOUND, 0)
@@ -692,7 +902,7 @@ class VehicleDomain(Domain):
     def setColor(self, vehID, color):
         """setColor(string, (integer, integer, integer, integer))
         sets color for vehicle with the given ID.
-        i.e. (255,0,0,0) for the color red. 
+        i.e. (255,0,0,0) for the color red.
         The fourth integer (alpha) is only used when drawing vehicles with raster images
         """
         self._connection._beginMessage(
@@ -725,14 +935,6 @@ class VehicleDomain(Domain):
         self._connection._sendDoubleCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_SPEED_FACTOR, vehID, factor)
 
-    def setSpeedDeviation(self, vehID, deviation):
-        """setSpeedDeviation(string, double) -> None
-
-        Sets the maximum speed deviation for this vehicle.
-        """
-        self._connection._sendDoubleCmd(
-            tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_SPEED_DEVIATION, vehID, deviation)
-
     def setEmissionClass(self, vehID, clazz):
         """setEmissionClass(string, string) -> None
 
@@ -749,6 +951,38 @@ class VehicleDomain(Domain):
         self._connection._sendDoubleCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_WIDTH, vehID, width)
 
+    def setHeight(self, vehID, height):
+        """setHeight(string, double) -> None
+
+        Sets the height in m for this vehicle.
+        """
+        self._connection._sendDoubleCmd(
+            tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_HEIGHT, vehID, height)
+
+    def setLine(self, vehID, line):
+        """setHeight(string, string) -> None
+
+        Sets the line information for this vehicle.
+        """
+        self._connection._sendStringCmd(
+            tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_LINE, vehID, line)
+
+    def setVia(self, vehID, edgeList):
+        """
+        setVia(string, list) ->  None
+
+        changes the via edges to the given edges list (to be used during
+        subsequent rerouting calls).
+
+        Note: a single edgeId as argument is allowed as shorthand for a list of length 1
+        """
+        if isinstance(edgeList, str):
+            edgeList = [edgeList]
+        self._connection._beginMessage(tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_VIA, vehID,
+                                       1 + 4 + sum(map(len, edgeList)) + 4 * len(edgeList))
+        self._connection._packStringList(edgeList)
+        self._connection._sendExact()
+
     def setMinGap(self, vehID, minGap):
         """setMinGap(string, double) -> None
 
@@ -757,6 +991,22 @@ class VehicleDomain(Domain):
         self._connection._sendDoubleCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_MINGAP, vehID, minGap)
 
+    def setMinGapLat(self, vehID, minGapLat):
+        """setMinGapLat(string, double) -> None
+
+        Sets the minimum lateral gap of the vehicle at 50km/h in m
+        """
+        self._connection._sendDoubleCmd(
+            tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_MINGAP_LAT, vehID, minGapLat)
+
+    def setLateralAlignment(self, vehID, align):
+        """setLateralAlignment(string, string) -> None
+
+        Sets the preferred lateral alignment for this vehicle.
+        """
+        self._connection._sendStringCmd(
+            tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_LATALIGNMENT, vehID, align)
+
     def setShapeClass(self, vehID, clazz):
         """setShapeClass(string, string) -> None
 
@@ -784,7 +1034,7 @@ class VehicleDomain(Domain):
     def setImperfection(self, vehID, imperfection):
         """setImperfection(string, double) -> None
 
-        .
+        Sets the driver imperfection sigma.
         """
         self._connection._sendDoubleCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_IMPERFECTION, vehID, imperfection)
@@ -806,14 +1056,18 @@ class VehicleDomain(Domain):
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_LANECHANGE_MODE, vehID, lcm)
 
     def setSpeedMode(self, vehID, sm):
-        """setLaneChangeMode(string, integer) -> None
+        """setSpeedMode(string, integer) -> None
 
         Sets the vehicle's speed mode as a bitset.
         """
         self._connection._sendIntCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_SPEEDSETMODE, vehID, sm)
 
-    def add(self, vehID, routeID, depart=DEPART_NOW, pos=0, speed=0, lane=0, typeID="DEFAULT_VEHTYPE"):
+    def add(self, vehID, routeID, depart=tc.DEPARTFLAG_NOW, pos=0, speed=0,
+            lane=tc.DEPARTFLAG_LANE_FIRST_ALLOWED, typeID="DEFAULT_VEHTYPE"):
+        """
+        Add a new vehicle (old style)
+        """
         self._connection._beginMessage(tc.CMD_SET_VEHICLE_VARIABLE, tc.ADD, vehID,
                                        1 + 4 + 1 + 4 + len(typeID) + 1 + 4 + len(routeID) + 1 + 4 + 1 + 8 + 1 + 8 + 1 + 1)
         if depart > 0:
@@ -824,13 +1078,16 @@ class VehicleDomain(Domain):
         self._connection._string += struct.pack("!Bi", tc.TYPE_INTEGER, depart)
         self._connection._string += struct.pack("!BdBd",
                                                 tc.TYPE_DOUBLE, pos, tc.TYPE_DOUBLE, speed)
-        self._connection._string += struct.pack("!BB", tc.TYPE_BYTE, lane)
+        self._connection._string += struct.pack("!Bb", tc.TYPE_BYTE, lane)
         self._connection._sendExact()
 
     def addFull(self, vehID, routeID, typeID="DEFAULT_VEHTYPE", depart=None,
-                departLane="0", departPos="base", departSpeed="0",
+                departLane="first", departPos="base", departSpeed="0",
                 arrivalLane="current", arrivalPos="max", arrivalSpeed="current",
                 fromTaz="", toTaz="", line="", personCapacity=0, personNumber=0):
+        """
+        Add a new vehicle (new style with all possible parameters)
+        """
         messageString = struct.pack("!Bi", tc.TYPE_COMPOUND, 14)
         if depart is None:
             depart = str(self._connection.simulation.getCurrentTime() / 1000.)
@@ -847,30 +1104,49 @@ class VehicleDomain(Domain):
         self._connection._sendExact()
 
     def remove(self, vehID, reason=tc.REMOVE_VAPORIZED):
-        '''Remove vehicle with the given ID for the give reason. 
+        '''Remove vehicle with the given ID for the give reason.
            Reasons are defined in module constants and start with REMOVE_'''
         self._connection._sendByteCmd(
             tc.CMD_SET_VEHICLE_VARIABLE, tc.REMOVE, vehID, reason)
 
-    def moveToVTD(self, vehID, edgeID, lane, x, y, angle):
-        self._connection._beginMessage(tc.CMD_SET_VEHICLE_VARIABLE, tc.VAR_MOVE_TO_VTD,
-                                       vehID, 1 + 4 + 1 + 4 + len(edgeID) + 1 + 4 + 1 + 8 + 1 + 8 + 1 + 8)
-        self._connection._string += struct.pack("!Bi", tc.TYPE_COMPOUND, 5)
+    def moveToXY(self, vehID, edgeID, lane, x, y, angle=tc.INVALID_DOUBLE_VALUE, keepRoute=1):
+        '''Place vehicle at the given x,y coordinates and force it's angle to
+        the given value (for drawing). 
+        If the angle is set to INVALID_DOUBLE_VALUE, the vehicle assumes the
+        natural angle of the edge on which it is driving.
+        If keepRoute is set to 1, the closest position
+        within the existing route is taken. If keepRoute is set to 0, the vehicle may move to
+        any edge in the network but it's route then only consists of that edge.
+        If keepRoute is set to 2 the vehicle has all the freedom of keepRoute=0
+        but in addition to that may even move outside the road network.
+        edgeID and lane are optional placement hints to resovle ambiguities'''
+        self._connection._beginMessage(tc.CMD_SET_VEHICLE_VARIABLE, tc.MOVE_TO_XY,
+                                       vehID, 1 + 4 + 1 + 4 + len(edgeID) + 1 + 4 + 1 + 8 + 1 + 8 + 1 + 8 + 1 + 1)
+        self._connection._string += struct.pack("!Bi", tc.TYPE_COMPOUND, 6)
         self._connection._packString(edgeID)
         self._connection._string += struct.pack("!Bi", tc.TYPE_INTEGER, lane)
         self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, x)
         self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, y)
         self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, angle)
+        self._connection._string += struct.pack("!BB", tc.TYPE_BYTE, keepRoute)
         self._connection._sendExact()
 
+    moveToVTD = moveToXY  # deprecated method name for backwards compatibility
+
     def subscribe(self, objectID, varIDs=(tc.VAR_ROAD_ID, tc.VAR_LANEPOSITION), begin=0, end=2**31 - 1):
-        """subscribe(string, list(integer), double, double) -> None
+        """subscribe(string, list(integer), int, int) -> None
 
         Subscribe to one or more object values for the given interval.
         """
         Domain.subscribe(self, objectID, varIDs, begin, end)
 
-    def subscribeContext(self, objectID, domain, dist, varIDs=(tc.VAR_ROAD_ID, tc.VAR_LANEPOSITION), begin=0, end=2**31 - 1):
+    def subscribeContext(self, objectID, domain, dist, varIDs=(
+            tc.VAR_ROAD_ID, tc.VAR_LANEPOSITION), begin=0, end=2**31 - 1):
+        """subscribe(string, int, double, list(integer), int, int) -> None
+
+        Subscribe to one or more object values of the given domain around the
+        given objectID in a given radius
+        """
         Domain.subscribeContext(
             self, objectID, domain, dist, varIDs, begin, end)
 
