@@ -4,12 +4,12 @@
 @author  Karol Stosiek
 @author  Michael Behrisch
 @date    2011-10-26
-@version $Id: turndefinitions.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: turndefinitions.py 23885 2017-04-08 08:13:37Z behrisch $
 
 Operations and classes necessary to work on SUMO turn definitions.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -17,17 +17,20 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
+from __future__ import absolute_import
 
-import connections
 import logging
-import xml.dom.minidom
-import collectinghandler
 import unittest
 
+import sumolib
+import connections
+import collectinghandler
+
 LOGGER = logging.getLogger(__name__)
 
 
 class TurnDefinitions():
+
     """ Represents a connection of turn definitions. """
 
     logger = logging.getLogger(__name__)
@@ -42,7 +45,7 @@ class TurnDefinitions():
             a warning. """
 
         self.logger.debug("Adding turn definition for %s -> %s "
-            "with probability %f" % (source, destination, probability))
+                          "with probability %f" % (source, destination, probability))
 
         if source not in self.turn_definitions:
             self.turn_definitions[source] = {}
@@ -54,15 +57,14 @@ class TurnDefinitions():
 
         if self.turn_definitions[source][destination] > 100:
             self.logger.warn("Turn probability overflow: %f; lowered to 100" %
-                (self.turn_definitions[source][destination]))
+                             (self.turn_definitions[source][destination]))
             self.turn_definitions[source][destination] = 100
 
     def get_sources(self):
         """ Returns all of the turn definitions incoming edges. The result
             will be sorted in alphabetical. """
 
-        sources = self.turn_definitions.keys()
-        sources.sort()
+        sources = sorted(self.turn_definitions.keys())
         return sources
 
     def get_destinations(self, source):
@@ -71,8 +73,7 @@ class TurnDefinitions():
             have been added before. The result will be sorted in alphabetical
             order."""
 
-        destinations = self.turn_definitions[source].keys()
-        destinations.sort()
+        destinations = sorted(self.turn_definitions[source].keys())
         return destinations
 
     def get_turning_probability(self,
@@ -94,6 +95,7 @@ class TurnDefinitions():
 
         return self.turn_definitions == other.turn_definitions
 
+
 def from_connections(input_connections):
     """ Creates a TurnDefinitions object from given Connections' object. """
 
@@ -105,10 +107,10 @@ def from_connections(input_connections):
             for destination in input_connections.get_destinations(source,
                                                                   source_lane):
                 weight = input_connections.calculate_destination_weight(source,
-                    source_lane, destination)
+                                                                        source_lane, destination)
 
                 LOGGER.debug("Adding connection %s -> %s (%f)" %
-                    (source, destination, weight))
+                             (source, destination, weight))
 
                 turn_definitions.add(source,
                                      destination,
@@ -123,14 +125,13 @@ def to_xml(turn_definitions):
 
     LOGGER.info("Converting turn definitions to XML")
     LOGGER.debug("Turn definitions sources number: %i" %
-        (len(turn_definitions.get_sources())))
+                 (len(turn_definitions.get_sources())))
 
-    turn_definitions_xml = xml.dom.minidom.Element("turn-defs")
+    turn_definitions_xml = sumolib.xml.create_document("turns")
     for source in turn_definitions.get_sources():
         LOGGER.debug("Converting turn definition with source %s" % (source))
 
-        from_edge_element = xml.dom.minidom.Element("fromEdge")
-        from_edge_element.setAttribute("id", source)
+        from_edge_element = turn_definitions_xml.addChild("fromEdge", {"id": source})
 
         for destination in turn_definitions.get_destinations(source):
             probability = turn_definitions.get_turning_probability(source,
@@ -139,20 +140,15 @@ def to_xml(turn_definitions):
             LOGGER.debug("Converting turn definition destination %s "
                          "with probability %f" % (destination, probability))
 
-            to_edge_element = xml.dom.minidom.Element("toEdge")
+            to_edge_element = from_edge_element.addChild("toEdge")
             to_edge_element.setAttribute("id", destination)
-            to_edge_element.setAttribute("probability", str(probability))
-            from_edge_element.appendChild(to_edge_element)
-
-        turn_definitions_xml.appendChild(from_edge_element)
-
-    return turn_definitions_xml.toprettyxml()
-
+            to_edge_element.setAttribute("probability", "%.10g" % probability)
 
+    return turn_definitions_xml.toXML()
 
 
 class TurnDefinitionsTestCase(unittest.TestCase):
-    # pylint: disable=C,R,W,E,F  
+    # pylint: disable=C,R,W,E,F
 
     def setUp(self):
         self.turn_definitions = TurnDefinitions()
@@ -171,35 +167,35 @@ class TurnDefinitionsTestCase(unittest.TestCase):
         self.turn_definitions.add("source 1", "destination", 100)
         self.turn_definitions.add("source 2", "destination", 100)
         self.assertEqual(["source 1", "source 2"],
-            self.turn_definitions.get_sources())
+                         self.turn_definitions.get_sources())
 
     def test_get_destinations(self):
         self.turn_definitions.add("source", "destination", 100)
         self.assertEqual(["destination"],
-            self.turn_definitions.get_destinations("source"))
+                         self.turn_definitions.get_destinations("source"))
 
     def test_get_destinations_is_sorted(self):
         self.turn_definitions.add("source", "destination 1", 100)
         self.turn_definitions.add("source", "destination 2", 100)
         self.assertEqual(["destination 1", "destination 2"],
-            self.turn_definitions.get_destinations("source"))
+                         self.turn_definitions.get_destinations("source"))
 
     def test_get_turning_probability(self):
         self.turn_definitions.add("source", "destination", 100)
         self.assertEqual(100,
-            self.turn_definitions.get_turning_probability("source",
-                                                          "destination"))
+                         self.turn_definitions.get_turning_probability("source",
+                                                                       "destination"))
 
     def test_probability_overflow_raises_warning_on_initial_add(self):
         collecting_handler = collectinghandler.CollectingHandler()
         self.turn_definitions.logger.addHandler(collecting_handler)
-      
+
         self.turn_definitions.add("source", "destination", 101)
 
         self.assertTrue(
-           "Turn probability overflow: 101.000000; lowered to 100" 
-               in [ record.getMessage()
-                    for record in collecting_handler.log_records ])
+            "Turn probability overflow: 101.000000; lowered to 100"
+            in [record.getMessage()
+                for record in collecting_handler.log_records])
 
     def test_probability_overflow_raises_warning_after_addition(self):
         collecting_handler = collectinghandler.CollectingHandler()
@@ -209,17 +205,17 @@ class TurnDefinitionsTestCase(unittest.TestCase):
         self.turn_definitions.add("source", "destination", 11)
 
         self.assertTrue(
-            "Turn probability overflow: 101.000000; lowered to 100" 
-                in [ record.getMessage()
-                     for record in collecting_handler.log_records ])
+            "Turn probability overflow: 101.000000; lowered to 100"
+            in [record.getMessage()
+                for record in collecting_handler.log_records])
+
 
-          
 class CreateTurnDefinitionsTestCase(unittest.TestCase):
-    # pylint: disable=C,R,W,E,F  
+    # pylint: disable=C,R,W,E,F
 
     def test_creation_with_0_sources(self):
         self.assertEqual(TurnDefinitions(),
-            from_connections(connections.Connections()))
+                         from_connections(connections.Connections()))
 
     def test_creation_with_one_source(self):
         input_connections = connections.Connections()
@@ -229,7 +225,7 @@ class CreateTurnDefinitionsTestCase(unittest.TestCase):
         turn_definitions.add("source 1", "destination 1", 100.0)
 
         self.assertEqual(turn_definitions,
-            from_connections(input_connections))
+                         from_connections(input_connections))
 
     def test_creation_with_two_sources(self):
         input_connections = connections.Connections()
@@ -241,8 +237,7 @@ class CreateTurnDefinitionsTestCase(unittest.TestCase):
         turn_definitions.add("source 2", "destination 1", 100.0)
 
         self.assertEqual(turn_definitions,
-            from_connections(input_connections))
-
+                         from_connections(input_connections))
 
     def test_creation_two_destinations_from_two_lanes_overlapping(self):
         input_connections = connections.Connections()
@@ -251,11 +246,12 @@ class CreateTurnDefinitionsTestCase(unittest.TestCase):
         input_connections.add("source 1", "source lane 2", "destination 1")
 
         turn_definitions = TurnDefinitions()
-        turn_definitions.add("source 1", "destination 1", 100.0/2/2+100.0/2)
-        turn_definitions.add("source 1", "destination 2", 100.0/2/2)
+        turn_definitions.add(
+            "source 1", "destination 1", 100.0 / 2 / 2 + 100.0 / 2)
+        turn_definitions.add("source 1", "destination 2", 100.0 / 2 / 2)
 
         self.assertEqual(turn_definitions,
-            from_connections(input_connections))
+                         from_connections(input_connections))
 
     def test_creation_one_destination_from_two_lanes(self):
         input_connections = connections.Connections()
@@ -266,7 +262,7 @@ class CreateTurnDefinitionsTestCase(unittest.TestCase):
         turn_definitions.add("source 1", "destination 1", 100.0)
 
         self.assertEqual(turn_definitions,
-            from_connections(input_connections))
+                         from_connections(input_connections))
 
     def test_creation_with_one_destination_from_one_lane(self):
         input_connections = connections.Connections()
@@ -276,7 +272,7 @@ class CreateTurnDefinitionsTestCase(unittest.TestCase):
         turn_definitions.add("source 1", "destination 1", 100.0)
 
         self.assertEqual(turn_definitions,
-           from_connections(input_connections))
+                         from_connections(input_connections))
 
     def test_creation_with_two_destinations_from_one_lane(self):
         input_connections = connections.Connections()
@@ -284,26 +280,25 @@ class CreateTurnDefinitionsTestCase(unittest.TestCase):
         input_connections.add("source 1", "source lane 1", "destination 2")
 
         turn_definitions = TurnDefinitions()
-        turn_definitions.add("source 1", "destination 1", 100.0/2)
-        turn_definitions.add("source 1", "destination 2", 100.0/2)
+        turn_definitions.add("source 1", "destination 1", 100.0 / 2)
+        turn_definitions.add("source 1", "destination 2", 100.0 / 2)
 
         self.assertEqual(turn_definitions,
-            from_connections(input_connections))
+                         from_connections(input_connections))
 
     def test_creation_with_three_destinations_from_one_lane(self):
         input_connections = connections.Connections()
         input_connections.add("source 1", "source lane 1", "destination 1")
         input_connections.add("source 1", "source lane 1", "destination 2")
         input_connections.add("source 1", "source lane 1", "destination 3")
-    
+
         turn_definitions = TurnDefinitions()
-        turn_definitions.add("source 1", "destination 1", 100.0/3)
-        turn_definitions.add("source 1", "destination 2", 100.0/3)
-        turn_definitions.add("source 1", "destination 3", 100.0/3)
+        turn_definitions.add("source 1", "destination 1", 100.0 / 3)
+        turn_definitions.add("source 1", "destination 2", 100.0 / 3)
+        turn_definitions.add("source 1", "destination 3", 100.0 / 3)
 
         self.assertEqual(turn_definitions,
-            from_connections(input_connections))
+                         from_connections(input_connections))
 
 if __name__ == "__main__":
     unittest.main()
-
