@@ -3,12 +3,12 @@
 @file    rebuildSchemata.py
 @author  Michael Behrisch
 @date    2011-07-11
-@version $Id: rebuildSchemata.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: rebuildSchemata.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Let all SUMO binaries write the schema for their config
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -16,11 +16,17 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 """
-import os, sys, subprocess
-homeDir = os.environ.get("SUMO_HOME", os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
+from __future__ import absolute_import
+from __future__ import print_function
+import os
+import sys
+import subprocess
+homeDir = os.environ.get("SUMO_HOME", os.path.dirname(
+    os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
 for exe in "activitygen dfrouter duarouter marouter jtrrouter netconvert netgenerate od2trips polyconvert sumo".split():
     exePath = os.path.join(homeDir, "bin", exe)
     if os.path.exists(exePath) or os.path.exists(exePath + ".exe"):
-        subprocess.call([exePath, "--save-schema", os.path.join(homeDir, "data", "xsd" , exe+"Configuration.xsd")])
+        subprocess.call(
+            [exePath, "--save-schema", os.path.join(homeDir, "data", "xsd", exe + "Configuration.xsd")])
     else:
-        print "Warning! %s not found." % exe
+        print("Warning! %s not found." % exe)
