@@ -6,12 +6,12 @@
 @author  Michael Behrisch
 @author  Laura Bieker
 @date    2013-12-08
-@version $Id: xml2csv.py 17235 2014-11-03 10:53:02Z behrisch $
+@version $Id: xml2csv.py 22608 2017-01-17 06:28:54Z behrisch $
 
 Convert hierarchical xml files to csv. This only makes sense if the hierarchy has low depth.
 
 SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2013-2014 DLR (http://www.dlr.de/) and contributors
+Copyright (C) 2013-2017 DLR (http://www.dlr.de/) and contributors
 
 This file is part of SUMO.
 SUMO is free software; you can redistribute it and/or modify
@@ -21,7 +21,11 @@ the Free Software Foundation; either version 3 of the License, or
 """
 
 from __future__ import print_function
-import os, sys, socket, collections
+from __future__ import absolute_import
+import os
+import sys
+import socket
+import collections
 from optparse import OptionParser
 import xml.sax
 try:
@@ -33,8 +37,13 @@ except ImportError:
 
 import xsd
 
+PY3 = sys.version_info > (3,)
+
+
 class NestingHandler(xml.sax.handler.ContentHandler):
+
     """A handler which knows the current nesting of tags"""
+
     def __init__(self):
         self.tagstack = []
 
@@ -48,14 +57,17 @@ class NestingHandler(xml.sax.handler.ContentHandler):
         # do not count the root element
         return len(self.tagstack) - 1
 
+
 class AttrFinder(NestingHandler):
+
     def __init__(self, xsdFile, source, split):
         NestingHandler.__init__(self)
-        self.tagDepths = {} # tag -> depth of appearance
-        self.tagAttrs = collections.defaultdict(collections.OrderedDict) # tag -> set of attrs
-        self.renamedAttrs = {} # (name, attr) -> renamedAttr
+        self.tagDepths = {}  # tag -> depth of appearance
+        self.tagAttrs = collections.defaultdict(
+            collections.OrderedDict)  # tag -> set of attrs
+        self.renamedAttrs = {}  # (name, attr) -> renamedAttr
         self.attrs = {}
-        self.depthTags = {} # child of root: depth of appearance -> tag list
+        self.depthTags = {}  # child of root: depth of appearance -> tag list
         self.rootDepth = 1 if split else 0
         if xsdFile:
             self.xsdStruc = xsd.XsdStructure(xsdFile)
@@ -67,7 +79,8 @@ class AttrFinder(NestingHandler):
             else:
                 self.attrs[self.xsdStruc.root.name] = []
                 self.depthTags[self.xsdStruc.root.name] = []
-                self.recursiveAttrFind(self.xsdStruc.root, self.xsdStruc.root, 0)
+                self.recursiveAttrFind(
+                    self.xsdStruc.root, self.xsdStruc.root, 0)
         else:
             self.xsdStruc = None
             xml.sax.parse(source, self)
@@ -80,14 +93,15 @@ class AttrFinder(NestingHandler):
             self.depthTags[root][depth].append(name)
             return True
         if name not in self.depthTags[root][depth]:
-            print("Ignoring tag %s at depth %s" % (name, depth), file=sys.stderr)
+            print("Ignoring tag %s at depth %s" %
+                  (name, depth), file=sys.stderr)
         return False
 
     def recursiveAttrFind(self, root, currEle, depth):
         if not self.addElement(root.name, currEle.name, depth):
             return
         for a in currEle.attributes:
-            if ":" not in a.name: # no namespace support yet
+            if ":" not in a.name:  # no namespace support yet
                 self.tagAttrs[currEle.name][a.name] = a
                 anew = "%s_%s" % (currEle.name, a.name)
                 self.renamedAttrs[(currEle.name, a.name)] = anew
@@ -108,7 +122,7 @@ class AttrFinder(NestingHandler):
             if not self.addElement(root, name, self.depth()):
                 return
             # collect attributes
-            for a in attrs.keys():
+            for a in sorted(list(attrs.keys())):
                 if a not in self.tagAttrs[name] and ":" not in a:
                     self.tagAttrs[name][a] = xsd.XmlAttribute(a)
                     if not (name, a) in self.renamedAttrs:
@@ -118,6 +132,7 @@ class AttrFinder(NestingHandler):
 
 
 class CSVWriter(NestingHandler):
+
     def __init__(self, attrFinder, options):
         NestingHandler.__init__(self)
         self.attrFinder = attrFinder
@@ -126,7 +141,7 @@ class CSVWriter(NestingHandler):
         self.haveUnsavedValues = False
         self.outfiles = {}
         self.rootDepth = 1 if options.split else 0
-        for root in attrFinder.depthTags.iterkeys():
+        for root in sorted(attrFinder.depthTags):
             if len(attrFinder.depthTags) == 1:
                 if not options.output:
                     options.output = os.path.splitext(options.source)[0]
@@ -137,9 +152,15 @@ class CSVWriter(NestingHandler):
                 if options.output:
                     outfilename = options.output + "%s.csv" % root
                 else:
-                    outfilename = os.path.splitext(options.source)[0] + "%s.csv" % root
+                    outfilename = os.path.splitext(
+                        options.source)[0] + "%s.csv" % root
                 self.outfiles[root] = open(outfilename, 'w')
-            self.outfiles[root].write(options.separator.join(map(self.quote,attrFinder.attrs[root])) + "\n")
+            if (PY3):
+                self.outfiles[root].write(str.encode(
+                    options.separator.join(map(self.quote, attrFinder.attrs[root])) + "\n"))
+            else:
+                self.outfiles[root].write(
+                    options.separator.join(map(self.quote, attrFinder.attrs[root])) + "\n")
 
     def quote(self, s):
         return "%s%s%s" % (self.options.quotechar, s, self.options.quotechar)
@@ -163,7 +184,8 @@ class CSVWriter(NestingHandler):
 #                    print(a, dict(self.attrFinder.tagAttrs[name]))
                     if a in self.attrFinder.tagAttrs[name]:
                         if self.attrFinder.xsdStruc:
-                            enum = self.attrFinder.xsdStruc.getEnumeration(self.attrFinder.tagAttrs[name][a].type)
+                            enum = self.attrFinder.xsdStruc.getEnumeration(
+                                self.attrFinder.tagAttrs[name][a].type)
                             if enum:
                                 v = enum.index(v)
                         a2 = self.attrFinder.renamedAttrs.get((name, a), a)
@@ -176,14 +198,19 @@ class CSVWriter(NestingHandler):
 #            print("end", name, root, self.depth(), self.attrFinder.depthTags[root][self.depth()], self.haveUnsavedValues)
             if name in self.attrFinder.depthTags[root][self.depth()]:
                 if self.haveUnsavedValues:
-                    self.outfiles[root].write(self.options.separator.join(
-                        [self.quote(self.currentValues[a]) for a in self.attrFinder.attrs[root]]) + "\n")
+                    if(PY3):
+                        self.outfiles[root].write(str.encode(self.options.separator.join(
+                            [self.quote(self.currentValues[a]) for a in self.attrFinder.attrs[root]]) + "\n"))
+                    else:
+                        self.outfiles[root].write(self.options.separator.join(
+                            [self.quote(self.currentValues[a]) for a in self.attrFinder.attrs[root]]) + "\n")
                     self.haveUnsavedValues = False
                 for a in self.attrFinder.tagAttrs[name]:
                     a2 = self.attrFinder.renamedAttrs.get((name, a), a)
                     del self.currentValues[a2]
         NestingHandler.endElement(self, name)
 
+
 def getSocketStream(port, mode='rb'):
     s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     s.bind(("localhost", port))
@@ -191,13 +218,16 @@ def getSocketStream(port, mode='rb'):
     conn, addr = s.accept()
     return conn.makefile(mode)
 
+
 def getOutStream(output):
     if output.isdigit():
         return getSocketStream(int(output), 'wb')
     return open(output, 'wb')
-    
+
+
 def get_options():
-    optParser = OptionParser(usage=os.path.basename(sys.argv[0]) + " [<options>] <input_file_or_port>")
+    optParser = OptionParser(
+        usage=os.path.basename(sys.argv[0]) + " [<options>] <input_file_or_port>")
     optParser.add_option("-s", "--separator", default=";",
                          help="separating character for fields")
     optParser.add_option("-q", "--quotechar", default='',
@@ -223,9 +253,11 @@ def get_options():
     else:
         options.source = args[0]
     if options.output and options.output.isdigit() and options.split:
-        print("it is not possible to use splitting together with stream output", file=sys.stderr)
+        print(
+            "it is not possible to use splitting together with stream output", file=sys.stderr)
         sys.exit()
-    return options 
+    return options
+
 
 def main():
     options = get_options()
