@@ -3,12 +3,12 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    2013-06-05
-/// @version $Id: MSCFModelTest.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id: MSCFModelTest.cpp 23699 2017-03-29 07:16:27Z namdre $
 ///
 // Tests the cfmodel functions 
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -30,6 +30,7 @@
 
 #include <gtest/gtest.h>
 #include <utils/vehicle/SUMOVTypeParameter.h>
+#include <microsim/MSGlobals.h>
 #include <microsim/MSVehicleType.h>
 #include <microsim/cfmodels/MSCFModel.h>
 #include <microsim/cfmodels/MSCFModel_Krauss.h>
@@ -39,10 +40,10 @@ class MSCFModelTest : public testing::Test {
     protected :
         MSVehicleType* type;
         MSCFModel* m;
-        SUMOReal accel;
-        SUMOReal decel;
-        SUMOReal dawdle;
-        SUMOReal tau; // headway time
+        double accel;
+        double decel;
+        double dawdle;
+        double tau; // headway time
 
         virtual void SetUp(){
             accel = 2;
@@ -51,7 +52,8 @@ class MSCFModelTest : public testing::Test {
             tau = 1;
             type = new MSVehicleType(SUMOVTypeParameter("0"));
             m = new MSCFModel_Krauss(type,
-                    accel, decel, dawdle, tau);
+                    accel, decel, decel, decel, dawdle, tau);
+            MSGlobals::gSemiImplicitEulerUpdate = true;
         }
 
         virtual void TearDown(){
@@ -64,14 +66,14 @@ class MSCFModelTest : public testing::Test {
 
 TEST_F(MSCFModelTest, test_method_brakeGap) {
     // discrete braking model. keep driving for 1 s
-    const SUMOReal v = 3;
+    const double v = 3;
     EXPECT_DOUBLE_EQ(tau * v, m->brakeGap(v));
 }
 
 TEST_F(MSCFModelTest, test_method_static_brakeGap) {
-    const SUMOReal v = 3;
-    const SUMOReal b = 4;
-    const SUMOReal tau = 1;
+    const double v = 3;
+    const double b = 4;
+    const double tau = 1;
     EXPECT_DOUBLE_EQ(3, MSCFModel::brakeGap(v, b, tau));
     EXPECT_DOUBLE_EQ(0, MSCFModel::brakeGap(v, b, 0));
     EXPECT_DOUBLE_EQ(3, MSCFModel::brakeGap(7, b, 0));
@@ -81,24 +83,25 @@ TEST_F(MSCFModelTest, test_method_static_brakeGap) {
 }
 
 TEST_F(MSCFModelTest, test_method_static_freeSpeed) {
-    const SUMOReal b = 4;
-    const SUMOReal v = 0;
-    const SUMOReal g = 4;
-    EXPECT_DOUBLE_EQ(4, MSCFModel::freeSpeed(b, g, v, false));
-    EXPECT_DOUBLE_EQ(8, MSCFModel::freeSpeed(b, g, v, true));
-    EXPECT_DOUBLE_EQ(17.5, MSCFModel::freeSpeed(5, 30, 10, false));
-    EXPECT_DOUBLE_EQ(18.4, MSCFModel::freeSpeed(4.5, 20, 13.9, false));
-    EXPECT_DOUBLE_EQ(18.4, MSCFModel::freeSpeed(4.5, 30, 13.9, false));
-    EXPECT_DOUBLE_EQ(22.9, MSCFModel::freeSpeed(4.5, 30, 13.9, true));
-    EXPECT_DOUBLE_EQ(22.25, MSCFModel::freeSpeed(4.5, 40, 13.9, false));
+    const double vCur = 10;
+    const double b = 4;
+    const double v = 0;
+    const double g = 4;
+    EXPECT_DOUBLE_EQ(4, MSCFModel::freeSpeed(vCur, b, g, v, false));
+    EXPECT_DOUBLE_EQ(8, MSCFModel::freeSpeed(vCur, b, g, v, true));
+    EXPECT_DOUBLE_EQ(17.5, MSCFModel::freeSpeed(vCur, 5, 30, 10, false));
+    EXPECT_DOUBLE_EQ(18.4, MSCFModel::freeSpeed(vCur, 4.5, 20, 13.9, false));
+    EXPECT_DOUBLE_EQ(18.4, MSCFModel::freeSpeed(vCur, 4.5, 30, 13.9, false));
+    EXPECT_DOUBLE_EQ(22.9, MSCFModel::freeSpeed(vCur, 4.5, 30, 13.9, true));
+    EXPECT_DOUBLE_EQ(22.25, MSCFModel::freeSpeed(vCur, 4.5, 40, 13.9, false));
 }
 
 #ifdef HAVE_SUBSECOND_TIMESTEPS
 TEST_F(MSCFModelTest, test_method_static_freeSpeed_half) {
     DELTA_T = 500;
-    const SUMOReal b = 4;
-    const SUMOReal v = 0;
-    const SUMOReal g = 4;
+    const double b = 4;
+    const double v = 0;
+    const double g = 4;
     EXPECT_DOUBLE_EQ(14./3., MSCFModel::freeSpeed(b, g, v, false));
     EXPECT_DOUBLE_EQ(6., MSCFModel::freeSpeed(b, 6, v, false));
     EXPECT_DOUBLE_EQ(18.75, MSCFModel::freeSpeed(5, 30, 10, false));
